@@ -107,6 +107,11 @@ public abstract class SourceReaderBase<E, T, SplitT extends SourceSplit, SplitSt
 
     @Nullable protected final RecordEvaluator<T> eofRecordEvaluator;
 
+    /**
+     * @deprecated Please use {@link #SourceReaderBase(SplitFetcherManager, RecordEmitter,
+     *     Configuration, SourceReaderContext)} instead.
+     */
+    @Deprecated
     public SourceReaderBase(
             FutureCompletingBlockingQueue<RecordsWithSplitIds<E>> elementsQueue,
             SplitFetcherManager<E, SplitT> splitFetcherManager,
@@ -116,6 +121,11 @@ public abstract class SourceReaderBase<E, T, SplitT extends SourceSplit, SplitSt
         this(elementsQueue, splitFetcherManager, recordEmitter, null, config, context);
     }
 
+    /**
+     * @deprecated Please use {@link #SourceReaderBase(SplitFetcherManager, RecordEmitter,
+     *     RecordEvaluator, Configuration, SourceReaderContext)} instead.
+     */
+    @Deprecated
     public SourceReaderBase(
             FutureCompletingBlockingQueue<RecordsWithSplitIds<E>> elementsQueue,
             SplitFetcherManager<E, SplitT> splitFetcherManager,
@@ -136,6 +146,39 @@ public abstract class SourceReaderBase<E, T, SplitT extends SourceSplit, SplitSt
         numRecordsInCounter = context.metricGroup().getIOMetricGroup().getNumRecordsInCounter();
     }
 
+    /**
+     * The primary constructor for the source reader.
+     *
+     * <p>The reader will use a handover queue sized as configured via {@link
+     * SourceReaderOptions#ELEMENT_QUEUE_CAPACITY}.
+     */
+    public SourceReaderBase(
+            SplitFetcherManager<E, SplitT> splitFetcherManager,
+            RecordEmitter<E, T, SplitStateT> recordEmitter,
+            Configuration config,
+            SourceReaderContext context) {
+        this(splitFetcherManager, recordEmitter, null, config, context);
+    }
+
+    public SourceReaderBase(
+            SplitFetcherManager<E, SplitT> splitFetcherManager,
+            RecordEmitter<E, T, SplitStateT> recordEmitter,
+            @Nullable RecordEvaluator<T> eofRecordEvaluator,
+            Configuration config,
+            SourceReaderContext context) {
+        this.elementsQueue = splitFetcherManager.getQueue();
+        this.splitFetcherManager = splitFetcherManager;
+        this.recordEmitter = recordEmitter;
+        this.splitStates = new HashMap<>();
+        this.options = new SourceReaderOptions(config);
+        this.config = config;
+        this.context = context;
+        this.noMoreSplitsAssignment = false;
+        this.eofRecordEvaluator = eofRecordEvaluator;
+
+        numRecordsInCounter = context.metricGroup().getIOMetricGroup().getNumRecordsInCounter();
+    }
+
     @Override
     public void start() {}
 
@@ -308,6 +351,7 @@ public abstract class SourceReaderBase<E, T, SplitT extends SourceSplit, SplitSt
     }
 
     // -------------------- Abstract method to allow different implementations ------------------
+
     /** Handles the finished splits to clean the state if needed. */
     protected abstract void onSplitFinished(Map<String, SplitStateT> finishedSplitIds);
 
