@@ -21,6 +21,7 @@ package org.apache.flink.connectors.hive;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
 import org.apache.flink.connector.file.table.PartitionFetcher;
 import org.apache.flink.connector.file.table.PartitionReader;
+import org.apache.flink.table.api.DataTypes;
 import org.apache.flink.table.api.EnvironmentSettings;
 import org.apache.flink.table.api.SqlDialect;
 import org.apache.flink.table.api.TableEnvironment;
@@ -37,6 +38,7 @@ import org.apache.flink.table.factories.FactoryUtil;
 import org.apache.flink.table.planner.factories.TestValuesTableFactory;
 import org.apache.flink.table.planner.factories.utils.TestCollectionTableFactory;
 import org.apache.flink.table.runtime.typeutils.InternalSerializers;
+import org.apache.flink.table.types.DataType;
 import org.apache.flink.types.Row;
 import org.apache.flink.util.CollectionUtil;
 
@@ -180,7 +182,7 @@ public class HiveLookupJoinITCase {
         batchEnv.registerCatalog(hiveCatalog.getName(), hiveCatalog);
         batchEnv.useCatalog(hiveCatalog.getName());
         batchEnv.executeSql(
-                        "insert overwrite partition_table values "
+                        "insert overwrite table partition_table values "
                                 + "(1,'a',08,2019,'08','01'),"
                                 + "(1,'a',10,2020,'08','31'),"
                                 + "(2,'a',21,2020,'08','31'),"
@@ -205,10 +207,16 @@ public class HiveLookupJoinITCase {
                 ObjectIdentifier.of(hiveCatalog.getName(), "default", "partition_table");
         CatalogTable catalogTable =
                 (CatalogTable) hiveCatalog.getTable(tableIdentifier.toObjectPath());
-        GenericRowData reuse = new GenericRowData(catalogTable.getSchema().getFieldCount());
+        GenericRowData reuse =
+                new GenericRowData(catalogTable.getUnresolvedSchema().getColumns().size());
+
         TypeSerializer<RowData> serializer =
                 InternalSerializers.create(
-                        catalogTable.getSchema().toRowDataType().getLogicalType());
+                        DataTypes.ROW(
+                                        catalogTable.getUnresolvedSchema().getColumns().stream()
+                                                .map(HiveTestUtils::getType)
+                                                .toArray(DataType[]::new))
+                                .getLogicalType());
 
         RowData row;
         while ((row = reader.read(reuse)) != null) {
@@ -241,7 +249,7 @@ public class HiveLookupJoinITCase {
         batchEnv.registerCatalog(hiveCatalog.getName(), hiveCatalog);
         batchEnv.useCatalog(hiveCatalog.getName());
         batchEnv.executeSql(
-                        "insert overwrite bounded_partition_table values "
+                        "insert overwrite table bounded_partition_table values "
                                 + "(1,'a',08,2019,'08','01'),"
                                 + "(1,'a',10,2020,'08','31'),"
                                 + "(2,'a',21,2020,'08','31'),"
@@ -267,7 +275,7 @@ public class HiveLookupJoinITCase {
         batchEnv.registerCatalog(hiveCatalog.getName(), hiveCatalog);
         batchEnv.useCatalog(hiveCatalog.getName());
         batchEnv.executeSql(
-                        "insert overwrite partition_table_1 values "
+                        "insert overwrite table partition_table_1 values "
                                 + "(1,'a',08,2019,'09','01'),"
                                 + "(1,'a',10,2020,'09','31'),"
                                 + "(2,'a',21,2020,'09','31'),"
@@ -297,7 +305,7 @@ public class HiveLookupJoinITCase {
         batchEnv.registerCatalog(hiveCatalog.getName(), hiveCatalog);
         batchEnv.useCatalog(hiveCatalog.getName());
         batchEnv.executeSql(
-                        "insert overwrite partition_table_2 values "
+                        "insert overwrite table partition_table_2 values "
                                 + "(1,'a',08,2020,'08','01'),"
                                 + "(1,'a',10,2020,'08','31'),"
                                 + "(2,'a',21,2019,'08','31'),"
@@ -326,7 +334,7 @@ public class HiveLookupJoinITCase {
         batchEnv.registerCatalog(hiveCatalog.getName(), hiveCatalog);
         batchEnv.useCatalog(hiveCatalog.getName());
         batchEnv.executeSql(
-                        "insert overwrite partition_table_3 values "
+                        "insert overwrite table partition_table_3 values "
                                 + "(1,'a',08,2020,'month1','01'),"
                                 + "(1,'a',10,2020,'month2','02'),"
                                 + "(2,'a',21,2020,'month1','02'),"
@@ -340,7 +348,7 @@ public class HiveLookupJoinITCase {
 
         // inert a new partition
         batchEnv.executeSql(
-                        "insert overwrite partition_table_3 values "
+                        "insert overwrite table partition_table_3 values "
                                 + "(1,'a',101,2020,'08','01'),"
                                 + "(2,'a',121,2020,'08','01'),"
                                 + "(2,'b',122,2020,'08','01')")
@@ -363,7 +371,7 @@ public class HiveLookupJoinITCase {
         batchEnv.registerCatalog(hiveCatalog.getName(), hiveCatalog);
         batchEnv.useCatalog(hiveCatalog.getName());
         batchEnv.executeSql(
-                        "insert overwrite bounded_table values (1,'a',10),(2,'b',22),(3,'c',33)")
+                        "insert overwrite table bounded_table values (1,'a',10),(2,'b',22),(3,'c',33)")
                 .await();
         tableEnv.getConfig().setSqlDialect(SqlDialect.DEFAULT);
         TableImpl flinkTable =
