@@ -25,18 +25,24 @@ import org.apache.flink.client.deployment.application.ApplicationClusterEntryPoi
 import org.apache.flink.client.program.DefaultPackagedProgramRetriever;
 import org.apache.flink.client.program.PackagedProgram;
 import org.apache.flink.client.program.PackagedProgramRetriever;
+import org.apache.flink.client.program.artifact.ArtifactFetchManager;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.PipelineOptionsInternal;
+import org.apache.flink.core.fs.FileSystem;
+import org.apache.flink.core.plugin.PluginManager;
+import org.apache.flink.core.plugin.PluginUtils;
 import org.apache.flink.runtime.entrypoint.ClusterEntrypoint;
 import org.apache.flink.runtime.entrypoint.ClusterEntrypointUtils;
+import org.apache.flink.runtime.jobgraph.RestoreMode;
 import org.apache.flink.runtime.jobgraph.SavepointRestoreSettings;
 import org.apache.flink.runtime.resourcemanager.StandaloneResourceManagerFactory;
+import org.apache.flink.runtime.security.contexts.SecurityContext;
 import org.apache.flink.runtime.util.EnvironmentInformation;
 import org.apache.flink.runtime.util.JvmShutdownSafeguard;
 import org.apache.flink.runtime.util.SignalHandler;
-import org.apache.flink.util.FlinkException;
 
 import java.io.File;
+import java.util.Collection;
 
 /** An {@link ApplicationClusterEntryPoint} which is started with a job in a predefined location. */
 @Internal
@@ -61,9 +67,27 @@ public final class StandaloneApplicationClusterEntryPoint extends ApplicationClu
                         StandaloneApplicationClusterEntryPoint.class);
 
         Configuration configuration = loadConfigurationFromClusterConfig(clusterConfiguration);
+        if (clusterConfiguration
+                .getSavepointRestoreSettings()
+                .getRestoreMode()
+                .equals(RestoreMode.LEGACY)) {
+            LOG.warn(
+                    "The {} restore mode is deprecated, please use {} or {} mode instead.",
+                    RestoreMode.LEGACY,
+                    RestoreMode.CLAIM,
+                    RestoreMode.NO_CLAIM);
+        }
         PackagedProgram program = null;
         try {
-            program = getPackagedProgram(clusterConfiguration, configuration);
+            PluginManager pluginManager =
+                    PluginUtils.createPluginManagerFromRootFolder(configuration);
+            LOG.info(
+                    "Install default filesystem for fetching user artifacts in Standalone Application Mode.");
+            FileSystem.initialize(configuration, pluginManager);
+            SecurityContext securityContext = installSecurityContext(configuration);
+            program =
+                    securityContext.runSecured(
+                            () -> getPackagedProgram(clusterConfiguration, configuration));
         } catch (Exception e) {
             LOG.error("Could not create application program.", e);
             System.exit(1);
@@ -100,11 +124,25 @@ public final class StandaloneApplicationClusterEntryPoint extends ApplicationClu
     private static PackagedProgram getPackagedProgram(
             final StandaloneApplicationClusterConfiguration clusterConfiguration,
             Configuration flinkConfiguration)
-            throws FlinkException {
+            throws Exception {
         final File userLibDir = ClusterEntrypointUtils.tryFindUserLibDirectory().orElse(null);
+
+        File jobJar = null;
+        Collection<File> artifacts = null;
+        if (clusterConfiguration.hasJars()) {
+            ArtifactFetchManager fetchMgr = new ArtifactFetchManager(flinkConfiguration);
+            ArtifactFetchManager.Result res =
+                    fetchMgr.fetchArtifacts(clusterConfiguration.getJars());
+
+            jobJar = res.getJobJar();
+            artifacts = res.getArtifacts();
+        }
+
         final PackagedProgramRetriever programRetriever =
                 DefaultPackagedProgramRetriever.create(
                         userLibDir,
+                        jobJar,
+                        artifacts,
                         clusterConfiguration.getJobClassName(),
                         clusterConfiguration.getArgs(),
                         flinkConfiguration);
