@@ -22,9 +22,10 @@ import org.apache.flink.annotation.Internal;
 import org.apache.flink.annotation.Public;
 import org.apache.flink.annotation.PublicEvolving;
 import org.apache.flink.api.common.restartstrategy.RestartStrategies;
+import org.apache.flink.api.common.serialization.SerializerConfig;
+import org.apache.flink.api.common.serialization.SerializerConfigImpl;
 import org.apache.flink.configuration.ConfigOption;
 import org.apache.flink.configuration.Configuration;
-import org.apache.flink.configuration.ConfigurationUtils;
 import org.apache.flink.configuration.CoreOptions;
 import org.apache.flink.configuration.DescribedEnum;
 import org.apache.flink.configuration.ExecutionOptions;
@@ -33,6 +34,7 @@ import org.apache.flink.configuration.JobManagerOptions.SchedulerType;
 import org.apache.flink.configuration.MetricOptions;
 import org.apache.flink.configuration.PipelineOptions;
 import org.apache.flink.configuration.ReadableConfig;
+import org.apache.flink.configuration.RestartStrategyOptions;
 import org.apache.flink.configuration.StateChangelogOptions;
 import org.apache.flink.configuration.TaskManagerOptions;
 import org.apache.flink.configuration.description.InlineElement;
@@ -43,13 +45,12 @@ import com.esotericsoftware.kryo.Serializer;
 import java.io.Serializable;
 import java.time.Duration;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
-import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
-import java.util.stream.Collectors;
 
 import static org.apache.flink.configuration.ConfigOptions.key;
 import static org.apache.flink.configuration.description.TextElement.text;
@@ -142,41 +143,41 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      * In the long run, this field should be somehow merged with the {@link Configuration} from
      * StreamExecutionEnvironment.
      */
-    private final Configuration configuration = new Configuration();
+    private final Configuration configuration;
+
+    private final SerializerConfig serializerConfig;
+
+    @Internal
+    public SerializerConfig getSerializerConfig() {
+        return serializerConfig;
+    }
 
     /**
      * @deprecated Should no longer be used because it is subsumed by RestartStrategyConfiguration
      */
     @Deprecated private long executionRetryDelay = DEFAULT_RESTART_DELAY;
 
+    /**
+     * @deprecated The field is marked as deprecated because starting from Flink 1.19, the usage of
+     *     all complex Java objects related to configuration, including their getter and setter
+     *     methods, should be replaced by ConfigOption. In a future major version of Flink, this
+     *     method will be removed entirely. It is recommended to switch to using the ConfigOptions
+     *     provided by {@link org.apache.flink.configuration.RestartStrategyOptions} for configuring
+     *     restart strategies.
+     */
+    @Deprecated
     private RestartStrategies.RestartStrategyConfiguration restartStrategyConfiguration =
             new RestartStrategies.FallbackRestartStrategyConfiguration();
 
-    // ------------------------------- User code values --------------------------------------------
+    public ExecutionConfig() {
+        this(new Configuration());
+    }
 
-    private GlobalJobParameters globalJobParameters = new GlobalJobParameters();
-
-    // Serializers and types registered with Kryo and the PojoSerializer
-    // we store them in linked maps/sets to ensure they are registered in order in all kryo
-    // instances.
-
-    private LinkedHashMap<Class<?>, SerializableSerializer<?>> registeredTypesWithKryoSerializers =
-            new LinkedHashMap<>();
-
-    private LinkedHashMap<Class<?>, Class<? extends Serializer<?>>>
-            registeredTypesWithKryoSerializerClasses = new LinkedHashMap<>();
-
-    private LinkedHashMap<Class<?>, SerializableSerializer<?>> defaultKryoSerializers =
-            new LinkedHashMap<>();
-
-    private LinkedHashMap<Class<?>, Class<? extends Serializer<?>>> defaultKryoSerializerClasses =
-            new LinkedHashMap<>();
-
-    private LinkedHashSet<Class<?>> registeredKryoTypes = new LinkedHashSet<>();
-
-    private LinkedHashSet<Class<?>> registeredPojoTypes = new LinkedHashSet<>();
-
-    // --------------------------------------------------------------------------------------------
+    @Internal
+    public ExecutionConfig(Configuration configuration) {
+        this.configuration = configuration;
+        this.serializerConfig = new SerializerConfigImpl(configuration, this);
+    }
 
     /**
      * Enables the ClosureCleaner. This analyzes user code functions and sets fields to null that
@@ -279,6 +280,16 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
         return configuration.getOptional(MetricOptions.LATENCY_INTERVAL).isPresent();
     }
 
+    @Internal
+    public boolean isPeriodicMaterializeEnabled() {
+        return configuration.get(StateChangelogOptions.PERIODIC_MATERIALIZATION_ENABLED);
+    }
+
+    @Internal
+    public void enablePeriodicMaterialize(boolean enabled) {
+        configuration.set(StateChangelogOptions.PERIODIC_MATERIALIZATION_ENABLED, enabled);
+    }
+
     @Internal
     public long getPeriodicMaterializeIntervalMillis() {
         return configuration
@@ -436,8 +447,15 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      * 	1000 // delay between retries));
      * }</pre>
      *
+     * @deprecated The method is marked as deprecated because starting from Flink 1.19, the usage of
+     *     all complex Java objects related to configuration, including their getter and setter
+     *     methods, should be replaced by ConfigOption. In a future major version of Flink, this
+     *     method will be removed entirely. It is recommended to switch to using the ConfigOptions
+     *     provided by {@link org.apache.flink.configuration.RestartStrategyOptions} for configuring
+     *     restart strategies.
      * @param restartStrategyConfiguration Configuration defining the restart strategy to use
      */
+    @Deprecated
     @PublicEvolving
     public void setRestartStrategy(
             RestartStrategies.RestartStrategyConfiguration restartStrategyConfiguration) {
@@ -448,10 +466,16 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
     /**
      * Returns the restart strategy which has been set for the current job.
      *
+     * @deprecated The method is marked as deprecated because starting from Flink 1.19, the usage of
+     *     all complex Java objects related to configuration, including their getter and setter
+     *     methods, should be replaced by ConfigOption. In a future major version of Flink, this
+     *     method will be removed entirely. It is recommended to switch to using the ConfigOptions
+     *     provided by {@link org.apache.flink.configuration.RestartStrategyOptions} for configuring
+     *     restart strategies.
      * @return The specified restart configuration
      */
+    @Deprecated
     @PublicEvolving
-    @SuppressWarnings("deprecation")
     public RestartStrategies.RestartStrategyConfiguration getRestartStrategy() {
         if (restartStrategyConfiguration
                 instanceof RestartStrategies.FallbackRestartStrategyConfiguration) {
@@ -607,22 +631,38 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      * Force TypeExtractor to use Kryo serializer for POJOS even though we could analyze as POJO. In
      * some cases this might be preferable. For example, when using interfaces with subclasses that
      * cannot be analyzed as POJO.
+     *
+     * @deprecated Configure serialization behavior through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#FORCE_KRYO}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      */
+    @Deprecated
     public void enableForceKryo() {
-        setForceKryo(true);
+        serializerConfig.setForceKryo(true);
     }
 
-    /** Disable use of Kryo serializer for all POJOs. */
+    /**
+     * Disable use of Kryo serializer for all POJOs.
+     *
+     * @deprecated Configure serialization behavior through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#FORCE_KRYO}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
+     */
+    @Deprecated
     public void disableForceKryo() {
-        setForceKryo(false);
-    }
-
-    private void setForceKryo(boolean forceKryo) {
-        configuration.set(PipelineOptions.FORCE_KRYO, forceKryo);
+        serializerConfig.setForceKryo(false);
     }
 
+    /** @deprecated Use {@link SerializerConfig#isForceKryoEnabled}. */
+    @Deprecated
     public boolean isForceKryoEnabled() {
-        return configuration.get(PipelineOptions.FORCE_KRYO);
+        return serializerConfig.isForceKryoEnabled();
     }
 
     /**
@@ -630,10 +670,17 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      *
      * <p>Generic types are enabled by default.
      *
+     * @deprecated Configure serialization behavior through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#GENERIC_TYPES}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      * @see #disableGenericTypes()
      */
+    @Deprecated
     public void enableGenericTypes() {
-        setGenericTypes(true);
+        serializerConfig.setGenericTypes(true);
     }
 
     /**
@@ -650,14 +697,17 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      * input data may be such that new, previously unseen, types occur at some point. In that case,
      * setting this option would cause the program to fail.
      *
+     * @deprecated Configure serialization behavior through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#GENERIC_TYPES}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      * @see #enableGenericTypes()
      */
+    @Deprecated
     public void disableGenericTypes() {
-        setGenericTypes(false);
-    }
-
-    private void setGenericTypes(boolean genericTypes) {
-        configuration.set(PipelineOptions.GENERIC_TYPES, genericTypes);
+        serializerConfig.setGenericTypes(false);
     }
 
     /**
@@ -666,11 +716,13 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      *
      * <p>Generic types are enabled by default.
      *
+     * @deprecated Use {@link SerializerConfig#hasGenericTypesDisabled}.
      * @see #enableGenericTypes()
      * @see #disableGenericTypes()
      */
+    @Deprecated
     public boolean hasGenericTypesDisabled() {
-        return !configuration.get(PipelineOptions.GENERIC_TYPES);
+        return serializerConfig.hasGenericTypesDisabled();
     }
 
     /**
@@ -715,23 +767,42 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      * Forces Flink to use the Apache Avro serializer for POJOs.
      *
      * <p><b>Important:</b> Make sure to include the <i>flink-avro</i> module.
+     *
+     * @deprecated Configure serialization behavior through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#FORCE_AVRO}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      */
+    @Deprecated
     public void enableForceAvro() {
-        setForceAvro(true);
+        serializerConfig.setForceAvro(true);
     }
 
-    /** Disables the Apache Avro serializer as the forced serializer for POJOs. */
+    /**
+     * Disables the Apache Avro serializer as the forced serializer for POJOs.
+     *
+     * @deprecated Configure serialization behavior through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#FORCE_AVRO}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
+     */
+    @Deprecated
     public void disableForceAvro() {
-        setForceAvro(false);
+        serializerConfig.setForceAvro(false);
     }
 
-    private void setForceAvro(boolean forceAvro) {
-        configuration.set(PipelineOptions.FORCE_AVRO, forceAvro);
-    }
-
-    /** Returns whether the Apache Avro is the default serializer for POJOs. */
+    /**
+     * Returns whether the Apache Avro is the default serializer for POJOs.
+     *
+     * @deprecated Use {@link SerializerConfig#isForceAvroEnabled}.
+     */
+    @Deprecated
     public boolean isForceAvroEnabled() {
-        return configuration.get(PipelineOptions.FORCE_AVRO);
+        return serializerConfig.isForceAvroEnabled();
     }
 
     /**
@@ -762,7 +833,10 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
     }
 
     public GlobalJobParameters getGlobalJobParameters() {
-        return globalJobParameters;
+        return configuration
+                .getOptional(PipelineOptions.GLOBAL_JOB_PARAMETERS)
+                .map(MapBasedJobParameters::new)
+                .orElse(new MapBasedJobParameters(Collections.emptyMap()));
     }
 
     /**
@@ -772,7 +846,11 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      */
     public void setGlobalJobParameters(GlobalJobParameters globalJobParameters) {
         Preconditions.checkNotNull(globalJobParameters, "globalJobParameters shouldn't be null");
-        this.globalJobParameters = globalJobParameters;
+        setGlobalJobParameters(globalJobParameters.toMap());
+    }
+
+    private void setGlobalJobParameters(Map<String, String> parameters) {
+        configuration.set(PipelineOptions.GLOBAL_JOB_PARAMETERS, parameters);
     }
 
     // --------------------------------------------------------------------------------------------
@@ -788,14 +866,17 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      *
      * @param type The class of the types serialized with the given serializer.
      * @param serializer The serializer to use.
+     * @deprecated Register data types and serializers through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#SERIALIZATION_CONFIG}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      */
+    @Deprecated
     public <T extends Serializer<?> & Serializable> void addDefaultKryoSerializer(
             Class<?> type, T serializer) {
-        if (type == null || serializer == null) {
-            throw new NullPointerException("Cannot register null class or serializer.");
-        }
-
-        defaultKryoSerializers.put(type, new SerializableSerializer<>(serializer));
+        serializerConfig.addDefaultKryoSerializer(type, serializer);
     }
 
     /**
@@ -803,13 +884,17 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      *
      * @param type The class of the types serialized with the given serializer.
      * @param serializerClass The class of the serializer to use.
+     * @deprecated Register data types and serializers through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#SERIALIZATION_CONFIG}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      */
+    @Deprecated
     public void addDefaultKryoSerializer(
             Class<?> type, Class<? extends Serializer<?>> serializerClass) {
-        if (type == null || serializerClass == null) {
-            throw new NullPointerException("Cannot register null class or serializer.");
-        }
-        defaultKryoSerializerClasses.put(type, serializerClass);
+        serializerConfig.addDefaultKryoSerializer(type, serializerClass);
     }
 
     /**
@@ -821,34 +906,37 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      *
      * @param type The class of the types serialized with the given serializer.
      * @param serializer The serializer to use.
+     * @deprecated Register data types and serializers through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#SERIALIZATION_CONFIG}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      */
+    @Deprecated
     public <T extends Serializer<?> & Serializable> void registerTypeWithKryoSerializer(
             Class<?> type, T serializer) {
-        if (type == null || serializer == null) {
-            throw new NullPointerException("Cannot register null class or serializer.");
-        }
-
-        registeredTypesWithKryoSerializers.put(type, new SerializableSerializer<>(serializer));
+        serializerConfig.registerTypeWithKryoSerializer(type, serializer);
     }
 
     /**
      * Registers the given Serializer via its class as a serializer for the given type at the
-     * KryoSerializer
+     * KryoSerializer.
      *
      * @param type The class of the types serialized with the given serializer.
      * @param serializerClass The class of the serializer to use.
+     * @deprecated Register data types and serializers through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#SERIALIZATION_CONFIG}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      */
+    @Deprecated
     @SuppressWarnings("rawtypes")
     public void registerTypeWithKryoSerializer(
             Class<?> type, Class<? extends Serializer> serializerClass) {
-        if (type == null || serializerClass == null) {
-            throw new NullPointerException("Cannot register null class or serializer.");
-        }
-
-        @SuppressWarnings("unchecked")
-        Class<? extends Serializer<?>> castedSerializerClass =
-                (Class<? extends Serializer<?>>) serializerClass;
-        registeredTypesWithKryoSerializerClasses.put(type, castedSerializerClass);
+        serializerConfig.registerTypeWithKryoSerializer(type, serializerClass);
     }
 
     /**
@@ -858,14 +946,16 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      * written.
      *
      * @param type The class of the type to register.
+     * @deprecated Register data types and serializers through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#SERIALIZATION_CONFIG}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      */
+    @Deprecated
     public void registerPojoType(Class<?> type) {
-        if (type == null) {
-            throw new NullPointerException("Cannot register null type class.");
-        }
-        if (!registeredPojoTypes.contains(type)) {
-            registeredPojoTypes.add(type);
-        }
+        serializerConfig.registerPojoType(type);
     }
 
     /**
@@ -875,58 +965,79 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
      * written.
      *
      * @param type The class of the type to register.
+     * @deprecated Register data types and serializers through hard codes is deprecated, because you
+     *     need to modify the codes when upgrading job version. You should configure this by config
+     *     option {@link PipelineOptions#SERIALIZATION_CONFIG}.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
      */
+    @Deprecated
     public void registerKryoType(Class<?> type) {
-        if (type == null) {
-            throw new NullPointerException("Cannot register null type class.");
-        }
-        registeredKryoTypes.add(type);
+        serializerConfig.registerKryoType(type);
     }
 
-    /** Returns the registered types with Kryo Serializers. */
+    /**
+     * Returns the registered types with Kryo Serializers.
+     *
+     * @deprecated Use {@link SerializerConfig#getRegisteredTypesWithKryoSerializers}.
+     */
+    @Deprecated
     public LinkedHashMap<Class<?>, SerializableSerializer<?>>
             getRegisteredTypesWithKryoSerializers() {
-        return registeredTypesWithKryoSerializers;
+        return serializerConfig.getRegisteredTypesWithKryoSerializers();
     }
 
-    /** Returns the registered types with their Kryo Serializer classes. */
+    /**
+     * Returns the registered types with their Kryo Serializer classes.
+     *
+     * @deprecated Use {@link SerializerConfig#getRegisteredTypesWithKryoSerializerClasses}.
+     */
+    @Deprecated
     public LinkedHashMap<Class<?>, Class<? extends Serializer<?>>>
             getRegisteredTypesWithKryoSerializerClasses() {
-        return registeredTypesWithKryoSerializerClasses;
+        return serializerConfig.getRegisteredTypesWithKryoSerializerClasses();
     }
 
-    /** Returns the registered default Kryo Serializers. */
+    /**
+     * Returns the registered default Kryo Serializers.
+     *
+     * @deprecated Use {@link SerializerConfig#getDefaultKryoSerializers}.
+     */
+    @Deprecated
     public LinkedHashMap<Class<?>, SerializableSerializer<?>> getDefaultKryoSerializers() {
-        return defaultKryoSerializers;
+        return serializerConfig.getDefaultKryoSerializers();
     }
 
-    /** Returns the registered default Kryo Serializer classes. */
+    /**
+     * Returns the registered default Kryo Serializer classes.
+     *
+     * @deprecated Use {@link SerializerConfig#getDefaultKryoSerializerClasses}.
+     */
+    @Deprecated
     public LinkedHashMap<Class<?>, Class<? extends Serializer<?>>>
             getDefaultKryoSerializerClasses() {
-        return defaultKryoSerializerClasses;
+        return serializerConfig.getDefaultKryoSerializerClasses();
     }
 
-    /** Returns the registered Kryo types. */
+    /**
+     * Returns the registered Kryo types.
+     *
+     * @deprecated Use {@link SerializerConfig#getRegisteredKryoTypes}.
+     */
+    @Deprecated
     public LinkedHashSet<Class<?>> getRegisteredKryoTypes() {
-        if (isForceKryoEnabled()) {
-            // if we force kryo, we must also return all the types that
-            // were previously only registered as POJO
-            LinkedHashSet<Class<?>> result = new LinkedHashSet<>();
-            result.addAll(registeredKryoTypes);
-            for (Class<?> t : registeredPojoTypes) {
-                if (!result.contains(t)) {
-                    result.add(t);
-                }
-            }
-            return result;
-        } else {
-            return registeredKryoTypes;
-        }
+        return serializerConfig.getRegisteredKryoTypes();
     }
 
-    /** Returns the registered POJO types. */
+    /**
+     * Returns the registered POJO types.
+     *
+     * @deprecated Use {@link SerializerConfig#getRegisteredPojoTypes}.
+     */
+    @Deprecated
     public LinkedHashSet<Class<?>> getRegisteredPojoTypes() {
-        return registeredPojoTypes;
+        return serializerConfig.getRegisteredPojoTypes();
     }
 
     /**
@@ -980,17 +1091,12 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
             ExecutionConfig other = (ExecutionConfig) obj;
 
             return Objects.equals(configuration, other.configuration)
+                    && Objects.equals(serializerConfig, other.serializerConfig)
                     && ((restartStrategyConfiguration == null
                                     && other.restartStrategyConfiguration == null)
                             || (null != restartStrategyConfiguration
                                     && restartStrategyConfiguration.equals(
-                                            other.restartStrategyConfiguration)))
-                    && Objects.equals(globalJobParameters, other.globalJobParameters)
-                    && registeredTypesWithKryoSerializerClasses.equals(
-                            other.registeredTypesWithKryoSerializerClasses)
-                    && defaultKryoSerializerClasses.equals(other.defaultKryoSerializerClasses)
-                    && registeredKryoTypes.equals(other.registeredKryoTypes)
-                    && registeredPojoTypes.equals(other.registeredPojoTypes);
+                                            other.restartStrategyConfiguration)));
 
         } else {
             return false;
@@ -999,14 +1105,7 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
 
     @Override
     public int hashCode() {
-        return Objects.hash(
-                configuration,
-                restartStrategyConfiguration,
-                globalJobParameters,
-                registeredTypesWithKryoSerializerClasses,
-                defaultKryoSerializerClasses,
-                registeredKryoTypes,
-                registeredPojoTypes);
+        return Objects.hash(configuration, serializerConfig, restartStrategyConfiguration);
     }
 
     @Override
@@ -1014,24 +1113,12 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
         return "ExecutionConfig{"
                 + "configuration="
                 + configuration
+                + ", serializerConfig="
+                + serializerConfig
                 + ", executionRetryDelay="
                 + executionRetryDelay
                 + ", restartStrategyConfiguration="
                 + restartStrategyConfiguration
-                + ", globalJobParameters="
-                + globalJobParameters
-                + ", registeredTypesWithKryoSerializers="
-                + registeredTypesWithKryoSerializers
-                + ", registeredTypesWithKryoSerializerClasses="
-                + registeredTypesWithKryoSerializerClasses
-                + ", defaultKryoSerializers="
-                + defaultKryoSerializers
-                + ", defaultKryoSerializerClasses="
-                + defaultKryoSerializerClasses
-                + ", registeredKryoTypes="
-                + registeredKryoTypes
-                + ", registeredPojoTypes="
-                + registeredPojoTypes
                 + '}';
     }
 
@@ -1053,6 +1140,18 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
 
     // ------------------------------ Utilities  ----------------------------------
 
+    /**
+     * @deprecated The class is deprecated because instance-type serializer definition where
+     *     serializers are serialized and written into the snapshot and deserialized for use is
+     *     deprecated. Use class-type serializer definition instead, where only the class name is
+     *     written into the snapshot and new instance of the serializer is created for use. This is
+     *     a breaking change, and it will be removed in Flink 2.0.
+     * @see <a
+     *     href="https://cwiki.apache.org/confluence/display/FLINK/FLIP-398:+Improve+Serialization+Configuration+And+Usage+In+Flink">
+     *     FLIP-398: Improve Serialization Configuration And Usage In Flink</a>
+     */
+    @Deprecated
+    @Public
     public static class SerializableSerializer<T extends Serializer<?> & Serializable>
             implements Serializable {
         private static final long serialVersionUID = 4687893502781067189L;
@@ -1145,18 +1244,17 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
         configuration
                 .getOptional(PipelineOptions.CLOSURE_CLEANER_LEVEL)
                 .ifPresent(this::setClosureCleanerLevel);
-        configuration.getOptional(PipelineOptions.FORCE_AVRO).ifPresent(this::setForceAvro);
-        configuration.getOptional(PipelineOptions.GENERIC_TYPES).ifPresent(this::setGenericTypes);
-        configuration.getOptional(PipelineOptions.FORCE_KRYO).ifPresent(this::setForceKryo);
         configuration
                 .getOptional(PipelineOptions.GLOBAL_JOB_PARAMETERS)
-                .<GlobalJobParameters>map(MapBasedJobParameters::new)
                 .ifPresent(this::setGlobalJobParameters);
 
         configuration
                 .getOptional(MetricOptions.LATENCY_INTERVAL)
                 .ifPresent(this::setLatencyTrackingInterval);
 
+        configuration
+                .getOptional(StateChangelogOptions.PERIODIC_MATERIALIZATION_ENABLED)
+                .ifPresent(this::enablePeriodicMaterialize);
         configuration
                 .getOptional(StateChangelogOptions.PERIODIC_MATERIALIZATION_INTERVAL)
                 .ifPresent(this::setPeriodicMaterializeIntervalMillis);
@@ -1178,92 +1276,43 @@ public class ExecutionConfig implements Serializable, Archiveable<ArchivedExecut
         configuration
                 .getOptional(ExecutionOptions.SNAPSHOT_COMPRESSION)
                 .ifPresent(this::setUseSnapshotCompression);
-        RestartStrategies.fromConfiguration(configuration).ifPresent(this::setRestartStrategy);
         configuration
-                .getOptional(PipelineOptions.KRYO_DEFAULT_SERIALIZERS)
-                .map(s -> parseKryoSerializersWithExceptionHandling(classLoader, s))
-                .ifPresent(s -> this.defaultKryoSerializerClasses = s);
-
-        configuration
-                .getOptional(PipelineOptions.POJO_REGISTERED_CLASSES)
-                .map(c -> loadClasses(c, classLoader, "Could not load pojo type to be registered."))
-                .ifPresent(c -> this.registeredPojoTypes = c);
-
-        configuration
-                .getOptional(PipelineOptions.KRYO_REGISTERED_CLASSES)
-                .map(c -> loadClasses(c, classLoader, "Could not load kryo type to be registered."))
-                .ifPresent(c -> this.registeredKryoTypes = c);
+                .getOptional(RestartStrategyOptions.RESTART_STRATEGY)
+                .ifPresent(
+                        s -> {
+                            this.setRestartStrategy(configuration);
+                            // reset RestartStrategies for backward compatibility
+                            this.setRestartStrategy(
+                                    new RestartStrategies.FallbackRestartStrategyConfiguration());
+                        });
 
         configuration
                 .getOptional(JobManagerOptions.SCHEDULER)
                 .ifPresent(t -> this.configuration.set(JobManagerOptions.SCHEDULER, t));
+
+        serializerConfig.configure(configuration, classLoader);
+    }
+
+    private void setRestartStrategy(ReadableConfig configuration) {
+        Map<String, String> map = configuration.toMap();
+        Map<String, String> restartStrategyEntries = new HashMap<>();
+        for (Map.Entry<String, String> entry : map.entrySet()) {
+            if (entry.getKey().startsWith(RestartStrategyOptions.RESTART_STRATEGY_CONFIG_PREFIX)) {
+                restartStrategyEntries.put(entry.getKey(), entry.getValue());
+            }
+        }
+        this.configuration.addAll(Configuration.fromMap(restartStrategyEntries));
     }
 
     /**
      * @return A copy of internal {@link #configuration}. Note it is missing all options that are
-     *     stored as plain java fields in {@link ExecutionConfig}, for example {@link
-     *     #registeredKryoTypes} or {@link #globalJobParameters}.
+     *     stored as plain java fields in {@link ExecutionConfig}.
      */
     @Internal
     public Configuration toConfiguration() {
         return new Configuration(configuration);
     }
 
-    private LinkedHashSet<Class<?>> loadClasses(
-            List<String> classNames, ClassLoader classLoader, String errorMessage) {
-        return classNames.stream()
-                .map(name -> this.<Class<?>>loadClass(name, classLoader, errorMessage))
-                .collect(Collectors.toCollection(LinkedHashSet::new));
-    }
-
-    private LinkedHashMap<Class<?>, Class<? extends Serializer<?>>>
-            parseKryoSerializersWithExceptionHandling(
-                    ClassLoader classLoader, List<String> kryoSerializers) {
-        try {
-            return parseKryoSerializers(classLoader, kryoSerializers);
-        } catch (Exception e) {
-            throw new IllegalArgumentException(
-                    String.format(
-                            "Could not configure kryo serializers from %s. The expected format is:"
-                                    + "'class:<fully qualified class name>,serializer:<fully qualified serializer name>;...",
-                            kryoSerializers),
-                    e);
-        }
-    }
-
-    private LinkedHashMap<Class<?>, Class<? extends Serializer<?>>> parseKryoSerializers(
-            ClassLoader classLoader, List<String> kryoSerializers) {
-        return kryoSerializers.stream()
-                .map(ConfigurationUtils::parseMap)
-                .collect(
-                        Collectors.toMap(
-                                m ->
-                                        loadClass(
-                                                m.get("class"),
-                                                classLoader,
-                                                "Could not load class for kryo serialization"),
-                                m ->
-                                        loadClass(
-                                                m.get("serializer"),
-                                                classLoader,
-                                                "Could not load serializer's class"),
-                                (m1, m2) -> {
-                                    throw new IllegalArgumentException(
-                                            "Duplicated serializer for class: " + m1);
-                                },
-                                LinkedHashMap::new));
-    }
-
-    @SuppressWarnings("unchecked")
-    private <T extends Class> T loadClass(
-            String className, ClassLoader classLoader, String errorMessage) {
-        try {
-            return (T) Class.forName(className, false, classLoader);
-        } catch (ClassNotFoundException e) {
-            throw new IllegalArgumentException(errorMessage, e);
-        }
-    }
-
     private static class MapBasedJobParameters extends GlobalJobParameters {
         private final Map<String, String> properties;
 
