@@ -20,8 +20,15 @@ package org.apache.flink.api.common;
 
 import org.apache.flink.annotation.PublicEvolving;
 
-/** This constraint indicates when a task should be scheduled considering its inputs status. */
+/**
+ * This constraint indicates when a task should be scheduled considering its inputs status.
+ *
+ * @deprecated {@code InputDependencyConstraint} is not used anymore and will be deleted in one of
+ *     the future versions. It was previously used in the scheduler implementations that were
+ *     removed as part of FLINK-20589.
+ */
 @PublicEvolving
+@Deprecated
 public enum InputDependencyConstraint {
 
     /** Schedule the task if any input is consumable. */
