@@ -22,6 +22,7 @@ import org.apache.flink.annotation.PublicEvolving;
 import org.apache.flink.api.common.time.Time;
 import org.apache.flink.configuration.ReadableConfig;
 import org.apache.flink.configuration.RestartStrategyOptions;
+import org.apache.flink.configuration.RestartStrategyOptions.RestartStrategyType;
 
 import java.io.Serializable;
 import java.time.Duration;
@@ -35,7 +36,25 @@ import java.util.concurrent.TimeUnit;
  *
  * <p>The RestartStrategyConfigurations are used to decouple the core module from the runtime
  * module.
+ *
+ * @deprecated The {@link RestartStrategies} class is marked as deprecated because starting from
+ *     Flink 1.19, all complex Java objects related to configuration should be replaced by
+ *     ConfigOption. In a future major version of Flink, this class will be removed entirely. It is
+ *     recommended to switch to using the ConfigOptions provided by {@link
+ *     org.apache.flink.configuration.RestartStrategyOptions} for configuring restart strategies
+ *     like the following code snippet:
+ *     <pre>{@code
+ * Configuration config = new Configuration();
+ * config.set(RestartStrategyOptions.RESTART_STRATEGY, "fixed-delay");
+ * config.set(RestartStrategyOptions.RESTART_STRATEGY_FIXED_DELAY_ATTEMPTS, 3);
+ * config.set(RestartStrategyOptions.RESTART_STRATEGY_FIXED_DELAY_DELAY, Duration.ofMinutes(1));
+ * StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment(config);
+ * }</pre>
+ *     For more details on using ConfigOption for restart strategies, please refer to the Flink
+ *     documentation: <a
+ *     href="https://nightlies.apache.org/flink/flink-docs-stable/docs/ops/state/task_failure_recovery/#restart-strategies">restart-strategies</a>
  */
+@Deprecated
 @PublicEvolving
 public class RestartStrategies {
 
@@ -72,12 +91,42 @@ public class RestartStrategies {
      * @param restartAttempts Number of restart attempts for the FixedDelayRestartStrategy
      * @param delayInterval Delay in-between restart attempts for the FixedDelayRestartStrategy
      * @return FixedDelayRestartStrategy
+     * @deprecated Use {@link #fixedDelayRestart(int, Duration)}
      */
+    @Deprecated
     public static RestartStrategyConfiguration fixedDelayRestart(
             int restartAttempts, Time delayInterval) {
+        return fixedDelayRestart(restartAttempts, Time.toDuration(delayInterval));
+    }
+
+    /**
+     * Generates a FixedDelayRestartStrategyConfiguration.
+     *
+     * @param restartAttempts Number of restart attempts for the FixedDelayRestartStrategy
+     * @param delayInterval Delay in-between restart attempts for the FixedDelayRestartStrategy
+     * @return FixedDelayRestartStrategy
+     */
+    public static RestartStrategyConfiguration fixedDelayRestart(
+            int restartAttempts, Duration delayInterval) {
         return new FixedDelayRestartStrategyConfiguration(restartAttempts, delayInterval);
     }
 
+    /**
+     * Generates a FailureRateRestartStrategyConfiguration.
+     *
+     * @param failureRate Maximum number of restarts in given interval {@code failureInterval}
+     *     before failing a job
+     * @param failureInterval Time interval for failures
+     * @param delayInterval Delay in-between restart attempts
+     * @deprecated Use {@link #failureRateRestart(int, Duration, Duration)}
+     */
+    @Deprecated
+    public static FailureRateRestartStrategyConfiguration failureRateRestart(
+            int failureRate, Time failureInterval, Time delayInterval) {
+        return failureRateRestart(
+                failureRate, Time.toDuration(failureInterval), Time.toDuration(delayInterval));
+    }
+
     /**
      * Generates a FailureRateRestartStrategyConfiguration.
      *
@@ -87,7 +136,7 @@ public class RestartStrategies {
      * @param delayInterval Delay in-between restart attempts
      */
     public static FailureRateRestartStrategyConfiguration failureRateRestart(
-            int failureRate, Time failureInterval, Time delayInterval) {
+            int failureRate, Duration failureInterval, Duration delayInterval) {
         return new FailureRateRestartStrategyConfiguration(
                 failureRate, failureInterval, delayInterval);
     }
@@ -100,18 +149,45 @@ public class RestartStrategies {
      * @param backoffMultiplier Delay multiplier how many times is the delay longer than before
      * @param resetBackoffThreshold How long the job must run smoothly to reset the time interval
      * @param jitterFactor How much the delay may differ (in percentage)
+     * @deprecated Use {@link #exponentialDelayRestart(Duration, Duration, double, Duration,
+     *     double)}
      */
+    @Deprecated
     public static ExponentialDelayRestartStrategyConfiguration exponentialDelayRestart(
             Time initialBackoff,
             Time maxBackoff,
             double backoffMultiplier,
             Time resetBackoffThreshold,
             double jitterFactor) {
+        return exponentialDelayRestart(
+                Time.toDuration(initialBackoff),
+                Time.toDuration(maxBackoff),
+                backoffMultiplier,
+                Time.toDuration(resetBackoffThreshold),
+                jitterFactor);
+    }
+
+    /**
+     * Generates a ExponentialDelayRestartStrategyConfiguration.
+     *
+     * @param initialBackoff Starting duration between restarts
+     * @param maxBackoff The highest possible duration between restarts
+     * @param backoffMultiplier Delay multiplier how many times is the delay longer than before
+     * @param resetBackoffThreshold How long the job must run smoothly to reset the time interval
+     * @param jitterFactor How much the delay may differ (in percentage)
+     */
+    public static ExponentialDelayRestartStrategyConfiguration exponentialDelayRestart(
+            Duration initialBackoff,
+            Duration maxBackoff,
+            double backoffMultiplier,
+            Duration resetBackoffThreshold,
+            double jitterFactor) {
         return new ExponentialDelayRestartStrategyConfiguration(
                 initialBackoff, maxBackoff, backoffMultiplier, resetBackoffThreshold, jitterFactor);
     }
 
     /** Abstract configuration for restart strategies. */
+    @PublicEvolving
     public abstract static class RestartStrategyConfiguration implements Serializable {
         private static final long serialVersionUID = 6285853591578313960L;
 
@@ -131,6 +207,7 @@ public class RestartStrategies {
     }
 
     /** Configuration representing no restart strategy. */
+    @PublicEvolving
     public static final class NoRestartStrategyConfiguration extends RestartStrategyConfiguration {
         private static final long serialVersionUID = -5894362702943349962L;
 
@@ -154,15 +231,16 @@ public class RestartStrategies {
     }
 
     /** Configuration representing a fixed delay restart strategy. */
+    @PublicEvolving
     public static final class FixedDelayRestartStrategyConfiguration
             extends RestartStrategyConfiguration {
         private static final long serialVersionUID = 4149870149673363190L;
 
         private final int restartAttempts;
-        private final Time delayBetweenAttemptsInterval;
+        private final Duration delayBetweenAttemptsInterval;
 
         FixedDelayRestartStrategyConfiguration(
-                int restartAttempts, Time delayBetweenAttemptsInterval) {
+                int restartAttempts, Duration delayBetweenAttemptsInterval) {
             this.restartAttempts = restartAttempts;
             this.delayBetweenAttemptsInterval = delayBetweenAttemptsInterval;
         }
@@ -171,7 +249,13 @@ public class RestartStrategies {
             return restartAttempts;
         }
 
+        /** @deprecated Use {@link #getDurationBetweenAttempts()} */
+        @Deprecated
         public Time getDelayBetweenAttemptsInterval() {
+            return Time.fromDuration(getDurationBetweenAttempts());
+        }
+
+        public Duration getDurationBetweenAttempts() {
             return delayBetweenAttemptsInterval;
         }
 
@@ -208,22 +292,43 @@ public class RestartStrategies {
     }
 
     /** Configuration representing an exponential delay restart strategy. */
+    @PublicEvolving
     public static final class ExponentialDelayRestartStrategyConfiguration
             extends RestartStrategyConfiguration {
         private static final long serialVersionUID = 1467941615941965194L;
 
-        private final Time initialBackoff;
-        private final Time maxBackoff;
+        private final Duration initialBackoff;
+        private final Duration maxBackoff;
         private final double backoffMultiplier;
-        private final Time resetBackoffThreshold;
+        private final Duration resetBackoffThreshold;
         private final double jitterFactor;
 
+        /**
+         * @deprecated Use {@link
+         *     ExponentialDelayRestartStrategyConfiguration#ExponentialDelayRestartStrategyConfiguration(Duration,
+         *     Duration, double, Duration, double)}
+         */
+        @Deprecated
         public ExponentialDelayRestartStrategyConfiguration(
                 Time initialBackoff,
                 Time maxBackoff,
                 double backoffMultiplier,
                 Time resetBackoffThreshold,
                 double jitterFactor) {
+            this(
+                    Time.toDuration(initialBackoff),
+                    Time.toDuration(maxBackoff),
+                    backoffMultiplier,
+                    Time.toDuration(resetBackoffThreshold),
+                    jitterFactor);
+        }
+
+        public ExponentialDelayRestartStrategyConfiguration(
+                Duration initialBackoff,
+                Duration maxBackoff,
+                double backoffMultiplier,
+                Duration resetBackoffThreshold,
+                double jitterFactor) {
             this.initialBackoff = initialBackoff;
             this.maxBackoff = maxBackoff;
             this.backoffMultiplier = backoffMultiplier;
@@ -231,11 +336,23 @@ public class RestartStrategies {
             this.jitterFactor = jitterFactor;
         }
 
+        /** @deprecated Use {@link #getInitialBackoffDuration()} */
+        @Deprecated
         public Time getInitialBackoff() {
+            return Time.fromDuration(getInitialBackoffDuration());
+        }
+
+        public Duration getInitialBackoffDuration() {
             return initialBackoff;
         }
 
+        /** @deprecated Use {@link #getMaxBackoffDuration()} */
+        @Deprecated
         public Time getMaxBackoff() {
+            return Time.fromDuration(maxBackoff);
+        }
+
+        public Duration getMaxBackoffDuration() {
             return maxBackoff;
         }
 
@@ -243,7 +360,13 @@ public class RestartStrategies {
             return backoffMultiplier;
         }
 
+        /** @deprecated Use {@link #getResetBackoffDurationThreshold()} */
+        @Deprecated
         public Time getResetBackoffThreshold() {
+            return Time.fromDuration(resetBackoffThreshold);
+        }
+
+        public Duration getResetBackoffDurationThreshold() {
             return resetBackoffThreshold;
         }
 
@@ -292,16 +415,31 @@ public class RestartStrategies {
     }
 
     /** Configuration representing a failure rate restart strategy. */
+    @PublicEvolving
     public static final class FailureRateRestartStrategyConfiguration
             extends RestartStrategyConfiguration {
         private static final long serialVersionUID = 1195028697539661739L;
         private final int maxFailureRate;
 
-        private final Time failureInterval;
-        private final Time delayBetweenAttemptsInterval;
+        private final Duration failureInterval;
+        private final Duration delayBetweenAttemptsInterval;
 
+        /**
+         * @deprecated Use {@link #FailureRateRestartStrategyConfiguration(int, Duration, Duration)}
+         */
+        @Deprecated
         public FailureRateRestartStrategyConfiguration(
                 int maxFailureRate, Time failureInterval, Time delayBetweenAttemptsInterval) {
+            this(
+                    maxFailureRate,
+                    Time.toDuration(failureInterval),
+                    Time.toDuration(delayBetweenAttemptsInterval));
+        }
+
+        public FailureRateRestartStrategyConfiguration(
+                int maxFailureRate,
+                Duration failureInterval,
+                Duration delayBetweenAttemptsInterval) {
             this.maxFailureRate = maxFailureRate;
             this.failureInterval = failureInterval;
             this.delayBetweenAttemptsInterval = delayBetweenAttemptsInterval;
@@ -311,11 +449,23 @@ public class RestartStrategies {
             return maxFailureRate;
         }
 
+        /** @deprecated Use {@link #getFailureIntervalDuration()} */
+        @Deprecated
         public Time getFailureInterval() {
+            return Time.fromDuration(getFailureIntervalDuration());
+        }
+
+        public Duration getFailureIntervalDuration() {
             return failureInterval;
         }
 
+        /** @deprecated Use {@link #getDurationBetweenAttempts()} */
+        @Deprecated
         public Time getDelayBetweenAttemptsInterval() {
+            return Time.fromDuration(getDurationBetweenAttempts());
+        }
+
+        public Duration getDurationBetweenAttempts() {
             return delayBetweenAttemptsInterval;
         }
 
@@ -353,8 +503,9 @@ public class RestartStrategies {
     /**
      * Restart strategy configuration that could be used by jobs to use cluster level restart
      * strategy. Useful especially when one has a custom implementation of restart strategy set via
-     * flink-conf.yaml.
+     * config.yaml.
      */
+    @PublicEvolving
     public static final class FallbackRestartStrategyConfiguration
             extends RestartStrategyConfiguration {
         private static final long serialVersionUID = -4441787204284085544L;
@@ -393,13 +544,10 @@ public class RestartStrategies {
 
     private static RestartStrategyConfiguration parseConfiguration(
             String restartstrategyKind, ReadableConfig configuration) {
-        switch (restartstrategyKind.toLowerCase()) {
-            case "none":
-            case "off":
-            case "disable":
+        switch (RestartStrategyType.of(restartstrategyKind.toLowerCase())) {
+            case NO_RESTART_STRATEGY:
                 return noRestart();
-            case "fixeddelay":
-            case "fixed-delay":
+            case FIXED_DELAY:
                 int attempts =
                         configuration.get(
                                 RestartStrategyOptions.RESTART_STRATEGY_FIXED_DELAY_ATTEMPTS);
@@ -407,8 +555,7 @@ public class RestartStrategies {
                         configuration.get(
                                 RestartStrategyOptions.RESTART_STRATEGY_FIXED_DELAY_DELAY);
                 return fixedDelayRestart(attempts, delay.toMillis());
-            case "exponentialdelay":
-            case "exponential-delay":
+            case EXPONENTIAL_DELAY:
                 Duration initialBackoff =
                         configuration.get(
                                 RestartStrategyOptions
@@ -430,13 +577,12 @@ public class RestartStrategies {
                                 RestartStrategyOptions
                                         .RESTART_STRATEGY_EXPONENTIAL_DELAY_JITTER_FACTOR);
                 return exponentialDelayRestart(
-                        Time.milliseconds(initialBackoff.toMillis()),
-                        Time.milliseconds(maxBackoff.toMillis()),
+                        initialBackoff,
+                        maxBackoff,
                         backoffMultiplier,
-                        Time.milliseconds(resetBackoffThreshold.toMillis()),
+                        resetBackoffThreshold,
                         jitter);
-            case "failurerate":
-            case "failure-rate":
+            case FAILURE_RATE:
                 int maxFailures =
                         configuration.get(
                                 RestartStrategyOptions
