@@ -20,6 +20,7 @@ package org.apache.flink.api.java.typeutils;
 import org.apache.flink.annotation.PublicEvolving;
 import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.operators.Keys.ExpressionKeys;
+import org.apache.flink.api.common.serialization.SerializerConfig;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.common.typeutils.CompositeType;
 import org.apache.flink.api.common.typeutils.TypeComparator;
@@ -248,7 +249,7 @@ public class RowTypeInfo extends TupleTypeInfoBase<Row> {
     }
 
     @Override
-    public TypeSerializer<Row> createSerializer(ExecutionConfig config) {
+    public TypeSerializer<Row> createSerializer(SerializerConfig config) {
         int len = getArity();
         TypeSerializer<?>[] fieldSerializers = new TypeSerializer[len];
         for (int i = 0; i < len; i++) {
@@ -261,6 +262,11 @@ public class RowTypeInfo extends TupleTypeInfoBase<Row> {
         return new RowSerializer(fieldSerializers, positionByName);
     }
 
+    @Override
+    public TypeSerializer<Row> createSerializer(ExecutionConfig config) {
+        return createSerializer(config.getSerializerConfig());
+    }
+
     @Override
     public boolean canEqual(Object obj) {
         return obj instanceof RowTypeInfo;
@@ -307,7 +313,7 @@ public class RowTypeInfo extends TupleTypeInfoBase<Row> {
      * <p>The serialization format has changed from 1.10 to 1.11 and added {@link Row#getKind()}.
      */
     @Deprecated
-    public TypeSerializer<Row> createLegacySerializer(ExecutionConfig config) {
+    public TypeSerializer<Row> createLegacySerializer(SerializerConfig config) {
         int len = getArity();
         TypeSerializer<?>[] fieldSerializers = new TypeSerializer[len];
         for (int i = 0; i < len; i++) {
@@ -374,7 +380,7 @@ public class RowTypeInfo extends TupleTypeInfoBase<Row> {
             TypeSerializer<?>[] fieldSerializers = new TypeSerializer<?>[maxKey + 1];
 
             for (int i = 0; i <= maxKey; i++) {
-                fieldSerializers[i] = types[i].createSerializer(config);
+                fieldSerializers[i] = types[i].createSerializer(config.getSerializerConfig());
             }
 
             int[] keyPositions = new int[logicalKeyFields.size()];
