@@ -18,8 +18,10 @@
 
 package org.apache.flink.configuration;
 
+import org.apache.flink.annotation.Internal;
 import org.apache.flink.annotation.Public;
 import org.apache.flink.annotation.PublicEvolving;
+import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.core.io.IOReadableWritable;
 import org.apache.flink.core.memory.DataInputView;
@@ -39,6 +41,7 @@ import java.util.Optional;
 import java.util.Properties;
 import java.util.Set;
 import java.util.function.BiFunction;
+import java.util.stream.Collectors;
 
 import static org.apache.flink.configuration.ConfigurationUtils.canBePrefixMap;
 import static org.apache.flink.configuration.ConfigurationUtils.containsPrefixMap;
@@ -68,14 +71,29 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
     /** The log object used for debugging. */
     private static final Logger LOG = LoggerFactory.getLogger(Configuration.class);
 
-    /** Stores the concrete key/value pairs of this configuration object. */
+    /**
+     * Stores the concrete key/value pairs of this configuration object.
+     *
+     * <p>NOTE: This map stores the values that are actually used, and does not include any escaping
+     * that is required by the standard YAML syntax.
+     */
     protected final HashMap<String, Object> confData;
 
+    protected final boolean standardYaml;
+
     // --------------------------------------------------------------------------------------------
 
     /** Creates a new empty configuration. */
     public Configuration() {
         this.confData = new HashMap<>();
+        this.standardYaml = GlobalConfiguration.isStandardYaml();
+    }
+
+    @VisibleForTesting
+    @Internal
+    public Configuration(boolean standardYaml) {
+        this.confData = new HashMap<>();
+        this.standardYaml = standardYaml;
     }
 
     /**
@@ -85,6 +103,7 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      */
     public Configuration(Configuration other) {
         this.confData = new HashMap<>(other.confData);
+        this.standardYaml = other.standardYaml;
     }
 
     // --------------------------------------------------------------------------------------------
@@ -108,6 +127,7 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @return The value associated with the given key, or the default value, if to entry for the
      *     key exists.
      */
+    @Deprecated
     @SuppressWarnings("unchecked")
     public <T> Class<T> getClass(
             String key, Class<? extends T> defaultValue, ClassLoader classLoader)
@@ -136,23 +156,27 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param klazz The value of the pair to be added
      * @see #getClass(String, Class, ClassLoader)
      */
+    @Deprecated
     public void setClass(String key, Class<?> klazz) {
         setValueInternal(key, klazz.getName());
     }
 
     /**
-     * Returns the value associated with the given key as a string.
+     * Returns the value associated with the given key as a string. We encourage users and
+     * developers to always use ConfigOption for getting the configurations if possible, for its
+     * rich description, type, default-value and other supports. The string-key-based getter should
+     * only be used when ConfigOption is not applicable, e.g., the key is programmatically generated
+     * in runtime.
      *
      * @param key the key pointing to the associated value
      * @param defaultValue the default value which is returned in case there is no value associated
      *     with the given key
      * @return the (default) value associated with the given key
-     * @deprecated use {@link #getString(ConfigOption, String)} or {@link
-     *     #getOptional(ConfigOption)}
      */
-    @Deprecated
     public String getString(String key, String defaultValue) {
-        return getRawValue(key).map(ConfigurationUtils::convertToString).orElse(defaultValue);
+        return getRawValue(key)
+                .map(o -> ConfigurationUtils.convertToString(o, standardYaml))
+                .orElse(defaultValue);
     }
 
     /**
@@ -160,7 +184,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param configOption The configuration option
      * @return the (default) value associated with the given config option
+     * @deprecated use {@link #get(ConfigOption)} or {@link #getOptional(ConfigOption)}
      */
+    @Deprecated
     @PublicEvolving
     public String getString(ConfigOption<String> configOption) {
         return getOptional(configOption).orElseGet(configOption::defaultValue);
@@ -173,14 +199,20 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param configOption The configuration option
      * @return the (default) value associated with the given config option
+     * @deprecated use {@link #get(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public String getString(ConfigOption<String> configOption, String overrideDefault) {
         return getOptional(configOption).orElse(overrideDefault);
     }
 
     /**
-     * Adds the given key/value pair to the configuration object.
+     * Adds the given key/value pair to the configuration object. We encourage users and developers
+     * to always use ConfigOption for setting the configurations if possible, for its rich
+     * description, type, default-value and other supports. The string-key-based setter should only
+     * be used when ConfigOption is not applicable, e.g., the key is programmatically generated in
+     * runtime.
      *
      * @param key the key of the key/value pair to be added
      * @param value the value of the key/value pair to be added
@@ -195,7 +227,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the option specifying the key to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public void setString(ConfigOption<String> key, String value) {
         setValueInternal(key.key(), value);
@@ -208,7 +242,8 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param defaultValue the default value which is returned in case there is no value associated
      *     with the given key
      * @return the (default) value associated with the given key
-     * @deprecated use {@link #getInteger(ConfigOption, int)} or {@link #getOptional(ConfigOption)}
+     * @deprecated use {@link #get(ConfigOption)}, {@link #get(ConfigOption, Object)} or {@link
+     *     #getOptional(ConfigOption)}
      */
     @Deprecated
     public int getInteger(String key, int defaultValue) {
@@ -220,7 +255,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param configOption The configuration option
      * @return the (default) value associated with the given config option
+     * @deprecated use {@link #get(ConfigOption)} or {@link #getOptional(ConfigOption)}
      */
+    @Deprecated
     @PublicEvolving
     public int getInteger(ConfigOption<Integer> configOption) {
         return getOptional(configOption).orElseGet(configOption::defaultValue);
@@ -234,7 +271,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param configOption The configuration option
      * @param overrideDefault The value to return if no value was mapper for any key of the option
      * @return the configured value associated with the given config option, or the overrideDefault
+     * @deprecated use {@link #get(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public int getInteger(ConfigOption<Integer> configOption, int overrideDefault) {
         return getOptional(configOption).orElse(overrideDefault);
@@ -245,7 +284,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the key of the key/value pair to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     public void setInteger(String key, int value) {
         setValueInternal(key, value);
     }
@@ -256,7 +297,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the option specifying the key to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public void setInteger(ConfigOption<Integer> key, int value) {
         setValueInternal(key.key(), value);
@@ -269,7 +312,8 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param defaultValue the default value which is returned in case there is no value associated
      *     with the given key
      * @return the (default) value associated with the given key
-     * @deprecated use {@link #getLong(ConfigOption, long)} or {@link #getOptional(ConfigOption)}
+     * @deprecated use {@link #get(ConfigOption)}, {@link #get(ConfigOption, Object)} or {@link
+     *     #getOptional(ConfigOption)}
      */
     @Deprecated
     public long getLong(String key, long defaultValue) {
@@ -281,7 +325,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param configOption The configuration option
      * @return the (default) value associated with the given config option
+     * @deprecated use {@link #get(ConfigOption)} or {@link #getOptional(ConfigOption)}
      */
+    @Deprecated
     @PublicEvolving
     public long getLong(ConfigOption<Long> configOption) {
         return getOptional(configOption).orElseGet(configOption::defaultValue);
@@ -295,7 +341,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param configOption The configuration option
      * @param overrideDefault The value to return if no value was mapper for any key of the option
      * @return the configured value associated with the given config option, or the overrideDefault
+     * @deprecated use {@link #get(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public long getLong(ConfigOption<Long> configOption, long overrideDefault) {
         return getOptional(configOption).orElse(overrideDefault);
@@ -306,7 +354,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the key of the key/value pair to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     public void setLong(String key, long value) {
         setValueInternal(key, value);
     }
@@ -317,7 +367,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the option specifying the key to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public void setLong(ConfigOption<Long> key, long value) {
         setValueInternal(key.key(), value);
@@ -330,7 +382,7 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param defaultValue the default value which is returned in case there is no value associated
      *     with the given key
      * @return the (default) value associated with the given key
-     * @deprecated use {@link #getBoolean(ConfigOption, boolean)} or {@link
+     * @deprecated use {@link #get(ConfigOption)}, {@link #get(ConfigOption, Object)} or {@link
      *     #getOptional(ConfigOption)}
      */
     @Deprecated
@@ -343,7 +395,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param configOption The configuration option
      * @return the (default) value associated with the given config option
+     * @deprecated use {@link #get(ConfigOption)} or {@link #getOptional(ConfigOption)}
      */
+    @Deprecated
     @PublicEvolving
     public boolean getBoolean(ConfigOption<Boolean> configOption) {
         return getOptional(configOption).orElseGet(configOption::defaultValue);
@@ -357,7 +411,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param configOption The configuration option
      * @param overrideDefault The value to return if no value was mapper for any key of the option
      * @return the configured value associated with the given config option, or the overrideDefault
+     * @deprecated use {@link #get(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public boolean getBoolean(ConfigOption<Boolean> configOption, boolean overrideDefault) {
         return getOptional(configOption).orElse(overrideDefault);
@@ -368,7 +424,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the key of the key/value pair to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     public void setBoolean(String key, boolean value) {
         setValueInternal(key, value);
     }
@@ -379,7 +437,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the option specifying the key to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public void setBoolean(ConfigOption<Boolean> key, boolean value) {
         setValueInternal(key.key(), value);
@@ -392,7 +452,8 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param defaultValue the default value which is returned in case there is no value associated
      *     with the given key
      * @return the (default) value associated with the given key
-     * @deprecated use {@link #getFloat(ConfigOption, float)} or {@link #getOptional(ConfigOption)}
+     * @deprecated use {@link #get(ConfigOption)}, {@link #get(ConfigOption, Object)} or {@link
+     *     #getOptional(ConfigOption)}
      */
     @Deprecated
     public float getFloat(String key, float defaultValue) {
@@ -404,7 +465,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param configOption The configuration option
      * @return the (default) value associated with the given config option
+     * @deprecated use {@link #get(ConfigOption)} or {@link #getOptional(ConfigOption)}
      */
+    @Deprecated
     @PublicEvolving
     public float getFloat(ConfigOption<Float> configOption) {
         return getOptional(configOption).orElseGet(configOption::defaultValue);
@@ -418,7 +481,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param configOption The configuration option
      * @param overrideDefault The value to return if no value was mapper for any key of the option
      * @return the configured value associated with the given config option, or the overrideDefault
+     * @deprecated use {@link #get(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public float getFloat(ConfigOption<Float> configOption, float overrideDefault) {
         return getOptional(configOption).orElse(overrideDefault);
@@ -429,7 +494,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the key of the key/value pair to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     public void setFloat(String key, float value) {
         setValueInternal(key, value);
     }
@@ -440,7 +507,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the option specifying the key to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public void setFloat(ConfigOption<Float> key, float value) {
         setValueInternal(key.key(), value);
@@ -453,7 +522,7 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param defaultValue the default value which is returned in case there is no value associated
      *     with the given key
      * @return the (default) value associated with the given key
-     * @deprecated use {@link #getDouble(ConfigOption, double)} or {@link
+     * @deprecated use {@link #get(ConfigOption)}, {@link #get(ConfigOption, Object)} or {@link
      *     #getOptional(ConfigOption)}
      */
     @Deprecated
@@ -466,7 +535,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param configOption The configuration option
      * @return the (default) value associated with the given config option
+     * @deprecated use {@link #get(ConfigOption)} or {@link #getOptional(ConfigOption)}
      */
+    @Deprecated
     @PublicEvolving
     public double getDouble(ConfigOption<Double> configOption) {
         return getOptional(configOption).orElseGet(configOption::defaultValue);
@@ -480,7 +551,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      * @param configOption The configuration option
      * @param overrideDefault The value to return if no value was mapper for any key of the option
      * @return the configured value associated with the given config option, or the overrideDefault
+     * @deprecated use {@link #get(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public double getDouble(ConfigOption<Double> configOption, double overrideDefault) {
         return getOptional(configOption).orElse(overrideDefault);
@@ -491,7 +564,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the key of the key/value pair to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     public void setDouble(String key, double value) {
         setValueInternal(key, value);
     }
@@ -502,7 +577,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
      *
      * @param key the option specifying the key to be added
      * @param value the value of the key/value pair to be added
+     * @deprecated use {@link #set(ConfigOption, Object)}
      */
+    @Deprecated
     @PublicEvolving
     public void setDouble(ConfigOption<Double> key, double value) {
         setValueInternal(key.key(), value);
@@ -718,6 +795,20 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
         return getOptional(option).orElseGet(option::defaultValue);
     }
 
+    /**
+     * Returns the value associated with the given config option as a T. If no value is mapped under
+     * any key of the option, it returns the specified default instead of the option's default
+     * value.
+     *
+     * @param configOption The configuration option
+     * @param overrideDefault The value to return if no value was mapper for any key of the option
+     * @return the configured value associated with the given config option, or the overrideDefault
+     */
+    @PublicEvolving
+    public <T> T get(ConfigOption<T> configOption, T overrideDefault) {
+        return getOptional(configOption).orElse(overrideDefault);
+    }
+
     @Override
     public <T> Optional<T> getOptional(ConfigOption<T> option) {
         Optional<Object> rawValue = getRawValueFromOption(option);
@@ -725,9 +816,9 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
 
         try {
             if (option.isList()) {
-                return rawValue.map(v -> ConfigurationUtils.convertToList(v, clazz));
+                return rawValue.map(v -> ConfigurationUtils.convertToList(v, clazz, standardYaml));
             } else {
-                return rawValue.map(v -> ConfigurationUtils.convertValue(v, clazz));
+                return rawValue.map(v -> ConfigurationUtils.convertValue(v, clazz, standardYaml));
             }
         } catch (Exception e) {
             throw new IllegalArgumentException(
@@ -755,12 +846,41 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
             Map<String, String> ret =
                     CollectionUtil.newHashMapWithExpectedSize(this.confData.size());
             for (Map.Entry<String, Object> entry : confData.entrySet()) {
-                ret.put(entry.getKey(), ConfigurationUtils.convertToString(entry.getValue()));
+                ret.put(
+                        entry.getKey(),
+                        ConfigurationUtils.convertToString(entry.getValue(), standardYaml));
             }
             return ret;
         }
     }
 
+    /**
+     * Convert Config into a {@code Map<String, String>} representation.
+     *
+     * <p>NOTE: This method is extracted from the {@link Configuration#toMap} method and should be
+     * called when Config needs to be written to a file.
+     *
+     * <p>This method ensures the value is properly escaped when writing the key-value pair to a
+     * standard YAML file.
+     */
+    @Internal
+    public Map<String, String> toFileWritableMap() {
+        if (standardYaml) {
+            synchronized (this.confData) {
+                Map<String, String> ret =
+                        CollectionUtil.newHashMapWithExpectedSize(this.confData.size());
+                for (Map.Entry<String, Object> entry : confData.entrySet()) {
+                    // Because some character in standard yaml should be escaped by quotes, such as
+                    // '*', here we should wrap the value by Yaml pattern
+                    ret.put(entry.getKey(), YamlParserUtils.toYAMLString(entry.getValue()));
+                }
+                return ret;
+            }
+        } else {
+            return toMap();
+        }
+    }
+
     /**
      * Removes given config option from the configuration.
      *
@@ -833,7 +953,7 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
                 return Optional.ofNullable(valueFromExactKey);
             }
             final Map<String, String> valueFromPrefixMap =
-                    convertToPropertiesPrefixed(confData, key);
+                    convertToPropertiesPrefixed(confData, key, standardYaml);
             if (valueFromPrefixMap.isEmpty()) {
                 return Optional.empty();
             }
@@ -1007,6 +1127,12 @@ public class Configuration extends ExecutionConfig.GlobalJobParameters
 
     @Override
     public String toString() {
-        return this.confData.toString();
+        return ConfigurationUtils.hideSensitiveValues(
+                        this.confData.entrySet().stream()
+                                .collect(
+                                        Collectors.toMap(
+                                                Map.Entry::getKey,
+                                                entry -> entry.getValue().toString())))
+                .toString();
     }
 }
