@@ -28,6 +28,7 @@ import javax.annotation.Nonnull;
 import java.io.File;
 import java.time.Duration;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Locale;
@@ -54,12 +55,11 @@ public class ConfigurationUtils {
      */
     public static Optional<Time> getSystemResourceMetricsProbingInterval(
             Configuration configuration) {
-        if (!configuration.getBoolean(SYSTEM_RESOURCE_METRICS)) {
+        if (!configuration.get(SYSTEM_RESOURCE_METRICS)) {
             return Optional.empty();
         } else {
             return Optional.of(
-                    Time.milliseconds(
-                            configuration.getLong(SYSTEM_RESOURCE_METRICS_PROBING_INTERVAL)));
+                    Time.milliseconds(configuration.get(SYSTEM_RESOURCE_METRICS_PROBING_INTERVAL)));
         }
     }
 
@@ -72,7 +72,7 @@ public class ConfigurationUtils {
      */
     @Nonnull
     public static String[] parseTempDirectories(Configuration configuration) {
-        return splitPaths(configuration.getString(CoreOptions.TMP_DIRS));
+        return splitPaths(configuration.get(CoreOptions.TMP_DIRS));
     }
 
     /**
@@ -106,44 +106,46 @@ public class ConfigurationUtils {
     @Nonnull
     public static String[] parseLocalStateDirectories(Configuration configuration) {
         String configValue =
-                configuration.getString(
+                configuration.get(
                         CheckpointingOptions.LOCAL_RECOVERY_TASK_MANAGER_STATE_ROOT_DIRS, "");
         return splitPaths(configValue);
     }
 
     /**
-     * Parses a string as a map of strings. The expected format of the map is:
+     * Parses a string as a map of strings. The expected format of the map to be parsed` by FLINK
+     * parser is:
      *
      * <pre>
      * key1:value1,key2:value2
      * </pre>
      *
+     * <p>The expected format of the map to be parsed by standard YAML parser is:
+     *
+     * <pre>
+     * {key1: value1, key2: value2}
+     * </pre>
+     *
      * <p>Parts of the string can be escaped by wrapping with single or double quotes.
      *
      * @param stringSerializedMap a string to parse
      * @return parsed map
      */
-    public static Map<String, String> parseMap(String stringSerializedMap) {
-        return StructuredOptionsSplitter.splitEscaped(stringSerializedMap, ',').stream()
-                .map(p -> StructuredOptionsSplitter.splitEscaped(p, ':'))
-                .collect(
-                        Collectors.toMap(
-                                arr -> arr.get(0), // key name
-                                arr -> arr.get(1) // value
-                                ));
+    public static Map<String, String> parseStringToMap(String stringSerializedMap) {
+        return convertToProperties(stringSerializedMap, GlobalConfiguration.isStandardYaml());
+    }
+
+    public static String parseMapToString(Map<String, String> map) {
+        return convertToString(map, GlobalConfiguration.isStandardYaml());
     }
 
     public static Time getStandaloneClusterStartupPeriodTime(Configuration configuration) {
         final Time timeout;
         long standaloneClusterStartupPeriodTime =
-                configuration.getLong(
-                        ResourceManagerOptions.STANDALONE_CLUSTER_STARTUP_PERIOD_TIME);
+                configuration.get(ResourceManagerOptions.STANDALONE_CLUSTER_STARTUP_PERIOD_TIME);
         if (standaloneClusterStartupPeriodTime >= 0) {
             timeout = Time.milliseconds(standaloneClusterStartupPeriodTime);
         } else {
-            timeout =
-                    Time.milliseconds(
-                            configuration.getLong(JobManagerOptions.SLOT_REQUEST_TIMEOUT));
+            timeout = Time.milliseconds(configuration.get(JobManagerOptions.SLOT_REQUEST_TIMEOUT));
         }
         return timeout;
     }
@@ -199,6 +201,62 @@ public class ConfigurationUtils {
                 : EMPTY;
     }
 
+    /**
+     * Converts the provided configuration data into a format suitable for writing to a file, based
+     * on the {@code flattenYaml} flag and the {@code standardYaml} attribute of the configuration
+     * object.
+     *
+     * <p>Only when {@code flattenYaml} is set to {@code false} and the configuration object is
+     * standard yaml, a nested YAML format is used. Otherwise, a flat key-value pair format is
+     * output.
+     *
+     * <p>Each entry in the returned list represents a single line that can be written directly to a
+     * file.
+     *
+     * <p>Example input (flat map configuration data):
+     *
+     * <pre>{@code
+     * {
+     *      "parent.child": "value1",
+     *      "parent.child2": "value2"
+     * }
+     * }</pre>
+     *
+     * <p>Example output when {@code flattenYaml} is {@code false} and the configuration object is
+     * standard yaml:
+     *
+     * <pre>{@code
+     * parent:
+     *   child: value1
+     *   child2: value2
+     * }</pre>
+     *
+     * <p>Otherwise, the Example output is:
+     *
+     * <pre>{@code
+     * parent.child: value1
+     * parent.child2: value2
+     * }</pre>
+     *
+     * @param configuration The configuration to be converted.
+     * @param flattenYaml A boolean flag indicating if the configuration data should be output in a
+     *     flattened format.
+     * @return A list of strings, where each string represents a line of the file-writable data in
+     *     the chosen format.
+     */
+    public static List<String> convertConfigToWritableLines(
+            Configuration configuration, boolean flattenYaml) {
+        if (configuration.standardYaml && !flattenYaml) {
+            return YamlParserUtils.convertAndDumpYamlFromFlatMap(
+                    Collections.unmodifiableMap(configuration.confData));
+        } else {
+            Map<String, String> fileWritableMap = configuration.toFileWritableMap();
+            return fileWritableMap.entrySet().stream()
+                    .map(entry -> entry.getKey() + ": " + entry.getValue())
+                    .collect(Collectors.toList());
+        }
+    }
+
     /**
      * Creates a dynamic parameter list {@code String} of the passed configuration map.
      *
@@ -313,6 +371,11 @@ public class ConfigurationUtils {
      */
     @SuppressWarnings("unchecked")
     public static <T> T convertValue(Object rawValue, Class<?> clazz) {
+        return convertValue(rawValue, clazz, GlobalConfiguration.isStandardYaml());
+    }
+
+    @SuppressWarnings("unchecked")
+    public static <T> T convertValue(Object rawValue, Class<?> clazz, boolean standardYaml) {
         if (Integer.class.equals(clazz)) {
             return (T) convertToInt(rawValue);
         } else if (Long.class.equals(clazz)) {
@@ -324,7 +387,7 @@ public class ConfigurationUtils {
         } else if (Double.class.equals(clazz)) {
             return (T) convertToDouble(rawValue);
         } else if (String.class.equals(clazz)) {
-            return (T) convertToString(rawValue);
+            return (T) convertToString(rawValue, standardYaml);
         } else if (clazz.isEnum()) {
             return (T) convertToEnum(rawValue, (Class<? extends Enum<?>>) clazz);
         } else if (clazz == Duration.class) {
@@ -332,44 +395,94 @@ public class ConfigurationUtils {
         } else if (clazz == MemorySize.class) {
             return (T) convertToMemorySize(rawValue);
         } else if (clazz == Map.class) {
-            return (T) convertToProperties(rawValue);
+            return (T) convertToProperties(rawValue, standardYaml);
         }
 
         throw new IllegalArgumentException("Unsupported type: " + clazz);
     }
 
     @SuppressWarnings("unchecked")
-    static <T> T convertToList(Object rawValue, Class<?> atomicClass) {
+    static <T> T convertToList(Object rawValue, Class<?> atomicClass, boolean standardYaml) {
         if (rawValue instanceof List) {
             return (T) rawValue;
+        } else if (standardYaml) {
+            try {
+                List<Object> data =
+                        YamlParserUtils.convertToObject(rawValue.toString(), List.class);
+                // The Yaml parser conversion results in data of type List<Map<Object, Object>>,
+                // such as List<Map<Object, Boolean>>. However, ConfigOption currently requires that
+                // the data for Map type be strictly of the type Map<String, String>. Therefore, we
+                // convert each map in the list to Map<String, String>.
+                if (atomicClass == Map.class) {
+                    return (T)
+                            data.stream()
+                                    .map(map -> convertToStringMap((Map<Object, Object>) map, true))
+                                    .collect(Collectors.toList());
+                }
+
+                return (T)
+                        data.stream()
+                                .map(s -> convertValue(s, atomicClass, true))
+                                .collect(Collectors.toList());
+            } catch (Exception e) {
+                // Fallback to legacy pattern
+                return convertToListWithLegacyProperties(rawValue, atomicClass);
+            }
         } else {
-            return (T)
-                    StructuredOptionsSplitter.splitEscaped(rawValue.toString(), ';').stream()
-                            .map(s -> convertValue(s, atomicClass))
-                            .collect(Collectors.toList());
+            return convertToListWithLegacyProperties(rawValue, atomicClass);
         }
     }
 
+    @Nonnull
+    private static <T> T convertToListWithLegacyProperties(Object rawValue, Class<?> atomicClass) {
+        return (T)
+                StructuredOptionsSplitter.splitEscaped(rawValue.toString(), ';').stream()
+                        .map(s -> convertValue(s, atomicClass, false))
+                        .collect(Collectors.toList());
+    }
+
     @SuppressWarnings("unchecked")
-    static Map<String, String> convertToProperties(Object o) {
+    static Map<String, String> convertToProperties(Object o, boolean standardYaml) {
         if (o instanceof Map) {
             return (Map<String, String>) o;
+        } else if (standardYaml) {
+            try {
+                Map<Object, Object> map = YamlParserUtils.convertToObject(o.toString(), Map.class);
+                return convertToStringMap(map, true);
+            } catch (Exception e) {
+                // Fallback to legacy pattern
+                return convertToPropertiesWithLegacyPattern(o);
+            }
         } else {
-            List<String> listOfRawProperties =
-                    StructuredOptionsSplitter.splitEscaped(o.toString(), ',');
-            return listOfRawProperties.stream()
-                    .map(s -> StructuredOptionsSplitter.splitEscaped(s, ':'))
-                    .peek(
-                            pair -> {
-                                if (pair.size() != 2) {
-                                    throw new IllegalArgumentException(
-                                            "Map item is not a key-value pair (missing ':'?)");
-                                }
-                            })
-                    .collect(Collectors.toMap(a -> a.get(0), a -> a.get(1)));
+            return convertToPropertiesWithLegacyPattern(o);
         }
     }
 
+    @Nonnull
+    private static Map<String, String> convertToPropertiesWithLegacyPattern(Object o) {
+        List<String> listOfRawProperties =
+                StructuredOptionsSplitter.splitEscaped(o.toString(), ',');
+        return listOfRawProperties.stream()
+                .map(s -> StructuredOptionsSplitter.splitEscaped(s, ':'))
+                .peek(
+                        pair -> {
+                            if (pair.size() != 2) {
+                                throw new IllegalArgumentException(
+                                        "Map item is not a key-value pair (missing ':'?)");
+                            }
+                        })
+                .collect(Collectors.toMap(a -> a.get(0), a -> a.get(1)));
+    }
+
+    private static Map<String, String> convertToStringMap(
+            Map<Object, Object> map, boolean standardYaml) {
+        return map.entrySet().stream()
+                .collect(
+                        Collectors.toMap(
+                                entry -> convertToString(entry.getKey(), standardYaml),
+                                entry -> convertToString(entry.getValue(), standardYaml)));
+    }
+
     @SuppressWarnings("unchecked")
     public static <E extends Enum<?>> E convertToEnum(Object o, Class<E> clazz) {
         if (o.getClass().equals(clazz)) {
@@ -407,7 +520,15 @@ public class ConfigurationUtils {
         return MemorySize.parse(o.toString());
     }
 
-    static String convertToString(Object o) {
+    static String convertToString(Object o, boolean standardYaml) {
+        if (standardYaml) {
+            if (o.getClass() == String.class) {
+                return (String) o;
+            } else {
+                return YamlParserUtils.toYAMLString(o);
+            }
+        }
+
         if (o.getClass() == String.class) {
             return (String) o;
         } else if (o.getClass() == Duration.class) {
@@ -416,7 +537,7 @@ public class ConfigurationUtils {
         } else if (o instanceof List) {
             return ((List<?>) o)
                     .stream()
-                            .map(e -> escapeWithSingleQuote(convertToString(e), ";"))
+                            .map(e -> escapeWithSingleQuote(convertToString(e, false), ";"))
                             .collect(Collectors.joining(";"));
         } else if (o instanceof Map) {
             return ((Map<?, ?>) o)
@@ -544,14 +665,14 @@ public class ConfigurationUtils {
     }
 
     static Map<String, String> convertToPropertiesPrefixed(
-            Map<String, Object> confData, String key) {
+            Map<String, Object> confData, String key, boolean standardYaml) {
         final String prefixKey = key + ".";
         return confData.keySet().stream()
                 .filter(k -> k.startsWith(prefixKey))
                 .collect(
                         Collectors.toMap(
                                 k -> k.substring(prefixKey.length()),
-                                k -> convertToString(confData.get(k))));
+                                k -> convertToString(confData.get(k), standardYaml)));
     }
 
     static boolean containsPrefixMap(Map<String, Object> confData, String key) {
