@@ -44,7 +44,7 @@ public class StateBackendOptions {
     public static final ConfigOption<String> STATE_BACKEND =
             ConfigOptions.key("state.backend.type")
                     .stringType()
-                    .noDefaultValue()
+                    .defaultValue("hashmap")
                     .withDeprecatedKeys("state.backend")
                     .withDescription(
                             Description.builder()
