@@ -20,8 +20,10 @@ package org.apache.flink.configuration;
 
 import org.apache.flink.annotation.PublicEvolving;
 import org.apache.flink.annotation.docs.Documentation;
+import org.apache.flink.configuration.description.Description;
 
 import static org.apache.flink.configuration.ConfigOptions.key;
+import static org.apache.flink.configuration.description.TextElement.code;
 
 /** Configuration options for the WebMonitorEndpoint. */
 @PublicEvolving
@@ -31,6 +33,7 @@ public class WebOptions {
     @Deprecated
     public static final ConfigOption<String> ADDRESS =
             key("web.address")
+                    .stringType()
                     .noDefaultValue()
                     .withDeprecatedKeys("jobmanager.web.address")
                     .withDescription("Address for runtime monitor web-frontend server.");
@@ -42,7 +45,7 @@ public class WebOptions {
      */
     @Deprecated
     public static final ConfigOption<Integer> PORT =
-            key("web.port").defaultValue(8081).withDeprecatedKeys("jobmanager.web.port");
+            key("web.port").intType().defaultValue(8081).withDeprecatedKeys("jobmanager.web.port");
 
     /**
      * The config parameter defining the Access-Control-Allow-Origin header for all responses from
@@ -50,6 +53,7 @@ public class WebOptions {
      */
     public static final ConfigOption<String> ACCESS_CONTROL_ALLOW_ORIGIN =
             key("web.access-control-allow-origin")
+                    .stringType()
                     .defaultValue("*")
                     .withDeprecatedKeys("jobmanager.web.access-control-allow-origin")
                     .withDescription(
@@ -58,6 +62,7 @@ public class WebOptions {
     /** The config parameter defining the refresh interval for the web-frontend in milliseconds. */
     public static final ConfigOption<Long> REFRESH_INTERVAL =
             key("web.refresh-interval")
+                    .longType()
                     .defaultValue(3000L)
                     .withDeprecatedKeys("jobmanager.web.refresh-interval")
                     .withDescription("Refresh interval for the web-frontend in milliseconds.");
@@ -66,6 +71,7 @@ public class WebOptions {
     @Deprecated
     public static final ConfigOption<Boolean> SSL_ENABLED =
             key("web.ssl.enabled")
+                    .booleanType()
                     .defaultValue(true)
                     .withDeprecatedKeys("jobmanager.web.ssl.enabled")
                     .withDescription(
@@ -75,9 +81,11 @@ public class WebOptions {
     @Documentation.OverrideDefault("System.getProperty(\"java.io.tmpdir\")")
     public static final ConfigOption<String> TMP_DIR =
             key("web.tmpdir")
+                    .stringType()
                     .defaultValue(System.getProperty("java.io.tmpdir"))
                     .withDeprecatedKeys("jobmanager.web.tmpdir")
-                    .withDescription("Flink web directory which is used by the webmonitor.");
+                    .withDescription(
+                            "Local directory that is used by the REST API for temporary files.");
 
     /**
      * The config parameter defining the directory for uploading the job jars. If not specified a
@@ -85,15 +93,21 @@ public class WebOptions {
      */
     public static final ConfigOption<String> UPLOAD_DIR =
             key("web.upload.dir")
+                    .stringType()
                     .noDefaultValue()
                     .withDeprecatedKeys("jobmanager.web.upload.dir")
                     .withDescription(
-                            "Directory for uploading the job jars. If not specified a dynamic directory will be used"
-                                    + " under the directory specified by JOB_MANAGER_WEB_TMPDIR_KEY.");
+                            Description.builder()
+                                    .text(
+                                            "Local directory that is used by the REST API for storing uploaded jars. If not specified a dynamic directory will be created"
+                                                    + " under %s.",
+                                            code(TMP_DIR.key()))
+                                    .build());
 
     /** The config parameter defining the number of archived jobs for the JobManager. */
     public static final ConfigOption<Integer> ARCHIVE_COUNT =
             key("web.history")
+                    .intType()
                     .defaultValue(5)
                     .withDeprecatedKeys("jobmanager.web.history")
                     .withDescription("Number of archived jobs for the JobManager.");
@@ -104,6 +118,7 @@ public class WebOptions {
      */
     public static final ConfigOption<String> LOG_PATH =
             key("web.log.path")
+                    .stringType()
                     .noDefaultValue()
                     .withDeprecatedKeys("jobmanager.web.log.path")
                     .withDescription(
@@ -112,12 +127,13 @@ public class WebOptions {
     /** Config parameter indicating whether jobs can be uploaded and run from the web-frontend. */
     public static final ConfigOption<Boolean> SUBMIT_ENABLE =
             key("web.submit.enable")
+                    .booleanType()
                     .defaultValue(true)
                     .withDeprecatedKeys("jobmanager.web.submit.enable")
                     .withDescription(
                             "Flag indicating whether jobs can be uploaded and run from the web-frontend.");
 
-    /** Config parameter indicating whether jobs can be cancel from the web-frontend. */
+    /** Config parameter indicating whether jobs can be canceled from the web-frontend. */
     public static final ConfigOption<Boolean> CANCEL_ENABLE =
             key("web.cancel.enable")
                     .booleanType()
@@ -125,9 +141,18 @@ public class WebOptions {
                     .withDescription(
                             "Flag indicating whether jobs can be canceled from the web-frontend.");
 
+    /** Config parameter indicating whether jobs can be rescaled from the web-frontend. */
+    public static final ConfigOption<Boolean> RESCALE_ENABLE =
+            key("web.rescale.enable")
+                    .booleanType()
+                    .defaultValue(true)
+                    .withDescription(
+                            "Flag indicating whether jobs can be rescaled from the web-frontend.");
+
     /** Config parameter defining the number of checkpoints to remember for recent history. */
     public static final ConfigOption<Integer> CHECKPOINTS_HISTORY_SIZE =
             key("web.checkpoints.history")
+                    .intType()
                     .defaultValue(10)
                     .withDeprecatedKeys("jobmanager.web.checkpoints.history")
                     .withDescription("Number of checkpoints to remember for recent history.");
@@ -146,6 +171,7 @@ public class WebOptions {
     @Deprecated
     public static final ConfigOption<Integer> BACKPRESSURE_CLEANUP_INTERVAL =
             key("web.backpressure.cleanup-interval")
+                    .intType()
                     .defaultValue(10 * 60 * 1000)
                     .withDeprecatedKeys("jobmanager.web.backpressure.cleanup-interval")
                     .withDescription("This config option is no longer used");
@@ -154,6 +180,7 @@ public class WebOptions {
     @Deprecated
     public static final ConfigOption<Integer> BACKPRESSURE_REFRESH_INTERVAL =
             key("web.backpressure.refresh-interval")
+                    .intType()
                     .defaultValue(60 * 1000)
                     .withDeprecatedKeys("jobmanager.web.backpressure.refresh-interval")
                     .withDescription("This config option is no longer used");
@@ -162,6 +189,7 @@ public class WebOptions {
     @Deprecated
     public static final ConfigOption<Integer> BACKPRESSURE_NUM_SAMPLES =
             key("web.backpressure.num-samples")
+                    .intType()
                     .defaultValue(100)
                     .withDeprecatedKeys("jobmanager.web.backpressure.num-samples")
                     .withDescription("This config option is no longer used");
@@ -170,6 +198,7 @@ public class WebOptions {
     @Deprecated
     public static final ConfigOption<Integer> BACKPRESSURE_DELAY =
             key("web.backpressure.delay-between-samples")
+                    .intType()
                     .defaultValue(50)
                     .withDeprecatedKeys("jobmanager.web.backpressure.delay-between-samples")
                     .withDescription("This config option is no longer used");
@@ -177,6 +206,7 @@ public class WebOptions {
     /** Timeout for asynchronous operations by the web monitor in milliseconds. */
     public static final ConfigOption<Long> TIMEOUT =
             key("web.timeout")
+                    .longType()
                     .defaultValue(10L * 60L * 1000L)
                     .withDescription(
                             "Timeout for asynchronous operations by the web monitor in milliseconds.");
