@@ -20,6 +20,7 @@ package org.apache.flink.api.common.io;
 
 import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.TaskInfo;
+import org.apache.flink.api.common.TaskInfoImpl;
 import org.apache.flink.api.common.accumulators.Accumulator;
 import org.apache.flink.api.common.functions.util.RuntimeUDFContext;
 import org.apache.flink.core.fs.Path;
@@ -33,13 +34,13 @@ import java.util.concurrent.Future;
 
 import static org.junit.Assert.assertEquals;
 
-/** Tests runtime context access from inside an RichInputFormat class */
+/** Tests runtime context access from inside an RichInputFormat class. */
 public class RichInputFormatTest {
 
     @Test
     public void testCheckRuntimeContextAccess() {
         final SerializedInputFormat<Value> inputFormat = new SerializedInputFormat<Value>();
-        final TaskInfo taskInfo = new TaskInfo("test name", 3, 1, 3, 0);
+        final TaskInfo taskInfo = new TaskInfoImpl("test name", 3, 1, 3, 0);
         inputFormat.setRuntimeContext(
                 new RuntimeUDFContext(
                         taskInfo,
@@ -49,7 +50,8 @@ public class RichInputFormatTest {
                         new HashMap<String, Accumulator<?, ?>>(),
                         UnregisteredMetricsGroup.createOperatorMetricGroup()));
 
-        assertEquals(inputFormat.getRuntimeContext().getIndexOfThisSubtask(), 1);
-        assertEquals(inputFormat.getRuntimeContext().getNumberOfParallelSubtasks(), 3);
+        assertEquals(inputFormat.getRuntimeContext().getTaskInfo().getIndexOfThisSubtask(), 1);
+        assertEquals(
+                inputFormat.getRuntimeContext().getTaskInfo().getNumberOfParallelSubtasks(), 3);
     }
 }
