@@ -20,13 +20,14 @@ package org.apache.flink.api.common.operators.base;
 
 import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.TaskInfo;
+import org.apache.flink.api.common.TaskInfoImpl;
 import org.apache.flink.api.common.accumulators.Accumulator;
 import org.apache.flink.api.common.functions.FlatJoinFunction;
+import org.apache.flink.api.common.functions.OpenContext;
 import org.apache.flink.api.common.functions.RichFlatJoinFunction;
 import org.apache.flink.api.common.functions.util.RuntimeUDFContext;
 import org.apache.flink.api.common.operators.BinaryOperatorInformation;
 import org.apache.flink.api.common.typeinfo.BasicTypeInfo;
-import org.apache.flink.configuration.Configuration;
 import org.apache.flink.core.fs.Path;
 import org.apache.flink.metrics.groups.UnregisteredMetricsGroup;
 import org.apache.flink.util.Collector;
@@ -45,6 +46,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
+/** The test for inner join operator. */
 @SuppressWarnings("serial")
 public class InnerJoinOperatorBaseTest implements Serializable {
 
@@ -104,10 +106,11 @@ public class InnerJoinOperatorBaseTest implements Serializable {
         final RichFlatJoinFunction<String, String, Integer> joiner =
                 new RichFlatJoinFunction<String, String, Integer>() {
                     @Override
-                    public void open(Configuration parameters) throws Exception {
+                    public void open(OpenContext openContext) throws Exception {
                         opened.compareAndSet(false, true);
-                        assertEquals(0, getRuntimeContext().getIndexOfThisSubtask());
-                        assertEquals(1, getRuntimeContext().getNumberOfParallelSubtasks());
+                        assertEquals(0, getRuntimeContext().getTaskInfo().getIndexOfThisSubtask());
+                        assertEquals(
+                                1, getRuntimeContext().getTaskInfo().getNumberOfParallelSubtasks());
                     }
 
                     @Override
@@ -146,7 +149,7 @@ public class InnerJoinOperatorBaseTest implements Serializable {
         final List<Integer> expected = new ArrayList<Integer>(Arrays.asList(3, 3, 6, 6));
 
         try {
-            final TaskInfo taskInfo = new TaskInfo(taskName, 1, 0, 1, 0);
+            final TaskInfo taskInfo = new TaskInfoImpl(taskName, 1, 0, 1, 0);
             final HashMap<String, Accumulator<?, ?>> accumulatorMap =
                     new HashMap<String, Accumulator<?, ?>>();
             final HashMap<String, Future<Path>> cpTasks = new HashMap<>();
