@@ -19,6 +19,7 @@
 package org.apache.flink.api.java.typeutils;
 
 import org.apache.flink.api.common.ExecutionConfig;
+import org.apache.flink.api.common.serialization.SerializerConfig;
 import org.apache.flink.api.common.typeinfo.BasicTypeInfo;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.common.typeutils.TypeInformationTestBase;
@@ -52,10 +53,15 @@ class TupleTypeInfoTest extends TypeInformationTestBase<TupleTypeInfo<?>> {
                     private static final long serialVersionUID = -7985593598027660836L;
 
                     @Override
-                    public TypeSerializer<Tuple1> createSerializer(ExecutionConfig config) {
+                    public TypeSerializer<Tuple1> createSerializer(SerializerConfig config) {
                         return null;
                     }
 
+                    @Override
+                    public TypeSerializer<Tuple1> createSerializer(ExecutionConfig config) {
+                        return createSerializer(config.getSerializerConfig());
+                    }
+
                     @Override
                     protected TypeComparatorBuilder<Tuple1> createTypeComparatorBuilder() {
                         return null;
