@@ -18,7 +18,7 @@
 
 package org.apache.flink.api.java.typeutils.runtime;
 
-import org.apache.flink.api.common.ExecutionConfig;
+import org.apache.flink.api.common.serialization.SerializerConfigImpl;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.common.typeutils.SerializerTestBase;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
@@ -38,7 +38,7 @@ class PojoSubclassSerializerTest
     @Override
     protected TypeSerializer<TestUserClassBase> createSerializer() {
         // only register one of the three child classes, the third child class is NO POJO
-        ExecutionConfig conf = new ExecutionConfig();
+        SerializerConfigImpl conf = new SerializerConfigImpl();
         conf.registerPojoType(TestUserClass1.class);
         TypeSerializer<TestUserClassBase> serializer = type.createSerializer(conf);
         assert (serializer instanceof PojoSerializer);
