@@ -18,36 +18,42 @@
 
 package org.apache.flink.configuration;
 
+import org.apache.flink.testutils.junit.extensions.parameterized.Parameter;
+import org.apache.flink.testutils.junit.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.flink.testutils.junit.extensions.parameterized.Parameters;
 import org.apache.flink.util.ExceptionUtils;
 import org.apache.flink.util.InstantiationUtil;
-import org.apache.flink.util.TestLogger;
 
 import org.assertj.core.api.Assertions;
-import org.junit.Test;
+import org.assertj.core.data.Offset;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import java.time.Duration;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
 
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
-import static org.hamcrest.Matchers.containsInAnyOrder;
-import static org.hamcrest.Matchers.containsString;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.fail;
 
 /**
  * This class contains test for the configuration package. In particular, the serialization of
  * {@link Configuration} objects is tested.
  */
-public class ConfigurationTest extends TestLogger {
+@ExtendWith(ParameterizedTestExtension.class)
+public class ConfigurationTest {
+
+    @Parameter public boolean standardYaml;
+
+    @Parameters(name = "standardYaml: {0}")
+    public static Collection<Boolean> parameters() {
+        return Arrays.asList(true, false);
+    }
 
     private static final ConfigOption<String> STRING_OPTION =
             ConfigOptions.key("test-string-key").stringType().noDefaultValue();
@@ -73,10 +79,10 @@ public class ConfigurationTest extends TestLogger {
     private static final String MAP_PROPERTY_2 = MAP_OPTION.key() + ".prop2";
 
     /** This test checks the serialization/deserialization of configuration objects. */
-    @Test
-    public void testConfigurationSerializationAndGetters() {
+    @TestTemplate
+    void testConfigurationSerializationAndGetters() {
         try {
-            final Configuration orig = new Configuration();
+            final Configuration orig = new Configuration(standardYaml);
             orig.setString("mykey", "myvalue");
             orig.setInteger("mynumber", 100);
             orig.setLong("longvalue", 478236947162389746L);
@@ -87,18 +93,19 @@ public class ConfigurationTest extends TestLogger {
             orig.setClass("myclass", this.getClass());
 
             final Configuration copy = InstantiationUtil.createCopyWritable(orig);
-            assertEquals("myvalue", copy.getString("mykey", "null"));
-            assertEquals(100, copy.getInteger("mynumber", 0));
-            assertEquals(478236947162389746L, copy.getLong("longvalue", 0L));
-            assertEquals(3.1415926f, copy.getFloat("PI", 3.1415926f), 0.0);
-            assertEquals(Math.E, copy.getDouble("E", 0.0), 0.0);
-            assertEquals(true, copy.getBoolean("shouldbetrue", false));
-            assertArrayEquals(new byte[] {1, 2, 3, 4, 5}, copy.getBytes("bytes sequence", null));
-            assertEquals(getClass(), copy.getClass("myclass", null, getClass().getClassLoader()));
+            assertThat("myvalue").isEqualTo(copy.getString("mykey", "null"));
+            assertThat(copy.getInteger("mynumber", 0)).isEqualTo(100);
+            assertThat(478236947162389746L).isEqualTo(copy.getLong("longvalue", 0L));
+            assertThat(3.1415926f).isCloseTo(copy.getFloat("PI", 3.1415926f), Offset.offset(0.0f));
+            assertThat(Math.E).isCloseTo(copy.getDouble("E", 0.0), Offset.offset(0.0));
+            assertThat(copy.getBoolean("shouldbetrue", false)).isTrue();
+            assertThat(new byte[] {1, 2, 3, 4, 5}).isEqualTo(copy.getBytes("bytes sequence", null));
+            assertThat(getClass())
+                    .isEqualTo(copy.getClass("myclass", null, getClass().getClassLoader()));
 
-            assertEquals(orig, copy);
-            assertEquals(orig.keySet(), copy.keySet());
-            assertEquals(orig.hashCode(), copy.hashCode());
+            assertThat(orig).isEqualTo(copy);
+            assertThat(orig.keySet()).isEqualTo(copy.keySet());
+            assertThat(orig.hashCode()).isEqualTo(copy.hashCode());
 
         } catch (Exception e) {
             e.printStackTrace();
@@ -106,27 +113,27 @@ public class ConfigurationTest extends TestLogger {
         }
     }
 
-    @Test
-    public void testCopyConstructor() {
+    @TestTemplate
+    void testCopyConstructor() {
         try {
             final String key = "theKey";
 
-            Configuration cfg1 = new Configuration();
+            Configuration cfg1 = new Configuration(standardYaml);
             cfg1.setString(key, "value");
 
             Configuration cfg2 = new Configuration(cfg1);
             cfg2.setString(key, "another value");
 
-            assertEquals("value", cfg1.getString(key, ""));
+            assertThat("value").isEqualTo(cfg1.getString(key, ""));
         } catch (Exception e) {
             e.printStackTrace();
             fail(e.getMessage());
         }
     }
 
-    @Test
-    public void testOptionWithDefault() {
-        Configuration cfg = new Configuration();
+    @TestTemplate
+    void testOptionWithDefault() {
+        Configuration cfg = new Configuration(standardYaml);
         cfg.setInteger("int-key", 11);
         cfg.setString("string-key", "abc");
 
@@ -135,11 +142,11 @@ public class ConfigurationTest extends TestLogger {
         ConfigOption<Integer> presentIntOption =
                 ConfigOptions.key("int-key").intType().defaultValue(87);
 
-        assertEquals("abc", cfg.getString(presentStringOption));
-        assertEquals("abc", cfg.getValue(presentStringOption));
+        assertThat("abc").isEqualTo(cfg.getString(presentStringOption));
+        assertThat("abc").isEqualTo(cfg.getValue(presentStringOption));
 
-        assertEquals(11, cfg.getInteger(presentIntOption));
-        assertEquals("11", cfg.getValue(presentIntOption));
+        assertThat(11).isEqualTo(cfg.getInteger(presentIntOption));
+        assertThat("11").isEqualTo(cfg.getValue(presentIntOption));
 
         // test getting default when no value is present
 
@@ -148,44 +155,44 @@ public class ConfigurationTest extends TestLogger {
         ConfigOption<Integer> intOption = ConfigOptions.key("test2").intType().defaultValue(87);
 
         // getting strings with default value should work
-        assertEquals("my-beautiful-default", cfg.getValue(stringOption));
-        assertEquals("my-beautiful-default", cfg.getString(stringOption));
+        assertThat("my-beautiful-default").isEqualTo(cfg.getValue(stringOption));
+        assertThat("my-beautiful-default").isEqualTo(cfg.getString(stringOption));
 
         // overriding the default should work
-        assertEquals("override", cfg.getString(stringOption, "override"));
+        assertThat("override").isEqualTo(cfg.getString(stringOption, "override"));
 
         // getting a primitive with a default value should work
-        assertEquals(87, cfg.getInteger(intOption));
-        assertEquals("87", cfg.getValue(intOption));
+        assertThat(87).isEqualTo(cfg.getInteger(intOption));
+        assertThat("87").isEqualTo(cfg.getValue(intOption));
     }
 
-    @Test
-    public void testOptionWithNoDefault() {
-        Configuration cfg = new Configuration();
+    @TestTemplate
+    void testOptionWithNoDefault() {
+        Configuration cfg = new Configuration(standardYaml);
         cfg.setInteger("int-key", 11);
         cfg.setString("string-key", "abc");
 
         ConfigOption<String> presentStringOption =
                 ConfigOptions.key("string-key").stringType().noDefaultValue();
 
-        assertEquals("abc", cfg.getString(presentStringOption));
-        assertEquals("abc", cfg.getValue(presentStringOption));
+        assertThat("abc").isEqualTo(cfg.getString(presentStringOption));
+        assertThat("abc").isEqualTo(cfg.getValue(presentStringOption));
 
         // test getting default when no value is present
 
         ConfigOption<String> stringOption = ConfigOptions.key("test").stringType().noDefaultValue();
 
         // getting strings for null should work
-        assertNull(cfg.getValue(stringOption));
-        assertNull(cfg.getString(stringOption));
+        assertThat(cfg.getValue(stringOption)).isNull();
+        assertThat(cfg.getString(stringOption)).isNull();
 
         // overriding the null default should work
-        assertEquals("override", cfg.getString(stringOption, "override"));
+        assertThat("override").isEqualTo(cfg.getString(stringOption, "override"));
     }
 
-    @Test
-    public void testDeprecatedKeys() {
-        Configuration cfg = new Configuration();
+    @TestTemplate
+    void testDeprecatedKeys() {
+        Configuration cfg = new Configuration(standardYaml);
         cfg.setInteger("the-key", 11);
         cfg.setInteger("old-key", 12);
         cfg.setInteger("older-key", 13);
@@ -214,15 +221,15 @@ public class ConfigurationTest extends TestLogger {
                         .defaultValue(-1)
                         .withDeprecatedKeys("not-there", "also-not-there");
 
-        assertEquals(11, cfg.getInteger(matchesFirst));
-        assertEquals(12, cfg.getInteger(matchesSecond));
-        assertEquals(13, cfg.getInteger(matchesThird));
-        assertEquals(-1, cfg.getInteger(notContained));
+        assertThat(11).isEqualTo(cfg.getInteger(matchesFirst));
+        assertThat(12).isEqualTo(cfg.getInteger(matchesSecond));
+        assertThat(13).isEqualTo(cfg.getInteger(matchesThird));
+        assertThat(-1).isEqualTo(cfg.getInteger(notContained));
     }
 
-    @Test
-    public void testFallbackKeys() {
-        Configuration cfg = new Configuration();
+    @TestTemplate
+    void testFallbackKeys() {
+        Configuration cfg = new Configuration(standardYaml);
         cfg.setInteger("the-key", 11);
         cfg.setInteger("old-key", 12);
         cfg.setInteger("older-key", 13);
@@ -251,14 +258,14 @@ public class ConfigurationTest extends TestLogger {
                         .defaultValue(-1)
                         .withFallbackKeys("not-there", "also-not-there");
 
-        assertEquals(11, cfg.getInteger(matchesFirst));
-        assertEquals(12, cfg.getInteger(matchesSecond));
-        assertEquals(13, cfg.getInteger(matchesThird));
-        assertEquals(-1, cfg.getInteger(notContained));
+        assertThat(11).isEqualTo(cfg.getInteger(matchesFirst));
+        assertThat(12).isEqualTo(cfg.getInteger(matchesSecond));
+        assertThat(13).isEqualTo(cfg.getInteger(matchesThird));
+        assertThat(-1).isEqualTo(cfg.getInteger(notContained));
     }
 
-    @Test
-    public void testFallbackAndDeprecatedKeys() {
+    @TestTemplate
+    void testFallbackAndDeprecatedKeys() {
         final ConfigOption<Integer> fallback =
                 ConfigOptions.key("fallback").intType().defaultValue(-1);
 
@@ -272,13 +279,13 @@ public class ConfigurationTest extends TestLogger {
                         .withFallbackKeys(fallback.key())
                         .withDeprecatedKeys(deprecated.key());
 
-        final Configuration fallbackCfg = new Configuration();
+        final Configuration fallbackCfg = new Configuration(standardYaml);
         fallbackCfg.setInteger(fallback, 1);
-        assertEquals(1, fallbackCfg.getInteger(mainOption));
+        assertThat(fallbackCfg.getInteger(mainOption)).isOne();
 
-        final Configuration deprecatedCfg = new Configuration();
+        final Configuration deprecatedCfg = new Configuration(standardYaml);
         deprecatedCfg.setInteger(deprecated, 2);
-        assertEquals(2, deprecatedCfg.getInteger(mainOption));
+        assertThat(deprecatedCfg.getInteger(mainOption)).isEqualTo(2);
 
         // reverse declaration of fallback and deprecated keys, fallback keys should always be used
         // first
@@ -289,16 +296,16 @@ public class ConfigurationTest extends TestLogger {
                         .withDeprecatedKeys(deprecated.key())
                         .withFallbackKeys(fallback.key());
 
-        final Configuration deprecatedAndFallBackConfig = new Configuration();
+        final Configuration deprecatedAndFallBackConfig = new Configuration(standardYaml);
         deprecatedAndFallBackConfig.setInteger(fallback, 1);
         deprecatedAndFallBackConfig.setInteger(deprecated, 2);
-        assertEquals(1, deprecatedAndFallBackConfig.getInteger(mainOption));
-        assertEquals(1, deprecatedAndFallBackConfig.getInteger(reversedMainOption));
+        assertThat(deprecatedAndFallBackConfig.getInteger(mainOption)).isOne();
+        assertThat(deprecatedAndFallBackConfig.getInteger(reversedMainOption)).isOne();
     }
 
-    @Test
-    public void testRemove() {
-        Configuration cfg = new Configuration();
+    @TestTemplate
+    void testRemove() {
+        Configuration cfg = new Configuration(standardYaml);
         cfg.setInteger("a", 1);
         cfg.setInteger("b", 2);
 
@@ -310,17 +317,21 @@ public class ConfigurationTest extends TestLogger {
         ConfigOption<Integer> unexistedOption =
                 ConfigOptions.key("e").intType().defaultValue(-1).withDeprecatedKeys("f", "g", "j");
 
-        assertEquals("Wrong expectation about size", cfg.keySet().size(), 2);
-        assertTrue("Expected 'validOption' is removed", cfg.removeConfig(validOption));
-        assertEquals("Wrong expectation about size", cfg.keySet().size(), 1);
-        assertTrue("Expected 'existedOption' is removed", cfg.removeConfig(deprecatedOption));
-        assertEquals("Wrong expectation about size", cfg.keySet().size(), 0);
-        assertFalse("Expected 'unexistedOption' is not removed", cfg.removeConfig(unexistedOption));
+        assertThat(cfg.keySet()).hasSize(2).as("Wrong expectation about size");
+        assertThat(cfg.removeConfig(validOption)).isTrue().as("Expected 'validOption' is removed");
+        assertThat(cfg.keySet()).hasSize(1).as("Wrong expectation about size");
+        assertThat(cfg.removeConfig(deprecatedOption))
+                .isTrue()
+                .as("Expected 'existedOption' is removed");
+        assertThat(cfg.keySet()).hasSize(0).as("Wrong expectation about size");
+        assertThat(cfg.removeConfig(unexistedOption))
+                .isFalse()
+                .as("Expected 'unexistedOption' is not removed");
     }
 
-    @Test
-    public void testRemoveKey() {
-        Configuration cfg = new Configuration();
+    @TestTemplate
+    void testRemoveKey() {
+        Configuration cfg = new Configuration(standardYaml);
         String key1 = "a.b";
         String key2 = "c.d";
         cfg.setInteger(key1, 42);
@@ -329,35 +340,35 @@ public class ConfigurationTest extends TestLogger {
         cfg.setInteger(key2 + ".f2", 44);
         cfg.setInteger("e.f", 1337);
 
-        assertFalse(cfg.removeKey("not-existing-key"));
-        assertTrue(cfg.removeKey(key1));
-        assertFalse(cfg.containsKey(key1));
+        assertThat(cfg.removeKey("not-existing-key")).isFalse();
+        assertThat(cfg.removeKey(key1)).isTrue();
+        assertThat(cfg.containsKey(key1)).isFalse();
 
-        assertTrue(cfg.removeKey(key2));
-        assertThat(cfg.keySet(), containsInAnyOrder("e.f"));
+        assertThat(cfg.removeKey(key2)).isTrue();
+        assertThat(cfg.keySet()).containsExactlyInAnyOrder("e.f");
     }
 
-    @Test
-    public void testShouldParseValidStringToEnum() {
-        final Configuration configuration = new Configuration();
+    @TestTemplate
+    void testShouldParseValidStringToEnum() {
+        final Configuration configuration = new Configuration(standardYaml);
         configuration.setString(STRING_OPTION.key(), TestEnum.VALUE1.toString());
 
         final TestEnum parsedEnumValue = configuration.getEnum(TestEnum.class, STRING_OPTION);
-        assertEquals(TestEnum.VALUE1, parsedEnumValue);
+        assertThat(TestEnum.VALUE1).isEqualTo(parsedEnumValue);
     }
 
-    @Test
-    public void testShouldParseValidStringToEnumIgnoringCase() {
-        final Configuration configuration = new Configuration();
+    @TestTemplate
+    void testShouldParseValidStringToEnumIgnoringCase() {
+        final Configuration configuration = new Configuration(standardYaml);
         configuration.setString(STRING_OPTION.key(), TestEnum.VALUE1.toString().toLowerCase());
 
         final TestEnum parsedEnumValue = configuration.getEnum(TestEnum.class, STRING_OPTION);
-        assertEquals(TestEnum.VALUE1, parsedEnumValue);
+        assertThat(TestEnum.VALUE1).isEqualTo(parsedEnumValue);
     }
 
-    @Test
-    public void testThrowsExceptionIfTryingToParseInvalidStringForEnum() {
-        final Configuration configuration = new Configuration();
+    @TestTemplate
+    void testThrowsExceptionIfTryingToParseInvalidStringForEnum() {
+        final Configuration configuration = new Configuration(standardYaml);
         final String invalidValueForTestEnum = "InvalidValueForTestEnum";
         configuration.setString(STRING_OPTION.key(), invalidValueForTestEnum);
 
@@ -371,17 +382,19 @@ public class ConfigurationTest extends TestLogger {
                             + " must be one of [VALUE1, VALUE2] (was "
                             + invalidValueForTestEnum
                             + ")";
-            assertThat(e.getMessage(), containsString(expectedMessage));
+            assertThat(e.getMessage()).contains(expectedMessage);
         }
     }
 
-    @Test
-    public void testToMap() {
-        final Configuration configuration = new Configuration();
+    @TestTemplate
+    void testToMap() {
+        final Configuration configuration = new Configuration(standardYaml);
         final String listValues = "value1;value2;value3";
+        final String yamlListValues = "[value1, value2, value3]";
         configuration.set(LIST_STRING_OPTION, Arrays.asList(listValues.split(";")));
 
         final String mapValues = "key1:value1,key2:value2";
+        final String yamlMapValues = "{key1: value1, key2: value2}";
         configuration.set(
                 MAP_OPTION,
                 Arrays.stream(mapValues.split(","))
@@ -390,82 +403,127 @@ public class ConfigurationTest extends TestLogger {
         final Duration duration = Duration.ofMillis(3000);
         configuration.set(DURATION_OPTION, duration);
 
-        assertEquals(listValues, configuration.toMap().get(LIST_STRING_OPTION.key()));
-        assertEquals(mapValues, configuration.toMap().get(MAP_OPTION.key()));
-        assertEquals("3 s", configuration.toMap().get(DURATION_OPTION.key()));
+        if (standardYaml) {
+            assertThat(yamlListValues)
+                    .isEqualTo(configuration.toMap().get(LIST_STRING_OPTION.key()));
+            assertThat(yamlMapValues).isEqualTo(configuration.toMap().get(MAP_OPTION.key()));
+        } else {
+            assertThat(listValues).isEqualTo(configuration.toMap().get(LIST_STRING_OPTION.key()));
+            assertThat(mapValues).isEqualTo(configuration.toMap().get(MAP_OPTION.key()));
+        }
+        assertThat("3 s").isEqualTo(configuration.toMap().get(DURATION_OPTION.key()));
     }
 
-    @Test
-    public void testMapNotContained() {
-        final Configuration cfg = new Configuration();
+    @TestTemplate
+    void testToFileWritableMap() {
+        final Configuration configuration = new Configuration(standardYaml);
+        final String listValues = "value1;value2;value3";
+        final String yamlListValues = "[value1, value2, value3]";
+        configuration.set(LIST_STRING_OPTION, Arrays.asList(listValues.split(";")));
 
-        assertFalse(cfg.getOptional(MAP_OPTION).isPresent());
-        assertFalse(cfg.contains(MAP_OPTION));
+        final String mapValues = "key1:value1,key2:value2";
+        final String yamlMapValues = "{key1: value1, key2: value2}";
+        configuration.set(
+                MAP_OPTION,
+                Arrays.stream(mapValues.split(","))
+                        .collect(Collectors.toMap(e -> e.split(":")[0], e -> e.split(":")[1])));
+
+        final Duration duration = Duration.ofMillis(3000);
+        configuration.set(DURATION_OPTION, duration);
+
+        final String strValues = "*";
+        final String yamlStrValues = "'*'";
+        configuration.set(STRING_OPTION, strValues);
+
+        if (standardYaml) {
+            assertThat(yamlListValues)
+                    .isEqualTo(configuration.toFileWritableMap().get(LIST_STRING_OPTION.key()));
+            assertThat(yamlMapValues)
+                    .isEqualTo(configuration.toFileWritableMap().get(MAP_OPTION.key()));
+            assertThat(yamlStrValues)
+                    .isEqualTo(configuration.toFileWritableMap().get(STRING_OPTION.key()));
+        } else {
+            assertThat(listValues)
+                    .isEqualTo(configuration.toFileWritableMap().get(LIST_STRING_OPTION.key()));
+            assertThat(mapValues)
+                    .isEqualTo(configuration.toFileWritableMap().get(MAP_OPTION.key()));
+            assertThat(strValues)
+                    .isEqualTo(configuration.toFileWritableMap().get(STRING_OPTION.key()));
+        }
+        assertThat("3 s").isEqualTo(configuration.toMap().get(DURATION_OPTION.key()));
     }
 
-    @Test
-    public void testMapWithPrefix() {
-        final Configuration cfg = new Configuration();
+    @TestTemplate
+    void testMapNotContained() {
+        final Configuration cfg = new Configuration(standardYaml);
+
+        assertThat(cfg.getOptional(MAP_OPTION).isPresent()).isFalse();
+        assertThat(cfg.contains(MAP_OPTION)).isFalse();
+    }
+
+    @TestTemplate
+    void testMapWithPrefix() {
+        final Configuration cfg = new Configuration(standardYaml);
         cfg.setString(MAP_PROPERTY_1, "value1");
         cfg.setInteger(MAP_PROPERTY_2, 12);
 
-        assertEquals(cfg.get(MAP_OPTION), PROPERTIES_MAP);
-        assertTrue(cfg.contains(MAP_OPTION));
+        assertThat(cfg.get(MAP_OPTION)).isEqualTo(PROPERTIES_MAP);
+        assertThat(cfg.contains(MAP_OPTION)).isTrue();
     }
 
-    @Test
-    public void testMapWithoutPrefix() {
-        final Configuration cfg = new Configuration();
+    @TestTemplate
+    void testMapWithoutPrefix() {
+        final Configuration cfg = new Configuration(standardYaml);
         cfg.set(MAP_OPTION, PROPERTIES_MAP);
 
-        assertEquals(cfg.get(MAP_OPTION), PROPERTIES_MAP);
-        assertTrue(cfg.contains(MAP_OPTION));
+        assertThat(cfg.get(MAP_OPTION)).isEqualTo(PROPERTIES_MAP);
+        assertThat(cfg.contains(MAP_OPTION)).isTrue();
     }
 
-    @Test
-    public void testMapNonPrefixHasPrecedence() {
-        final Configuration cfg = new Configuration();
+    @TestTemplate
+    void testMapNonPrefixHasPrecedence() {
+        final Configuration cfg = new Configuration(standardYaml);
         cfg.set(MAP_OPTION, PROPERTIES_MAP);
         cfg.setString(MAP_PROPERTY_1, "value1");
         cfg.setInteger(MAP_PROPERTY_2, 99999);
 
-        assertEquals(cfg.get(MAP_OPTION), PROPERTIES_MAP);
-        assertTrue(cfg.contains(MAP_OPTION));
-        assertTrue(cfg.containsKey(MAP_PROPERTY_1));
+        assertThat(cfg.get(MAP_OPTION)).isEqualTo(PROPERTIES_MAP);
+        assertThat(cfg.contains(MAP_OPTION)).isTrue();
+        assertThat(cfg.containsKey(MAP_PROPERTY_1)).isTrue();
     }
 
-    @Test
-    public void testMapThatOverwritesPrefix() {
-        final Configuration cfg = new Configuration();
+    @TestTemplate
+    void testMapThatOverwritesPrefix() {
+        final Configuration cfg = new Configuration(standardYaml);
         cfg.setString(MAP_PROPERTY_1, "value1");
         cfg.setInteger(MAP_PROPERTY_2, 99999);
         cfg.set(MAP_OPTION, PROPERTIES_MAP);
 
-        assertEquals(cfg.get(MAP_OPTION), PROPERTIES_MAP);
-        assertTrue(cfg.contains(MAP_OPTION));
-        assertFalse(cfg.containsKey(MAP_PROPERTY_1));
+        assertThat(cfg.get(MAP_OPTION)).isEqualTo(PROPERTIES_MAP);
+        assertThat(cfg.contains(MAP_OPTION)).isTrue();
+        assertThat(cfg.containsKey(MAP_PROPERTY_1)).isFalse();
     }
 
-    @Test
-    public void testMapRemovePrefix() {
-        final Configuration cfg = new Configuration();
+    @TestTemplate
+    void testMapRemovePrefix() {
+        final Configuration cfg = new Configuration(standardYaml);
         cfg.setString(MAP_PROPERTY_1, "value1");
         cfg.setInteger(MAP_PROPERTY_2, 99999);
         cfg.removeConfig(MAP_OPTION);
 
-        assertFalse(cfg.contains(MAP_OPTION));
-        assertFalse(cfg.containsKey(MAP_PROPERTY_1));
-        assertFalse(cfg.containsKey(MAP_PROPERTY_2));
+        assertThat(cfg.contains(MAP_OPTION)).isFalse();
+        assertThat(cfg.containsKey(MAP_PROPERTY_1)).isFalse();
+        assertThat(cfg.containsKey(MAP_PROPERTY_2)).isFalse();
     }
 
-    @Test
-    public void testListParserErrorDoesNotLeakSensitiveData() {
+    @TestTemplate
+    void testListParserErrorDoesNotLeakSensitiveData() {
         ConfigOption<List<String>> secret =
                 ConfigOptions.key("secret").stringType().asList().noDefaultValue();
 
         Assertions.assertThat(GlobalConfiguration.isSensitive(secret.key())).isTrue();
 
-        final Configuration cfg = new Configuration();
+        final Configuration cfg = new Configuration(standardYaml);
         // missing closing quote
         cfg.setString(secret.key(), "'secret_value");
 
@@ -477,14 +535,14 @@ public class ConfigurationTest extends TestLogger {
                                         .doesNotContain("secret_value"));
     }
 
-    @Test
-    public void testMapParserErrorDoesNotLeakSensitiveData() {
+    @TestTemplate
+    void testMapParserErrorDoesNotLeakSensitiveData() {
         ConfigOption<Map<String, String>> secret =
                 ConfigOptions.key("secret").mapType().noDefaultValue();
 
         Assertions.assertThat(GlobalConfiguration.isSensitive(secret.key())).isTrue();
 
-        final Configuration cfg = new Configuration();
+        final Configuration cfg = new Configuration(standardYaml);
         // malformed map representation
         cfg.setString(secret.key(), "secret_value");
 
@@ -496,6 +554,58 @@ public class ConfigurationTest extends TestLogger {
                                         .doesNotContain("secret_value"));
     }
 
+    @TestTemplate
+    void testToStringDoesNotLeakSensitiveData() {
+        ConfigOption<Map<String, String>> secret =
+                ConfigOptions.key("secret").mapType().noDefaultValue();
+
+        Assertions.assertThat(GlobalConfiguration.isSensitive(secret.key())).isTrue();
+
+        final Configuration cfg = new Configuration(standardYaml);
+        cfg.setString(secret.key(), "secret_value");
+
+        assertThat(cfg.toString()).doesNotContain("secret_value");
+    }
+
+    @TestTemplate
+    void testGetWithOverrideDefault() {
+        final Configuration conf = new Configuration(standardYaml);
+
+        // Test for integer without default value.
+        ConfigOption<Integer> integerOption0 =
+                ConfigOptions.key("integer.key0").intType().noDefaultValue();
+        // integerOption0 doesn't exist in conf, and it should be overrideDefault.
+        assertThat(conf.get(integerOption0, 2)).isEqualTo(2);
+        // integerOption0 exists in conf, and it should be value that set before.
+        conf.set(integerOption0, 3);
+        assertThat(conf.get(integerOption0, 2)).isEqualTo(3);
+
+        // Test for integer with default value, the default value should be ignored.
+        ConfigOption<Integer> integerOption1 =
+                ConfigOptions.key("integer.key1").intType().defaultValue(4);
+        assertThat(conf.get(integerOption1, 5)).isEqualTo(5);
+        // integerOption1 is changed.
+        conf.set(integerOption1, 6);
+        assertThat(conf.get(integerOption1, 5)).isEqualTo(6);
+
+        // Test for string without default value.
+        ConfigOption<String> stringOption0 =
+                ConfigOptions.key("string.key0").stringType().noDefaultValue();
+        // stringOption0 doesn't exist in conf, and it should be overrideDefault.
+        assertThat(conf.get(stringOption0, "a")).isEqualTo("a");
+        // stringOption0 exists in conf, and it should be value that set before.
+        conf.set(stringOption0, "b");
+        assertThat(conf.get(stringOption0, "a")).isEqualTo("b");
+
+        // Test for string with default value, the default value should be ignored.
+        ConfigOption<String> stringOption1 =
+                ConfigOptions.key("string.key1").stringType().defaultValue("c");
+        assertThat(conf.get(stringOption1, "d")).isEqualTo("d");
+        // stringOption1 is changed.
+        conf.set(stringOption1, "e");
+        assertThat(conf.get(stringOption1, "d")).isEqualTo("e");
+    }
+
     // --------------------------------------------------------------------------------------------
     // Test classes
     // --------------------------------------------------------------------------------------------
