@@ -216,17 +216,29 @@ public class EntropyInjectorTest {
     }
 
     @Test
-    public void testIsEntropyFs() {
-        final FileSystem efs = new TestEntropyInjectingFs("test", "ignored");
-
-        assertTrue(EntropyInjector.isEntropyInjecting(efs));
+    public void testIsEntropyFs() throws Exception {
+        final String entropyKey = "_test_";
+        final FileSystem efs = new TestEntropyInjectingFs(entropyKey, "ignored");
+        final File folder = TMP_FOLDER.newFolder();
+        final Path path = new Path(Path.fromLocalFile(folder), entropyKey + "/path/");
+        assertTrue(EntropyInjector.isEntropyInjecting(efs, path));
     }
 
     @Test
-    public void testIsEntropyFsWithNullEntropyKey() {
+    public void testIsEntropyFsWithNullEntropyKey() throws Exception {
         final FileSystem efs = new TestEntropyInjectingFs(null, "ignored");
 
-        assertFalse(EntropyInjector.isEntropyInjecting(efs));
+        final File folder = TMP_FOLDER.newFolder();
+        assertFalse(EntropyInjector.isEntropyInjecting(efs, Path.fromLocalFile(folder)));
+    }
+
+    @Test
+    public void testIsEntropyFsPathDoesNotIncludeEntropyKey() throws Exception {
+        final String entropyKey = "_test_";
+        final FileSystem efs = new TestEntropyInjectingFs(entropyKey, "ignored");
+        final File folder = TMP_FOLDER.newFolder();
+        final Path path = new Path(Path.fromLocalFile(folder), "path"); // no entropy key
+        assertFalse(EntropyInjector.isEntropyInjecting(efs, path));
     }
 
     // ------------------------------------------------------------------------
