@@ -44,26 +44,36 @@ class RetryingExecutor implements AutoCloseable {
     private final ScheduledExecutorService timer; // schedule timeouts
     private final ScheduledExecutorService blockingExecutor; // schedule and run actual uploads
     private final Histogram attemptsPerTaskHistogram;
+    private final Histogram totalAttemptsPerTaskHistogram;
 
-    RetryingExecutor(int nThreads, Histogram attemptsPerTaskHistogram) {
+    RetryingExecutor(
+            int nThreads,
+            Histogram attemptsPerTaskHistogram,
+            Histogram totalAttemptsPerTaskHistogram) {
         this(
                 SchedulerFactory.create(1, "ChangelogRetryScheduler", LOG),
                 SchedulerFactory.create(nThreads, "ChangelogBlockingExecutor", LOG),
-                attemptsPerTaskHistogram);
+                attemptsPerTaskHistogram,
+                totalAttemptsPerTaskHistogram);
     }
 
     @VisibleForTesting
-    RetryingExecutor(ScheduledExecutorService executor, Histogram attemptsPerTaskHistogram) {
-        this(executor, executor, attemptsPerTaskHistogram);
+    RetryingExecutor(
+            ScheduledExecutorService executor,
+            Histogram attemptsPerTaskHistogram,
+            Histogram totalAttemptsPerTaskHistogram) {
+        this(executor, executor, attemptsPerTaskHistogram, totalAttemptsPerTaskHistogram);
     }
 
     RetryingExecutor(
             ScheduledExecutorService timer,
             ScheduledExecutorService blockingExecutor,
-            Histogram attemptsPerTaskHistogram) {
+            Histogram attemptsPerTaskHistogram,
+            Histogram totalAttemptsPerTaskHistogram) {
         this.timer = timer;
         this.blockingExecutor = blockingExecutor;
         this.attemptsPerTaskHistogram = attemptsPerTaskHistogram;
+        this.totalAttemptsPerTaskHistogram = totalAttemptsPerTaskHistogram;
     }
 
     /**
@@ -76,7 +86,12 @@ class RetryingExecutor implements AutoCloseable {
         LOG.debug("execute with retryPolicy: {}", retryPolicy);
         RetriableActionAttempt<T> task =
                 RetriableActionAttempt.initialize(
-                        action, retryPolicy, blockingExecutor, attemptsPerTaskHistogram, timer);
+                        action,
+                        retryPolicy,
+                        blockingExecutor,
+                        attemptsPerTaskHistogram,
+                        totalAttemptsPerTaskHistogram,
+                        timer);
         blockingExecutor.submit(task);
     }
 
@@ -165,8 +180,16 @@ class RetryingExecutor implements AutoCloseable {
 
         private final AtomicInteger activeAttempts;
 
+        /**
+         * The field shared across all attempts to execute the same {#link #runnable action}
+         * representing the total count of upload attempts.
+         */
+        private final AtomicInteger totalAttempts;
+
         private final Histogram attemptsPerTaskHistogram;
 
+        private final Histogram totalAttemptsPerTaskHistogram;
+
         private RetriableActionAttempt(
                 int attemptNumber,
                 AtomicBoolean actionCompleted,
@@ -175,15 +198,19 @@ class RetryingExecutor implements AutoCloseable {
                 ScheduledExecutorService blockingExecutor,
                 ScheduledExecutorService timer,
                 AtomicInteger activeAttempts,
-                Histogram attemptsPerTaskHistogram) {
+                AtomicInteger totalAttempts,
+                Histogram attemptsPerTaskHistogram,
+                Histogram totalAttemptsPerTaskHistogram) {
             this.attemptNumber = attemptNumber;
             this.action = action;
             this.retryPolicy = retryPolicy;
             this.blockingExecutor = blockingExecutor;
             this.actionCompleted = actionCompleted;
             this.attemptsPerTaskHistogram = attemptsPerTaskHistogram;
+            this.totalAttemptsPerTaskHistogram = totalAttemptsPerTaskHistogram;
             this.timer = timer;
             this.activeAttempts = activeAttempts;
+            this.totalAttempts = totalAttempts;
             this.attemptCompleted = new AtomicBoolean(false);
         }
 
@@ -200,6 +227,7 @@ class RetryingExecutor implements AutoCloseable {
                     LOG.debug("succeeded with {} attempts", attemptNumber);
                     action.completeWithResult(result);
                     attemptsPerTaskHistogram.update(attemptNumber);
+                    totalAttemptsPerTaskHistogram.update(totalAttempts.get());
                 } else {
                     LOG.debug("discard unnecessarily uploaded state, attempt {}", attemptNumber);
                     try {
@@ -225,6 +253,7 @@ class RetryingExecutor implements AutoCloseable {
             long nextAttemptDelay = retryPolicy.retryAfter(attemptNumber, e);
             if (nextAttemptDelay >= 0L) {
                 activeAttempts.incrementAndGet();
+                totalAttempts.incrementAndGet();
                 scheduleNext(nextAttemptDelay, next());
             }
             if (activeAttempts.decrementAndGet() == 0
@@ -247,6 +276,7 @@ class RetryingExecutor implements AutoCloseable {
                 RetryPolicy retryPolicy,
                 ScheduledExecutorService blockingExecutor,
                 Histogram attemptsPerTaskHistogram,
+                Histogram totalAttemptsPerTaskHistogram,
                 ScheduledExecutorService timer) {
             return new RetriableActionAttempt(
                     1,
@@ -256,7 +286,9 @@ class RetryingExecutor implements AutoCloseable {
                     blockingExecutor,
                     timer,
                     new AtomicInteger(1),
-                    attemptsPerTaskHistogram);
+                    new AtomicInteger(1),
+                    attemptsPerTaskHistogram,
+                    totalAttemptsPerTaskHistogram);
         }
 
         private RetriableActionAttempt<Result> next() {
@@ -268,7 +300,9 @@ class RetryingExecutor implements AutoCloseable {
                     blockingExecutor,
                     timer,
                     activeAttempts,
-                    attemptsPerTaskHistogram);
+                    totalAttempts,
+                    attemptsPerTaskHistogram,
+                    totalAttemptsPerTaskHistogram);
         }
 
         private Optional<ScheduledFuture<?>> scheduleTimeout() {
