@@ -386,6 +386,12 @@ public class DataStreamAllroundTestJobFactory {
         }
     }
 
+    /**
+     * @deprecated This method relies on the {@link
+     *     org.apache.flink.streaming.api.functions.source.SourceFunction} API, which is due to be
+     *     removed. Use the new {@link org.apache.flink.api.connector.source.Source} API instead.
+     */
+    @Deprecated
     static SourceFunction<Event> createEventSource(ParameterTool pt) {
         return new SequenceGeneratorSource(
                 pt.getInt(
