@@ -22,8 +22,13 @@ import org.apache.flink.api.java.DataSet;
 import org.apache.flink.api.java.ExecutionEnvironment;
 import org.apache.flink.api.java.tuple.Tuple2;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import java.util.List;
 
+import static org.apache.flink.examples.java.util.DataSetDeprecationInfo.DATASET_DEPRECATION_INFO;
+
 /**
  * This example shows how to use the collection based execution of Flink.
  *
@@ -32,9 +37,15 @@ import java.util.List;
  *
  * <p>See the "Local Execution" section in the documentation for more details:
  * https://flink.apache.org/docs/latest/apis/local_execution.html
+ *
+ * <p>Note: All Flink DataSet APIs are deprecated since Flink 1.18 and will be removed in a future
+ * Flink major version. You can still build your application in DataSet, but you should move to
+ * either the DataStream and/or Table API. This class is retained for testing purposes.
  */
 public class CollectionExecutionExample {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(CollectionExecutionExample.class);
+
     /** POJO class representing a user. */
     public static class User {
         public int userIdentifier;
@@ -72,6 +83,9 @@ public class CollectionExecutionExample {
     }
 
     public static void main(String[] args) throws Exception {
+
+        LOGGER.warn(DATASET_DEPRECATION_INFO);
+
         // initialize a new Collection-based execution environment
         final ExecutionEnvironment env = ExecutionEnvironment.createCollectionsEnvironment();
 
