@@ -39,7 +39,6 @@ import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.streaming.api.functions.ProcessFunction;
 import org.apache.flink.streaming.api.functions.sink.filesystem.rollingpolicies.DefaultRollingPolicy;
 import org.apache.flink.streaming.api.windowing.assigners.TumblingEventTimeWindows;
-import org.apache.flink.streaming.api.windowing.time.Time;
 import org.apache.flink.streaming.examples.wordcount.util.WordCountData;
 import org.apache.flink.util.Collector;
 import org.apache.flink.util.OutputTag;
@@ -87,7 +86,7 @@ public class SideOutputExample {
             System.out.println("Executing WordCount example with default input data set.");
             System.out.println("Use --input to specify file input.");
             // get default test text data
-            DataStreamSource<String> text = env.fromElements(WordCountData.WORDS);
+            DataStreamSource<String> text = env.fromData(WordCountData.WORDS);
             // We assign the WatermarkStrategy after creating the source because
             // StreamExecutionEnvironment#fromElemenets() methods currently does not accept
             // WatermarkStrategies. In a real-world job you should integrate the WatermarkStrategy
@@ -107,7 +106,7 @@ public class SideOutputExample {
         DataStream<Tuple2<String, Integer>> counts =
                 tokenized
                         .keyBy(value -> value.f0)
-                        .window(TumblingEventTimeWindows.of(Time.seconds(5)))
+                        .window(TumblingEventTimeWindows.of(Duration.ofSeconds(5)))
                         // group by the tuple field "0" and sum up tuple field "1"
                         .sum(1);
 
