@@ -137,7 +137,7 @@ public class CsvReaderFormat<T> extends SimpleStreamFormat<T> {
      *
      * @param mapperFactory The factory creating the {@code CsvMapper}.
      * @param schemaGenerator A generator that creates and configures the Jackson CSV schema for
-     *     parsins specific CSV files, from a mapper created by the mapper factory.
+     *     parsing specific CSV files, from a mapper created by the mapper factory.
      * @param typeInformation The Flink type descriptor of the returned elements.
      * @param <T> The type of the returned elements.
      */
@@ -164,17 +164,17 @@ public class CsvReaderFormat<T> extends SimpleStreamFormat<T> {
      */
     public static <T> CsvReaderFormat<T> forPojo(Class<T> pojoType) {
         return forSchema(
-                () -> JacksonMapperFactory.createCsvMapper(),
+                JacksonMapperFactory::createCsvMapper,
                 mapper -> mapper.schemaFor(pojoType).withoutQuoteChar(),
                 TypeInformation.of(pojoType));
     }
 
     /**
-     * Returns a new {@code CsvReaderFormat} configured to ignore all parsing errors. All thye other
+     * Returns a new {@code CsvReaderFormat} configured to ignore all parsing errors. All the other
      * options directly carried over from the subject of the method call.
      */
     public CsvReaderFormat<T> withIgnoreParseErrors() {
-        return new CsvReaderFormat<T>(
+        return new CsvReaderFormat<>(
                 this.mapperFactory,
                 this.schemaGenerator,
                 this.rootType,
