@@ -45,12 +45,14 @@ import java.util.List;
 import java.util.stream.Collectors;
 
 import static org.apache.flink.connector.testutils.formats.SchemaTestUtils.open;
+import static org.apache.flink.core.testutils.FlinkAssertions.anyCauseMatches;
 import static org.apache.flink.table.api.DataTypes.FIELD;
 import static org.apache.flink.table.api.DataTypes.FLOAT;
 import static org.apache.flink.table.api.DataTypes.INT;
 import static org.apache.flink.table.api.DataTypes.ROW;
 import static org.apache.flink.table.api.DataTypes.STRING;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** Tests for {@link OggJsonSerializationSchema} and {@link OggJsonDeserializationSchema}. */
 class OggJsonSerDeSchemaTest {
@@ -79,6 +81,33 @@ class OggJsonSerDeSchemaTest {
         testDeserializationWithMetadata("ogg-data.txt");
     }
 
+    @Test
+    void testIgnoreParseErrors() throws Exception {
+        List<String> lines = readLines("ogg-data.txt");
+        OggJsonDeserializationSchema deserializationSchema =
+                new OggJsonDeserializationSchema(
+                        PHYSICAL_DATA_TYPE,
+                        Collections.emptyList(),
+                        InternalTypeInfo.of(PHYSICAL_DATA_TYPE.getLogicalType()),
+                        true,
+                        TimestampFormat.ISO_8601);
+        open(deserializationSchema);
+
+        ThrowingExceptionCollector collector = new ThrowingExceptionCollector();
+        assertThatThrownBy(
+                        () -> {
+                            for (String line : lines) {
+                                deserializationSchema.deserialize(
+                                        line.getBytes(StandardCharsets.UTF_8), collector);
+                            }
+                        })
+                .isInstanceOf(RuntimeException.class)
+                .satisfies(
+                        anyCauseMatches(
+                                RuntimeException.class,
+                                "An error occurred while collecting data."));
+    }
+
     @Test
     void testTombstoneMessages() throws Exception {
         OggJsonDeserializationSchema deserializationSchema =
@@ -263,4 +292,17 @@ class OggJsonSerDeSchemaTest {
             // do nothing
         }
     }
+
+    private static class ThrowingExceptionCollector implements Collector<RowData> {
+
+        @Override
+        public void collect(RowData record) {
+            throw new RuntimeException("An error occurred while collecting data.");
+        }
+
+        @Override
+        public void close() {
+            // do nothing
+        }
+    }
 }
