@@ -18,6 +18,7 @@
 
 package org.apache.flink.formats.parquet.vector;
 
+import org.apache.flink.annotation.Internal;
 import org.apache.flink.formats.parquet.utils.ParquetSchemaConverter;
 import org.apache.flink.table.data.DecimalData;
 import org.apache.flink.table.data.columnar.vector.BytesColumnVector;
@@ -26,10 +27,13 @@ import org.apache.flink.table.data.columnar.vector.DecimalColumnVector;
 import org.apache.flink.table.data.columnar.vector.IntColumnVector;
 import org.apache.flink.table.data.columnar.vector.LongColumnVector;
 
+import org.apache.parquet.Preconditions;
+
 /**
  * Parquet write decimal as int32 and int64 and binary, this class wrap the real vector to provide
  * {@link DecimalColumnVector} interface.
  */
+@Internal
 public class ParquetDecimalVector implements DecimalColumnVector {
 
     private final ColumnVector vector;
@@ -40,18 +44,27 @@ public class ParquetDecimalVector implements DecimalColumnVector {
 
     @Override
     public DecimalData getDecimal(int i, int precision, int scale) {
-        if (ParquetSchemaConverter.is32BitDecimal(precision)) {
+        if (ParquetSchemaConverter.is32BitDecimal(precision) && vector instanceof IntColumnVector) {
             return DecimalData.fromUnscaledLong(
                     ((IntColumnVector) vector).getInt(i), precision, scale);
-        } else if (ParquetSchemaConverter.is64BitDecimal(precision)) {
+        } else if (ParquetSchemaConverter.is64BitDecimal(precision)
+                && vector instanceof LongColumnVector) {
             return DecimalData.fromUnscaledLong(
                     ((LongColumnVector) vector).getLong(i), precision, scale);
         } else {
+            Preconditions.checkArgument(
+                    vector instanceof BytesColumnVector,
+                    "Reading decimal type occur unsupported vector type: %s",
+                    vector.getClass());
             return DecimalData.fromUnscaledBytes(
                     ((BytesColumnVector) vector).getBytes(i).getBytes(), precision, scale);
         }
     }
 
+    public ColumnVector getVector() {
+        return vector;
+    }
+
     @Override
     public boolean isNullAt(int i) {
         return vector.isNullAt(i);
