@@ -18,6 +18,7 @@
 
 package org.apache.flink.formats.protobuf.deserialize;
 
+import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.formats.protobuf.PbCodegenException;
 import org.apache.flink.formats.protobuf.PbConstant;
 import org.apache.flink.formats.protobuf.PbFormatConfig;
@@ -54,6 +55,7 @@ public class ProtoToRowConverter {
     private static final Logger LOG = LoggerFactory.getLogger(ProtoToRowConverter.class);
     private final Method parseFromMethod;
     private final Method decodeMethod;
+    private boolean isCodeSplit = false;
 
     public ProtoToRowConverter(RowType rowType, PbFormatConfig formatConfig)
             throws PbCodegenException {
@@ -108,6 +110,12 @@ public class ProtoToRowConverter {
             codegenAppender.appendSegment(genCode);
             codegenAppender.appendLine("return rowData");
             codegenAppender.appendSegment("}");
+            if (!pbFormatContext.getSplitMethodStack().isEmpty()) {
+                isCodeSplit = true;
+                for (String splitMethod : pbFormatContext.getSplitMethodStack()) {
+                    codegenAppender.appendSegment(splitMethod);
+                }
+            }
             codegenAppender.appendSegment("}");
 
             String printCode = codegenAppender.printWithLineNumber();
@@ -129,4 +137,9 @@ public class ProtoToRowConverter {
         Object messageObj = parseFromMethod.invoke(null, data);
         return (RowData) decodeMethod.invoke(null, messageObj);
     }
+
+    @VisibleForTesting
+    protected boolean isCodeSplit() {
+        return isCodeSplit;
+    }
 }
