@@ -18,6 +18,7 @@
 
 package org.apache.flink.formats.protobuf.serialize;
 
+import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.formats.protobuf.PbCodegenException;
 import org.apache.flink.formats.protobuf.PbConstant;
 import org.apache.flink.formats.protobuf.PbFormatConfig;
@@ -51,6 +52,7 @@ import java.util.UUID;
 public class RowToProtoConverter {
     private static final Logger LOG = LoggerFactory.getLogger(ProtoToRowConverter.class);
     private final Method encodeMethod;
+    private boolean isCodeSplit = false;
 
     public RowToProtoConverter(RowType rowType, PbFormatConfig formatConfig)
             throws PbCodegenException {
@@ -89,6 +91,12 @@ public class RowToProtoConverter {
             codegenAppender.appendSegment(genCode);
             codegenAppender.appendLine("return message");
             codegenAppender.end("}");
+            if (!formatContext.getSplitMethodStack().isEmpty()) {
+                isCodeSplit = true;
+                for (String spliteMethod : formatContext.getSplitMethodStack()) {
+                    codegenAppender.appendSegment(spliteMethod);
+                }
+            }
             codegenAppender.end("}");
 
             String printCode = codegenAppender.printWithLineNumber();
@@ -109,4 +117,9 @@ public class RowToProtoConverter {
         AbstractMessage message = (AbstractMessage) encodeMethod.invoke(null, rowData);
         return message.toByteArray();
     }
+
+    @VisibleForTesting
+    protected boolean isCodeSplit() {
+        return isCodeSplit;
+    }
 }
