@@ -20,6 +20,7 @@ package org.apache.flink.api.java.operators;
 
 import org.apache.flink.annotation.Internal;
 import org.apache.flink.annotation.Public;
+import org.apache.flink.api.common.functions.OpenContext;
 import org.apache.flink.api.common.operators.SemanticProperties;
 import org.apache.flink.api.java.DataSet;
 import org.apache.flink.configuration.Configuration;
@@ -49,7 +50,7 @@ public interface UdfOperator<O extends UdfOperator<O>> {
 
     /**
      * Gets the configuration parameters that will be passed to the UDF's open method {@link
-     * org.apache.flink.api.common.functions.AbstractRichFunction#open(Configuration)}. The
+     * org.apache.flink.api.common.functions.AbstractRichFunction#open(OpenContext)}. The
      * configuration is set via the {@link #withParameters(Configuration)} method.
      *
      * @return The configuration parameters for the UDF.
@@ -80,7 +81,7 @@ public interface UdfOperator<O extends UdfOperator<O>> {
     /**
      * Sets the configuration parameters for the UDF. These are optional parameters that are passed
      * to the UDF in the {@link
-     * org.apache.flink.api.common.functions.AbstractRichFunction#open(Configuration)} method.
+     * org.apache.flink.api.common.functions.AbstractRichFunction#open(OpenContext)} method.
      *
      * @param parameters The configuration parameters for the UDF.
      * @return The operator itself, to allow chaining function calls.
