@@ -30,8 +30,8 @@ import org.apache.flink.types.Row;
 import org.apache.flink.types.parser.FieldParser;
 import org.apache.flink.types.parser.StringParser;
 
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
 import java.io.File;
 import java.io.FileOutputStream;
@@ -44,14 +44,11 @@ import java.sql.Timestamp;
 import java.util.HashMap;
 import java.util.Map;
 
-import static junit.framework.TestCase.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.fail;
 
 /** Tests for {@link RowCsvInputFormat}. */
-public class RowCsvInputFormatTest {
+class RowCsvInputFormatTest {
 
     private static final Path PATH = new Path("an/ignored/file/");
 
@@ -60,7 +57,7 @@ public class RowCsvInputFormatTest {
     private static final String SECOND_PART = "That is the second part";
 
     @Test
-    public void ignoreInvalidLines() throws Exception {
+    void ignoreInvalidLines() throws Exception {
         String fileContent =
                 "#description of the data\n"
                         + "header1|header2|header3|\n"
@@ -98,10 +95,9 @@ public class RowCsvInputFormatTest {
         } // => ok
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("this is", result.getField(0));
-        assertEquals(1, result.getField(1));
-        assertEquals(2.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("this is");
+        assertThat(result.getField(1)).isEqualTo(1);
+        assertThat(result.getField(2)).isEqualTo(2.0);
 
         try {
             result = format.nextRecord(result);
@@ -110,19 +106,17 @@ public class RowCsvInputFormatTest {
         } // => ok
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("a test", result.getField(0));
-        assertEquals(3, result.getField(1));
-        assertEquals(4.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("a test");
+        assertThat(result.getField(1)).isEqualTo(3);
+        assertThat(result.getField(2)).isEqualTo(4.0);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("#next", result.getField(0));
-        assertEquals(5, result.getField(1));
-        assertEquals(6.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("#next");
+        assertThat(result.getField(1)).isEqualTo(5);
+        assertThat(result.getField(2)).isEqualTo(6.0);
 
         result = format.nextRecord(result);
-        assertNull(result);
+        assertThat(result).isNull();
 
         // re-open with lenient = true
         format.setLenient(true);
@@ -132,34 +126,30 @@ public class RowCsvInputFormatTest {
         result = new Row(3);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("header1", result.getField(0));
-        assertNull(result.getField(1));
-        assertNull(result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("header1");
+        assertThat(result.getField(1)).isNull();
+        assertThat(result.getField(2)).isNull();
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("this is", result.getField(0));
-        assertEquals(1, result.getField(1));
-        assertEquals(2.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("this is");
+        assertThat(result.getField(1)).isEqualTo(1);
+        assertThat(result.getField(2)).isEqualTo(2.0);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("a test", result.getField(0));
-        assertEquals(3, result.getField(1));
-        assertEquals(4.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("a test");
+        assertThat(result.getField(1)).isEqualTo(3);
+        assertThat(result.getField(2)).isEqualTo(4.0);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("#next", result.getField(0));
-        assertEquals(5, result.getField(1));
-        assertEquals(6.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("#next");
+        assertThat(result.getField(1)).isEqualTo(5);
+        assertThat(result.getField(2)).isEqualTo(6.0);
         result = format.nextRecord(result);
-        assertNull(result);
+        assertThat(result).isNull();
     }
 
     @Test
-    public void ignoreSingleCharPrefixComments() throws Exception {
+    void ignoreSingleCharPrefixComments() throws Exception {
         String fileContent =
                 "#description of the data\n"
                         + "#successive commented line\n"
@@ -184,23 +174,21 @@ public class RowCsvInputFormatTest {
         Row result = new Row(3);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("this is", result.getField(0));
-        assertEquals(1, result.getField(1));
-        assertEquals(2.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("this is");
+        assertThat(result.getField(1)).isEqualTo(1);
+        assertThat(result.getField(2)).isEqualTo(2.0);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("a test", result.getField(0));
-        assertEquals(3, result.getField(1));
-        assertEquals(4.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("a test");
+        assertThat(result.getField(1)).isEqualTo(3);
+        assertThat(result.getField(2)).isEqualTo(4.0);
 
         result = format.nextRecord(result);
-        assertNull(result);
+        assertThat(result).isNull();
     }
 
     @Test
-    public void ignoreMultiCharPrefixComments() throws Exception {
+    void ignoreMultiCharPrefixComments() throws Exception {
         String fileContent =
                 "//description of the data\n"
                         + "//successive commented line\n"
@@ -225,22 +213,20 @@ public class RowCsvInputFormatTest {
         Row result = new Row(3);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("this is", result.getField(0));
-        assertEquals(1, result.getField(1));
-        assertEquals(2.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("this is");
+        assertThat(result.getField(1)).isEqualTo(1);
+        assertThat(result.getField(2)).isEqualTo(2.0);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("a test", result.getField(0));
-        assertEquals(3, result.getField(1));
-        assertEquals(4.0, result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("a test");
+        assertThat(result.getField(1)).isEqualTo(3);
+        assertThat(result.getField(2)).isEqualTo(4.0);
         result = format.nextRecord(result);
-        assertNull(result);
+        assertThat(result).isNull();
     }
 
     @Test
-    public void readStringFields() throws Exception {
+    void readStringFields() throws Exception {
         String fileContent = "abc|def|ghijk\nabc||hhg\n|||\n||";
 
         FileInputSplit split = createTempFile(fileContent);
@@ -259,36 +245,32 @@ public class RowCsvInputFormatTest {
         Row result = new Row(3);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("abc", result.getField(0));
-        assertEquals("def", result.getField(1));
-        assertEquals("ghijk", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("abc");
+        assertThat(result.getField(1)).isEqualTo("def");
+        assertThat(result.getField(2)).isEqualTo("ghijk");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("abc", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("hhg", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("abc");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("hhg");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("");
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void readMixedQuotedStringFields() throws Exception {
+    void readMixedQuotedStringFields() throws Exception {
         String fileContent = "@a|b|c@|def|@ghijk@\nabc||@|hhg@\n|||\n";
 
         FileInputSplit split = createTempFile(fileContent);
@@ -308,30 +290,27 @@ public class RowCsvInputFormatTest {
         Row result = new Row(3);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("a|b|c", result.getField(0));
-        assertEquals("def", result.getField(1));
-        assertEquals("ghijk", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("a|b|c");
+        assertThat(result.getField(1)).isEqualTo("def");
+        assertThat(result.getField(2)).isEqualTo("ghijk");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("abc", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("|hhg", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("abc");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("|hhg");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("");
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void readStringFieldsWithTrailingDelimiters() throws Exception {
+    void readStringFieldsWithTrailingDelimiters() throws Exception {
         String fileContent = "abc|-def|-ghijk\nabc|-|-hhg\n|-|-|-\n";
 
         FileInputSplit split = createTempFile(fileContent);
@@ -351,30 +330,27 @@ public class RowCsvInputFormatTest {
         Row result = new Row(3);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("abc", result.getField(0));
-        assertEquals("def", result.getField(1));
-        assertEquals("ghijk", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("abc");
+        assertThat(result.getField(1)).isEqualTo("def");
+        assertThat(result.getField(2)).isEqualTo("ghijk");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("abc", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("hhg", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("abc");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("hhg");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("");
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testTailingEmptyFields() throws Exception {
+    void testTailingEmptyFields() throws Exception {
         String fileContent =
                 "abc|-def|-ghijk\n"
                         + "abc|-def|-\n"
@@ -400,34 +376,29 @@ public class RowCsvInputFormatTest {
         Row result = new Row(3);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("abc", result.getField(0));
-        assertEquals("def", result.getField(1));
-        assertEquals("ghijk", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("abc");
+        assertThat(result.getField(1)).isEqualTo("def");
+        assertThat(result.getField(2)).isEqualTo("ghijk");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("abc", result.getField(0));
-        assertEquals("def", result.getField(1));
-        assertEquals("", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("abc");
+        assertThat(result.getField(1)).isEqualTo("def");
+        assertThat(result.getField(2)).isEqualTo("");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("abc", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("abc");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("");
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals("", result.getField(0));
-        assertEquals("", result.getField(1));
-        assertEquals("", result.getField(2));
+        assertThat(result.getField(0)).isEqualTo("");
+        assertThat(result.getField(1)).isEqualTo("");
+        assertThat(result.getField(2)).isEqualTo("");
 
         try {
             format.nextRecord(result);
@@ -437,7 +408,7 @@ public class RowCsvInputFormatTest {
     }
 
     @Test
-    public void testIntegerFields() throws Exception {
+    void testIntegerFields() throws Exception {
         String fileContent = "111|222|333|444|555\n666|777|888|999|000|\n";
 
         FileInputSplit split = createTempFile(fileContent);
@@ -460,28 +431,26 @@ public class RowCsvInputFormatTest {
         Row result = new Row(5);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(111, result.getField(0));
-        assertEquals(222, result.getField(1));
-        assertEquals(333, result.getField(2));
-        assertEquals(444, result.getField(3));
-        assertEquals(555, result.getField(4));
+        assertThat(result.getField(0)).isEqualTo(111);
+        assertThat(result.getField(1)).isEqualTo(222);
+        assertThat(result.getField(2)).isEqualTo(333);
+        assertThat(result.getField(3)).isEqualTo(444);
+        assertThat(result.getField(4)).isEqualTo(555);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(666, result.getField(0));
-        assertEquals(777, result.getField(1));
-        assertEquals(888, result.getField(2));
-        assertEquals(999, result.getField(3));
-        assertEquals(0, result.getField(4));
+        assertThat(result.getField(0)).isEqualTo(666);
+        assertThat(result.getField(1)).isEqualTo(777);
+        assertThat(result.getField(2)).isEqualTo(888);
+        assertThat(result.getField(3)).isEqualTo(999);
+        assertThat(result.getField(4)).isEqualTo(0);
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testEmptyFields() throws Exception {
+    void testEmptyFields() throws Exception {
         String fileContent =
                 ",,,,,,,,\n"
                         + ",,,,,,,\n"
@@ -516,16 +485,16 @@ public class RowCsvInputFormatTest {
 
         for (int i = 0; i < linesCnt; i++) {
             result = format.nextRecord(result);
-            assertNull(result.getField(i));
+            assertThat(result.getField(i)).isNull();
         }
 
         // ensure no more rows
-        assertNull(format.nextRecord(result));
-        assertTrue(format.reachedEnd());
+        assertThat(format.nextRecord(result)).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testDoubleFields() throws Exception {
+    void testDoubleFields() throws Exception {
         String fileContent = "11.1|22.2|33.3|44.4|55.5\n66.6|77.7|88.8|99.9|00.0|\n";
 
         FileInputSplit split = createTempFile(fileContent);
@@ -547,28 +516,28 @@ public class RowCsvInputFormatTest {
         Row result = new Row(5);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(11.1, result.getField(0));
-        assertEquals(22.2, result.getField(1));
-        assertEquals(33.3, result.getField(2));
-        assertEquals(44.4, result.getField(3));
-        assertEquals(55.5, result.getField(4));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(11.1);
+        assertThat(result.getField(1)).isEqualTo(22.2);
+        assertThat(result.getField(2)).isEqualTo(33.3);
+        assertThat(result.getField(3)).isEqualTo(44.4);
+        assertThat(result.getField(4)).isEqualTo(55.5);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(66.6, result.getField(0));
-        assertEquals(77.7, result.getField(1));
-        assertEquals(88.8, result.getField(2));
-        assertEquals(99.9, result.getField(3));
-        assertEquals(0.0, result.getField(4));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(66.6);
+        assertThat(result.getField(1)).isEqualTo(77.7);
+        assertThat(result.getField(2)).isEqualTo(88.8);
+        assertThat(result.getField(3)).isEqualTo(99.9);
+        assertThat(result.getField(4)).isEqualTo(0.0);
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testReadFirstN() throws Exception {
+    void testReadFirstN() throws Exception {
         String fileContent = "111|222|333|444|555|\n666|777|888|999|000|\n";
 
         FileInputSplit split = createTempFile(fileContent);
@@ -584,22 +553,22 @@ public class RowCsvInputFormatTest {
         Row result = new Row(2);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(111, result.getField(0));
-        assertEquals(222, result.getField(1));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(111);
+        assertThat(result.getField(1)).isEqualTo(222);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(666, result.getField(0));
-        assertEquals(777, result.getField(1));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(666);
+        assertThat(result.getField(1)).isEqualTo(777);
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testReadSparseWithNullFieldsForTypes() throws Exception {
+    void testReadSparseWithNullFieldsForTypes() throws Exception {
         String fileContent =
                 "111|x|222|x|333|x|444|x|555|x|666|x|777|x|888|x|999|x|000|x|\n"
                         + "000|x|999|x|888|x|777|x|666|x|555|x|444|x|333|x|222|x|111|x|";
@@ -621,24 +590,24 @@ public class RowCsvInputFormatTest {
         Row result = new Row(3);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(111, result.getField(0));
-        assertEquals(444, result.getField(1));
-        assertEquals(888, result.getField(2));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(111);
+        assertThat(result.getField(1)).isEqualTo(444);
+        assertThat(result.getField(2)).isEqualTo(888);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(0, result.getField(0));
-        assertEquals(777, result.getField(1));
-        assertEquals(333, result.getField(2));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(0);
+        assertThat(result.getField(1)).isEqualTo(777);
+        assertThat(result.getField(2)).isEqualTo(333);
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testReadSparseWithPositionSetter() throws Exception {
+    void testReadSparseWithPositionSetter() throws Exception {
         String fileContent =
                 "111|222|333|444|555|666|777|888|999|000|\n"
                         + "000|999|888|777|666|555|444|333|222|111|";
@@ -660,24 +629,24 @@ public class RowCsvInputFormatTest {
         Row result = new Row(3);
         result = format.nextRecord(result);
 
-        assertNotNull(result);
-        assertEquals(111, result.getField(0));
-        assertEquals(444, result.getField(1));
-        assertEquals(888, result.getField(2));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(111);
+        assertThat(result.getField(1)).isEqualTo(444);
+        assertThat(result.getField(2)).isEqualTo(888);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(0, result.getField(0));
-        assertEquals(777, result.getField(1));
-        assertEquals(333, result.getField(2));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(0);
+        assertThat(result.getField(1)).isEqualTo(777);
+        assertThat(result.getField(2)).isEqualTo(333);
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testReadSparseWithMask() throws Exception {
+    void testReadSparseWithMask() throws Exception {
         String fileContent =
                 "111&&222&&333&&444&&555&&666&&777&&888&&999&&000&&\n"
                         + "000&&999&&888&&777&&666&&555&&444&&333&&222&&111&&";
@@ -699,24 +668,24 @@ public class RowCsvInputFormatTest {
         Row result = new Row(3);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(111, result.getField(0));
-        assertEquals(444, result.getField(1));
-        assertEquals(888, result.getField(2));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(111);
+        assertThat(result.getField(1)).isEqualTo(444);
+        assertThat(result.getField(2)).isEqualTo(888);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(0, result.getField(0));
-        assertEquals(777, result.getField(1));
-        assertEquals(333, result.getField(2));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(0);
+        assertThat(result.getField(1)).isEqualTo(777);
+        assertThat(result.getField(2)).isEqualTo(333);
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testParseStringErrors() throws Exception {
+    void testParseStringErrors() {
         StringParser stringParser = new StringParser();
 
         stringParser.enableQuotedStringParsing((byte) '"');
@@ -735,14 +704,14 @@ public class RowCsvInputFormatTest {
                             failure.getKey().length(),
                             new byte[] {(byte) '|'},
                             null);
-            assertEquals(-1, result);
-            assertEquals(failure.getValue(), stringParser.getErrorState());
+            assertThat(result).isEqualTo(-1);
+            assertThat(stringParser.getErrorState()).isEqualTo(failure.getValue());
         }
     }
 
     @Test
-    @Ignore("Test disabled because we do not support double-quote escaped quotes right now.")
-    public void testParserCorrectness() throws Exception {
+    @Disabled("Test disabled because we do not support double-quote escaped quotes right now.")
+    void testParserCorrectness() throws Exception {
         // RFC 4180 Compliance Test content
         // Taken from http://en.wikipedia.org/wiki/Comma-separated_values#Example
         String fileContent =
@@ -809,14 +778,14 @@ public class RowCsvInputFormatTest {
         Row[] expectedLines = new Row[] {r1, r2, r3, r4, r5};
         for (Row expected : expectedLines) {
             result = format.nextRecord(result);
-            assertEquals(expected, result);
+            assertThat(result).isEqualTo(expected);
         }
-        assertNull(format.nextRecord(result));
-        assertTrue(format.reachedEnd());
+        assertThat(format.nextRecord(result)).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testWindowsLineEndRemoval() throws Exception {
+    void testWindowsLineEndRemoval() throws Exception {
 
         // check typical use case -- linux file is correct and it is set up to linux(\n)
         testRemovingTrailingCR("\n", "\n");
@@ -836,7 +805,7 @@ public class RowCsvInputFormatTest {
     }
 
     @Test
-    public void testQuotedStringParsingWithIncludeFields() throws Exception {
+    void testQuotedStringParsingWithIncludeFields() throws Exception {
         String fileContent =
                 "\"20:41:52-1-3-2015\"|\"Re: Taskmanager memory error in Eclipse\"|"
                         + "\"Blahblah <blah@blahblah.org>\"|\"blaaa|\"blubb\"";
@@ -865,12 +834,12 @@ public class RowCsvInputFormatTest {
         inputFormat.open(splits[0]);
 
         Row record = inputFormat.nextRecord(new Row(2));
-        assertEquals("20:41:52-1-3-2015", record.getField(0));
-        assertEquals("Blahblah <blah@blahblah.org>", record.getField(1));
+        assertThat(record.getField(0)).isEqualTo("20:41:52-1-3-2015");
+        assertThat(record.getField(1)).isEqualTo("Blahblah <blah@blahblah.org>");
     }
 
     @Test
-    public void testQuotedStringParsingWithEscapedQuotes() throws Exception {
+    void testQuotedStringParsingWithEscapedQuotes() throws Exception {
         String fileContent = "\"\\\"Hello\\\" World\"|\"We are\\\" young\"";
         File tempFile = File.createTempFile("CsvReaderQuotedString", "tmp");
         tempFile.deleteOnExit();
@@ -896,12 +865,12 @@ public class RowCsvInputFormatTest {
         inputFormat.open(splits[0]);
 
         Row record = inputFormat.nextRecord(new Row(2));
-        assertEquals("\\\"Hello\\\" World", record.getField(0));
-        assertEquals("We are\\\" young", record.getField(1));
+        assertThat(record.getField(0)).isEqualTo("\\\"Hello\\\" World");
+        assertThat(record.getField(1)).isEqualTo("We are\\\" young");
     }
 
     @Test
-    public void testSqlTimeFields() throws Exception {
+    void testSqlTimeFields() throws Exception {
         String fileContent =
                 "1990-10-14|02:42:25|1990-10-14 02:42:25.123|1990-1-4 2:2:5\n"
                         + "1990-10-14|02:42:25|1990-10-14 02:42:25.123|1990-1-4 2:2:5.3\n";
@@ -924,26 +893,26 @@ public class RowCsvInputFormatTest {
         Row result = new Row(4);
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(Date.valueOf("1990-10-14"), result.getField(0));
-        assertEquals(Time.valueOf("02:42:25"), result.getField(1));
-        assertEquals(Timestamp.valueOf("1990-10-14 02:42:25.123"), result.getField(2));
-        assertEquals(Timestamp.valueOf("1990-01-04 02:02:05"), result.getField(3));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(Date.valueOf("1990-10-14"));
+        assertThat(result.getField(1)).isEqualTo(Time.valueOf("02:42:25"));
+        assertThat(result.getField(2)).isEqualTo(Timestamp.valueOf("1990-10-14 02:42:25.123"));
+        assertThat(result.getField(3)).isEqualTo(Timestamp.valueOf("1990-01-04 02:02:05"));
 
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(Date.valueOf("1990-10-14"), result.getField(0));
-        assertEquals(Time.valueOf("02:42:25"), result.getField(1));
-        assertEquals(Timestamp.valueOf("1990-10-14 02:42:25.123"), result.getField(2));
-        assertEquals(Timestamp.valueOf("1990-01-04 02:02:05.3"), result.getField(3));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(Date.valueOf("1990-10-14"));
+        assertThat(result.getField(1)).isEqualTo(Time.valueOf("02:42:25"));
+        assertThat(result.getField(2)).isEqualTo(Timestamp.valueOf("1990-10-14 02:42:25.123"));
+        assertThat(result.getField(3)).isEqualTo(Timestamp.valueOf("1990-01-04 02:02:05.3"));
 
         result = format.nextRecord(result);
-        assertNull(result);
-        assertTrue(format.reachedEnd());
+        assertThat(result).isNull();
+        assertThat(format.reachedEnd()).isTrue();
     }
 
     @Test
-    public void testScanOrder() throws Exception {
+    void testScanOrder() throws Exception {
         String fileContent =
                 // first row
                 "111|222|333|444|555|666|777|888|999|000|\n"
@@ -970,21 +939,21 @@ public class RowCsvInputFormatTest {
 
         // check first row
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(888, result.getField(0));
-        assertEquals(444, result.getField(1));
-        assertEquals(111, result.getField(2));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(888);
+        assertThat(result.getField(1)).isEqualTo(444);
+        assertThat(result.getField(2)).isEqualTo(111);
 
         // check second row
         result = format.nextRecord(result);
-        assertNotNull(result);
-        assertEquals(333, result.getField(0));
-        assertEquals(777, result.getField(1));
-        assertEquals(0, result.getField(2));
+        assertThat(result).isNotNull();
+        assertThat(result.getField(0)).isEqualTo(333);
+        assertThat(result.getField(1)).isEqualTo(777);
+        assertThat(result.getField(2)).isEqualTo(0);
     }
 
     @Test
-    public void testEmptyProjection() throws Exception {
+    void testEmptyProjection() throws Exception {
         String fileContent = "111|222|333\n" + "000|999|888";
         FileInputSplit split = createTempFile(fileContent);
 
@@ -998,11 +967,11 @@ public class RowCsvInputFormatTest {
 
         // check first row
         result = format.nextRecord(result);
-        assertNotNull(result);
+        assertThat(result).isNotNull();
 
         // check second row
         result = format.nextRecord(result);
-        assertNotNull(result);
+        assertThat(result).isNotNull();
     }
 
     private static FileInputSplit createTempFile(String content) throws IOException {
@@ -1044,11 +1013,11 @@ public class RowCsvInputFormatTest {
         inputFormat.open(splits[0]);
 
         Row result = inputFormat.nextRecord(new Row(1));
-        assertNotNull("Expecting to not return null", result);
-        assertEquals(FIRST_PART, result.getField(0));
+        assertThat(result).as("Expecting to not return null").isNotNull();
+        assertThat(result.getField(0)).isEqualTo(FIRST_PART);
 
         result = inputFormat.nextRecord(result);
-        assertNotNull("Expecting to not return null", result);
-        assertEquals(SECOND_PART, result.getField(0));
+        assertThat(result).as("Expecting to not return null").isNotNull();
+        assertThat(result.getField(0)).isEqualTo(SECOND_PART);
     }
 }
