@@ -60,7 +60,7 @@ import org.apache.flink.util.Preconditions;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.File;
+import java.net.URI;
 import java.util.List;
 import java.util.Optional;
 
@@ -88,7 +88,7 @@ public class KubernetesClusterDescriptor implements ClusterDescriptor<String> {
         this.client = clientFactory.fromConfiguration(flinkConfig, "client");
         this.clusterId =
                 checkNotNull(
-                        flinkConfig.getString(KubernetesConfigOptions.CLUSTER_ID),
+                        flinkConfig.get(KubernetesConfigOptions.CLUSTER_ID),
                         "ClusterId must be specified!");
     }
 
@@ -108,8 +108,8 @@ public class KubernetesClusterDescriptor implements ClusterDescriptor<String> {
             }
 
             if (restEndpoint.isPresent()) {
-                configuration.setString(RestOptions.ADDRESS, restEndpoint.get().getAddress());
-                configuration.setInteger(RestOptions.PORT, restEndpoint.get().getPort());
+                configuration.set(RestOptions.ADDRESS, restEndpoint.get().getAddress());
+                configuration.set(RestOptions.PORT, restEndpoint.get().getPort());
             } else {
                 throw new RuntimeException(
                         new ClusterRetrieveException(
@@ -212,7 +212,7 @@ public class KubernetesClusterDescriptor implements ClusterDescriptor<String> {
         // No need to do pipelineJars validation if it is a PyFlink job.
         if (!(PackagedProgramUtils.isPython(applicationConfiguration.getApplicationClassName())
                 || PackagedProgramUtils.isPython(applicationConfiguration.getProgramArguments()))) {
-            final List<File> pipelineJars =
+            final List<URI> pipelineJars =
                     KubernetesUtils.checkJarFileForApplicationMode(flinkConfig);
             Preconditions.checkArgument(pipelineJars.size() == 1, "Should only have one jar");
         }
@@ -247,10 +247,10 @@ public class KubernetesClusterDescriptor implements ClusterDescriptor<String> {
                 detached
                         ? ClusterEntrypoint.ExecutionMode.DETACHED
                         : ClusterEntrypoint.ExecutionMode.NORMAL;
-        flinkConfig.setString(
+        flinkConfig.set(
                 ClusterEntrypoint.INTERNAL_CLUSTER_EXECUTION_MODE, executionMode.toString());
 
-        flinkConfig.setString(KubernetesConfigOptionsInternal.ENTRY_POINT_CLASS, entryPoint);
+        flinkConfig.set(KubernetesConfigOptionsInternal.ENTRY_POINT_CLASS, entryPoint);
 
         // Rpc, blob, rest, taskManagerRpc ports need to be exposed, so update them to fixed values.
         KubernetesUtils.checkAndUpdatePortConfigOption(
@@ -261,7 +261,7 @@ public class KubernetesClusterDescriptor implements ClusterDescriptor<String> {
                 flinkConfig, RestOptions.BIND_PORT, Constants.REST_PORT);
 
         if (HighAvailabilityMode.isHighAvailabilityModeActivated(flinkConfig)) {
-            flinkConfig.setString(HighAvailabilityOptions.HA_CLUSTER_ID, clusterId);
+            flinkConfig.set(HighAvailabilityOptions.HA_CLUSTER_ID, clusterId);
             KubernetesUtils.checkAndUpdatePortConfigOption(
                     flinkConfig,
                     HighAvailabilityOptions.HA_JOB_MANAGER_PORT_RANGE,
