@@ -61,8 +61,6 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
                     Function<KubernetesConfigMap, Optional<KubernetesConfigMap>>,
                     CompletableFuture<Boolean>>
             checkAndUpdateConfigMapFunction;
-    private final Function<Map<String, String>, CompletableFuture<Void>>
-            deleteConfigMapByLabelFunction;
     private final Function<String, CompletableFuture<Void>> deleteConfigMapFunction;
     private final Consumer<Void> closeConsumer;
     private final BiFunction<
@@ -71,7 +69,7 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
                     KubernetesLeaderElector>
             createLeaderElectorFunction;
 
-    private final Function<Map<String, String>, KubernetesConfigMapSharedWatcher>
+    private final Function<String, KubernetesConfigMapSharedWatcher>
             createConfigMapSharedWatcherFunction;
 
     private TestingFlinkKubeClient(
@@ -88,7 +86,6 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
                             Function<KubernetesConfigMap, Optional<KubernetesConfigMap>>,
                             CompletableFuture<Boolean>>
                     checkAndUpdateConfigMapFunction,
-            Function<Map<String, String>, CompletableFuture<Void>> deleteConfigMapByLabelFunction,
             Function<String, CompletableFuture<Void>> deleteConfigMapFunction,
             Consumer<Void> closeConsumer,
             BiFunction<
@@ -96,7 +93,7 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
                             KubernetesLeaderElector.LeaderCallbackHandler,
                             KubernetesLeaderElector>
                     createLeaderElectorFunction,
-            Function<Map<String, String>, KubernetesConfigMapSharedWatcher>
+            Function<String, KubernetesConfigMapSharedWatcher>
                     createConfigMapSharedWatcherFunction) {
 
         this.createTaskManagerPodFunction = createTaskManagerPodFunction;
@@ -108,7 +105,6 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
         this.createConfigMapFunction = createConfigMapFunction;
         this.getConfigMapFunction = getConfigMapFunction;
         this.checkAndUpdateConfigMapFunction = checkAndUpdateConfigMapFunction;
-        this.deleteConfigMapByLabelFunction = deleteConfigMapByLabelFunction;
         this.deleteConfigMapFunction = deleteConfigMapFunction;
 
         this.closeConsumer = closeConsumer;
@@ -182,20 +178,14 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
         return checkAndUpdateConfigMapFunction.apply(configMapName, updateFunction);
     }
 
-    @Override
-    public CompletableFuture<Void> deleteConfigMapsByLabels(Map<String, String> labels) {
-        return deleteConfigMapByLabelFunction.apply(labels);
-    }
-
     @Override
     public CompletableFuture<Void> deleteConfigMap(String configMapName) {
         return deleteConfigMapFunction.apply(configMapName);
     }
 
     @Override
-    public KubernetesConfigMapSharedWatcher createConfigMapSharedWatcher(
-            Map<String, String> labels) {
-        return createConfigMapSharedWatcherFunction.apply(labels);
+    public KubernetesConfigMapSharedWatcher createConfigMapSharedWatcher(String name) {
+        return createConfigMapSharedWatcherFunction.apply(name);
     }
 
     @Override
@@ -241,8 +231,6 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
                         CompletableFuture<Boolean>>
                 checkAndUpdateConfigMapFunction =
                         (ignore1, ignore2) -> CompletableFuture.completedFuture(true);
-        private Function<Map<String, String>, CompletableFuture<Void>>
-                deleteConfigMapByLabelFunction = (ignore) -> FutureUtils.completedVoidFuture();
         private Function<String, CompletableFuture<Void>> deleteConfigMapFunction =
                 (ignore) -> FutureUtils.completedVoidFuture();
 
@@ -254,7 +242,7 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
                         KubernetesLeaderElector>
                 createLeaderElectorFunction = TestingKubernetesLeaderElector::new;
 
-        private Function<Map<String, String>, KubernetesConfigMapSharedWatcher>
+        private Function<String, KubernetesConfigMapSharedWatcher>
                 createConfigMapSharedWatcherFunction = TestingKubernetesConfigMapSharedWatcher::new;
 
         private Builder() {}
@@ -318,13 +306,6 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
             return this;
         }
 
-        public Builder setDeleteConfigMapByLabelFunction(
-                Function<Map<String, String>, CompletableFuture<Void>>
-                        deleteConfigMapByLabelFunction) {
-            this.deleteConfigMapByLabelFunction = deleteConfigMapByLabelFunction;
-            return this;
-        }
-
         public Builder setDeleteConfigMapFunction(
                 Function<String, CompletableFuture<Void>> deleteConfigMapFunction) {
             this.deleteConfigMapFunction = deleteConfigMapFunction;
@@ -347,7 +328,7 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
         }
 
         public Builder setCreateConfigMapSharedWatcherFunction(
-                Function<Map<String, String>, KubernetesConfigMapSharedWatcher>
+                Function<String, KubernetesConfigMapSharedWatcher>
                         createConfigMapSharedWatcherFunction) {
             this.createConfigMapSharedWatcherFunction = createConfigMapSharedWatcherFunction;
             return this;
@@ -363,7 +344,6 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
                     createConfigMapFunction,
                     getConfigMapFunction,
                     checkAndUpdateConfigMapFunction,
-                    deleteConfigMapByLabelFunction,
                     deleteConfigMapFunction,
                     closeConsumer,
                     createLeaderElectorFunction,
@@ -454,7 +434,7 @@ public class TestingFlinkKubeClient implements FlinkKubeClient {
         private BiFunction<String, WatchCallbackHandler<KubernetesConfigMap>, Watch> watchFunction =
                 (ignore1, ignore2) -> new MockKubernetesWatch();
 
-        public TestingKubernetesConfigMapSharedWatcher(Map<String, String> labels) {}
+        public TestingKubernetesConfigMapSharedWatcher(String name) {}
 
         public void setWatchFunction(
                 BiFunction<String, WatchCallbackHandler<KubernetesConfigMap>, Watch>
