@@ -29,7 +29,14 @@ import org.apache.flink.cep.pattern.conditions.IterativeCondition
  *   Base type of the elements appearing in the pattern
  * @tparam F
  *   Subtype of T to which the current pattern operator is constrained
+ * @deprecated
+ *   All Flink Scala APIs are deprecated and will be removed in a future Flink major version. You
+ *   can still build your application in Scala, but you should move to the Java version of either
+ *   the DataStream and/or Table API.
+ * @see
+ *   <a href="https://s.apache.org/flip-265">FLIP-265 Deprecate and remove Scala API support</a>
  */
+@deprecated(org.apache.flink.api.scala.FLIP_265_WARNING, since = "1.18.0")
 class GroupPattern[T, F <: T](jGroupPattern: JGroupPattern[T, F])
   extends Pattern[T, F](jGroupPattern) {
 
