@@ -34,8 +34,10 @@ import org.apache.flink.util.Preconditions;
 
 import javax.annotation.Nullable;
 
+import java.time.Duration;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Optional;
 
 /**
  * Base class for a pattern definition.
@@ -64,7 +66,7 @@ public class Pattern<T, F extends T> {
     private IterativeCondition<F> condition;
 
     /** Window length in which the pattern match has to occur. */
-    private final Map<WithinType, Time> windowTimes = new HashMap<>();
+    private final Map<WithinType, Duration> windowTimes = new HashMap<>();
 
     /**
      * A quantifier for the pattern. By default set to {@link Quantifier#one(ConsumingStrategy)}.
@@ -102,12 +104,26 @@ public class Pattern<T, F extends T> {
         return name;
     }
 
+    /** @deprecated Use {@link #getWindowSize()} */
+    @Deprecated
+    @Nullable
     public Time getWindowTime() {
-        return windowTimes.get(WithinType.FIRST_AND_LAST);
+        return getWindowSize().map(Time::of).orElse(null);
     }
 
+    public Optional<Duration> getWindowSize() {
+        return getWindowSize(WithinType.FIRST_AND_LAST);
+    }
+
+    /** @deprecated Use {@link #getWindowSize(WithinType)}. */
+    @Deprecated
+    @Nullable
     public Time getWindowTime(WithinType withinType) {
-        return windowTimes.get(withinType);
+        return getWindowSize(withinType).map(Time::of).orElse(null);
+    }
+
+    public Optional<Duration> getWindowSize(WithinType withinType) {
+        return Optional.ofNullable(windowTimes.get(withinType));
     }
 
     public Quantifier getQuantifier() {
@@ -250,8 +266,22 @@ public class Pattern<T, F extends T> {
      *
      * @param windowTime Time of the matching window
      * @return The same pattern operator with the new window length
+     * @deprecated Use {@link #within(Duration)}.
      */
-    public Pattern<T, F> within(Time windowTime) {
+    @Deprecated
+    public Pattern<T, F> within(@Nullable Time windowTime) {
+        return within(Time.toDuration(windowTime));
+    }
+
+    /**
+     * Defines the maximum time interval in which a matching pattern has to be completed in order to
+     * be considered valid. This interval corresponds to the maximum time gap between first and the
+     * last event.
+     *
+     * @param windowTime Time of the matching window
+     * @return The same pattern operator with the new window length
+     */
+    public Pattern<T, F> within(@Nullable Duration windowTime) {
         return within(windowTime, WithinType.FIRST_AND_LAST);
     }
 
@@ -262,8 +292,22 @@ public class Pattern<T, F extends T> {
      * @param withinType Type of the within interval between events
      * @param windowTime Time of the matching window
      * @return The same pattern operator with the new window length
+     * @deprecated Use {@link #within(Duration, WithinType)}.
      */
-    public Pattern<T, F> within(Time windowTime, WithinType withinType) {
+    @Deprecated
+    public Pattern<T, F> within(@Nullable Time windowTime, WithinType withinType) {
+        return within(Time.toDuration(windowTime), withinType);
+    }
+
+    /**
+     * Defines the maximum time interval in which a matching pattern has to be completed in order to
+     * be considered valid. This interval corresponds to the maximum time gap between events.
+     *
+     * @param withinType Type of the within interval between events
+     * @param windowTime Time of the matching window
+     * @return The same pattern operator with the new window length
+     */
+    public Pattern<T, F> within(@Nullable Duration windowTime, WithinType withinType) {
         if (windowTime != null) {
             windowTimes.put(withinType, windowTime);
         }
@@ -369,7 +413,27 @@ public class Pattern<T, F extends T> {
      * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
      */
     public Pattern<T, F> oneOrMore() {
-        return oneOrMore(null);
+        return oneOrMore((Duration) null);
+    }
+
+    /**
+     * Specifies that this pattern can occur {@code one or more} times and time interval corresponds
+     * to the maximum time gap between previous and current event for each times. This means at
+     * least one and at most infinite number of events can be matched to this pattern.
+     *
+     * <p>If this quantifier is enabled for a pattern {@code A.oneOrMore().followedBy(B)} and a
+     * sequence of events {@code A1 A2 B} appears, this will generate patterns: {@code A1 B} and
+     * {@code A1 A2 B}. See also {@link #allowCombinations()}.
+     *
+     * @param windowTime time of the matching window between times
+     * @return The same pattern with a {@link Quantifier#looping(ConsumingStrategy)} quantifier
+     *     applied.
+     * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
+     * @deprecated Use {@link #oneOrMore(Duration)}
+     */
+    @Deprecated
+    public Pattern<T, F> oneOrMore(@Nullable Time windowTime) {
+        return oneOrMore(Time.toDuration(windowTime));
     }
 
     /**
@@ -386,7 +450,7 @@ public class Pattern<T, F extends T> {
      *     applied.
      * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
      */
-    public Pattern<T, F> oneOrMore(@Nullable Time windowTime) {
+    public Pattern<T, F> oneOrMore(@Nullable Duration windowTime) {
         checkIfNoNotPattern();
         checkIfQuantifierApplied();
         this.quantifier = Quantifier.looping(quantifier.getConsumingStrategy());
@@ -416,7 +480,22 @@ public class Pattern<T, F extends T> {
      * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
      */
     public Pattern<T, F> times(int times) {
-        return times(times, null);
+        return times(times, (Duration) null);
+    }
+
+    /**
+     * Specifies exact number of times that this pattern should be matched and time interval
+     * corresponds to the maximum time gap between previous and current event for each times.
+     *
+     * @param times number of times matching event must appear
+     * @param windowTime time of the matching window between times
+     * @return The same pattern with number of times applied
+     * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
+     * @deprecated Using {@link #times(int, Duration)}
+     */
+    @Deprecated
+    public Pattern<T, F> times(int times, @Nullable Time windowTime) {
+        return times(times, Time.toDuration(windowTime));
     }
 
     /**
@@ -428,7 +507,7 @@ public class Pattern<T, F extends T> {
      * @return The same pattern with number of times applied
      * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
      */
-    public Pattern<T, F> times(int times, @Nullable Time windowTime) {
+    public Pattern<T, F> times(int times, @Nullable Duration windowTime) {
         checkIfNoNotPattern();
         checkIfQuantifierApplied();
         Preconditions.checkArgument(times > 0, "You should give a positive number greater than 0.");
@@ -446,7 +525,23 @@ public class Pattern<T, F extends T> {
      * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
      */
     public Pattern<T, F> times(int from, int to) {
-        return times(from, to, null);
+        return times(from, to, (Duration) null);
+    }
+
+    /**
+     * Specifies that the pattern can occur between from and to times with time interval corresponds
+     * to the maximum time gap between previous and current event for each times.
+     *
+     * @param from number of times matching event must appear at least
+     * @param to number of times matching event must appear at most
+     * @param windowTime time of the matching window between times
+     * @return The same pattern with the number of times range applied
+     * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
+     * @deprecated Use {@link #times(int, int, Duration)}
+     */
+    @Deprecated
+    public Pattern<T, F> times(int from, int to, @Nullable Time windowTime) {
+        return times(from, to, Time.toDuration(windowTime));
     }
 
     /**
@@ -459,7 +554,7 @@ public class Pattern<T, F extends T> {
      * @return The same pattern with the number of times range applied
      * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
      */
-    public Pattern<T, F> times(int from, int to, @Nullable Time windowTime) {
+    public Pattern<T, F> times(int from, int to, @Nullable Duration windowTime) {
         checkIfNoNotPattern();
         checkIfQuantifierApplied();
         this.quantifier = Quantifier.times(quantifier.getConsumingStrategy());
@@ -480,7 +575,25 @@ public class Pattern<T, F extends T> {
      * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
      */
     public Pattern<T, F> timesOrMore(int times) {
-        return timesOrMore(times, null);
+        return timesOrMore(times, (Duration) null);
+    }
+
+    /**
+     * Specifies that this pattern can occur the specified times at least with interval corresponds
+     * to the maximum time gap between previous and current event for each times. This means at
+     * least the specified times and at most infinite number of events can be matched to this
+     * pattern.
+     *
+     * @param times number of times at least matching event must appear
+     * @param windowTime time of the matching window between times
+     * @return The same pattern with a {@link Quantifier#looping(ConsumingStrategy)} quantifier
+     *     applied.
+     * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
+     * @deprecated Use {@link #timesOrMore(int, Duration)}
+     */
+    @Deprecated
+    public Pattern<T, F> timesOrMore(int times, @Nullable Time windowTime) {
+        return timesOrMore(times, Time.toDuration(windowTime));
     }
 
     /**
@@ -495,7 +608,7 @@ public class Pattern<T, F extends T> {
      *     applied.
      * @throws MalformedPatternException if the quantifier is not applicable to this pattern.
      */
-    public Pattern<T, F> timesOrMore(int times, @Nullable Time windowTime) {
+    public Pattern<T, F> timesOrMore(int times, @Nullable Duration windowTime) {
         checkIfNoNotPattern();
         checkIfQuantifierApplied();
         this.quantifier = Quantifier.looping(quantifier.getConsumingStrategy());
