@@ -70,7 +70,7 @@ public class StateBootstrapOperator<IN>
         TaggedOperatorSubtaskState state =
                 SnapshotUtils.snapshot(
                         this,
-                        getRuntimeContext().getIndexOfThisSubtask(),
+                        getRuntimeContext().getTaskInfo().getIndexOfThisSubtask(),
                         timestamp,
                         getContainingTask().getConfiguration().isExactlyOnceCheckpointMode(),
                         getContainingTask().getConfiguration().isUnalignedCheckpointsEnabled(),
