@@ -38,6 +38,7 @@ import org.apache.flink.streaming.api.operators.SetupableStreamOperator;
 import org.apache.flink.streaming.api.operators.StreamTaskStateInitializer;
 import org.apache.flink.streaming.api.watermark.Watermark;
 import org.apache.flink.streaming.runtime.streamrecord.LatencyMarker;
+import org.apache.flink.streaming.runtime.streamrecord.RecordAttributes;
 import org.apache.flink.streaming.runtime.streamrecord.StreamRecord;
 import org.apache.flink.streaming.runtime.tasks.StreamTask;
 import org.apache.flink.streaming.runtime.watermarkstatus.WatermarkStatus;
@@ -216,6 +217,9 @@ public final class StateBootstrapWrapperOperator<
         @Override
         public void emitLatencyMarker(LatencyMarker latencyMarker) {}
 
+        @Override
+        public void emitRecordAttributes(RecordAttributes recordAttributes) {}
+
         @Override
         public void collect(T record) {}
 
