@@ -247,10 +247,10 @@ class PyFlinkBatchExpressionTests(PyFlinkTestCase):
 
         from pyflink.table.expressions import UNBOUNDED_ROW, UNBOUNDED_RANGE, CURRENT_ROW, \
             CURRENT_RANGE
-        self.assertEqual('unboundedRow()', str(UNBOUNDED_ROW))
-        self.assertEqual('unboundedRange()', str(UNBOUNDED_RANGE))
-        self.assertEqual('currentRow()', str(CURRENT_ROW))
-        self.assertEqual('currentRange()', str(CURRENT_RANGE))
+        self.assertEqual('UNBOUNDED_ROW', str(UNBOUNDED_ROW))
+        self.assertEqual('UNBOUNDED_RANGE', str(UNBOUNDED_RANGE))
+        self.assertEqual('CURRENT_ROW', str(CURRENT_ROW))
+        self.assertEqual('CURRENT_RANGE', str(CURRENT_RANGE))
         self.assertEqual('currentDatabase()', str(current_database()))
 
         self.assertEqual('currentDate()', str(current_date()))
@@ -275,6 +275,15 @@ class PyFlinkBatchExpressionTests(PyFlinkTestCase):
                              lit(2).hours)))
         self.assertEqual("dateFormat(time, '%Y, %d %M')",
                          str(date_format(col("time"), "%Y, %d %M")))
+        self.assertEqual("dateFormat(toTimestamp('1970-01-01 08:01:40'), 'yyyy-MM-dd HH:mm:ss')",
+                         str(date_format(to_timestamp('1970-01-01 08:01:40'),
+                             "yyyy-MM-dd HH:mm:ss")))
+        self.assertEqual("dateFormat(toTimestamp('1970-01-01 08:01:40.123456+02:00'), "
+                         "'yyyy-MM-dd HH:mm:ss.SSSSSS z')",
+                         str(date_format(to_timestamp('1970-01-01 08:01:40.123456+02:00'),
+                             'yyyy-MM-dd HH:mm:ss.SSSSSS z')))
+        self.assertEqual("dateFormat('1970-01-01 08:01:40', 'yyyy-MM-dd HH:mm:ss')",
+                         str(date_format("1970-01-01 08:01:40", "yyyy-MM-dd HH:mm:ss")))
         self.assertEqual("timestampDiff(DAY, cast('2016-06-15', DATE), cast('2016-06-18', DATE))",
                          str(timestamp_diff(
                              TimePointUnit.DAY,
