@@ -108,20 +108,14 @@ public final class PythonDriver {
             LOG.info(
                     "--------------------------- Python Process Started --------------------------");
             // print the python process output to stdout and log file
-            final StringBuilder sb = new StringBuilder();
-            try {
-                while (true) {
-                    String line = in.readLine();
-                    if (line == null) {
-                        break;
-                    } else {
-                        System.out.println(line);
-                        sb.append(line);
-                        sb.append("\n");
-                    }
+            while (true) {
+                String line = in.readLine();
+                if (line == null) {
+                    break;
+                } else {
+                    System.out.println(line);
+                    LOG.info(line);
                 }
-            } finally {
-                LOG.info(sb.toString());
             }
             int exitCode = pythonProcess.waitFor();
             LOG.info(
