@@ -31,14 +31,17 @@ import org.apache.flink.python.env.PythonEnvironment;
 import org.apache.flink.python.env.process.ProcessPythonEnvironment;
 import org.apache.flink.python.env.process.ProcessPythonEnvironmentManager;
 import org.apache.flink.python.metric.process.FlinkMetricContainer;
+import org.apache.flink.runtime.execution.Environment;
 import org.apache.flink.runtime.memory.MemoryManager;
 import org.apache.flink.runtime.memory.OpaqueMemoryResource;
 import org.apache.flink.runtime.state.KeyedStateBackend;
 import org.apache.flink.runtime.state.OperatorStateBackend;
 import org.apache.flink.streaming.api.operators.python.process.timer.TimerRegistration;
+import org.apache.flink.streaming.api.operators.python.process.timer.TimerRegistrationAction;
 import org.apache.flink.streaming.api.runners.python.beam.state.BeamStateRequestHandler;
 import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.ShutdownHookUtil;
+import org.apache.flink.util.TemporaryClassLoaderContext;
 import org.apache.flink.util.function.LongFunctionWithException;
 
 import org.apache.beam.model.fnexecution.v1.BeamFnApi;
@@ -84,6 +87,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
@@ -189,7 +193,12 @@ public abstract class BeamPythonFunctionRunner implements PythonFunctionRunner {
 
     private transient Thread shutdownHook;
 
+    private transient Environment environment;
+
+    private transient volatile List<TimerRegistrationAction> unregisteredTimers;
+
     public BeamPythonFunctionRunner(
+            Environment environment,
             String taskName,
             ProcessPythonEnvironmentManager environmentManager,
             @Nullable FlinkMetricContainer flinkMetricContainer,
@@ -203,6 +212,7 @@ public abstract class BeamPythonFunctionRunner implements PythonFunctionRunner {
             FlinkFnApi.CoderInfoDescriptor inputCoderDescriptor,
             FlinkFnApi.CoderInfoDescriptor outputCoderDescriptor,
             Map<String, FlinkFnApi.CoderInfoDescriptor> sideOutputCoderDescriptors) {
+        this.environment = environment;
         this.taskName = Preconditions.checkNotNull(taskName);
         this.environmentManager = Preconditions.checkNotNull(environmentManager);
         this.flinkMetricContainer = flinkMetricContainer;
@@ -237,8 +247,14 @@ public abstract class BeamPythonFunctionRunner implements PythonFunctionRunner {
         // The creation of stageBundleFactory depends on the initialized environment manager.
         environmentManager.open();
 
-        PortablePipelineOptions portableOptions =
-                PipelineOptionsFactory.as(PortablePipelineOptions.class);
+        PortablePipelineOptions portableOptions;
+        try (TemporaryClassLoaderContext ignored =
+                TemporaryClassLoaderContext.of(getClass().getClassLoader())) {
+            // It loads classes using service loader under context classloader in Beam,
+            // make sure the classloader used to load SPI classes is the same as the class loader of
+            // the current class.
+            portableOptions = PipelineOptionsFactory.as(PortablePipelineOptions.class);
+        }
 
         int stateCacheSize = config.get(PythonOptions.STATE_CACHE_SIZE);
         if (stateCacheSize > 0) {
@@ -294,6 +310,8 @@ public abstract class BeamPythonFunctionRunner implements PythonFunctionRunner {
         shutdownHook =
                 ShutdownHookUtil.addShutdownHook(
                         this, BeamPythonFunctionRunner.class.getSimpleName(), LOG);
+
+        unregisteredTimers = Collections.synchronizedList(new LinkedList<>());
     }
 
     @Override
@@ -332,6 +350,16 @@ public abstract class BeamPythonFunctionRunner implements PythonFunctionRunner {
         mainInputReceiver.accept(WindowedValue.valueInGlobalWindow(data));
     }
 
+    @Override
+    public void drainUnregisteredTimers() {
+        synchronized (unregisteredTimers) {
+            for (TimerRegistrationAction timerRegistrationAction : unregisteredTimers) {
+                timerRegistrationAction.registerTimer();
+            }
+            unregisteredTimers.clear();
+        }
+    }
+
     @Override
     public void processTimer(byte[] timerData) throws Exception {
         if (timerInputReceiver == null) {
@@ -622,18 +650,28 @@ public abstract class BeamPythonFunctionRunner implements PythonFunctionRunner {
 
     @VisibleForTesting
     public JobBundleFactory createJobBundleFactory(Struct pipelineOptions) throws Exception {
-        return DefaultJobBundleFactory.create(
-                JobInfo.create(
-                        taskName,
-                        taskName,
-                        environmentManager.createRetrievalToken(),
-                        pipelineOptions));
+        try (TemporaryClassLoaderContext ignored =
+                TemporaryClassLoaderContext.of(getClass().getClassLoader())) {
+            // It loads classes using service loader under context classloader in Beam,
+            // make sure the classloader used to load SPI classes is the same as the class
+            // loader of the current class.
+            return DefaultJobBundleFactory.create(
+                    JobInfo.create(
+                            taskName,
+                            taskName,
+                            environmentManager.createRetrievalToken(),
+                            pipelineOptions));
+        }
     }
 
     /** To make the error messages more user friendly, throws an exception with the boot logs. */
     private StageBundleFactory createStageBundleFactory(
             JobBundleFactory jobBundleFactory, RunnerApi.Environment environment) throws Exception {
-        try {
+        try (TemporaryClassLoaderContext ignored =
+                TemporaryClassLoaderContext.of(getClass().getClassLoader())) {
+            // It loads classes using service loader under context classloader in Beam,
+            // make sure the classloader used to load SPI classes is the same as the class
+            // loader of the current class.
             return jobBundleFactory.forStage(createExecutableStage(environment));
         } catch (Throwable e) {
             throw new RuntimeException(environmentManager.getBootLog(), e);
@@ -664,7 +702,17 @@ public abstract class BeamPythonFunctionRunner implements PythonFunctionRunner {
 
     private TimerReceiverFactory createTimerReceiverFactory() {
         BiConsumer<Timer<?>, TimerInternals.TimerData> timerDataConsumer =
-                (timer, timerData) -> timerRegistration.setTimer((byte[]) timer.getUserKey());
+                (timer, timerData) -> {
+                    TimerRegistrationAction timerRegistrationAction =
+                            new TimerRegistrationAction(
+                                    timerRegistration,
+                                    (byte[]) timer.getUserKey(),
+                                    unregisteredTimers);
+                    unregisteredTimers.add(timerRegistrationAction);
+                    environment
+                            .getMainMailboxExecutor()
+                            .execute(timerRegistrationAction::run, "PythonTimerRegistration");
+                };
         return new TimerReceiverFactory(stageBundleFactory, timerDataConsumer, null);
     }
 
