@@ -21,6 +21,7 @@ package org.apache.flink.streaming.api.utils;
 import org.apache.flink.annotation.Internal;
 import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.io.InputFormat;
+import org.apache.flink.api.common.serialization.SerializerConfigImpl;
 import org.apache.flink.api.common.typeinfo.BasicArrayTypeInfo;
 import org.apache.flink.api.common.typeinfo.BasicTypeInfo;
 import org.apache.flink.api.common.typeinfo.LocalTimeTypeInfo;
@@ -823,7 +824,7 @@ public class PythonTypeUtils {
                         .getCanonicalName()
                         .equals(
                                 "org.apache.flink.formats.avro.typeutils.GenericRecordAvroTypeInfo")) {
-                    return typeInformation.createSerializer(new ExecutionConfig());
+                    return typeInformation.createSerializer(new SerializerConfigImpl());
                 }
             }
 
@@ -1519,7 +1520,7 @@ public class PythonTypeUtils {
                 data.stream()
                         .map(objects -> (T) converter.apply(objects))
                         .collect(Collectors.toList()),
-                dataType.createSerializer(config));
+                dataType.createSerializer(config.getSerializerConfig()));
     }
 
     private static BiFunction<Integer, Function<Integer, Object>, Object> arrayConstructor(
@@ -1970,7 +1971,8 @@ public class PythonTypeUtils {
 
             // other typeinfos will use the corresponding serializer to deserialize data.
             byte[] b = (byte[]) c;
-            TypeSerializer<?> dataSerializer = dataType.createSerializer(config);
+            TypeSerializer<?> dataSerializer =
+                    dataType.createSerializer(config.getSerializerConfig());
             ByteArrayInputStreamWithPos bais = new ByteArrayInputStreamWithPos();
             DataInputViewStreamWrapper baisWrapper = new DataInputViewStreamWrapper(bais);
             bais.setBuffer(b, 0, b.length);
