@@ -19,6 +19,7 @@
 package org.apache.flink.queryablestate.network;
 
 import org.apache.flink.api.common.ExecutionConfig;
+import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.state.ListStateDescriptor;
 import org.apache.flink.api.common.state.MapStateDescriptor;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
@@ -29,6 +30,8 @@ import org.apache.flink.core.fs.CloseableRegistry;
 import org.apache.flink.queryablestate.client.VoidNamespace;
 import org.apache.flink.queryablestate.client.VoidNamespaceSerializer;
 import org.apache.flink.queryablestate.client.state.serialization.KvStateSerializer;
+import org.apache.flink.runtime.jobgraph.JobVertexID;
+import org.apache.flink.runtime.query.KvStateRegistry;
 import org.apache.flink.runtime.query.TaskKvStateRegistry;
 import org.apache.flink.runtime.state.AbstractStateBackend;
 import org.apache.flink.runtime.state.BackendBuildingException;
@@ -43,9 +46,9 @@ import org.apache.flink.runtime.state.internal.InternalMapState;
 import org.apache.flink.runtime.state.metrics.LatencyTrackingStateConfig;
 import org.apache.flink.runtime.state.ttl.TtlTimeProvider;
 
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.MethodSource;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
@@ -58,23 +61,19 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ThreadLocalRandom;
 
-import static org.junit.Assert.assertEquals;
-import static org.mockito.Mockito.mock;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** Tests for {@link KvStateSerializer}. */
-@RunWith(Parameterized.class)
-public class KvStateRequestSerializerTest {
+class KvStateRequestSerializerTest {
 
-    @Parameterized.Parameters
-    public static Collection<Boolean> parameters() {
+    public static Collection<Boolean> data() {
         return Arrays.asList(false, true);
     }
 
-    @Parameterized.Parameter public boolean async;
-
     /** Tests key and namespace serialization utils. */
     @Test
-    public void testKeyAndNamespaceSerialization() throws Exception {
+    void testKeyAndNamespaceSerialization() throws Exception {
         TypeSerializer<Long> keySerializer = LongSerializer.INSTANCE;
         TypeSerializer<String> namespaceSerializer = StringSerializer.INSTANCE;
 
@@ -89,91 +88,124 @@ public class KvStateRequestSerializerTest {
                 KvStateSerializer.deserializeKeyAndNamespace(
                         serializedKeyAndNamespace, keySerializer, namespaceSerializer);
 
-        assertEquals(expectedKey, actual.f0.longValue());
-        assertEquals(expectedNamespace, actual.f1);
+        assertThat(actual.f0.longValue()).isEqualTo(expectedKey);
+        assertThat(actual.f1).isEqualTo(expectedNamespace);
     }
 
     /** Tests key and namespace deserialization utils with too few bytes. */
-    @Test(expected = IOException.class)
-    public void testKeyAndNamespaceDeserializationEmpty() throws Exception {
-        KvStateSerializer.deserializeKeyAndNamespace(
-                new byte[] {}, LongSerializer.INSTANCE, StringSerializer.INSTANCE);
+    @Test
+    void testKeyAndNamespaceDeserializationEmpty() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                KvStateSerializer.deserializeKeyAndNamespace(
+                                        new byte[] {},
+                                        LongSerializer.INSTANCE,
+                                        StringSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests key and namespace deserialization utils with too few bytes. */
-    @Test(expected = IOException.class)
-    public void testKeyAndNamespaceDeserializationTooShort() throws Exception {
-        KvStateSerializer.deserializeKeyAndNamespace(
-                new byte[] {1}, LongSerializer.INSTANCE, StringSerializer.INSTANCE);
+    @Test
+    void testKeyAndNamespaceDeserializationTooShort() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                KvStateSerializer.deserializeKeyAndNamespace(
+                                        new byte[] {1},
+                                        LongSerializer.INSTANCE,
+                                        StringSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests key and namespace deserialization utils with too many bytes. */
-    @Test(expected = IOException.class)
-    public void testKeyAndNamespaceDeserializationTooMany1() throws Exception {
-        // Long + null String + 1 byte
-        KvStateSerializer.deserializeKeyAndNamespace(
-                new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 42, 0, 2},
-                LongSerializer.INSTANCE,
-                StringSerializer.INSTANCE);
+    @Test
+    void testKeyAndNamespaceDeserializationTooMany1() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // Long + null String + 1 byte
+                                KvStateSerializer.deserializeKeyAndNamespace(
+                                        new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 42, 0, 2},
+                                        LongSerializer.INSTANCE,
+                                        StringSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests key and namespace deserialization utils with too many bytes. */
-    @Test(expected = IOException.class)
-    public void testKeyAndNamespaceDeserializationTooMany2() throws Exception {
-        // Long + null String + 2 bytes
-        KvStateSerializer.deserializeKeyAndNamespace(
-                new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 42, 0, 2, 2},
-                LongSerializer.INSTANCE,
-                StringSerializer.INSTANCE);
+    @Test
+    void testKeyAndNamespaceDeserializationTooMany2() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // Long + null String + 2 bytes
+                                KvStateSerializer.deserializeKeyAndNamespace(
+                                        new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 42, 0, 2, 2},
+                                        LongSerializer.INSTANCE,
+                                        StringSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests value serialization utils. */
     @Test
-    public void testValueSerialization() throws Exception {
+    void testValueSerialization() throws Exception {
         TypeSerializer<Long> valueSerializer = LongSerializer.INSTANCE;
         long expectedValue = Long.MAX_VALUE - 1292929292L;
 
         byte[] serializedValue = KvStateSerializer.serializeValue(expectedValue, valueSerializer);
         long actualValue = KvStateSerializer.deserializeValue(serializedValue, valueSerializer);
 
-        assertEquals(expectedValue, actualValue);
+        assertThat(actualValue).isEqualTo(expectedValue);
     }
 
     /** Tests value deserialization with too few bytes. */
-    @Test(expected = IOException.class)
-    public void testDeserializeValueEmpty() throws Exception {
-        KvStateSerializer.deserializeValue(new byte[] {}, LongSerializer.INSTANCE);
+    @Test
+    void testDeserializeValueEmpty() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                KvStateSerializer.deserializeValue(
+                                        new byte[] {}, LongSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests value deserialization with too few bytes. */
-    @Test(expected = IOException.class)
-    public void testDeserializeValueTooShort() throws Exception {
-        // 1 byte (incomplete Long)
-        KvStateSerializer.deserializeValue(new byte[] {1}, LongSerializer.INSTANCE);
+    @Test
+    void testDeserializeValueTooShort() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // 1 byte (incomplete Long)
+                                KvStateSerializer.deserializeValue(
+                                        new byte[] {1}, LongSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests value deserialization with too many bytes. */
-    @Test(expected = IOException.class)
-    public void testDeserializeValueTooMany1() throws Exception {
-        // Long + 1 byte
-        KvStateSerializer.deserializeValue(
-                new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 2}, LongSerializer.INSTANCE);
+    @Test
+    void testDeserializeValueTooMany1() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // Long + 1 byte
+                                KvStateSerializer.deserializeValue(
+                                        new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 2},
+                                        LongSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests value deserialization with too many bytes. */
-    @Test(expected = IOException.class)
-    public void testDeserializeValueTooMany2() throws Exception {
-        // Long + 2 bytes
-        KvStateSerializer.deserializeValue(
-                new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 2, 2}, LongSerializer.INSTANCE);
+    @Test
+    void testDeserializeValueTooMany2() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // Long + 2 bytes
+                                KvStateSerializer.deserializeValue(
+                                        new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 2, 2},
+                                        LongSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests list serialization utils. */
-    @Test
-    public void testListSerialization() throws Exception {
+    @ParameterizedTest
+    @MethodSource("data")
+    void testListSerialization(boolean async) throws Exception {
         final long key = 0L;
         final HeapKeyedStateBackend<Long> longHeapKeyedStateBackend =
-                getLongHeapKeyedStateBackend(key);
+                getLongHeapKeyedStateBackend(key, async);
 
         final InternalListState<Long, VoidNamespace, Long> listState =
                 longHeapKeyedStateBackend.createOrUpdateInternalState(
@@ -225,46 +257,54 @@ public class KvStateRequestSerializerTest {
 
         List<Long> actualValues =
                 KvStateSerializer.deserializeList(serializedValues, valueSerializer);
-        assertEquals(expectedValues, actualValues);
+        assertThat(actualValues).isEqualTo(expectedValues);
 
         // Single value
         long expectedValue = ThreadLocalRandom.current().nextLong();
         byte[] serializedValue = KvStateSerializer.serializeValue(expectedValue, valueSerializer);
         List<Long> actualValue =
                 KvStateSerializer.deserializeList(serializedValue, valueSerializer);
-        assertEquals(1, actualValue.size());
-        assertEquals(expectedValue, actualValue.get(0).longValue());
+        assertThat(actualValue).containsExactly(expectedValue);
     }
 
     /** Tests list deserialization with too few bytes. */
     @Test
-    public void testDeserializeListEmpty() throws Exception {
+    void testDeserializeListEmpty() throws Exception {
         List<Long> actualValue =
                 KvStateSerializer.deserializeList(new byte[] {}, LongSerializer.INSTANCE);
-        assertEquals(0, actualValue.size());
+        assertThat(actualValue).isEmpty();
     }
 
     /** Tests list deserialization with too few bytes. */
-    @Test(expected = IOException.class)
-    public void testDeserializeListTooShort1() throws Exception {
-        // 1 byte (incomplete Long)
-        KvStateSerializer.deserializeList(new byte[] {1}, LongSerializer.INSTANCE);
+    @Test
+    void testDeserializeListTooShort1() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // 1 byte (incomplete Long)
+                                KvStateSerializer.deserializeList(
+                                        new byte[] {1}, LongSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests list deserialization with too few bytes. */
-    @Test(expected = IOException.class)
-    public void testDeserializeListTooShort2() throws Exception {
-        // Long + 1 byte (separator) + 1 byte (incomplete Long)
-        KvStateSerializer.deserializeList(
-                new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 2, 3}, LongSerializer.INSTANCE);
+    @Test
+    void testDeserializeListTooShort2() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // Long + 1 byte (separator) + 1 byte (incomplete Long)
+                                KvStateSerializer.deserializeList(
+                                        new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 2, 3},
+                                        LongSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests map serialization utils. */
-    @Test
-    public void testMapSerialization() throws Exception {
+    @ParameterizedTest
+    @MethodSource("data")
+    public void testMapSerialization(boolean async) throws Exception {
         final long key = 0L;
         final HeapKeyedStateBackend<Long> longHeapKeyedStateBackend =
-                getLongHeapKeyedStateBackend(key);
+                getLongHeapKeyedStateBackend(key, async);
 
         final InternalMapState<Long, VoidNamespace, Long, String> mapState =
                 (InternalMapState<Long, VoidNamespace, Long, String>)
@@ -279,14 +319,16 @@ public class KvStateRequestSerializerTest {
         testMapSerialization(key, mapState);
     }
 
-    private HeapKeyedStateBackend<Long> getLongHeapKeyedStateBackend(final long key)
+    private HeapKeyedStateBackend<Long> getLongHeapKeyedStateBackend(final long key, boolean async)
             throws BackendBuildingException {
         final KeyGroupRange keyGroupRange = new KeyGroupRange(0, 0);
         ExecutionConfig executionConfig = new ExecutionConfig();
+        TaskKvStateRegistry taskKvStateRegistry =
+                new KvStateRegistry().createTaskRegistry(JobID.generate(), new JobVertexID());
         // objects for heap state list serialisation
         final HeapKeyedStateBackend<Long> longHeapKeyedStateBackend =
                 new HeapKeyedStateBackendBuilder<>(
-                                mock(TaskKvStateRegistry.class),
+                                taskKvStateRegistry,
                                 LongSerializer.INSTANCE,
                                 ClassLoader.getSystemClassLoader(),
                                 keyGroupRange.getNumberOfKeyGroups(),
@@ -353,9 +395,9 @@ public class KvStateRequestSerializerTest {
         Map<Long, String> actualValues =
                 KvStateSerializer.deserializeMap(
                         serializedValues, userKeySerializer, userValueSerializer);
-        assertEquals(expectedValues.size(), actualValues.size());
+        assertThat(actualValues).hasSize(expectedValues.size());
         for (Map.Entry<Long, String> actualEntry : actualValues.entrySet()) {
-            assertEquals(expectedValues.get(actualEntry.getKey()), actualEntry.getValue());
+            assertThat(actualEntry.getValue()).isEqualTo(expectedValues.get(actualEntry.getKey()));
         }
 
         // Single value
@@ -372,45 +414,59 @@ public class KvStateRequestSerializerTest {
         Map<Long, String> actualValue =
                 KvStateSerializer.deserializeMap(
                         serializedValue, userKeySerializer, userValueSerializer);
-        assertEquals(1, actualValue.size());
-        assertEquals(expectedValue, actualValue.get(expectedKey));
+        assertThat(actualValue).hasSize(1);
+        assertThat(actualValue.get(expectedKey)).isEqualTo(expectedValue);
     }
 
     /** Tests map deserialization with too few bytes. */
     @Test
-    public void testDeserializeMapEmpty() throws Exception {
+    void testDeserializeMapEmpty() throws Exception {
         Map<Long, String> actualValue =
                 KvStateSerializer.deserializeMap(
                         new byte[] {}, LongSerializer.INSTANCE, StringSerializer.INSTANCE);
-        assertEquals(0, actualValue.size());
+        assertThat(actualValue).hasSize(0);
     }
 
     /** Tests map deserialization with too few bytes. */
-    @Test(expected = IOException.class)
-    public void testDeserializeMapTooShort1() throws Exception {
-        // 1 byte (incomplete Key)
-        KvStateSerializer.deserializeMap(
-                new byte[] {1}, LongSerializer.INSTANCE, StringSerializer.INSTANCE);
+    @Test
+    void testDeserializeMapTooShort1() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // 1 byte (incomplete Key)
+                                KvStateSerializer.deserializeMap(
+                                        new byte[] {1},
+                                        LongSerializer.INSTANCE,
+                                        StringSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests map deserialization with too few bytes. */
-    @Test(expected = IOException.class)
-    public void testDeserializeMapTooShort2() throws Exception {
-        // Long (Key) + 1 byte (incomplete Value)
-        KvStateSerializer.deserializeMap(
-                new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 0},
-                LongSerializer.INSTANCE,
-                LongSerializer.INSTANCE);
+    @Test
+    void testDeserializeMapTooShort2() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // Long (Key) + 1 byte (incomplete Value)
+                                KvStateSerializer.deserializeMap(
+                                        new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 0},
+                                        LongSerializer.INSTANCE,
+                                        LongSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     /** Tests map deserialization with too few bytes. */
-    @Test(expected = IOException.class)
-    public void testDeserializeMapTooShort3() throws Exception {
-        // Long (Key1) + Boolean (false) + Long (Value1) + 1 byte (incomplete Key2)
-        KvStateSerializer.deserializeMap(
-                new byte[] {1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 3},
-                LongSerializer.INSTANCE,
-                LongSerializer.INSTANCE);
+    @Test
+    void testDeserializeMapTooShort3() throws Exception {
+        assertThatThrownBy(
+                        () ->
+                                // Long (Key1) + Boolean (false) + Long (Value1) + 1 byte
+                                // (incomplete Key2)
+                                KvStateSerializer.deserializeMap(
+                                        new byte[] {
+                                            1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 3
+                                        },
+                                        LongSerializer.INSTANCE,
+                                        LongSerializer.INSTANCE))
+                .isInstanceOf(IOException.class);
     }
 
     private byte[] randomByteArray(int capacity) {
