@@ -48,10 +48,12 @@ import org.apache.flink.runtime.jobgraph.JobVertexID;
 import org.apache.flink.runtime.operators.testutils.DummyEnvironment;
 import org.apache.flink.runtime.query.KvStateRegistry;
 import org.apache.flink.runtime.query.KvStateRegistryListener;
+import org.apache.flink.runtime.query.TaskKvStateRegistry;
 import org.apache.flink.runtime.state.AbstractKeyedStateBackend;
 import org.apache.flink.runtime.state.AbstractStateBackend;
 import org.apache.flink.runtime.state.KeyGroupRange;
 import org.apache.flink.runtime.state.KeyedStateBackend;
+import org.apache.flink.runtime.state.KeyedStateBackendParametersImpl;
 import org.apache.flink.runtime.state.internal.InternalKvState;
 import org.apache.flink.runtime.state.memory.MemoryStateBackend;
 import org.apache.flink.runtime.state.ttl.TtlTimeProvider;
@@ -826,17 +828,23 @@ class KvStateServerHandlerTest {
             AbstractStateBackend abstractBackend,
             DummyEnvironment dummyEnv)
             throws java.io.IOException {
+        JobID jobID = dummyEnv.getJobID();
+        KeyGroupRange keyGroupRange = new KeyGroupRange(0, 0);
+        TaskKvStateRegistry kvStateRegistry =
+                registry.createTaskRegistry(dummyEnv.getJobID(), dummyEnv.getJobVertexId());
+        CloseableRegistry cancelStreamRegistry = new CloseableRegistry();
         return abstractBackend.createKeyedStateBackend(
-                dummyEnv,
-                dummyEnv.getJobID(),
-                "test_op",
-                IntSerializer.INSTANCE,
-                numKeyGroups,
-                new KeyGroupRange(0, 0),
-                registry.createTaskRegistry(dummyEnv.getJobID(), dummyEnv.getJobVertexId()),
-                TtlTimeProvider.DEFAULT,
-                new UnregisteredMetricsGroup(),
-                Collections.emptyList(),
-                new CloseableRegistry());
+                new KeyedStateBackendParametersImpl<>(
+                        dummyEnv,
+                        jobID,
+                        "test_op",
+                        IntSerializer.INSTANCE,
+                        numKeyGroups,
+                        keyGroupRange,
+                        kvStateRegistry,
+                        TtlTimeProvider.DEFAULT,
+                        new UnregisteredMetricsGroup(),
+                        Collections.emptyList(),
+                        cancelStreamRegistry));
     }
 }
