@@ -83,8 +83,7 @@ public class JarListHandler
 
     @Override
     protected CompletableFuture<JarListInfo> handleRequest(
-            @Nonnull HandlerRequest<EmptyRequestBody, EmptyMessageParameters> request,
-            @Nonnull RestfulGateway gateway)
+            @Nonnull HandlerRequest<EmptyRequestBody> request, @Nonnull RestfulGateway gateway)
             throws RestHandlerException {
         final String localAddress;
         Preconditions.checkState(localAddressFuture.isDone());
