@@ -106,9 +106,9 @@ class WebFrontendITCase {
             Files.createFile(logFile);
             Files.createFile(outFile);
 
-            config.setString(WebOptions.LOG_PATH, logFile.toAbsolutePath().toString());
-            config.setString(
-                    ConfigConstants.TASK_MANAGER_LOG_PATH_KEY, logFile.toAbsolutePath().toString());
+            config.set(WebOptions.LOG_PATH, logFile.toAbsolutePath().toString());
+            config.set(
+                    TaskManagerOptions.TASK_MANAGER_LOG_PATH, logFile.toAbsolutePath().toString());
         } catch (Exception e) {
             throw new AssertionError("Could not setup test.", e);
         }
