@@ -26,43 +26,34 @@ import org.apache.flink.runtime.dispatcher.DispatcherGateway;
 import org.apache.flink.runtime.rest.handler.HandlerRequest;
 import org.apache.flink.runtime.rest.messages.EmptyMessageParameters;
 import org.apache.flink.runtime.rest.messages.EmptyRequestBody;
-import org.apache.flink.runtime.webmonitor.handlers.JarIdPathParameter;
 import org.apache.flink.runtime.webmonitor.handlers.JarRunHandler;
 import org.apache.flink.runtime.webmonitor.handlers.JarRunMessageParameters;
 import org.apache.flink.runtime.webmonitor.handlers.JarRunRequestBody;
 import org.apache.flink.runtime.webmonitor.handlers.JarUploadHandler;
 import org.apache.flink.util.concurrent.Executors;
 
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.HashMap;
 import java.util.IdentityHashMap;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.TimeUnit;
 
-import static org.junit.Assert.assertEquals;
+import static org.assertj.core.api.Assertions.assertThat;
 
-/** Tests for the {@link WebSubmissionExtension}. */
-public class WebSubmissionExtensionTest {
+class WebSubmissionExtensionTest {
 
     private static final String JAR_NAME = "output-test-program.jar";
 
-    @Rule public final TemporaryFolder temporaryFolder = new TemporaryFolder();
-
     @Test
-    public void applicationsRunInSeparateThreads() throws Exception {
-        final Path tempDir = temporaryFolder.getRoot().toPath();
-
+    void applicationsRunInSeparateThreads(@TempDir Path tempDir) throws Exception {
         final Path uploadDir = Files.createDirectories(tempDir.resolve("uploadDir"));
         // create a copy because the upload handler moves uploaded jars (because it assumes it to be
         // a temporary file)
@@ -71,7 +62,7 @@ public class WebSubmissionExtensionTest {
                         Paths.get(System.getProperty("targetDir")).resolve(JAR_NAME),
                         tempDir.resolve("app.jar"));
 
-        final DispatcherGateway dispatcherGateway = new TestingDispatcherGateway.Builder().build();
+        final DispatcherGateway dispatcherGateway = TestingDispatcherGateway.newBuilder().build();
 
         final ThreadCapturingApplicationRunner threadCapturingApplicationRunner =
                 new ThreadCapturingApplicationRunner();
@@ -87,26 +78,21 @@ public class WebSubmissionExtensionTest {
                         Time.of(5, TimeUnit.SECONDS),
                         () -> threadCapturingApplicationRunner);
 
-        final String jarPath = uploadJar(webSubmissionExtension, jarFile, dispatcherGateway);
-        final String jarId = Paths.get(jarPath).getFileName().toString();
+        final String jarId = uploadJar(webSubmissionExtension, jarFile, dispatcherGateway);
 
         final JarRunHandler jarRunHandler = webSubmissionExtension.getJarRunHandler();
 
-        final Map<String, String> pathParameters = new HashMap<>();
-        pathParameters.put(JarIdPathParameter.KEY, jarId);
-        final HandlerRequest<JarRunRequestBody, JarRunMessageParameters> runRequest =
-                new HandlerRequest(
-                        new JarRunRequestBody(),
-                        new JarRunMessageParameters(),
-                        pathParameters,
-                        Collections.emptyMap());
+        final JarRunMessageParameters parameters = new JarRunMessageParameters();
+        parameters.jarIdPathParameter.resolve(jarId);
+        final HandlerRequest<JarRunRequestBody> runRequest =
+                HandlerRequest.create(new JarRunRequestBody(), parameters);
 
         // run several applications in sequence, and verify that each thread is unique
         int numApplications = 20;
         for (int i = 0; i < numApplications; i++) {
             jarRunHandler.handleRequest(runRequest, dispatcherGateway).get();
         }
-        assertEquals(numApplications, threadCapturingApplicationRunner.getThreads().size());
+        assertThat(threadCapturingApplicationRunner.getThreads().size()).isEqualTo(numApplications);
     }
 
     private static String uploadJar(
@@ -114,12 +100,10 @@ public class WebSubmissionExtensionTest {
             throws Exception {
         final JarUploadHandler jarUploadHandler = extension.getJarUploadHandler();
 
-        final HandlerRequest<EmptyRequestBody, EmptyMessageParameters> uploadRequest =
-                new HandlerRequest<>(
+        final HandlerRequest<EmptyRequestBody> uploadRequest =
+                HandlerRequest.create(
                         EmptyRequestBody.getInstance(),
                         EmptyMessageParameters.getInstance(),
-                        Collections.emptyMap(),
-                        Collections.emptyMap(),
                         Collections.singletonList(jarFile.toFile()));
 
         return jarUploadHandler.handleRequest(uploadRequest, dispatcherGateway).get().getFilename();
