@@ -21,35 +21,34 @@ package org.apache.flink.runtime.webmonitor.history;
 import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.runtime.rest.handler.router.Router;
+import org.apache.flink.runtime.webmonitor.testutils.HttpUtils;
 import org.apache.flink.runtime.webmonitor.utils.WebFrontendBootstrap;
-import org.apache.flink.util.TestLogger;
 
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 import org.slf4j.LoggerFactory;
 
-import java.io.File;
+import java.nio.file.Files;
+import java.nio.file.Path;
 
-import static org.hamcrest.CoreMatchers.containsString;
-import static org.hamcrest.core.Is.is;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for the HistoryServerStaticFileServerHandler. */
-public class HistoryServerStaticFileServerHandlerTest extends TestLogger {
-
-    @Rule public TemporaryFolder tmp = new TemporaryFolder();
+class HistoryServerStaticFileServerHandlerTest {
 
     @Test
-    public void testRespondWithFile() throws Exception {
-        File webDir = tmp.newFolder("webDir");
+    void testRespondWithFile(@TempDir Path tmpDir) throws Exception {
+        final Path webDir = Files.createDirectory(tmpDir.resolve("webDir"));
+        final Path uploadDir = Files.createDirectory(tmpDir.resolve("uploadDir"));
+
         Router router =
-                new Router().addGet("/:*", new HistoryServerStaticFileServerHandler(webDir));
+                new Router()
+                        .addGet("/:*", new HistoryServerStaticFileServerHandler(webDir.toFile()));
         WebFrontendBootstrap webUI =
                 new WebFrontendBootstrap(
                         router,
                         LoggerFactory.getLogger(HistoryServerStaticFileServerHandlerTest.class),
-                        tmp.newFolder("uploadDir"),
+                        uploadDir.toFile(),
                         null,
                         "localhost",
                         0,
@@ -59,37 +58,36 @@ public class HistoryServerStaticFileServerHandlerTest extends TestLogger {
         try {
             // verify that 404 message is returned when requesting a non-existent file
             Tuple2<Integer, String> notFound404 =
-                    HistoryServerTest.getFromHTTP("http://localhost:" + port + "/hello");
-            Assert.assertThat(notFound404.f0, is(404));
-            Assert.assertThat(notFound404.f1, containsString("not found"));
+                    HttpUtils.getFromHTTP("http://localhost:" + port + "/hello");
+            assertThat(notFound404.f0).isEqualTo(404);
+            assertThat(notFound404.f1).contains("not found");
 
             // verify that a) a file can be loaded using the ClassLoader and b) that the
             // HistoryServer
             // index_hs.html is injected
             Tuple2<Integer, String> index =
-                    HistoryServerTest.getFromHTTP("http://localhost:" + port + "/index.html");
-            Assert.assertThat(index.f0, is(200));
-            Assert.assertThat(index.f1, containsString("Apache Flink Web Dashboard"));
+                    HttpUtils.getFromHTTP("http://localhost:" + port + "/index.html");
+            assertThat(index.f0).isEqualTo(200);
+            assertThat(index.f1).contains("Apache Flink Web Dashboard");
 
             // verify that index.html is appended if the request path ends on '/'
             Tuple2<Integer, String> index2 =
-                    HistoryServerTest.getFromHTTP("http://localhost:" + port + "/");
-            Assert.assertEquals(index, index2);
+                    HttpUtils.getFromHTTP("http://localhost:" + port + "/");
+            assertThat(index2).isEqualTo(index);
 
             // verify that a 405 message is returned when requesting a directory
-            File dir = new File(webDir, "dir.json");
-            dir.mkdirs();
+            Files.createDirectory(webDir.resolve("dir.json"));
             Tuple2<Integer, String> dirNotFound =
-                    HistoryServerTest.getFromHTTP("http://localhost:" + port + "/dir");
-            Assert.assertThat(dirNotFound.f0, is(405));
-            Assert.assertThat(dirNotFound.f1, containsString("not found"));
+                    HttpUtils.getFromHTTP("http://localhost:" + port + "/dir");
+            assertThat(dirNotFound.f0).isEqualTo(405);
+            assertThat(dirNotFound.f1).contains("not found");
 
             // verify that a 403 message is returned when requesting a file outside the webDir
-            tmp.newFile("secret");
+            Files.createFile(tmpDir.resolve("secret"));
             Tuple2<Integer, String> dirOutsideDirectory =
-                    HistoryServerTest.getFromHTTP("http://localhost:" + port + "/../secret");
-            Assert.assertThat(dirOutsideDirectory.f0, is(403));
-            Assert.assertThat(dirOutsideDirectory.f1, containsString("Forbidden"));
+                    HttpUtils.getFromHTTP("http://localhost:" + port + "/../secret");
+            assertThat(dirOutsideDirectory.f0).isEqualTo(403);
+            assertThat(dirOutsideDirectory.f1).contains("Forbidden");
         } finally {
             webUI.shutdown();
         }
