@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-import { NodesItem } from './job-detail';
+import { NodesItem, NodesItemCorrect, VerticesLink } from './job-detail';
 
 export interface Plan {
   plan: {
@@ -25,3 +25,8 @@ export interface Plan {
     nodes: NodesItem[];
   };
 }
+
+export interface PlanDetail {
+  nodes: NodesItemCorrect[];
+  links: VerticesLink[];
+}
