@@ -17,22 +17,28 @@
  */
 
 import { ChangeDetectorRef, Component, OnInit, ChangeDetectionStrategy, OnDestroy, Inject } from '@angular/core';
+import { FormsModule } from '@angular/forms';
 import { of, Subject } from 'rxjs';
 import { catchError, takeUntil } from 'rxjs/operators';
 
+import { AddonCompactComponent } from '@flink-runtime-web/components/addon-compact/addon-compact.component';
+import { AutoResizeDirective } from '@flink-runtime-web/components/editor/auto-resize.directive';
 import {
   JOB_MANAGER_MODULE_CONFIG,
   JOB_MANAGER_MODULE_DEFAULT_CONFIG,
   JobManagerModuleConfig
 } from '@flink-runtime-web/pages/job-manager/job-manager.config';
 import { ConfigService, JobManagerService } from '@flink-runtime-web/services';
+import { NzCodeEditorModule } from 'ng-zorro-antd/code-editor';
 import { EditorOptions } from 'ng-zorro-antd/code-editor/typings';
 
 @Component({
   selector: 'flink-job-manager-stdout',
   templateUrl: './job-manager-stdout.component.html',
   styleUrls: ['./job-manager-stdout.component.less'],
-  changeDetection: ChangeDetectionStrategy.OnPush
+  changeDetection: ChangeDetectionStrategy.OnPush,
+  imports: [NzCodeEditorModule, AutoResizeDirective, FormsModule, AddonCompactComponent],
+  standalone: true
 })
 export class JobManagerStdoutComponent implements OnInit, OnDestroy {
   public readonly downloadName = `jobmanager_stdout`;
