@@ -19,6 +19,7 @@
 package org.apache.flink.runtime.checkpoint;
 
 import org.apache.flink.annotation.VisibleForTesting;
+import org.apache.flink.runtime.state.AbstractChannelStateHandle;
 import org.apache.flink.runtime.state.CompositeStateHandle;
 import org.apache.flink.runtime.state.InputChannelStateHandle;
 import org.apache.flink.runtime.state.KeyedStateHandle;
@@ -33,8 +34,12 @@ import org.apache.flink.runtime.state.StateUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.util.ArrayList;
+import java.util.Collection;
 import java.util.List;
+import java.util.Objects;
+import java.util.function.Function;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 import static org.apache.flink.runtime.state.AbstractChannelStateHandle.collectUniqueDelegates;
 import static org.apache.flink.util.Preconditions.checkNotNull;
@@ -130,21 +135,26 @@ public class OperatorSubtaskState implements CompositeStateHandle {
         this.inputRescalingDescriptor = checkNotNull(inputRescalingDescriptor);
         this.outputRescalingDescriptor = checkNotNull(outputRescalingDescriptor);
 
-        long calculateStateSize = managedOperatorState.getStateSize();
-        calculateStateSize += rawOperatorState.getStateSize();
-        calculateStateSize += managedKeyedState.getStateSize();
-        calculateStateSize += rawKeyedState.getStateSize();
-        calculateStateSize += inputChannelState.getStateSize();
-        calculateStateSize += resultSubpartitionState.getStateSize();
-        stateSize = calculateStateSize;
+        this.stateSize = streamSubCollections().mapToLong(StateObject::getStateSize).sum();
+        this.checkpointedSize =
+                streamSubCollections().mapToLong(StateObjectCollection::getCheckpointedSize).sum();
+    }
 
-        long calculateCheckpointedSize = managedOperatorState.getCheckpointedSize();
-        calculateCheckpointedSize += rawOperatorState.getCheckpointedSize();
-        calculateCheckpointedSize += managedKeyedState.getCheckpointedSize();
-        calculateCheckpointedSize += rawKeyedState.getCheckpointedSize();
-        calculateCheckpointedSize += inputChannelState.getCheckpointedSize();
-        calculateCheckpointedSize += resultSubpartitionState.getCheckpointedSize();
-        this.checkpointedSize = calculateCheckpointedSize;
+    private Stream<StateObjectCollection<?>> streamSubCollections() {
+        return Stream.of(streamOperatorAndKeyedStates(), streamChannelStates())
+                .flatMap(Function.identity());
+    }
+
+    private Stream<StateObjectCollection<? extends StateObject>> streamOperatorAndKeyedStates() {
+        return Stream.of(managedOperatorState, rawOperatorState, managedKeyedState, rawKeyedState)
+                .filter(Objects::nonNull);
+    }
+
+    private Stream<StateObjectCollection<? extends AbstractChannelStateHandle<?>>>
+            streamChannelStates() {
+        return Stream.<StateObjectCollection<? extends AbstractChannelStateHandle<?>>>of(
+                        inputChannelState, resultSubpartitionState)
+                .filter(Objects::nonNull);
     }
 
     @VisibleForTesting
@@ -194,22 +204,17 @@ public class OperatorSubtaskState implements CompositeStateHandle {
         return outputRescalingDescriptor;
     }
 
+    public List<StateObject> getDiscardables() {
+        return Stream.concat(
+                        streamOperatorAndKeyedStates().flatMap(Collection::stream),
+                        collectUniqueDelegates(streamChannelStates()))
+                .collect(Collectors.toList());
+    }
+
     @Override
     public void discardState() {
         try {
-            List<StateObject> toDispose =
-                    new ArrayList<>(
-                            managedOperatorState.size()
-                                    + rawOperatorState.size()
-                                    + managedKeyedState.size()
-                                    + rawKeyedState.size()
-                                    + inputChannelState.size()
-                                    + resultSubpartitionState.size());
-            toDispose.addAll(managedOperatorState);
-            toDispose.addAll(rawOperatorState);
-            toDispose.addAll(managedKeyedState);
-            toDispose.addAll(rawKeyedState);
-            toDispose.addAll(collectUniqueDelegates(inputChannelState, resultSubpartitionState));
+            List<StateObject> toDispose = getDiscardables();
             StateUtil.bestEffortDiscardAllStateObjects(toDispose);
         } catch (Exception e) {
             LOG.warn("Error while discarding operator states.", e);
