@@ -61,6 +61,7 @@ import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Executor;
 import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.TimeUnit;
 
 import static org.apache.flink.runtime.io.network.metrics.NettyShuffleMetricFactory.METRIC_GROUP_INPUT;
 import static org.apache.flink.runtime.io.network.metrics.NettyShuffleMetricFactory.METRIC_GROUP_OUTPUT;
@@ -68,6 +69,7 @@ import static org.apache.flink.runtime.io.network.metrics.NettyShuffleMetricFact
 import static org.apache.flink.runtime.io.network.metrics.NettyShuffleMetricFactory.registerDebloatingTaskMetrics;
 import static org.apache.flink.runtime.io.network.metrics.NettyShuffleMetricFactory.registerInputMetrics;
 import static org.apache.flink.runtime.io.network.metrics.NettyShuffleMetricFactory.registerOutputMetrics;
+import static org.apache.flink.util.ExecutorUtils.gracefulShutdown;
 import static org.apache.flink.util.Preconditions.checkArgument;
 import static org.apache.flink.util.Preconditions.checkNotNull;
 
@@ -409,15 +411,15 @@ public class NettyShuffleEnvironment
             }
 
             try {
-                batchShuffleReadBufferPool.destroy();
+                gracefulShutdown(10, TimeUnit.SECONDS, batchShuffleReadIOExecutor);
             } catch (Throwable t) {
-                LOG.warn("Cannot shut down batch shuffle read buffer pool properly.", t);
+                LOG.warn("Cannot shut down batch shuffle read IO executor properly.", t);
             }
 
             try {
-                batchShuffleReadIOExecutor.shutdown();
+                batchShuffleReadBufferPool.destroy();
             } catch (Throwable t) {
-                LOG.warn("Cannot shut down batch shuffle read IO executor properly.", t);
+                LOG.warn("Cannot shut down batch shuffle read buffer pool properly.", t);
             }
 
             isClosed = true;
