@@ -23,7 +23,6 @@ import org.apache.flink.api.common.InvalidProgramException;
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.cache.DistributedCache;
 import org.apache.flink.configuration.Configuration;
-import org.apache.flink.configuration.StateChangelogOptionsInternal;
 import org.apache.flink.core.execution.JobStatusHook;
 import org.apache.flink.core.fs.Path;
 import org.apache.flink.runtime.blob.PermanentBlobKey;
@@ -33,7 +32,6 @@ import org.apache.flink.runtime.jobmanager.scheduler.SlotSharingGroup;
 import org.apache.flink.util.InstantiationUtil;
 import org.apache.flink.util.IterableUtils;
 import org.apache.flink.util.SerializedValue;
-import org.apache.flink.util.TernaryBoolean;
 
 import javax.annotation.Nullable;
 
@@ -79,7 +77,7 @@ public class JobGraph implements Serializable {
             new LinkedHashMap<JobVertexID, JobVertex>();
 
     /** The job configuration attached to this job. */
-    private final Configuration jobConfiguration = new Configuration();
+    private Configuration jobConfiguration = new Configuration();
 
     /** ID of this job. May be set if specific job id is desired (e.g. session management) */
     private JobID jobID;
@@ -200,6 +198,10 @@ public class JobGraph implements Serializable {
         return this.jobName;
     }
 
+    public void setJobConfiguration(Configuration jobConfiguration) {
+        this.jobConfiguration = jobConfiguration;
+    }
+
     /**
      * Returns the configuration object for this job. Job-wide parameters should be set into that
      * configuration object.
@@ -644,16 +646,6 @@ public class JobGraph implements Serializable {
         }
     }
 
-    public void setChangelogStateBackendEnabled(TernaryBoolean changelogStateBackendEnabled) {
-        if (changelogStateBackendEnabled == null
-                || TernaryBoolean.UNDEFINED.equals(changelogStateBackendEnabled)) {
-            return;
-        }
-        this.jobConfiguration.setBoolean(
-                StateChangelogOptionsInternal.ENABLE_CHANGE_LOG_FOR_APPLICATION,
-                changelogStateBackendEnabled.getAsBoolean());
-    }
-
     public void setJobStatusHooks(List<JobStatusHook> hooks) {
         checkNotNull(hooks, "Setting the JobStatusHook list to null is not allowed.");
         this.jobStatusHooks = hooks;
