@@ -37,6 +37,7 @@ import org.apache.flink.runtime.blocklist.BlocklistUtils;
 import org.apache.flink.runtime.checkpoint.CheckpointMetrics;
 import org.apache.flink.runtime.checkpoint.CheckpointStatsSnapshot;
 import org.apache.flink.runtime.checkpoint.CompletedCheckpoint;
+import org.apache.flink.runtime.checkpoint.SubTaskInitializationMetrics;
 import org.apache.flink.runtime.checkpoint.TaskStateSnapshot;
 import org.apache.flink.runtime.clusterframework.types.AllocationID;
 import org.apache.flink.runtime.clusterframework.types.ResourceID;
@@ -70,7 +71,6 @@ import org.apache.flink.runtime.leaderretrieval.LeaderRetrievalService;
 import org.apache.flink.runtime.messages.Acknowledge;
 import org.apache.flink.runtime.messages.FlinkJobNotFoundException;
 import org.apache.flink.runtime.messages.checkpoint.DeclineCheckpoint;
-import org.apache.flink.runtime.messages.webmonitor.JobDetails;
 import org.apache.flink.runtime.metrics.groups.JobManagerJobMetricGroup;
 import org.apache.flink.runtime.operators.coordination.CoordinationRequest;
 import org.apache.flink.runtime.operators.coordination.CoordinationResponse;
@@ -311,7 +311,7 @@ public class JobMaster extends FencedRpcEndpoint<JobMasterId>
         this.retrieveTaskManagerHostName =
                 jobMasterConfiguration
                         .getConfiguration()
-                        .getBoolean(JobManagerOptions.RETRIEVE_TASK_MANAGER_HOSTNAME);
+                        .get(JobManagerOptions.RETRIEVE_TASK_MANAGER_HOSTNAME);
 
         final String jobName = jobGraph.getName();
         final JobID jid = jobGraph.getJobID();
@@ -587,6 +587,12 @@ public class JobMaster extends FencedRpcEndpoint<JobMasterId>
                 jobID, executionAttemptID, checkpointId, checkpointMetrics);
     }
 
+    @Override
+    public void reportInitializationMetrics(
+            JobID jobId, SubTaskInitializationMetrics initializationMetrics) {
+        schedulerNG.reportInitializationMetrics(jobId, initializationMetrics);
+    }
+
     // TODO: This method needs a leader session ID
     @Override
     public void declineCheckpoint(DeclineCheckpoint decline) {
@@ -833,14 +839,29 @@ public class JobMaster extends FencedRpcEndpoint<JobMasterId>
     public void disconnectResourceManager(
             final ResourceManagerId resourceManagerId, final Exception cause) {
 
-        if (isConnectingToResourceManager(resourceManagerId)) {
+        if (resourceManagerAddress == null) {
+            log.debug(
+                    "Disconnecting ResourceManager {} was triggered with no ResourceManager address "
+                            + "being set (anymore). That either indicates that the ResourceManager "
+                            + "lost leadership in the mean time or the message was received while "
+                            + "shutting down the JobMaster. No reconnect will be initiated.",
+                    resourceManagerId);
+        } else if (!resourceManagerAddress.getResourceManagerId().equals(resourceManagerId)) {
+            log.debug(
+                    "Disconnecting ResourceManager {} was received while this instance is currently "
+                            + "connected to another ResourceManager {} indicating that a ResourceManager "
+                            + "leader change happened. No reconnect will be initiated.",
+                    resourceManagerId,
+                    resourceManagerAddress.getResourceManagerId());
+        } else {
             reconnectToResourceManager(cause);
         }
     }
 
-    private boolean isConnectingToResourceManager(ResourceManagerId resourceManagerId) {
-        return resourceManagerAddress != null
-                && resourceManagerAddress.getResourceManagerId().equals(resourceManagerId);
+    private void shutdownResourceManagerConnection(Exception cause) {
+        // unsetting the resourceManagerAddress will prevent reconnection
+        resourceManagerAddress = null;
+        closeResourceManagerConnection(cause);
     }
 
     @Override
@@ -854,11 +875,6 @@ public class JobMaster extends FencedRpcEndpoint<JobMasterId>
         return resourceManagerHeartbeatManager.requestHeartbeat(resourceID, null);
     }
 
-    @Override
-    public CompletableFuture<JobDetails> requestJobDetails(Time timeout) {
-        return CompletableFuture.completedFuture(schedulerNG.requestJobDetails());
-    }
-
     @Override
     public CompletableFuture<JobStatus> requestJobStatus(Time timeout) {
         return CompletableFuture.completedFuture(schedulerNG.requestJobStatus());
@@ -1044,13 +1060,14 @@ public class JobMaster extends FencedRpcEndpoint<JobMasterId>
 
         final CompletableFuture<Void> terminationFuture = stopScheduling();
 
-        return FutureUtils.runAfterwards(
+        return FutureUtils.runAfterwardsAsync(
                 terminationFuture,
                 () -> {
                     shuffleMaster.unregisterJob(jobGraph.getJobID());
                     disconnectTaskManagerResourceManagerConnections(cause);
                     stopJobMasterServices();
-                });
+                },
+                getMainThreadExecutor());
     }
 
     private void disconnectTaskManagerResourceManagerConnections(Exception cause) {
@@ -1062,8 +1079,7 @@ public class JobMaster extends FencedRpcEndpoint<JobMasterId>
             disconnectTaskManager(taskManagerResourceId, cause);
         }
 
-        // disconnect from resource manager:
-        closeResourceManagerConnection(cause);
+        shutdownResourceManagerConnection(cause);
     }
 
     private void stopHeartbeatServices() {
