@@ -27,7 +27,6 @@ import org.apache.flink.runtime.highavailability.JobResultStore;
 import org.apache.flink.runtime.jobmaster.factories.JobMasterServiceProcessFactory;
 import org.apache.flink.runtime.leaderelection.LeaderContender;
 import org.apache.flink.runtime.leaderelection.LeaderElection;
-import org.apache.flink.runtime.leaderelection.LeadershipLostException;
 import org.apache.flink.runtime.messages.Acknowledge;
 import org.apache.flink.runtime.messages.webmonitor.JobDetails;
 import org.apache.flink.runtime.rpc.FatalErrorHandler;
@@ -256,47 +255,36 @@ public class JobMasterServiceLeadershipRunner implements JobManagerRunner, Leade
         sequentialOperation =
                 sequentialOperation.thenCompose(
                         unused ->
-                                supplyAsyncIfValidLeader(
-                                                leaderSessionId,
-                                                () ->
-                                                        jobResultStore.hasJobResultEntryAsync(
-                                                                getJobID()),
-                                                () ->
-                                                        FutureUtils.completedExceptionally(
-                                                                new LeadershipLostException(
-                                                                        "The leadership is lost.")))
-                                        .handle(
-                                                (hasJobResult, throwable) -> {
-                                                    if (throwable
-                                                            instanceof LeadershipLostException) {
-                                                        printLogIfNotValidLeader(
-                                                                "verify job result entry",
-                                                                leaderSessionId);
-                                                        return null;
-                                                    } else if (throwable != null) {
-                                                        ExceptionUtils.rethrow(throwable);
-                                                    }
+                                jobResultStore
+                                        .hasJobResultEntryAsync(getJobID())
+                                        .thenCompose(
+                                                hasJobResult -> {
                                                     if (hasJobResult) {
-                                                        handleJobAlreadyDoneIfValidLeader(
+                                                        return handleJobAlreadyDoneIfValidLeader(
                                                                 leaderSessionId);
                                                     } else {
-                                                        createNewJobMasterServiceProcessIfValidLeader(
+                                                        return createNewJobMasterServiceProcessIfValidLeader(
                                                                 leaderSessionId);
                                                     }
-                                                    return null;
                                                 }));
         handleAsyncOperationError(sequentialOperation, "Could not start the job manager.");
     }
 
-    private void handleJobAlreadyDoneIfValidLeader(UUID leaderSessionId) {
-        runIfValidLeader(
+    private CompletableFuture<Void> handleJobAlreadyDoneIfValidLeader(UUID leaderSessionId) {
+        return runIfValidLeader(
                 leaderSessionId, () -> jobAlreadyDone(leaderSessionId), "check completed job");
     }
 
-    private void createNewJobMasterServiceProcessIfValidLeader(UUID leaderSessionId) {
-        runIfValidLeader(
+    private CompletableFuture<Void> createNewJobMasterServiceProcessIfValidLeader(
+            UUID leaderSessionId) {
+        return runIfValidLeader(
                 leaderSessionId,
                 () ->
+                        // the heavy lifting of the JobMasterServiceProcess instantiation is still
+                        // done asynchronously (see
+                        // DefaultJobMasterServiceFactory#createJobMasterService executing the logic
+                        // on the leaderOperation thread in the DefaultLeaderElectionService should
+                        // be, therefore, fine
                         ThrowingRunnable.unchecked(
                                         () -> createNewJobMasterServiceProcess(leaderSessionId))
                                 .run(),
@@ -354,16 +342,18 @@ public class JobMasterServiceLeadershipRunner implements JobManagerRunner, Leade
     private void confirmLeadership(
             UUID leaderSessionId, CompletableFuture<String> leaderAddressFuture) {
         FutureUtils.assertNoException(
-                leaderAddressFuture.thenAccept(
+                leaderAddressFuture.thenCompose(
                         address ->
-                                runIfValidLeader(
-                                        leaderSessionId,
-                                        () -> {
-                                            LOG.debug("Confirm leadership {}.", leaderSessionId);
-                                            leaderElection.confirmLeadership(
-                                                    leaderSessionId, address);
-                                        },
-                                        "confirming leadership")));
+                                callIfRunning(
+                                                () -> {
+                                                    LOG.debug(
+                                                            "Confirm leadership {}.",
+                                                            leaderSessionId);
+                                                    return leaderElection.confirmLeadershipAsync(
+                                                            leaderSessionId, address);
+                                                },
+                                                "confirming leadership")
+                                        .orElse(FutureUtils.completedVoidFuture())));
     }
 
     private void forwardResultFuture(
@@ -497,20 +487,32 @@ public class JobMasterServiceLeadershipRunner implements JobManagerRunner, Leade
         return state == State.RUNNING;
     }
 
-    private void runIfValidLeader(
+    private CompletableFuture<Void> runIfValidLeader(
             UUID expectedLeaderId, Runnable action, Runnable noLeaderFallback) {
         synchronized (lock) {
-            if (isValidLeader(expectedLeaderId)) {
-                action.run();
+            if (isRunning() && leaderElection != null) {
+                return leaderElection
+                        .hasLeadershipAsync(expectedLeaderId)
+                        .thenAccept(
+                                hasLeadership -> {
+                                    synchronized (lock) {
+                                        if (isRunning() && hasLeadership) {
+                                            action.run();
+                                        } else {
+                                            noLeaderFallback.run();
+                                        }
+                                    }
+                                });
             } else {
                 noLeaderFallback.run();
+                return FutureUtils.completedVoidFuture();
             }
         }
     }
 
-    private void runIfValidLeader(
+    private CompletableFuture<Void> runIfValidLeader(
             UUID expectedLeaderId, Runnable action, String noLeaderFallbackCommandDescription) {
-        runIfValidLeader(
+        return runIfValidLeader(
                 expectedLeaderId,
                 action,
                 () ->
@@ -518,26 +520,6 @@ public class JobMasterServiceLeadershipRunner implements JobManagerRunner, Leade
                                 noLeaderFallbackCommandDescription, expectedLeaderId));
     }
 
-    private <T> CompletableFuture<T> supplyAsyncIfValidLeader(
-            UUID expectedLeaderId,
-            Supplier<CompletableFuture<T>> supplier,
-            Supplier<CompletableFuture<T>> noLeaderFallback) {
-        final CompletableFuture<T> resultFuture = new CompletableFuture<>();
-        runIfValidLeader(
-                expectedLeaderId,
-                () -> FutureUtils.forward(supplier.get(), resultFuture),
-                () -> FutureUtils.forward(noLeaderFallback.get(), resultFuture));
-
-        return resultFuture;
-    }
-
-    @GuardedBy("lock")
-    private boolean isValidLeader(UUID expectedLeaderId) {
-        return isRunning()
-                && leaderElection != null
-                && leaderElection.hasLeadership(expectedLeaderId);
-    }
-
     private <T> void forwardIfValidLeader(
             UUID expectedLeaderId,
             CompletableFuture<? extends T> source,
