@@ -30,8 +30,10 @@ import org.apache.flink.metrics.reporter.MetricReporterFactory;
 import org.apache.flink.runtime.metrics.filter.DefaultMetricFilter;
 import org.apache.flink.runtime.metrics.filter.MetricFilter;
 import org.apache.flink.runtime.metrics.scope.ScopeFormat;
+import org.apache.flink.traces.reporter.TraceReporterFactory;
+import org.apache.flink.util.CollectionUtil;
 
-import org.apache.flink.shaded.guava30.com.google.common.collect.Iterators;
+import org.apache.flink.shaded.guava31.com.google.common.collect.Iterators;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -41,7 +43,6 @@ import javax.annotation.Nullable;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
@@ -65,12 +66,12 @@ public final class ReporterSetup {
     private static final Logger LOG = LoggerFactory.getLogger(ReporterSetup.class);
 
     // regex pattern to split the defined reporters
-    private static final Pattern reporterListPattern = Pattern.compile("\\s*,\\s*");
+    private static final Pattern metricReporterListPattern = Pattern.compile("\\s*,\\s*");
 
     // regex pattern to extract the name from reporter configuration keys, e.g. "rep" from
     // "metrics.reporter.rep.class"
     @SuppressWarnings("deprecation")
-    private static final Pattern reporterClassPattern =
+    private static final Pattern metricReporterClassPattern =
             Pattern.compile(
                     Pattern.quote(ConfigConstants.METRICS_REPORTER_PREFIX)
                             +
@@ -189,17 +190,23 @@ public final class ReporterSetup {
 
     public static List<ReporterSetup> fromConfiguration(
             final Configuration configuration, @Nullable final PluginManager pluginManager) {
-        String includedReportersString = configuration.getString(MetricOptions.REPORTERS_LIST, "");
+        String includedReportersString = configuration.get(MetricOptions.REPORTERS_LIST, "");
 
         Set<String> namedReporters =
-                findEnabledReportersInConfiguration(configuration, includedReportersString);
+                findEnabledTraceReportersInConfiguration(
+                        configuration,
+                        includedReportersString,
+                        metricReporterListPattern,
+                        metricReporterClassPattern,
+                        ConfigConstants.METRICS_REPORTER_PREFIX);
 
         if (namedReporters.isEmpty()) {
             return Collections.emptyList();
         }
 
         final List<Tuple2<String, Configuration>> reporterConfigurations =
-                loadReporterConfigurations(configuration, namedReporters);
+                loadReporterConfigurations(
+                        configuration, namedReporters, ConfigConstants.METRICS_REPORTER_PREFIX);
 
         final Map<String, MetricReporterFactory> reporterFactories =
                 loadAvailableReporterFactories(pluginManager);
@@ -207,8 +214,12 @@ public final class ReporterSetup {
         return setupReporters(reporterFactories, reporterConfigurations);
     }
 
-    private static Set<String> findEnabledReportersInConfiguration(
-            Configuration configuration, String includedReportersString) {
+    public static Set<String> findEnabledTraceReportersInConfiguration(
+            Configuration configuration,
+            String includedReportersString,
+            Pattern reporterListPattern,
+            Pattern reporterClassPattern,
+            String reporterPrefix) {
         Set<String> includedReporters =
                 reporterListPattern
                         .splitAsStream(includedReportersString)
@@ -219,24 +230,26 @@ public final class ReporterSetup {
         // use a TreeSet to make the reporter order deterministic, which is useful for testing
         Set<String> namedOrderedReporters = new TreeSet<>(String::compareTo);
 
-        // scan entire configuration for keys starting with METRICS_REPORTER_PREFIX and determine
+        // scan entire configuration for keys starting with reporterPrefix and determine
         // the set of enabled reporters
         for (String key : configuration.keySet()) {
-            if (key.startsWith(ConfigConstants.METRICS_REPORTER_PREFIX)) {
+            if (key.startsWith(reporterPrefix)) {
                 Matcher matcher = reporterClassPattern.matcher(key);
                 if (matcher.matches()) {
                     String reporterName = matcher.group(1);
                     if (includedReporters.isEmpty() || includedReporters.contains(reporterName)) {
                         if (namedOrderedReporters.contains(reporterName)) {
                             LOG.warn(
-                                    "Duplicate class configuration detected for reporter {}.",
+                                    "Duplicate class configuration detected for {}{}.",
+                                    reporterPrefix.replace('.', ' '),
                                     reporterName);
                         } else {
                             namedOrderedReporters.add(reporterName);
                         }
                     } else {
                         LOG.info(
-                                "Excluding reporter {}, not configured in reporter list ({}).",
+                                "Excluding {}{}, not configured in reporter list ({}).",
+                                reporterPrefix.replace('.', ' '),
                                 reporterName,
                                 includedReportersString);
                     }
@@ -246,16 +259,15 @@ public final class ReporterSetup {
         return namedOrderedReporters;
     }
 
-    private static List<Tuple2<String, Configuration>> loadReporterConfigurations(
-            Configuration configuration, Set<String> namedReporters) {
+    public static List<Tuple2<String, Configuration>> loadReporterConfigurations(
+            Configuration configuration, Set<String> namedReporters, String reporterPrefix) {
         final List<Tuple2<String, Configuration>> reporterConfigurations =
                 new ArrayList<>(namedReporters.size());
 
         for (String namedReporter : namedReporters) {
             DelegatingConfiguration delegatingConfiguration =
                     new DelegatingConfiguration(
-                            configuration,
-                            ConfigConstants.METRICS_REPORTER_PREFIX + namedReporter + '.');
+                            configuration, reporterPrefix + namedReporter + '.');
 
             reporterConfigurations.add(Tuple2.of(namedReporter, delegatingConfiguration));
         }
@@ -264,7 +276,8 @@ public final class ReporterSetup {
 
     private static Map<String, MetricReporterFactory> loadAvailableReporterFactories(
             @Nullable PluginManager pluginManager) {
-        final Map<String, MetricReporterFactory> reporterFactories = new HashMap<>(2);
+        final Map<String, MetricReporterFactory> reporterFactories =
+                CollectionUtil.newHashMapWithExpectedSize(2);
         final Iterator<MetricReporterFactory> factoryIterator =
                 getAllReporterFactories(pluginManager);
         // do not use streams or for-each loops here because they do not allow catching individual
@@ -279,7 +292,8 @@ public final class ReporterSetup {
                 if (existingFactory == null) {
                     reporterFactories.put(factoryClassName, factory);
                     LOG.debug(
-                            "Found reporter factory {} at {} ",
+                            "Found {} {} at {} ",
+                            MetricReporterFactory.class.getSimpleName(),
                             factoryClassName,
                             new File(
                                             factory.getClass()
@@ -290,11 +304,12 @@ public final class ReporterSetup {
                                     .getCanonicalPath());
                 } else {
                     LOG.warn(
-                            "Multiple implementations of the same reporter were found in 'lib' and/or 'plugins' directories for {}. It is recommended to remove redundant reporter JARs to resolve used versions' ambiguity.",
+                            "Multiple implementations of the same {} were found in 'lib' and/or 'plugins' directories for {}. It is recommended to remove redundant reporter JARs to resolve used versions' ambiguity.",
+                            MetricReporter.class.getSimpleName(),
                             factoryClassName);
                 }
             } catch (Exception | ServiceConfigurationError e) {
-                LOG.warn("Error while loading reporter factory.", e);
+                LOG.warn("Error while loading {}.", TraceReporterFactory.class.getSimpleName(), e);
             }
         }
 
@@ -351,7 +366,8 @@ public final class ReporterSetup {
                         });
             } catch (Throwable t) {
                 LOG.error(
-                        "Could not instantiate metrics reporter {}. Metrics might not be exposed/reported.",
+                        "Could not instantiate {} {}. Metrics might not be exposed/reported.",
+                        MetricReporter.class.getSimpleName(),
                         reporterName,
                         t);
             }
