@@ -19,10 +19,17 @@
 package org.apache.flink.runtime.operators.coordination;
 
 import org.apache.flink.annotation.VisibleForTesting;
+import org.apache.flink.api.common.ExecutionConfig;
+import org.apache.flink.metrics.MetricGroup;
+import org.apache.flink.metrics.groups.OperatorCoordinatorMetricGroup;
+import org.apache.flink.runtime.checkpoint.CheckpointCoordinator;
 import org.apache.flink.runtime.checkpoint.OperatorCoordinatorCheckpointContext;
 import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutor;
 import org.apache.flink.runtime.executiongraph.ExecutionJobVertex;
+import org.apache.flink.runtime.executiongraph.TaskInformation;
 import org.apache.flink.runtime.jobgraph.OperatorID;
+import org.apache.flink.runtime.metrics.groups.InternalOperatorCoordinatorMetricGroup;
+import org.apache.flink.runtime.metrics.groups.JobManagerJobMetricGroup;
 import org.apache.flink.runtime.operators.coordination.util.IncompleteFuturesTracker;
 import org.apache.flink.runtime.scheduler.GlobalFailureHandler;
 import org.apache.flink.util.ExceptionUtils;
@@ -111,11 +118,11 @@ public class OperatorCoordinatorHolder
 
     private final IncompleteFuturesTracker unconfirmedEvents;
 
-    private final int operatorParallelism;
     private final int operatorMaxParallelism;
 
     private GlobalFailureHandler globalFailureHandler;
     private ComponentMainThreadExecutor mainThreadExecutor;
+    private int operatorParallelism;
 
     private OperatorCoordinatorHolder(
             final OperatorID operatorId,
@@ -138,13 +145,29 @@ public class OperatorCoordinatorHolder
 
     public void lazyInitialize(
             GlobalFailureHandler globalFailureHandler,
-            ComponentMainThreadExecutor mainThreadExecutor) {
+            ComponentMainThreadExecutor mainThreadExecutor,
+            @Nullable CheckpointCoordinator checkpointCoordinator) {
+        lazyInitialize(
+                globalFailureHandler,
+                mainThreadExecutor,
+                checkpointCoordinator,
+                operatorParallelism);
+    }
 
+    public void lazyInitialize(
+            GlobalFailureHandler globalFailureHandler,
+            ComponentMainThreadExecutor mainThreadExecutor,
+            @Nullable CheckpointCoordinator checkpointCoordinator,
+            final int operatorParallelism) {
         this.globalFailureHandler = globalFailureHandler;
         this.mainThreadExecutor = mainThreadExecutor;
-
-        context.lazyInitialize(globalFailureHandler, mainThreadExecutor);
-
+        checkState(operatorParallelism != ExecutionConfig.PARALLELISM_DEFAULT);
+        this.operatorParallelism = operatorParallelism;
+        context.lazyInitialize(
+                globalFailureHandler,
+                mainThreadExecutor,
+                checkpointCoordinator,
+                operatorParallelism);
         setupAllSubtaskGateways();
     }
 
@@ -463,7 +486,9 @@ public class OperatorCoordinatorHolder
             ExecutionJobVertex jobVertex,
             ClassLoader classLoader,
             CoordinatorStore coordinatorStore,
-            boolean supportsConcurrentExecutionAttempts)
+            boolean supportsConcurrentExecutionAttempts,
+            TaskInformation taskInformation,
+            JobManagerJobMetricGroup metricGroup)
             throws Exception {
 
         try (TemporaryClassLoaderContext ignored = TemporaryClassLoaderContext.of(classLoader)) {
@@ -483,7 +508,9 @@ public class OperatorCoordinatorHolder
                     jobVertex.getParallelism(),
                     jobVertex.getMaxParallelism(),
                     taskAccesses,
-                    supportsConcurrentExecutionAttempts);
+                    supportsConcurrentExecutionAttempts,
+                    taskInformation,
+                    metricGroup);
         }
     }
 
@@ -497,9 +524,16 @@ public class OperatorCoordinatorHolder
             final int operatorParallelism,
             final int operatorMaxParallelism,
             final SubtaskAccess.SubtaskAccessFactory taskAccesses,
-            final boolean supportsConcurrentExecutionAttempts)
+            final boolean supportsConcurrentExecutionAttempts,
+            final TaskInformation taskInformation,
+            final JobManagerJobMetricGroup jobManagerJobMetricGroup)
             throws Exception {
-
+        final MetricGroup parentMetricGroup =
+                jobManagerJobMetricGroup.getOrAddOperator(
+                        taskInformation.getJobVertexId(),
+                        taskInformation.getTaskName(),
+                        opId,
+                        operatorName);
         final LazyInitializedCoordinatorContext context =
                 new LazyInitializedCoordinatorContext(
                         opId,
@@ -507,7 +541,8 @@ public class OperatorCoordinatorHolder
                         userCodeClassLoader,
                         operatorParallelism,
                         coordinatorStore,
-                        supportsConcurrentExecutionAttempts);
+                        supportsConcurrentExecutionAttempts,
+                        new InternalOperatorCoordinatorMetricGroup(parentMetricGroup));
 
         final OperatorCoordinator coordinator = coordinatorProvider.create(context);
 
@@ -542,12 +577,14 @@ public class OperatorCoordinatorHolder
         private final OperatorID operatorId;
         private final String operatorName;
         private final ClassLoader userCodeClassLoader;
-        private final int operatorParallelism;
         private final CoordinatorStore coordinatorStore;
         private final boolean supportsConcurrentExecutionAttempts;
+        private final OperatorCoordinatorMetricGroup metricGroup;
 
         private GlobalFailureHandler globalFailureHandler;
         private Executor schedulerExecutor;
+        @Nullable private CheckpointCoordinator checkpointCoordinator;
+        private int operatorParallelism;
 
         private volatile boolean failed;
 
@@ -557,23 +594,32 @@ public class OperatorCoordinatorHolder
                 final ClassLoader userCodeClassLoader,
                 final int operatorParallelism,
                 final CoordinatorStore coordinatorStore,
-                final boolean supportsConcurrentExecutionAttempts) {
+                final boolean supportsConcurrentExecutionAttempts,
+                final OperatorCoordinatorMetricGroup metricGroup) {
             this.operatorId = checkNotNull(operatorId);
             this.operatorName = checkNotNull(operatorName);
             this.userCodeClassLoader = checkNotNull(userCodeClassLoader);
             this.operatorParallelism = operatorParallelism;
             this.coordinatorStore = checkNotNull(coordinatorStore);
             this.supportsConcurrentExecutionAttempts = supportsConcurrentExecutionAttempts;
+            this.metricGroup = checkNotNull(metricGroup);
         }
 
-        void lazyInitialize(GlobalFailureHandler globalFailureHandler, Executor schedulerExecutor) {
+        void lazyInitialize(
+                GlobalFailureHandler globalFailureHandler,
+                Executor schedulerExecutor,
+                @Nullable CheckpointCoordinator checkpointCoordinator,
+                final int operatorParallelism) {
             this.globalFailureHandler = checkNotNull(globalFailureHandler);
             this.schedulerExecutor = checkNotNull(schedulerExecutor);
+            this.checkpointCoordinator = checkpointCoordinator;
+            this.operatorParallelism = operatorParallelism;
         }
 
         void unInitialize() {
             this.globalFailureHandler = null;
             this.schedulerExecutor = null;
+            this.checkpointCoordinator = null;
         }
 
         boolean isInitialized() {
@@ -593,6 +639,11 @@ public class OperatorCoordinatorHolder
             return operatorId;
         }
 
+        @Override
+        public OperatorCoordinatorMetricGroup metricGroup() {
+            return metricGroup;
+        }
+
         @Override
         public void failJob(final Throwable cause) {
             checkInitialized();
@@ -637,5 +688,11 @@ public class OperatorCoordinatorHolder
         public boolean isConcurrentExecutionAttemptsSupported() {
             return supportsConcurrentExecutionAttempts;
         }
+
+        @Override
+        @Nullable
+        public CheckpointCoordinator getCheckpointCoordinator() {
+            return checkpointCoordinator;
+        }
     }
 }
