@@ -21,16 +21,20 @@ package org.apache.flink.runtime.rest.handler.legacy.metrics;
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.runtime.messages.webmonitor.JobDetails;
 import org.apache.flink.runtime.messages.webmonitor.JobDetails.CurrentAttempts;
+import org.apache.flink.runtime.metrics.MetricNames;
 import org.apache.flink.runtime.metrics.dump.MetricDump;
 import org.apache.flink.runtime.metrics.dump.QueryScopeInfo;
+import org.apache.flink.util.CollectionUtil;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import javax.annotation.concurrent.ThreadSafe;
 
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
@@ -44,6 +48,7 @@ import static org.apache.flink.runtime.metrics.dump.MetricDump.METRIC_CATEGORY_G
 import static org.apache.flink.runtime.metrics.dump.MetricDump.METRIC_CATEGORY_HISTOGRAM;
 import static org.apache.flink.runtime.metrics.dump.MetricDump.METRIC_CATEGORY_METER;
 import static org.apache.flink.runtime.metrics.dump.QueryScopeInfo.INFO_CATEGORY_JM;
+import static org.apache.flink.runtime.metrics.dump.QueryScopeInfo.INFO_CATEGORY_JM_OPERATOR;
 import static org.apache.flink.runtime.metrics.dump.QueryScopeInfo.INFO_CATEGORY_JOB;
 import static org.apache.flink.runtime.metrics.dump.QueryScopeInfo.INFO_CATEGORY_OPERATOR;
 import static org.apache.flink.runtime.metrics.dump.QueryScopeInfo.INFO_CATEGORY_TASK;
@@ -55,6 +60,18 @@ import static org.apache.flink.util.Preconditions.checkNotNull;
 public class MetricStore {
     private static final Logger LOG = LoggerFactory.getLogger(MetricStore.class);
 
+    /**
+     * The set holds the names of the transient metrics which are no longer useful after a subtask
+     * reaches terminal state and shall be removed to avoid misleading users. Note that there may be
+     * other transient metrics, we currently only support cleaning these three.
+     */
+    private static final Set<String> TRANSIENT_METRIC_NAMES =
+            new HashSet<>(
+                    Arrays.asList(
+                            MetricNames.TASK_IDLE_TIME,
+                            MetricNames.TASK_BACK_PRESSURED_TIME,
+                            MetricNames.TASK_BUSY_TIME));
+
     private final ComponentMetricStore jobManager = new ComponentMetricStore();
     private final Map<String, TaskManagerMetricStore> taskManagers = new ConcurrentHashMap<>();
     private final Map<String, JobMetricStore> jobs = new ConcurrentHashMap<>();
@@ -94,7 +111,10 @@ public class MetricStore {
                     job.getCurrentExecutionAttempts();
             Map<String, Map<Integer, Integer>> jobRepresentativeAttempts =
                     representativeAttempts.compute(
-                            jobId, (k, overwritten) -> new HashMap<>(currentAttempts.size()));
+                            jobId,
+                            (k, overwritten) ->
+                                    CollectionUtil.newHashMapWithExpectedSize(
+                                            currentAttempts.size()));
             currentAttempts.forEach(
                     (vertexId, subtaskAttempts) -> {
                         Map<Integer, Integer> vertexAttempts =
@@ -124,6 +144,13 @@ public class MetricStore {
                                                     subtaskMetricStore ->
                                                             subtaskMetricStore.retainAttempts(
                                                                     attempts.getCurrentAttempts()));
+                                    // Remove transient metrics for terminal subtasks
+                                    if (attempts.isTerminalState()) {
+                                        taskMetricStoreOptional.ifPresent(
+                                                taskMetricStore ->
+                                                        taskMetricStore.removeTransientMetrics(
+                                                                subtaskIndex));
+                                    }
                                 });
                     });
         }
@@ -257,6 +284,7 @@ public class MetricStore {
             TaskMetricStore task;
             SubtaskMetricStore subtask;
             ComponentMetricStore attempt;
+            ComponentMetricStore jmOperator;
             boolean isRepresentativeAttempt;
 
             String name = info.scope.isEmpty() ? metric.name : info.scope + "." + metric.name;
@@ -365,6 +393,18 @@ public class MetricStore {
                                 metric);
                     }
                     break;
+                case INFO_CATEGORY_JM_OPERATOR:
+                    QueryScopeInfo.JobManagerOperatorQueryScopeInfo jmOperatorInfo =
+                            (QueryScopeInfo.JobManagerOperatorQueryScopeInfo) info;
+                    job = jobs.computeIfAbsent(jmOperatorInfo.jobID, k -> new JobMetricStore());
+                    task =
+                            job.tasks.computeIfAbsent(
+                                    jmOperatorInfo.vertexID, k -> new TaskMetricStore());
+                    jmOperator =
+                            task.jmOperators.computeIfAbsent(
+                                    jmOperatorInfo.operatorName, k -> new ComponentMetricStore());
+                    addMetric(jmOperator.metrics, name, metric);
+                    break;
                 default:
                     LOG.debug("Invalid metric dump category: " + info.getCategory());
             }
@@ -417,6 +457,11 @@ public class MetricStore {
         }
     }
 
+    private static boolean isTransientMetric(String fullMetricName) {
+        String metricName = fullMetricName.substring(fullMetricName.lastIndexOf('.') + 1);
+        return TRANSIENT_METRIC_NAMES.contains(metricName);
+    }
+
     // -----------------------------------------------------------------------------------------------------------------
     // sub MetricStore classes
     // -----------------------------------------------------------------------------------------------------------------
@@ -493,15 +538,19 @@ public class MetricStore {
     @ThreadSafe
     public static class TaskMetricStore extends ComponentMetricStore {
         private final Map<Integer, SubtaskMetricStore> subtasks;
+        private final Map<String, ComponentMetricStore> jmOperators;
 
         private TaskMetricStore() {
-            this(new ConcurrentHashMap<>(), new ConcurrentHashMap<>());
+            this(new ConcurrentHashMap<>(), new ConcurrentHashMap<>(), new ConcurrentHashMap<>());
         }
 
         private TaskMetricStore(
-                Map<String, String> metrics, Map<Integer, SubtaskMetricStore> subtasks) {
+                Map<String, String> metrics,
+                Map<Integer, SubtaskMetricStore> subtasks,
+                Map<String, ComponentMetricStore> jmOperators) {
             super(metrics);
             this.subtasks = checkNotNull(subtasks);
+            this.jmOperators = checkNotNull(jmOperators);
         }
 
         public SubtaskMetricStore getSubtaskMetricStore(int subtaskIndex) {
@@ -529,12 +578,31 @@ public class MetricStore {
             subtasks.keySet().retainAll(activeSubtasks);
         }
 
+        void removeTransientMetrics(int subtaskIndex) {
+            if (subtasks.containsKey(subtaskIndex)) {
+                // Remove in both places as task metrics are duplicated in task metric store and
+                // subtask metric store.
+                metrics.keySet()
+                        .removeIf(
+                                key ->
+                                        key.startsWith(subtaskIndex + ".")
+                                                && isTransientMetric(key));
+                subtasks.get(subtaskIndex).removeTransientMetrics();
+            }
+        }
+
+        public ComponentMetricStore getJobManagerOperatorMetricStores(String operatorName) {
+            return jmOperators.get(operatorName);
+        }
+
         private static TaskMetricStore unmodifiable(TaskMetricStore source) {
             if (source == null) {
                 return null;
             }
             return new TaskMetricStore(
-                    unmodifiableMap(source.metrics), unmodifiableMap(source.subtasks));
+                    unmodifiableMap(source.metrics),
+                    unmodifiableMap(source.subtasks),
+                    unmodifiableMap(source.jmOperators));
         }
     }
 
@@ -569,6 +637,16 @@ public class MetricStore {
                                     attempt < latestAttempt && !currentAttempts.contains(attempt));
         }
 
+        void removeTransientMetrics() {
+            attempts.values()
+                    .forEach(
+                            attempt ->
+                                    attempt.metrics
+                                            .keySet()
+                                            .removeIf(MetricStore::isTransientMetric));
+            metrics.keySet().removeIf(MetricStore::isTransientMetric);
+        }
+
         private static SubtaskMetricStore unmodifiable(SubtaskMetricStore source) {
             if (source == null) {
                 return null;
