@@ -176,7 +176,8 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
         public static final String FIELD_NAME_EXCEPTION_STACKTRACE = "stacktrace";
         public static final String FIELD_NAME_EXCEPTION_TIMESTAMP = "timestamp";
         public static final String FIELD_NAME_TASK_NAME = "taskName";
-        public static final String FIELD_NAME_LOCATION = "location";
+        @Deprecated public static final String FIELD_NAME_LOCATION = "location";
+        public static final String FIELD_NAME_ENDPOINT = "endpoint";
         public static final String FIELD_NAME_TASK_MANAGER_ID = "taskManagerId";
         public static final String FIELD_NAME_FAILURE_LABELS = "failureLabels";
 
@@ -194,11 +195,18 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
         @Nullable
         private final String taskName;
 
+        /** @deprecated Use {@link ExceptionInfo#endpoint} instead. */
+        @Deprecated
         @JsonInclude(NON_NULL)
         @JsonProperty(FIELD_NAME_LOCATION)
         @Nullable
         private final String location;
 
+        @JsonInclude(NON_NULL)
+        @JsonProperty(FIELD_NAME_ENDPOINT)
+        @Nullable
+        private final String endpoint;
+
         @JsonInclude(NON_NULL)
         @JsonProperty(FIELD_NAME_TASK_MANAGER_ID)
         @Nullable
@@ -208,7 +216,15 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
         private final Map<String, String> failureLabels;
 
         public ExceptionInfo(String exceptionName, String stacktrace, long timestamp) {
-            this(exceptionName, stacktrace, timestamp, Collections.emptyMap(), null, null, null);
+            this(
+                    exceptionName,
+                    stacktrace,
+                    timestamp,
+                    Collections.emptyMap(),
+                    null,
+                    null,
+                    null,
+                    null);
         }
 
         @JsonCreator
@@ -219,6 +235,7 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
                 @JsonProperty(FIELD_NAME_FAILURE_LABELS) Map<String, String> failureLabels,
                 @JsonProperty(FIELD_NAME_TASK_NAME) @Nullable String taskName,
                 @JsonProperty(FIELD_NAME_LOCATION) @Nullable String location,
+                @JsonProperty(FIELD_NAME_ENDPOINT) @Nullable String endpoint,
                 @JsonProperty(FIELD_NAME_TASK_MANAGER_ID) @Nullable String taskManagerId) {
             this.exceptionName = checkNotNull(exceptionName);
             this.stacktrace = checkNotNull(stacktrace);
@@ -226,6 +243,7 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
             this.failureLabels = checkNotNull(failureLabels);
             this.taskName = taskName;
             this.location = location;
+            this.endpoint = endpoint;
             this.taskManagerId = taskManagerId;
         }
 
@@ -250,12 +268,19 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
             return taskName;
         }
 
+        @Deprecated
         @JsonIgnore
         @Nullable
         public String getLocation() {
             return location;
         }
 
+        @JsonIgnore
+        @Nullable
+        public String getEndpoint() {
+            return endpoint;
+        }
+
         @JsonIgnore
         @Nullable
         public String getTaskManagerId() {
@@ -283,13 +308,20 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
                     && Objects.equals(timestamp, that.timestamp)
                     && Objects.equals(failureLabels, that.failureLabels)
                     && Objects.equals(taskName, that.taskName)
-                    && Objects.equals(location, that.location);
+                    && Objects.equals(location, that.location)
+                    && Objects.equals(location, that.endpoint);
         }
 
         @Override
         public int hashCode() {
             return Objects.hash(
-                    exceptionName, stacktrace, timestamp, failureLabels, taskName, location);
+                    exceptionName,
+                    stacktrace,
+                    timestamp,
+                    failureLabels,
+                    taskName,
+                    location,
+                    endpoint);
         }
 
         @Override
@@ -300,7 +332,7 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
                     .add("timestamp=" + timestamp)
                     .add("failureLabels=" + failureLabels)
                     .add("taskName='" + taskName + "'")
-                    .add("location='" + location + "'")
+                    .add("endpoint='" + endpoint + "'")
                     .toString();
         }
     }
@@ -330,6 +362,7 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
                     null,
                     null,
                     null,
+                    null,
                     concurrentExceptions);
         }
 
@@ -341,6 +374,7 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
                 @JsonProperty(FIELD_NAME_FAILURE_LABELS) Map<String, String> failureLabels,
                 @JsonProperty(FIELD_NAME_TASK_NAME) @Nullable String taskName,
                 @JsonProperty(FIELD_NAME_LOCATION) @Nullable String location,
+                @JsonProperty(FIELD_NAME_ENDPOINT) @Nullable String endpoint,
                 @JsonProperty(FIELD_NAME_TASK_MANAGER_ID) @Nullable String taskManagerId,
                 @JsonProperty(FIELD_NAME_CONCURRENT_EXCEPTIONS)
                         Collection<ExceptionInfo> concurrentExceptions) {
@@ -351,6 +385,7 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
                     failureLabels,
                     taskName,
                     location,
+                    endpoint,
                     taskManagerId);
             this.concurrentExceptions = concurrentExceptions;
         }
@@ -386,7 +421,7 @@ public class JobExceptionsInfoWithHistory extends JobExceptionsInfo implements R
                     .add("stacktrace='" + getStacktrace() + "'")
                     .add("timestamp=" + getTimestamp())
                     .add("taskName='" + getTaskName() + "'")
-                    .add("location='" + getLocation() + "'")
+                    .add("endpoint='" + getEndpoint() + "'")
                     .add("concurrentExceptions=" + getConcurrentExceptions())
                     .toString();
         }
