@@ -79,6 +79,11 @@ class Restarting extends StateWithExecutionGraph {
         return JobStatus.RESTARTING;
     }
 
+    @Override
+    public void suspend(Throwable cause) {
+        suspend(cause, JobStatus.SUSPENDED);
+    }
+
     @Override
     public void cancel() {
         context.goToCanceling(
