@@ -20,6 +20,7 @@ package org.apache.flink.runtime.source.coordinator;
 
 import org.apache.flink.annotation.Internal;
 import org.apache.flink.annotation.VisibleForTesting;
+import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.connector.source.ReaderInfo;
 import org.apache.flink.api.connector.source.SourceEvent;
 import org.apache.flink.api.connector.source.SourceSplit;
@@ -29,17 +30,22 @@ import org.apache.flink.api.connector.source.SplitsAssignment;
 import org.apache.flink.api.connector.source.SupportsIntermediateNoMoreSplits;
 import org.apache.flink.core.io.SimpleVersionedSerializer;
 import org.apache.flink.metrics.groups.SplitEnumeratorMetricGroup;
+import org.apache.flink.runtime.checkpoint.CheckpointCoordinator;
+import org.apache.flink.runtime.jobgraph.OperatorID;
+import org.apache.flink.runtime.metrics.groups.InternalSplitEnumeratorMetricGroup;
 import org.apache.flink.runtime.operators.coordination.OperatorCoordinator;
 import org.apache.flink.runtime.operators.coordination.OperatorEvent;
 import org.apache.flink.runtime.source.event.AddSplitEvent;
+import org.apache.flink.runtime.source.event.IsProcessingBacklogEvent;
 import org.apache.flink.runtime.source.event.NoMoreSplitsEvent;
 import org.apache.flink.runtime.source.event.SourceEventWrapper;
 import org.apache.flink.util.ExceptionUtils;
 import org.apache.flink.util.FlinkRuntimeException;
+import org.apache.flink.util.TernaryBoolean;
 import org.apache.flink.util.ThrowableCatchingRunnable;
 import org.apache.flink.util.concurrent.ExecutorThreadFactory;
 
-import org.apache.flink.shaded.guava30.com.google.common.collect.Iterables;
+import org.apache.flink.shaded.guava31.com.google.common.collect.Iterables;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -55,6 +61,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.Callable;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ExecutionException;
@@ -65,6 +72,7 @@ import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.TimeUnit;
 import java.util.function.BiConsumer;
+import java.util.function.Supplier;
 
 import static org.apache.flink.runtime.operators.coordination.ComponentClosingUtils.shutdownExecutorForcefully;
 import static org.apache.flink.util.Preconditions.checkState;
@@ -104,11 +112,12 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
     private final SplitAssignmentTracker<SplitT> assignmentTracker;
     private final SourceCoordinatorProvider.CoordinatorExecutorThreadFactory
             coordinatorThreadFactory;
-    private final SubtaskGateways subtaskGateways;
+    private SubtaskGateways subtaskGateways;
     private final String coordinatorThreadName;
     private final boolean supportsConcurrentExecutionAttempts;
-    private final boolean[] subtaskHasNoMoreSplits;
+    private boolean[] subtaskHasNoMoreSplits;
     private volatile boolean closed;
+    private volatile TernaryBoolean backlog = TernaryBoolean.UNDEFINED;
 
     public SourceCoordinatorContext(
             SourceCoordinatorProvider.CoordinatorExecutorThreadFactory coordinatorThreadFactory,
@@ -149,11 +158,6 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
         this.coordinatorThreadName = coordinatorThreadFactory.getCoordinatorThreadName();
         this.supportsConcurrentExecutionAttempts = supportsConcurrentExecutionAttempts;
 
-        final int parallelism = operatorCoordinatorContext.currentParallelism();
-        this.subtaskGateways = new SubtaskGateways(parallelism);
-        this.subtaskHasNoMoreSplits = new boolean[parallelism];
-        Arrays.fill(subtaskHasNoMoreSplits, false);
-
         final Executor errorHandlingCoordinatorExecutor =
                 (runnable) ->
                         coordinatorExecutor.execute(
@@ -169,11 +173,12 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
 
     @Override
     public SplitEnumeratorMetricGroup metricGroup() {
-        return null;
+        return new InternalSplitEnumeratorMetricGroup(operatorCoordinatorContext.metricGroup());
     }
 
     @Override
     public void sendEventToSourceReader(int subtaskId, SourceEvent event) {
+        checkAndLazyInitialize();
         checkState(
                 !supportsConcurrentExecutionAttempts,
                 "The split enumerator must invoke SplitEnumeratorContext"
@@ -195,6 +200,7 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
 
     @Override
     public void sendEventToSourceReader(int subtaskId, int attemptNumber, SourceEvent event) {
+        checkAndLazyInitialize();
         checkSubtaskIndex(subtaskId);
 
         callInCoordinatorThread(
@@ -210,6 +216,7 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
     }
 
     void sendEventToSourceOperator(int subtaskId, OperatorEvent event) {
+        checkAndLazyInitialize();
         checkSubtaskIndex(subtaskId);
 
         callInCoordinatorThread(
@@ -223,6 +230,7 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
     }
 
     void sendEventToSourceOperatorIfTaskReady(int subtaskId, OperatorEvent event) {
+        checkAndLazyInitialize();
         checkSubtaskIndex(subtaskId);
 
         callInCoordinatorThread(
@@ -359,21 +367,45 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
         return closed;
     }
 
+    @Override
+    public void setIsProcessingBacklog(boolean isProcessingBacklog) {
+        CheckpointCoordinator checkpointCoordinator =
+                getCoordinatorContext().getCheckpointCoordinator();
+        OperatorID operatorID = getCoordinatorContext().getOperatorId();
+        if (checkpointCoordinator != null) {
+            checkpointCoordinator.setIsProcessingBacklog(operatorID, isProcessingBacklog);
+        }
+        backlog = TernaryBoolean.fromBoolean(isProcessingBacklog);
+        callInCoordinatorThread(
+                () -> {
+                    final IsProcessingBacklogEvent isProcessingBacklogEvent =
+                            new IsProcessingBacklogEvent(isProcessingBacklog);
+                    for (int i = 0; i < getCoordinatorContext().currentParallelism(); i++) {
+                        sendEventToSourceOperatorIfTaskReady(i, isProcessingBacklogEvent);
+                    }
+                    return null;
+                },
+                "Failed to send BacklogEvent to reader.");
+    }
+
     // --------- Package private additional methods for the SourceCoordinator ------------
 
     void attemptReady(OperatorCoordinator.SubtaskGateway gateway) {
+        checkAndLazyInitialize();
         checkState(coordinatorThreadFactory.isCurrentThreadCoordinatorThread());
 
         subtaskGateways.registerSubtaskGateway(gateway);
     }
 
     void attemptFailed(int subtaskIndex, int attemptNumber) {
+        checkAndLazyInitialize();
         checkState(coordinatorThreadFactory.isCurrentThreadCoordinatorThread());
 
         subtaskGateways.unregisterSubtaskGateway(subtaskIndex, attemptNumber);
     }
 
     void subtaskReset(int subtaskIndex) {
+        checkAndLazyInitialize();
         checkState(coordinatorThreadFactory.isCurrentThreadCoordinatorThread());
 
         subtaskGateways.reset(subtaskIndex);
@@ -382,6 +414,7 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
     }
 
     boolean hasNoMoreSplits(int subtaskIndex) {
+        checkAndLazyInitialize();
         return subtaskHasNoMoreSplits[subtaskIndex];
     }
 
@@ -500,6 +533,10 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
                 unit);
     }
 
+    CompletableFuture<?> supplyAsync(Supplier<?> task) {
+        return CompletableFuture.supplyAsync(task, coordinatorExecutor);
+    }
+
     // ---------------- private helper methods -----------------
 
     private void checkSubtaskIndex(int subtaskIndex) {
@@ -511,6 +548,16 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
         }
     }
 
+    private void checkAndLazyInitialize() {
+        if (subtaskGateways == null) {
+            final int parallelism = operatorCoordinatorContext.currentParallelism();
+            checkState(parallelism != ExecutionConfig.PARALLELISM_DEFAULT);
+            this.subtaskGateways = new SubtaskGateways(parallelism);
+            this.subtaskHasNoMoreSplits = new boolean[parallelism];
+            Arrays.fill(subtaskHasNoMoreSplits, false);
+        }
+    }
+
     /**
      * A helper method that delegates the callable to the coordinator thread if the current thread
      * is not the coordinator thread, otherwise call the callable right away.
@@ -556,6 +603,7 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
     }
 
     private void assignSplitsToAttempt(int subtaskIndex, int attemptNumber, List<SplitT> splits) {
+        checkAndLazyInitialize();
         if (splits.isEmpty()) {
             return;
         }
@@ -580,6 +628,7 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
     }
 
     private void signalNoMoreSplitsToAttempt(int subtaskIndex, int attemptNumber) {
+        checkAndLazyInitialize();
         checkAttemptReaderReady(subtaskIndex, attemptNumber);
 
         final OperatorCoordinator.SubtaskGateway gateway =
@@ -605,15 +654,23 @@ public class SourceCoordinatorContext<SplitT extends SourceSplit>
                 assignmentTracker.uncheckpointedAssignments().get(subtaskIndex);
 
         if (cachedSplits != null) {
-            if (supportsConcurrentExecutionAttempts) {
-                assignSplitsToAttempt(subtaskIndex, attemptNumber, new ArrayList<>(cachedSplits));
-                if (hasNoMoreSplits(subtaskIndex)) {
-                    signalNoMoreSplitsToAttempt(subtaskIndex, attemptNumber);
-                }
-            } else {
+            if (!supportsConcurrentExecutionAttempts) {
                 throw new IllegalStateException("No cached split is expected.");
             }
+            assignSplitsToAttempt(subtaskIndex, attemptNumber, new ArrayList<>(cachedSplits));
         }
+
+        if (supportsConcurrentExecutionAttempts && hasNoMoreSplits(subtaskIndex)) {
+            signalNoMoreSplitsToAttempt(subtaskIndex, attemptNumber);
+        }
+    }
+
+    /**
+     * Returns whether the Source is processing backlog data. UNDEFINED is returned if it is not set
+     * by the {@link #setIsProcessingBacklog} method.
+     */
+    public TernaryBoolean isBacklog() {
+        return backlog;
     }
 
     /** Maintains the subtask gateways for different execution attempts of different subtasks. */
