@@ -18,6 +18,7 @@ limitations under the License.
 
 package org.apache.flink.runtime.source.coordinator;
 
+import org.apache.flink.api.common.eventtime.WatermarkAlignmentParams;
 import org.apache.flink.api.connector.source.Source;
 import org.apache.flink.api.connector.source.SourceSplit;
 import org.apache.flink.core.io.SimpleVersionedSerializer;
@@ -34,6 +35,8 @@ import java.util.concurrent.Callable;
 import java.util.concurrent.ThreadFactory;
 import java.util.function.BiConsumer;
 
+import static org.apache.flink.util.Preconditions.checkState;
+
 /** The provider of {@link SourceCoordinator}. */
 public class SourceCoordinatorProvider<SplitT extends SourceSplit>
         extends RecreateOnResetOperatorCoordinator.Provider {
@@ -41,6 +44,8 @@ public class SourceCoordinatorProvider<SplitT extends SourceSplit>
     private final String operatorName;
     private final Source<?, SplitT, ?> source;
     private final int numWorkerThreads;
+    private final WatermarkAlignmentParams alignmentParams;
+    @Nullable private final String coordinatorListeningID;
 
     /**
      * Construct the {@link SourceCoordinatorProvider}.
@@ -57,11 +62,15 @@ public class SourceCoordinatorProvider<SplitT extends SourceSplit>
             String operatorName,
             OperatorID operatorID,
             Source<?, SplitT, ?> source,
-            int numWorkerThreads) {
+            int numWorkerThreads,
+            WatermarkAlignmentParams alignmentParams,
+            @Nullable String coordinatorListeningID) {
         super(operatorID);
         this.operatorName = operatorName;
         this.source = source;
         this.numWorkerThreads = numWorkerThreads;
+        this.alignmentParams = alignmentParams;
+        this.coordinatorListeningID = coordinatorListeningID;
     }
 
     @Override
@@ -73,11 +82,24 @@ public class SourceCoordinatorProvider<SplitT extends SourceSplit>
         SimpleVersionedSerializer<SplitT> splitSerializer = source.getSplitSerializer();
         SourceCoordinatorContext<SplitT> sourceCoordinatorContext =
                 new SourceCoordinatorContext<>(
-                        coordinatorThreadFactory, numWorkerThreads, context, splitSerializer);
-        return new SourceCoordinator<>(operatorName, source, sourceCoordinatorContext);
+                        coordinatorThreadFactory,
+                        numWorkerThreads,
+                        context,
+                        splitSerializer,
+                        context.isConcurrentExecutionAttemptsSupported());
+        return new SourceCoordinator<>(
+                operatorName,
+                source,
+                sourceCoordinatorContext,
+                context.getCoordinatorStore(),
+                alignmentParams,
+                coordinatorListeningID);
     }
 
-    /** A thread factory class that provides some helper methods. */
+    /**
+     * A thread factory class that provides some helper methods. Because it is used to check the
+     * current thread, it is a one-off, do not use this ThreadFactory to create multiple threads.
+     */
     public static class CoordinatorExecutorThreadFactory
             implements ThreadFactory, Thread.UncaughtExceptionHandler {
 
@@ -113,6 +135,10 @@ public class SourceCoordinatorProvider<SplitT extends SourceSplit>
 
         @Override
         public synchronized Thread newThread(Runnable r) {
+            checkState(
+                    t == null,
+                    "Please using the new CoordinatorExecutorThreadFactory,"
+                            + " this factory cannot new multiple threads.");
             t = new Thread(r, coordinatorThreadName);
             t.setContextClassLoader(cl);
             t.setUncaughtExceptionHandler(this);
