@@ -61,6 +61,11 @@ public class OperatorStreamStateHandle implements OperatorStateHandle {
         return delegateStateHandle.getStateSize();
     }
 
+    @Override
+    public void collectSizeStats(StateObjectSizeStatsCollector collector) {
+        delegateStateHandle.collectSizeStats(collector);
+    }
+
     @Override
     public FSDataInputStream openInputStream() throws IOException {
         return delegateStateHandle.openInputStream();
