@@ -19,14 +19,19 @@
 package org.apache.flink.runtime.state;
 
 import org.apache.flink.api.common.state.CheckpointListener;
+import org.apache.flink.configuration.Configuration;
 import org.apache.flink.runtime.checkpoint.CheckpointMetaData;
 import org.apache.flink.runtime.checkpoint.CheckpointMetrics;
 import org.apache.flink.runtime.checkpoint.InflightDataRescalingDescriptor;
 import org.apache.flink.runtime.checkpoint.PrioritizedOperatorSubtaskState;
+import org.apache.flink.runtime.checkpoint.SubTaskInitializationMetrics;
 import org.apache.flink.runtime.checkpoint.TaskStateSnapshot;
 import org.apache.flink.runtime.checkpoint.channel.SequentialChannelStateReader;
+import org.apache.flink.runtime.checkpoint.filemerging.FileMergingSnapshotManager;
 import org.apache.flink.runtime.jobgraph.OperatorID;
+import org.apache.flink.runtime.state.changelog.ChangelogStateHandle;
 import org.apache.flink.runtime.state.changelog.StateChangelogStorage;
+import org.apache.flink.runtime.state.changelog.StateChangelogStorageView;
 
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
@@ -46,6 +51,8 @@ import java.util.Optional;
  */
 public interface TaskStateManager extends CheckpointListener, AutoCloseable {
 
+    void reportInitializationMetrics(SubTaskInitializationMetrics subTaskInitializationMetrics);
+
     /**
      * Report the state snapshots for the operator instances running in the owning task.
      *
@@ -74,7 +81,7 @@ public interface TaskStateManager extends CheckpointListener, AutoCloseable {
             CheckpointMetaData checkpointMetaData, CheckpointMetrics checkpointMetrics);
 
     /** Whether all the operators of the task are finished on restore. */
-    boolean isFinishedOnRestore();
+    boolean isTaskDeployedAsFinished();
 
     /** Acquires the checkpoint id to restore from. */
     Optional<Long> getRestoreCheckpointId();
@@ -101,4 +108,13 @@ public interface TaskStateManager extends CheckpointListener, AutoCloseable {
     /** Returns the configured state changelog storage for this task. */
     @Nullable
     StateChangelogStorage<?> getStateChangelogStorage();
+
+    /**
+     * Returns the state changelog storage view of given {@link ChangelogStateHandle} for this task.
+     */
+    @Nullable
+    StateChangelogStorageView<?> getStateChangelogStorageView(
+            Configuration configuration, ChangelogStateHandle changelogStateHandle);
+
+    FileMergingSnapshotManager getFileMergingSnapshotManager();
 }
