@@ -18,32 +18,47 @@
 
 package org.apache.flink.runtime.taskexecutor;
 
-import org.apache.flink.annotation.VisibleForTesting;
+import org.apache.flink.api.common.JobID;
 import org.apache.flink.configuration.CoreOptions;
 import org.apache.flink.metrics.MetricGroup;
+import org.apache.flink.runtime.blob.PermanentBlobKey;
 import org.apache.flink.runtime.blob.PermanentBlobService;
 import org.apache.flink.runtime.broadcast.BroadcastVariableManager;
 import org.apache.flink.runtime.clusterframework.types.AllocationID;
+import org.apache.flink.runtime.deployment.TaskDeploymentDescriptorFactory.ShuffleDescriptorGroup;
+import org.apache.flink.runtime.entrypoint.WorkingDirectory;
 import org.apache.flink.runtime.execution.librarycache.BlobLibraryCacheManager;
 import org.apache.flink.runtime.execution.librarycache.LibraryCacheManager;
+import org.apache.flink.runtime.executiongraph.JobInformation;
+import org.apache.flink.runtime.executiongraph.TaskInformation;
 import org.apache.flink.runtime.io.disk.iomanager.IOManager;
 import org.apache.flink.runtime.io.disk.iomanager.IOManagerAsync;
 import org.apache.flink.runtime.io.network.TaskEventDispatcher;
 import org.apache.flink.runtime.memory.MemoryManager;
+import org.apache.flink.runtime.memory.SharedResources;
 import org.apache.flink.runtime.rpc.FatalErrorHandler;
 import org.apache.flink.runtime.shuffle.ShuffleEnvironment;
 import org.apache.flink.runtime.shuffle.ShuffleEnvironmentContext;
 import org.apache.flink.runtime.shuffle.ShuffleServiceLoader;
+import org.apache.flink.runtime.state.TaskExecutorChannelStateExecutorFactoryManager;
+import org.apache.flink.runtime.state.TaskExecutorFileMergingManager;
 import org.apache.flink.runtime.state.TaskExecutorLocalStateStoresManager;
 import org.apache.flink.runtime.state.TaskExecutorStateChangelogStoragesManager;
+import org.apache.flink.runtime.taskexecutor.slot.DefaultTimerService;
+import org.apache.flink.runtime.taskexecutor.slot.FileSlotAllocationSnapshotPersistenceService;
+import org.apache.flink.runtime.taskexecutor.slot.NoOpSlotAllocationSnapshotPersistenceService;
+import org.apache.flink.runtime.taskexecutor.slot.SlotAllocationSnapshotPersistenceService;
 import org.apache.flink.runtime.taskexecutor.slot.TaskSlotTable;
 import org.apache.flink.runtime.taskexecutor.slot.TaskSlotTableImpl;
 import org.apache.flink.runtime.taskexecutor.slot.TimerService;
 import org.apache.flink.runtime.taskmanager.Task;
 import org.apache.flink.runtime.taskmanager.UnresolvedTaskManagerLocation;
+import org.apache.flink.runtime.util.DefaultGroupCache;
+import org.apache.flink.runtime.util.GroupCache;
 import org.apache.flink.util.ExceptionUtils;
 import org.apache.flink.util.FlinkException;
 import org.apache.flink.util.Preconditions;
+import org.apache.flink.util.concurrent.ScheduledExecutor;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -62,8 +77,6 @@ import java.util.concurrent.ScheduledThreadPoolExecutor;
 public class TaskManagerServices {
     private static final Logger LOG = LoggerFactory.getLogger(TaskManagerServices.class);
 
-    @VisibleForTesting public static final String LOCAL_STATE_SUB_DIRECTORY_ROOT = "localState";
-
     /** TaskManager services. */
     private final UnresolvedTaskManagerLocation unresolvedTaskManagerLocation;
 
@@ -76,10 +89,18 @@ public class TaskManagerServices {
     private final JobTable jobTable;
     private final JobLeaderService jobLeaderService;
     private final TaskExecutorLocalStateStoresManager taskManagerStateStore;
+    private final TaskExecutorFileMergingManager taskManagerFileMergingManager;
     private final TaskExecutorStateChangelogStoragesManager taskManagerChangelogManager;
+    private final TaskExecutorChannelStateExecutorFactoryManager taskManagerChannelStateManager;
     private final TaskEventDispatcher taskEventDispatcher;
     private final ExecutorService ioExecutor;
     private final LibraryCacheManager libraryCacheManager;
+    private final SlotAllocationSnapshotPersistenceService slotAllocationSnapshotPersistenceService;
+    private final SharedResources sharedResources;
+    private final GroupCache<JobID, PermanentBlobKey, JobInformation> jobInformationCache;
+    private final GroupCache<JobID, PermanentBlobKey, TaskInformation> taskInformationCache;
+    private final GroupCache<JobID, PermanentBlobKey, ShuffleDescriptorGroup>
+            shuffleDescriptorsCache;
 
     TaskManagerServices(
             UnresolvedTaskManagerLocation unresolvedTaskManagerLocation,
@@ -92,10 +113,17 @@ public class TaskManagerServices {
             JobTable jobTable,
             JobLeaderService jobLeaderService,
             TaskExecutorLocalStateStoresManager taskManagerStateStore,
+            TaskExecutorFileMergingManager taskManagerFileMergingManager,
             TaskExecutorStateChangelogStoragesManager taskManagerChangelogManager,
+            TaskExecutorChannelStateExecutorFactoryManager taskManagerChannelStateManager,
             TaskEventDispatcher taskEventDispatcher,
             ExecutorService ioExecutor,
-            LibraryCacheManager libraryCacheManager) {
+            LibraryCacheManager libraryCacheManager,
+            SlotAllocationSnapshotPersistenceService slotAllocationSnapshotPersistenceService,
+            SharedResources sharedResources,
+            GroupCache<JobID, PermanentBlobKey, JobInformation> jobInformationCache,
+            GroupCache<JobID, PermanentBlobKey, TaskInformation> taskInformationCache,
+            GroupCache<JobID, PermanentBlobKey, ShuffleDescriptorGroup> shuffleDescriptorsCache) {
 
         this.unresolvedTaskManagerLocation =
                 Preconditions.checkNotNull(unresolvedTaskManagerLocation);
@@ -108,10 +136,18 @@ public class TaskManagerServices {
         this.jobTable = Preconditions.checkNotNull(jobTable);
         this.jobLeaderService = Preconditions.checkNotNull(jobLeaderService);
         this.taskManagerStateStore = Preconditions.checkNotNull(taskManagerStateStore);
+        this.taskManagerFileMergingManager =
+                Preconditions.checkNotNull(taskManagerFileMergingManager);
         this.taskManagerChangelogManager = Preconditions.checkNotNull(taskManagerChangelogManager);
+        this.taskManagerChannelStateManager = taskManagerChannelStateManager;
         this.taskEventDispatcher = Preconditions.checkNotNull(taskEventDispatcher);
         this.ioExecutor = Preconditions.checkNotNull(ioExecutor);
         this.libraryCacheManager = Preconditions.checkNotNull(libraryCacheManager);
+        this.slotAllocationSnapshotPersistenceService = slotAllocationSnapshotPersistenceService;
+        this.sharedResources = Preconditions.checkNotNull(sharedResources);
+        this.jobInformationCache = jobInformationCache;
+        this.taskInformationCache = taskInformationCache;
+        this.shuffleDescriptorsCache = Preconditions.checkNotNull(shuffleDescriptorsCache);
     }
 
     // --------------------------------------------------------------------------------------------
@@ -158,10 +194,18 @@ public class TaskManagerServices {
         return taskManagerStateStore;
     }
 
+    public TaskExecutorFileMergingManager getTaskManagerFileMergingManager() {
+        return taskManagerFileMergingManager;
+    }
+
     public TaskExecutorStateChangelogStoragesManager getTaskManagerChangelogManager() {
         return taskManagerChangelogManager;
     }
 
+    public TaskExecutorChannelStateExecutorFactoryManager getTaskManagerChannelStateManager() {
+        return taskManagerChannelStateManager;
+    }
+
     public TaskEventDispatcher getTaskEventDispatcher() {
         return taskEventDispatcher;
     }
@@ -174,6 +218,22 @@ public class TaskManagerServices {
         return libraryCacheManager;
     }
 
+    public SharedResources getSharedResources() {
+        return sharedResources;
+    }
+
+    public GroupCache<JobID, PermanentBlobKey, JobInformation> getJobInformationCache() {
+        return jobInformationCache;
+    }
+
+    public GroupCache<JobID, PermanentBlobKey, TaskInformation> getTaskInformationCache() {
+        return taskInformationCache;
+    }
+
+    public GroupCache<JobID, PermanentBlobKey, ShuffleDescriptorGroup> getShuffleDescriptorCache() {
+        return shuffleDescriptorsCache;
+    }
+
     // --------------------------------------------------------------------------------------------
     //  Shut down method
     // --------------------------------------------------------------------------------------------
@@ -256,7 +316,9 @@ public class TaskManagerServices {
      * @param permanentBlobService permanentBlobService used by the services
      * @param taskManagerMetricGroup metric group of the task manager
      * @param ioExecutor executor for async IO operations
+     * @param scheduledExecutor scheduled executor in rpc service
      * @param fatalErrorHandler to handle class loading OOMs
+     * @param workingDirectory the working directory of the process
      * @return task manager components
      * @throws Exception
      */
@@ -265,7 +327,9 @@ public class TaskManagerServices {
             PermanentBlobService permanentBlobService,
             MetricGroup taskManagerMetricGroup,
             ExecutorService ioExecutor,
-            FatalErrorHandler fatalErrorHandler)
+            ScheduledExecutor scheduledExecutor,
+            FatalErrorHandler fatalErrorHandler,
+            WorkingDirectory workingDirectory)
             throws Exception {
 
         // pre-start checks
@@ -282,9 +346,14 @@ public class TaskManagerServices {
                         taskManagerServicesConfiguration,
                         taskEventDispatcher,
                         taskManagerMetricGroup,
-                        ioExecutor);
+                        ioExecutor,
+                        scheduledExecutor);
         final int listeningDataPort = shuffleEnvironment.start();
 
+        LOG.info(
+                "TaskManager data connection initialized successfully; listening internally on port: {}",
+                listeningDataPort);
+
         final KvStateService kvStateService =
                 KvStateService.fromConfiguration(taskManagerServicesConfiguration);
         kvStateService.start();
@@ -297,7 +366,8 @@ public class TaskManagerServices {
                         // iff the external data port is not explicitly defined
                         taskManagerServicesConfiguration.getExternalDataPort() > 0
                                 ? taskManagerServicesConfiguration.getExternalDataPort()
-                                : listeningDataPort);
+                                : listeningDataPort,
+                        taskManagerServicesConfiguration.getNodeId());
 
         final BroadcastVariableManager broadcastVariableManager = new BroadcastVariableManager();
 
@@ -316,33 +386,29 @@ public class TaskManagerServices {
                         unresolvedTaskManagerLocation,
                         taskManagerServicesConfiguration.getRetryingRegistrationConfiguration());
 
-        final String[] stateRootDirectoryStrings =
-                taskManagerServicesConfiguration.getLocalRecoveryStateRootDirectories();
-
-        final File[] stateRootDirectoryFiles = new File[stateRootDirectoryStrings.length];
-
-        for (int i = 0; i < stateRootDirectoryStrings.length; ++i) {
-            stateRootDirectoryFiles[i] =
-                    new File(stateRootDirectoryStrings[i], LOCAL_STATE_SUB_DIRECTORY_ROOT);
-        }
-
         final TaskExecutorLocalStateStoresManager taskStateManager =
                 new TaskExecutorLocalStateStoresManager(
                         taskManagerServicesConfiguration.isLocalRecoveryEnabled(),
-                        stateRootDirectoryFiles,
+                        taskManagerServicesConfiguration.getLocalRecoveryStateDirectories(),
                         ioExecutor);
 
         final TaskExecutorStateChangelogStoragesManager changelogStoragesManager =
                 new TaskExecutorStateChangelogStoragesManager();
 
+        final TaskExecutorChannelStateExecutorFactoryManager channelStateExecutorFactoryManager =
+                new TaskExecutorChannelStateExecutorFactoryManager();
+
+        final TaskExecutorFileMergingManager fileMergingManager =
+                new TaskExecutorFileMergingManager();
+
         final boolean failOnJvmMetaspaceOomError =
                 taskManagerServicesConfiguration
                         .getConfiguration()
-                        .getBoolean(CoreOptions.FAIL_ON_USER_CLASS_LOADING_METASPACE_OOM);
+                        .get(CoreOptions.FAIL_ON_USER_CLASS_LOADING_METASPACE_OOM);
         final boolean checkClassLoaderLeak =
                 taskManagerServicesConfiguration
                         .getConfiguration()
-                        .getBoolean(CoreOptions.CHECK_LEAKED_CLASSLOADER);
+                        .get(CoreOptions.CHECK_LEAKED_CLASSLOADER);
         final LibraryCacheManager libraryCacheManager =
                 new BlobLibraryCacheManager(
                         permanentBlobService,
@@ -351,7 +417,28 @@ public class TaskManagerServices {
                                 taskManagerServicesConfiguration
                                         .getAlwaysParentFirstLoaderPatterns(),
                                 failOnJvmMetaspaceOomError ? fatalErrorHandler : null,
-                                checkClassLoaderLeak));
+                                checkClassLoaderLeak),
+                        false);
+
+        final SlotAllocationSnapshotPersistenceService slotAllocationSnapshotPersistenceService;
+
+        if (taskManagerServicesConfiguration.isLocalRecoveryEnabled()) {
+            slotAllocationSnapshotPersistenceService =
+                    new FileSlotAllocationSnapshotPersistenceService(
+                            workingDirectory.getSlotAllocationSnapshotDirectory());
+        } else {
+            slotAllocationSnapshotPersistenceService =
+                    NoOpSlotAllocationSnapshotPersistenceService.INSTANCE;
+        }
+
+        final GroupCache<JobID, PermanentBlobKey, JobInformation> jobInformationCache =
+                new DefaultGroupCache.Factory<JobID, PermanentBlobKey, JobInformation>().create();
+        final GroupCache<JobID, PermanentBlobKey, TaskInformation> taskInformationCache =
+                new DefaultGroupCache.Factory<JobID, PermanentBlobKey, TaskInformation>().create();
+
+        final GroupCache<JobID, PermanentBlobKey, ShuffleDescriptorGroup> shuffleDescriptorsCache =
+                new DefaultGroupCache.Factory<JobID, PermanentBlobKey, ShuffleDescriptorGroup>()
+                        .create();
 
         return new TaskManagerServices(
                 unresolvedTaskManagerLocation,
@@ -364,10 +451,17 @@ public class TaskManagerServices {
                 jobTable,
                 jobLeaderService,
                 taskStateManager,
+                fileMergingManager,
                 changelogStoragesManager,
+                channelStateExecutorFactoryManager,
                 taskEventDispatcher,
                 ioExecutor,
-                libraryCacheManager);
+                libraryCacheManager,
+                slotAllocationSnapshotPersistenceService,
+                new SharedResources(),
+                jobInformationCache,
+                taskInformationCache,
+                shuffleDescriptorsCache);
     }
 
     private static TaskSlotTable<Task> createTaskSlotTable(
@@ -377,7 +471,8 @@ public class TaskManagerServices {
             final int pageSize,
             final Executor memoryVerificationExecutor) {
         final TimerService<AllocationID> timerService =
-                new TimerService<>(new ScheduledThreadPoolExecutor(1), timerServiceShutdownTimeout);
+                new DefaultTimerService<>(
+                        new ScheduledThreadPoolExecutor(1), timerServiceShutdownTimeout);
         return new TaskSlotTableImpl<>(
                 numberOfSlots,
                 TaskExecutorResourceUtils.generateTotalAvailableResourceProfile(
@@ -393,7 +488,8 @@ public class TaskManagerServices {
             TaskManagerServicesConfiguration taskManagerServicesConfiguration,
             TaskEventDispatcher taskEventDispatcher,
             MetricGroup taskManagerMetricGroup,
-            Executor ioExecutor)
+            Executor ioExecutor,
+            ScheduledExecutor scheduledExecutor)
             throws FlinkException {
 
         final ShuffleEnvironmentContext shuffleEnvironmentContext =
@@ -403,9 +499,12 @@ public class TaskManagerServices {
                         taskManagerServicesConfiguration.getNetworkMemorySize(),
                         taskManagerServicesConfiguration.isLocalCommunicationOnly(),
                         taskManagerServicesConfiguration.getBindAddress(),
+                        taskManagerServicesConfiguration.getNumberOfSlots(),
+                        taskManagerServicesConfiguration.getTmpDirPaths(),
                         taskEventDispatcher,
                         taskManagerMetricGroup,
-                        ioExecutor);
+                        ioExecutor,
+                        scheduledExecutor);
 
         return ShuffleServiceLoader.loadShuffleServiceFactory(
                         taskManagerServicesConfiguration.getConfiguration())
@@ -461,4 +560,8 @@ public class TaskManagerServices {
             }
         }
     }
+
+    public SlotAllocationSnapshotPersistenceService getSlotAllocationSnapshotPersistenceService() {
+        return slotAllocationSnapshotPersistenceService;
+    }
 }
