@@ -20,6 +20,7 @@ package org.apache.flink.runtime.taskmanager;
 
 import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.JobID;
+import org.apache.flink.api.common.JobInfo;
 import org.apache.flink.api.common.TaskInfo;
 import org.apache.flink.api.common.operators.MailboxExecutor;
 import org.apache.flink.configuration.Configuration;
@@ -65,6 +66,8 @@ public class RuntimeEnvironment implements Environment {
     private final JobVertexID jobVertexId;
     private final ExecutionAttemptID executionId;
 
+    private final JobInfo jobInfo;
+
     private final TaskInfo taskInfo;
 
     private final Configuration jobConfiguration;
@@ -118,6 +121,7 @@ public class RuntimeEnvironment implements Environment {
             JobVertexID jobVertexId,
             ExecutionAttemptID executionId,
             ExecutionConfig executionConfig,
+            JobInfo jobInfo,
             TaskInfo taskInfo,
             Configuration jobConfiguration,
             Configuration taskConfiguration,
@@ -147,6 +151,7 @@ public class RuntimeEnvironment implements Environment {
         this.jobId = checkNotNull(jobId);
         this.jobVertexId = checkNotNull(jobVertexId);
         this.executionId = checkNotNull(executionId);
+        this.jobInfo = checkNotNull(jobInfo);
         this.taskInfo = checkNotNull(taskInfo);
         this.executionConfig = checkNotNull(executionConfig);
         this.jobConfiguration = checkNotNull(jobConfiguration);
@@ -197,6 +202,11 @@ public class RuntimeEnvironment implements Environment {
         return executionId;
     }
 
+    @Override
+    public JobInfo getJobInfo() {
+        return jobInfo;
+    }
+
     @Override
     public TaskInfo getTaskInfo() {
         return this.taskInfo;
