@@ -19,36 +19,36 @@
 package org.apache.flink.runtime.blob;
 
 import org.apache.flink.api.common.JobID;
+import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.HighAvailabilityOptions;
-import org.apache.flink.util.TestLogger;
+import org.apache.flink.testutils.junit.utils.TempDirUtils;
 
-import org.junit.ClassRule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 import javax.annotation.Nullable;
 
 import java.io.IOException;
-import java.net.InetSocketAddress;
+import java.nio.file.Path;
 
 import static org.apache.flink.runtime.blob.BlobKey.BlobType.PERMANENT_BLOB;
 import static org.apache.flink.runtime.blob.BlobKey.BlobType.TRANSIENT_BLOB;
 import static org.apache.flink.runtime.blob.BlobServerPutTest.put;
 import static org.apache.flink.runtime.blob.BlobServerPutTest.verifyContents;
-import static org.junit.Assert.fail;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** Unit tests for the blob cache retrying the connection to the server. */
-public class BlobCacheRetriesTest extends TestLogger {
+class BlobCacheRetriesTest {
 
-    @ClassRule public static final TemporaryFolder TEMPORARY_FOLDER = new TemporaryFolder();
+    @TempDir private Path tempDir;
 
     /**
      * A test where the connection fails twice and then the get operation succeeds (job-unrelated
      * blob).
      */
     @Test
-    public void testBlobFetchRetries() throws IOException {
+    void testBlobFetchRetries() throws IOException {
         testBlobFetchRetries(new VoidBlobStore(), null, TRANSIENT_BLOB);
     }
 
@@ -57,7 +57,7 @@ public class BlobCacheRetriesTest extends TestLogger {
      * blob).
      */
     @Test
-    public void testBlobForJobFetchRetries() throws IOException {
+    void testBlobForJobFetchRetries() throws IOException {
         testBlobFetchRetries(new VoidBlobStore(), new JobID(), TRANSIENT_BLOB);
     }
 
@@ -66,11 +66,11 @@ public class BlobCacheRetriesTest extends TestLogger {
      * availability set, job-related job).
      */
     @Test
-    public void testBlobFetchRetriesHa() throws IOException {
+    void testBlobFetchRetriesHa() throws IOException {
         final Configuration config = new Configuration();
-        config.setString(HighAvailabilityOptions.HA_MODE, "ZOOKEEPER");
-        config.setString(
-                HighAvailabilityOptions.HA_STORAGE_PATH, TEMPORARY_FOLDER.newFolder().getPath());
+        config.set(HighAvailabilityOptions.HA_MODE, "ZOOKEEPER");
+        config.set(
+                HighAvailabilityOptions.HA_STORAGE_PATH, TempDirUtils.newFolder(tempDir).getPath());
 
         BlobStoreService blobStoreService = null;
 
@@ -80,7 +80,8 @@ public class BlobCacheRetriesTest extends TestLogger {
             testBlobFetchRetries(blobStoreService, new JobID(), PERMANENT_BLOB);
         } finally {
             if (blobStoreService != null) {
-                blobStoreService.closeAndCleanupAllData();
+                blobStoreService.cleanupAllData();
+                blobStoreService.close();
             }
         }
     }
@@ -91,24 +92,16 @@ public class BlobCacheRetriesTest extends TestLogger {
      *
      * @param blobType whether the BLOB should become permanent or transient
      */
-    private static void testBlobFetchRetries(
+    private void testBlobFetchRetries(
             final BlobStore blobStore, @Nullable final JobID jobId, BlobKey.BlobType blobType)
             throws IOException {
-
-        final Configuration configuration = new Configuration();
-
         final byte[] data = new byte[] {1, 2, 3, 4, 5, 6, 7, 8, 9, 0};
 
-        try (BlobServer server =
-                        new TestingFailingBlobServer(
-                                configuration, TEMPORARY_FOLDER.newFolder(), blobStore, 2);
-                BlobCacheService cache =
-                        new BlobCacheService(
-                                configuration,
-                                TEMPORARY_FOLDER.newFolder(),
-                                new VoidBlobStore(),
-                                new InetSocketAddress("localhost", server.getPort()))) {
+        Tuple2<BlobServer, BlobCacheService> serverAndCache =
+                TestingBlobUtils.createFailingServerAndCache(tempDir, blobStore, 1, 2);
 
+        try (BlobServer server = serverAndCache.f0;
+                BlobCacheService cache = serverAndCache.f1) {
             server.start();
 
             // upload some blob
@@ -125,7 +118,7 @@ public class BlobCacheRetriesTest extends TestLogger {
      * (job-unrelated blob).
      */
     @Test
-    public void testBlobNoJobFetchWithTooManyFailures() throws IOException {
+    void testBlobNoJobFetchWithTooManyFailures() throws IOException {
         testBlobFetchWithTooManyFailures(new VoidBlobStore(), null, TRANSIENT_BLOB);
     }
 
@@ -134,7 +127,7 @@ public class BlobCacheRetriesTest extends TestLogger {
      * blob).
      */
     @Test
-    public void testBlobForJobFetchWithTooManyFailures() throws IOException {
+    void testBlobForJobFetchWithTooManyFailures() throws IOException {
         testBlobFetchWithTooManyFailures(new VoidBlobStore(), new JobID(), TRANSIENT_BLOB);
     }
 
@@ -143,11 +136,10 @@ public class BlobCacheRetriesTest extends TestLogger {
      * availability set, job-related blob).
      */
     @Test
-    public void testBlobForJobFetchWithTooManyFailuresHa() throws IOException {
+    void testBlobForJobFetchWithTooManyFailuresHa() throws IOException {
         final Configuration config = new Configuration();
-        config.setString(HighAvailabilityOptions.HA_MODE, "ZOOKEEPER");
-        config.setString(
-                HighAvailabilityOptions.HA_STORAGE_PATH, TEMPORARY_FOLDER.getRoot().getPath());
+        config.set(HighAvailabilityOptions.HA_MODE, "ZOOKEEPER");
+        config.set(HighAvailabilityOptions.HA_STORAGE_PATH, tempDir.toString());
 
         BlobStoreService blobStoreService = null;
 
@@ -157,7 +149,8 @@ public class BlobCacheRetriesTest extends TestLogger {
             testBlobFetchWithTooManyFailures(blobStoreService, new JobID(), PERMANENT_BLOB);
         } finally {
             if (blobStoreService != null) {
-                blobStoreService.closeAndCleanupAllData();
+                blobStoreService.cleanupAllData();
+                blobStoreService.close();
             }
         }
     }
@@ -168,35 +161,24 @@ public class BlobCacheRetriesTest extends TestLogger {
      *
      * @param blobType whether the BLOB should become permanent or transient
      */
-    private static void testBlobFetchWithTooManyFailures(
+    private void testBlobFetchWithTooManyFailures(
             final BlobStore blobStore, @Nullable final JobID jobId, BlobKey.BlobType blobType)
             throws IOException {
-        final Configuration configuration = new Configuration();
-
         final byte[] data = new byte[] {1, 2, 3, 4, 5, 6, 7, 8, 9, 0};
 
-        try (BlobServer server =
-                        new TestingFailingBlobServer(
-                                configuration, TEMPORARY_FOLDER.newFolder(), blobStore, 0, 10);
-                BlobCacheService cache =
-                        new BlobCacheService(
-                                configuration,
-                                TEMPORARY_FOLDER.newFolder(),
-                                new VoidBlobStore(),
-                                new InetSocketAddress("localhost", server.getPort()))) {
+        Tuple2<BlobServer, BlobCacheService> serverAndCache =
+                TestingBlobUtils.createFailingServerAndCache(tempDir, blobStore, 0, 10);
 
+        try (BlobServer server = serverAndCache.f0;
+                BlobCacheService cache = serverAndCache.f1) {
             server.start();
 
             // upload some blob
             final BlobKey key = put(server, jobId, data, blobType);
 
             // trigger a download - it should fail eventually
-            try {
-                verifyContents(cache, jobId, key, data);
-                fail("This should fail");
-            } catch (IOException e) {
-                // as we expected
-            }
+            assertThatThrownBy(() -> verifyContents(cache, jobId, key, data))
+                    .isInstanceOf(IOException.class);
         }
     }
 }
