@@ -33,11 +33,10 @@ import org.apache.flink.runtime.jobgraph.JobVertex;
 import org.apache.flink.runtime.jobgraph.JobVertexID;
 import org.apache.flink.runtime.testtasks.NoOpInvokable;
 import org.apache.flink.testutils.TestingUtils;
-import org.apache.flink.testutils.executor.TestExecutorResource;
+import org.apache.flink.testutils.executor.TestExecutorExtension;
 
-import org.hamcrest.CoreMatchers;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -54,11 +53,8 @@ import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 
 import static java.util.EnumSet.complementOf;
-import static org.hamcrest.Matchers.containsInAnyOrder;
-import static org.hamcrest.Matchers.instanceOf;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.fail;
+import static org.apache.flink.core.testutils.FlinkAssertions.assertThatFuture;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /**
  * Declarative tests for {@link DefaultCheckpointPlanCalculator}.
@@ -66,14 +62,14 @@ import static org.junit.Assert.fail;
  * <p>This test contains a framework for declaring vertex and edge states to then assert the
  * calculator behavior.
  */
-public class DefaultCheckpointPlanCalculatorTest {
+class DefaultCheckpointPlanCalculatorTest {
 
-    @ClassRule
-    public static final TestExecutorResource<ScheduledExecutorService> EXECUTOR_RESOURCE =
-            TestingUtils.defaultExecutorResource();
+    @RegisterExtension
+    static final TestExecutorExtension<ScheduledExecutorService> EXECUTOR_EXTENSION =
+            TestingUtils.defaultExecutorExtension();
 
     @Test
-    public void testComputeAllRunningGraph() throws Exception {
+    void testComputeAllRunningGraph() throws Exception {
         runSingleTest(
                 Arrays.asList(
                         new VertexDeclaration(3, Collections.emptySet()),
@@ -89,7 +85,7 @@ public class DefaultCheckpointPlanCalculatorTest {
     }
 
     @Test
-    public void testAllToAllEdgeWithSomeSourcesFinished() throws Exception {
+    void testAllToAllEdgeWithSomeSourcesFinished() throws Exception {
         runSingleTest(
                 Arrays.asList(
                         new VertexDeclaration(3, range(0, 2)),
@@ -100,7 +96,7 @@ public class DefaultCheckpointPlanCalculatorTest {
     }
 
     @Test
-    public void testOneToOneEdgeWithSomeSourcesFinished() throws Exception {
+    void testOneToOneEdgeWithSomeSourcesFinished() throws Exception {
         runSingleTest(
                 Arrays.asList(
                         new VertexDeclaration(4, range(0, 2)),
@@ -111,7 +107,7 @@ public class DefaultCheckpointPlanCalculatorTest {
     }
 
     @Test
-    public void testOneToOnEdgeWithSomeSourcesAndTargetsFinished() throws Exception {
+    void testOneToOnEdgeWithSomeSourcesAndTargetsFinished() throws Exception {
         runSingleTest(
                 Arrays.asList(
                         new VertexDeclaration(4, range(0, 2)), new VertexDeclaration(4, of(0))),
@@ -121,7 +117,7 @@ public class DefaultCheckpointPlanCalculatorTest {
     }
 
     @Test
-    public void testComputeWithMultipleInputs() throws Exception {
+    void testComputeWithMultipleInputs() throws Exception {
         runSingleTest(
                 Arrays.asList(
                         new VertexDeclaration(3, range(0, 3)),
@@ -137,7 +133,7 @@ public class DefaultCheckpointPlanCalculatorTest {
     }
 
     @Test
-    public void testComputeWithMultipleLevels() throws Exception {
+    void testComputeWithMultipleLevels() throws Exception {
         runSingleTest(
                 Arrays.asList(
                         new VertexDeclaration(16, range(0, 4)),
@@ -159,7 +155,7 @@ public class DefaultCheckpointPlanCalculatorTest {
     }
 
     @Test
-    public void testPlanCalculationWhenOneTaskNotRunning() throws Exception {
+    void testPlanCalculationWhenOneTaskNotRunning() throws Exception {
         // when: All combinations of Source/Not Source for one RUNNING and one NOT RUNNING tasks.
         runWithNotRunningTask(true, true);
         runWithNotRunningTask(true, false);
@@ -180,7 +176,7 @@ public class DefaultCheckpointPlanCalculatorTest {
                             .addJobVertex(runningVertex, isRunningVertexSource)
                             .addJobVertex(notRunningVertex, isNotRunningVertexSource)
                             .setTransitToRunning(false)
-                            .build(EXECUTOR_RESOURCE.getExecutor());
+                            .build(EXECUTOR_EXTENSION.getExecutor());
 
             // The first vertex is always RUNNING.
             transitVertexToState(graph, runningVertex, ExecutionState.RUNNING);
@@ -190,19 +186,19 @@ public class DefaultCheckpointPlanCalculatorTest {
             DefaultCheckpointPlanCalculator checkpointPlanCalculator =
                     createCheckpointPlanCalculator(graph);
 
-            try {
-                checkpointPlanCalculator.calculateCheckpointPlan().get();
-                fail(
-                        "The computation should fail since some tasks to trigger are in "
-                                + notRunningState
-                                + " state");
-            } catch (ExecutionException e) {
-                Throwable cause = e.getCause();
-                assertThat(cause, instanceOf(CheckpointException.class));
-                assertEquals(
-                        CheckpointFailureReason.NOT_ALL_REQUIRED_TASKS_RUNNING,
-                        ((CheckpointException) cause).getCheckpointFailureReason());
-            }
+            assertThatFuture(checkpointPlanCalculator.calculateCheckpointPlan())
+                    .withFailMessage(
+                            "The computation should fail since some tasks to trigger are in %s state",
+                            notRunningState)
+                    .eventuallyFailsWith(ExecutionException.class)
+                    .havingCause()
+                    .isInstanceOfSatisfying(
+                            CheckpointException.class,
+                            e ->
+                                    assertThat(e.getCheckpointFailureReason())
+                                            .isEqualTo(
+                                                    CheckpointFailureReason
+                                                            .NOT_ALL_REQUIRED_TASKS_RUNNING));
         }
     }
 
@@ -308,7 +304,7 @@ public class DefaultCheckpointPlanCalculatorTest {
 
         ExecutionGraph graph =
                 ExecutionGraphTestUtils.createExecutionGraph(
-                        EXECUTOR_RESOURCE.getExecutor(), jobVertices);
+                        EXECUTOR_EXTENSION.getExecutor(), jobVertices);
         graph.start(ComponentMainThreadExecutorServiceAdapter.forMainThread());
         graph.transitionToRunning();
         graph.getAllExecutionVertices()
@@ -335,13 +331,11 @@ public class DefaultCheckpointPlanCalculatorTest {
     }
 
     private DefaultCheckpointPlanCalculator createCheckpointPlanCalculator(ExecutionGraph graph) {
-        DefaultCheckpointPlanCalculator checkpointPlanCalculator =
-                new DefaultCheckpointPlanCalculator(
-                        graph.getJobID(),
-                        new ExecutionGraphCheckpointPlanCalculatorContext(graph),
-                        graph.getVerticesTopologically(),
-                        true);
-        return checkpointPlanCalculator;
+        return new DefaultCheckpointPlanCalculator(
+                graph.getJobID(),
+                new ExecutionGraphCheckpointPlanCalculatorContext(graph),
+                graph.getVerticesTopologically(),
+                true);
     }
 
     private void checkCheckpointPlan(
@@ -390,13 +384,7 @@ public class DefaultCheckpointPlanCalculatorTest {
 
     private <T> void assertSameInstancesWithoutOrder(
             String comment, Collection<T> expected, Collection<T> actual) {
-        assertThat(
-                comment,
-                expected,
-                containsInAnyOrder(
-                        actual.stream()
-                                .map(CoreMatchers::sameInstance)
-                                .collect(Collectors.toList())));
+        assertThat(expected).as(comment).containsExactlyInAnyOrderElementsOf(actual);
     }
 
     private List<ExecutionVertex> chooseTasks(
