@@ -22,7 +22,6 @@ import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.JobStatus;
 import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.core.execution.SavepointFormatType;
-import org.apache.flink.core.testutils.FlinkMatchers;
 import org.apache.flink.runtime.jobgraph.RestoreMode;
 import org.apache.flink.runtime.persistence.StateHandleStore;
 import org.apache.flink.runtime.persistence.TestingRetrievableStateStorageHelper;
@@ -33,14 +32,12 @@ import org.apache.flink.runtime.state.SharedStateRegistryImpl;
 import org.apache.flink.runtime.state.SharedStateRegistryKey;
 import org.apache.flink.runtime.state.TestingStreamStateHandle;
 import org.apache.flink.runtime.state.testutils.TestCompletedCheckpointStorageLocation;
-import org.apache.flink.util.ExceptionUtils;
 import org.apache.flink.util.FlinkException;
-import org.apache.flink.util.TestLogger;
 import org.apache.flink.util.concurrent.ExecutorThreadFactory;
 
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -50,22 +47,19 @@ import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
-import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.stream.Collectors;
 
 import static java.util.Arrays.asList;
 import static java.util.Collections.emptyList;
+import static org.apache.flink.core.testutils.FlinkAssertions.assertThatFuture;
 import static org.apache.flink.runtime.checkpoint.CheckpointRetentionPolicy.NEVER_RETAIN_AFTER_TERMINATION;
-import static org.hamcrest.Matchers.contains;
-import static org.hamcrest.Matchers.is;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.assertThrows;
-import static org.junit.Assert.fail;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** Tests for {@link DefaultCompletedCheckpointStore}. */
-public class DefaultCompletedCheckpointStoreTest extends TestLogger {
+class DefaultCompletedCheckpointStoreTest {
 
     private final long timeout = 100L;
 
@@ -75,20 +69,20 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
 
     private ExecutorService executorService;
 
-    @Before
-    public void setup() {
+    @BeforeEach
+    void setup() {
         builder = TestingStateHandleStore.newBuilder();
         checkpointStorageHelper = new TestingRetrievableStateStorageHelper<>();
         executorService = Executors.newFixedThreadPool(2, new ExecutorThreadFactory("IO-Executor"));
     }
 
-    @After
-    public void after() {
+    @AfterEach
+    void after() {
         executorService.shutdownNow();
     }
 
     @Test
-    public void testAtLeastOneCheckpointRetained() throws Exception {
+    void testAtLeastOneCheckpointRetained() throws Exception {
         CompletedCheckpoint cp1 = getCheckpoint(false, 1L);
         CompletedCheckpoint cp2 = getCheckpoint(false, 2L);
         CompletedCheckpoint sp1 = getCheckpoint(true, 3L);
@@ -98,7 +92,7 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
     }
 
     @Test
-    public void testOlderSavepointSubsumed() throws Exception {
+    void testOlderSavepointSubsumed() throws Exception {
         CompletedCheckpoint cp1 = getCheckpoint(false, 1L);
         CompletedCheckpoint sp1 = getCheckpoint(true, 2L);
         CompletedCheckpoint cp2 = getCheckpoint(false, 3L);
@@ -106,7 +100,7 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
     }
 
     @Test
-    public void testSubsumeAfterStoppingWithSavepoint() throws Exception {
+    void testSubsumeAfterStoppingWithSavepoint() throws Exception {
         CompletedCheckpoint cp1 = getCheckpoint(false, 1L);
         CompletedCheckpoint sp1 = getCheckpoint(true, 2L);
         CompletedCheckpoint stop =
@@ -118,7 +112,7 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
     }
 
     @Test
-    public void testNotSubsumedIfNotNeeded() throws Exception {
+    void testNotSubsumedIfNotNeeded() throws Exception {
         CompletedCheckpoint cp1 = getCheckpoint(false, 1L);
         CompletedCheckpoint cp2 = getCheckpoint(false, 2L);
         CompletedCheckpoint cp3 = getCheckpoint(false, 3L);
@@ -139,7 +133,7 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
             completedCheckpointStore.addCheckpointAndSubsumeOldestOne(
                     c, new CheckpointsCleaner(), () -> {});
         }
-        assertEquals(expectedRetained, completedCheckpointStore.getAllCheckpoints());
+        assertThat(completedCheckpointStore.getAllCheckpoints()).isEqualTo(expectedRetained);
     }
 
     /**
@@ -148,24 +142,24 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
      * CheckpointStoreUtil)} should recover the sorted checkpoints by name.
      */
     @Test
-    public void testRecoverSortedCheckpoints() throws Exception {
+    void testRecoverSortedCheckpoints() throws Exception {
         final TestingStateHandleStore<CompletedCheckpoint> stateHandleStore =
                 builder.setGetAllSupplier(() -> createStateHandles(3)).build();
         final CompletedCheckpointStore completedCheckpointStore =
                 createCompletedCheckpointStore(stateHandleStore);
         final List<CompletedCheckpoint> recoveredCompletedCheckpoint =
                 completedCheckpointStore.getAllCheckpoints();
-        assertThat(recoveredCompletedCheckpoint.size(), is(3));
+        assertThat(recoveredCompletedCheckpoint).hasSize(3);
         final List<Long> checkpointIds =
                 recoveredCompletedCheckpoint.stream()
                         .map(CompletedCheckpoint::getCheckpointID)
                         .collect(Collectors.toList());
-        assertThat(checkpointIds, contains(1L, 2L, 3L));
+        assertThat(checkpointIds).containsExactly(1L, 2L, 3L);
     }
 
     /** We got an {@link IOException} when retrieving checkpoint 2. It should NOT be skipped. */
     @Test
-    public void testCorruptDataInStateHandleStoreShouldNotBeSkipped() throws Exception {
+    void testCorruptDataInStateHandleStoreShouldNotBeSkipped() throws Exception {
         final long corruptCkpId = 2L;
         checkpointStorageHelper.setRetrieveStateFunction(
                 state -> {
@@ -177,19 +171,14 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
 
         final TestingStateHandleStore<CompletedCheckpoint> stateHandleStore =
                 builder.setGetAllSupplier(() -> createStateHandles(3)).build();
-        try {
-            createCompletedCheckpointStore(stateHandleStore);
-        } catch (Exception e) {
-            if (ExceptionUtils.findThrowable(e, IOException.class).isPresent()) {
-                return;
-            }
-            throw e;
-        }
-        fail();
+
+        assertThatThrownBy(() -> createCompletedCheckpointStore(stateHandleStore))
+                .as("Exception should have been thrown.")
+                .hasCauseInstanceOf(IOException.class);
     }
 
     @Test
-    public void testAddCheckpointSuccessfullyShouldRemoveOldOnes() throws Exception {
+    void testAddCheckpointSuccessfullyShouldRemoveOldOnes() throws Exception {
         final int num = 1;
         final CompletableFuture<CompletedCheckpoint> addFuture = new CompletableFuture<>();
         final TestingStateHandleStore<CompletedCheckpoint> stateHandleStore =
@@ -203,8 +192,8 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
         final CompletedCheckpointStore completedCheckpointStore =
                 createCompletedCheckpointStore(stateHandleStore);
 
-        assertThat(completedCheckpointStore.getAllCheckpoints().size(), is(num));
-        assertThat(completedCheckpointStore.getAllCheckpoints().get(0).getCheckpointID(), is(1L));
+        assertThat(completedCheckpointStore.getAllCheckpoints()).hasSize(num);
+        assertThat(completedCheckpointStore.getAllCheckpoints().get(0).getCheckpointID()).isOne();
 
         final long ckpId = 100L;
         final CompletedCheckpoint ckp =
@@ -214,16 +203,16 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
 
         // We should persist the completed checkpoint to state handle store.
         final CompletedCheckpoint addedCkp = addFuture.get(timeout, TimeUnit.MILLISECONDS);
-        assertThat(addedCkp.getCheckpointID(), is(ckpId));
+        assertThat(addedCkp.getCheckpointID()).isEqualTo(ckpId);
 
         // Check the old checkpoint is removed and new one is added.
-        assertThat(completedCheckpointStore.getAllCheckpoints().size(), is(num));
-        assertThat(
-                completedCheckpointStore.getAllCheckpoints().get(0).getCheckpointID(), is(ckpId));
+        assertThat(completedCheckpointStore.getAllCheckpoints()).hasSize(num);
+        assertThat(completedCheckpointStore.getAllCheckpoints().get(0).getCheckpointID())
+                .isEqualTo(ckpId);
     }
 
     @Test
-    public void testAddCheckpointFailedShouldNotRemoveOldOnes() throws Exception {
+    void testAddCheckpointFailedShouldNotRemoveOldOnes() throws Exception {
         final int num = 1;
         final String errMsg = "Add to state handle failed.";
         final TestingStateHandleStore<CompletedCheckpoint> stateHandleStore =
@@ -236,28 +225,28 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
         final CompletedCheckpointStore completedCheckpointStore =
                 createCompletedCheckpointStore(stateHandleStore);
 
-        assertThat(completedCheckpointStore.getAllCheckpoints().size(), is(num));
-        assertThat(completedCheckpointStore.getAllCheckpoints().get(0).getCheckpointID(), is(1L));
+        assertThat(completedCheckpointStore.getAllCheckpoints()).hasSize(num);
+        assertThat(completedCheckpointStore.getAllCheckpoints().get(0).getCheckpointID()).isOne();
 
         final long ckpId = 100L;
         final CompletedCheckpoint ckp =
                 CompletedCheckpointStoreTest.createCheckpoint(ckpId, new SharedStateRegistryImpl());
 
-        try {
-            completedCheckpointStore.addCheckpointAndSubsumeOldestOne(
-                    ckp, new CheckpointsCleaner(), () -> {});
-            fail("We should get an exception when add checkpoint to failed..");
-        } catch (FlinkException ex) {
-            assertThat(ex, FlinkMatchers.containsMessage(errMsg));
-        }
+        assertThatThrownBy(
+                        () ->
+                                completedCheckpointStore.addCheckpointAndSubsumeOldestOne(
+                                        ckp, new CheckpointsCleaner(), () -> {}))
+                .as("We should get an exception when add checkpoint to failed..")
+                .hasMessageContaining(errMsg)
+                .isInstanceOf(FlinkException.class);
+
         // Check the old checkpoint still exists.
-        assertThat(completedCheckpointStore.getAllCheckpoints().size(), is(num));
-        assertThat(completedCheckpointStore.getAllCheckpoints().get(0).getCheckpointID(), is(1L));
+        assertThat(completedCheckpointStore.getAllCheckpoints()).hasSize(num);
+        assertThat(completedCheckpointStore.getAllCheckpoints().get(0).getCheckpointID()).isOne();
     }
 
     @Test
-    public void testShutdownShouldDiscardStateHandleWhenJobIsGloballyTerminalState()
-            throws Exception {
+    void testShutdownShouldDiscardStateHandleWhenJobIsGloballyTerminalState() throws Exception {
         int numBeforeRetained = 3;
         int numAfterRetained = 4;
         long retainedCheckpointID = numBeforeRetained + 1;
@@ -278,7 +267,7 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
         final CompletedCheckpointStore completedCheckpointStore =
                 createCompletedCheckpointStore(stateHandleStore);
 
-        assertThat(completedCheckpointStore.getAllCheckpoints().size(), is(numCheckpoints));
+        assertThat(completedCheckpointStore.getAllCheckpoints()).hasSize(numCheckpoints);
 
         // emulate shared state registration for two checkpoints which won't be completed
         TestingStreamStateHandle nonRetainedState =
@@ -290,17 +279,17 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
 
         completedCheckpointStore.shutdown(JobStatus.CANCELED, new CheckpointsCleaner());
 
-        assertThat(removeCalledNum.get(), is(numCheckpoints));
-        assertThat(clearEntriesAllFuture.isDone(), is(true));
-        assertThat(completedCheckpointStore.getAllCheckpoints().size(), is(0));
+        assertThat(removeCalledNum).hasValue(numCheckpoints);
+        assertThat(clearEntriesAllFuture).isDone();
+        assertThat(completedCheckpointStore.getAllCheckpoints()).isEmpty();
 
-        assertThat(nonRetainedState.isDisposed(), is(true));
-        assertThat(retainedState.isDisposed(), is(false));
-        assertThat(beyondRetained.isDisposed(), is(false));
+        assertThat(nonRetainedState.isDisposed()).isTrue();
+        assertThat(retainedState.isDisposed()).isFalse();
+        assertThat(beyondRetained.isDisposed()).isFalse();
     }
 
     @Test
-    public void testShutdownShouldNotDiscardStateHandleWhenJobIsNotGloballyTerminalState()
+    void testShutdownShouldNotDiscardStateHandleWhenJobIsNotGloballyTerminalState()
             throws Exception {
         final AtomicInteger removeCalledNum = new AtomicInteger(0);
         final CompletableFuture<Void> removeAllFuture = new CompletableFuture<>();
@@ -318,41 +307,40 @@ public class DefaultCompletedCheckpointStoreTest extends TestLogger {
         final CompletedCheckpointStore completedCheckpointStore =
                 createCompletedCheckpointStore(stateHandleStore);
 
-        assertThat(completedCheckpointStore.getAllCheckpoints().size(), is(3));
+        assertThat(completedCheckpointStore.getAllCheckpoints()).hasSize(3);
 
         TestingStreamStateHandle streamStateHandle = registerState(completedCheckpointStore, 3L);
 
         completedCheckpointStore.shutdown(JobStatus.CANCELLING, new CheckpointsCleaner());
-        try {
-            removeAllFuture.get(timeout, TimeUnit.MILLISECONDS);
-            fail("We should get an expected timeout because the job is not globally terminated.");
-        } catch (TimeoutException ex) {
-            // expected
-        }
-        assertThat(removeCalledNum.get(), is(0));
-        assertThat(removeAllFuture.isDone(), is(false));
-        assertThat(releaseAllFuture.isDone(), is(true));
-        assertThat(completedCheckpointStore.getAllCheckpoints().size(), is(0));
-        assertThat(streamStateHandle.isDisposed(), is(false));
+
+        assertThatFuture(removeAllFuture)
+                .as("We should get an expected timeout because the job is not globally terminated.")
+                .failsWithin(timeout, TimeUnit.MILLISECONDS);
+
+        assertThat(removeCalledNum).hasValue(0);
+        assertThat(removeAllFuture).isNotDone();
+        assertThat(releaseAllFuture).isDone();
+        assertThat(completedCheckpointStore.getAllCheckpoints()).isEmpty();
+        assertThat(streamStateHandle.isDisposed()).isFalse();
     }
 
     @Test
-    public void testShutdownFailsAnyFutureCallsToAddCheckpoint() throws Exception {
+    void testShutdownFailsAnyFutureCallsToAddCheckpoint() throws Exception {
         final CheckpointsCleaner checkpointsCleaner = new CheckpointsCleaner();
         for (JobStatus status : JobStatus.values()) {
             final CompletedCheckpointStore completedCheckpointStore =
                     createCompletedCheckpointStore(builder.build());
             completedCheckpointStore.shutdown(status, checkpointsCleaner);
-            assertThrows(
-                    IllegalStateException.class,
-                    () ->
-                            completedCheckpointStore.addCheckpointAndSubsumeOldestOne(
-                                    CompletedCheckpointStoreTest.createCheckpoint(
-                                            0L, new SharedStateRegistryImpl()),
-                                    checkpointsCleaner,
-                                    () -> {
-                                        // No-op.
-                                    }));
+            assertThatExceptionOfType(IllegalStateException.class)
+                    .isThrownBy(
+                            () ->
+                                    completedCheckpointStore.addCheckpointAndSubsumeOldestOne(
+                                            CompletedCheckpointStoreTest.createCheckpoint(
+                                                    0L, new SharedStateRegistryImpl()),
+                                            checkpointsCleaner,
+                                            () -> {
+                                                // No-op.
+                                            }));
         }
     }
 
