@@ -226,7 +226,7 @@ public class DispatcherTest extends AbstractDispatcherTest {
         final JobResult jobResult =
                 TestingJobResultStore.createJobResult(
                         jobGraph.getJobID(), ApplicationStatus.SUCCEEDED);
-        haServices.getJobResultStore().createDirtyResult(new JobResultEntry(jobResult));
+        haServices.getJobResultStore().createDirtyResultAsync(new JobResultEntry(jobResult)).get();
         assertDuplicateJobSubmission();
     }
 
@@ -235,8 +235,8 @@ public class DispatcherTest extends AbstractDispatcherTest {
         final JobResult jobResult =
                 TestingJobResultStore.createJobResult(
                         jobGraph.getJobID(), ApplicationStatus.SUCCEEDED);
-        haServices.getJobResultStore().createDirtyResult(new JobResultEntry(jobResult));
-        haServices.getJobResultStore().markResultAsClean(jobGraph.getJobID());
+        haServices.getJobResultStore().createDirtyResultAsync(new JobResultEntry(jobResult)).get();
+        haServices.getJobResultStore().markResultAsCleanAsync(jobGraph.getJobID()).get();
 
         assertDuplicateJobSubmission();
     }
@@ -737,7 +737,9 @@ public class DispatcherTest extends AbstractDispatcherTest {
     private CheckpointStatsSnapshot getTestCheckpointStatsSnapshotWithTwoFailedCheckpoints() {
         CheckpointStatsTracker checkpointStatsTracker =
                 new CheckpointStatsTracker(
-                        10, UnregisteredMetricGroups.createUnregisteredTaskManagerMetricGroup());
+                        10,
+                        UnregisteredMetricGroups.createUnregisteredTaskManagerMetricGroup(),
+                        new JobID());
         checkpointStatsTracker.reportFailedCheckpointsWithoutInProgress();
         checkpointStatsTracker.reportFailedCheckpointsWithoutInProgress();
         return checkpointStatsTracker.createSnapshot();
@@ -811,7 +813,10 @@ public class DispatcherTest extends AbstractDispatcherTest {
     private URI createTestingSavepoint() throws IOException, URISyntaxException {
         final CheckpointStorage storage =
                 Checkpoints.loadCheckpointStorage(
-                        configuration, Thread.currentThread().getContextClassLoader(), log);
+                        new Configuration(),
+                        configuration,
+                        Thread.currentThread().getContextClassLoader(),
+                        log);
         final CheckpointStorageCoordinatorView checkpointStorage =
                 storage.createCheckpointStorage(jobGraph.getJobID());
         final File savepointFile = temporaryFolder.newFolder();
@@ -1213,10 +1218,19 @@ public class DispatcherTest extends AbstractDispatcherTest {
                 ImmutableMap.of(
                         v1.getID().toHexString(), "10",
                         // v2 is omitted
-                        v3.getID().toHexString(), "42",
+                        v3.getID().toHexString(), "21",
                         // unknown vertex added
                         new JobVertexID().toHexString(), "23"));
 
+        jobGraph.getJobConfiguration()
+                .set(
+                        PipelineOptions.PARALLELISM_OVERRIDES,
+                        ImmutableMap.of(
+                                // verifies that job graph configuration has higher priority
+                                v3.getID().toHexString(), "42",
+                                // unknown vertex added
+                                new JobVertexID().toHexString(), "25"));
+
         dispatcher =
                 createAndStartDispatcher(
                         heartbeatServices,
