@@ -159,9 +159,7 @@ class ExecutionJobVertexTest {
                 1,
                 Time.milliseconds(1L),
                 1L,
-                new DefaultSubtaskAttemptNumberStore(Collections.emptyList()),
-                new CoordinatorStoreImpl(),
-                UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup());
+                new DefaultSubtaskAttemptNumberStore(Collections.emptyList()));
     }
 
     private static ExecutionJobVertex createDynamicExecutionJobVertex() throws Exception {
@@ -192,6 +190,11 @@ class ExecutionJobVertexTest {
         final VertexParallelismInformation vertexParallelismInfo =
                 vertexParallelismStore.getParallelismInfo(jobVertex.getID());
 
-        return new ExecutionJobVertex(eg, jobVertex, vertexParallelismInfo);
+        return new ExecutionJobVertex(
+                eg,
+                jobVertex,
+                vertexParallelismInfo,
+                new CoordinatorStoreImpl(),
+                UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup());
     }
 }
