@@ -19,7 +19,6 @@
 package org.apache.flink.runtime.jobmaster.slotpool;
 
 import org.apache.flink.api.common.time.Time;
-import org.apache.flink.core.testutils.FlinkMatchers;
 import org.apache.flink.runtime.clusterframework.types.AllocationID;
 import org.apache.flink.runtime.clusterframework.types.ResourceProfile;
 import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutor;
@@ -27,13 +26,14 @@ import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutorServiceAda
 import org.apache.flink.runtime.jobmaster.JobMasterId;
 import org.apache.flink.runtime.jobmaster.SlotRequestId;
 import org.apache.flink.runtime.util.ResourceCounter;
-import org.apache.flink.util.TestLogger;
+import org.apache.flink.testutils.junit.extensions.parameterized.Parameter;
+import org.apache.flink.testutils.junit.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.flink.testutils.junit.extensions.parameterized.Parameters;
 
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import java.io.IOException;
 import java.time.Duration;
@@ -44,37 +44,33 @@ import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 
+import static org.apache.flink.core.testutils.FlinkAssertions.assertThatFuture;
 import static org.apache.flink.runtime.jobmaster.slotpool.DeclarativeSlotPoolBridgeTest.createAllocatedSlot;
 import static org.apache.flink.runtime.jobmaster.slotpool.DeclarativeSlotPoolBridgeTest.createDeclarativeSlotPoolBridge;
-import static org.hamcrest.CoreMatchers.is;
-import static org.junit.Assert.assertThat;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for the {@link DeclarativeSlotPoolBridge}. */
-@RunWith(Parameterized.class)
-public class DeclarativeSlotPoolBridgeResourceDeclarationTest extends TestLogger {
+@ExtendWith(ParameterizedTestExtension.class)
+class DeclarativeSlotPoolBridgeResourceDeclarationTest {
 
     private static final JobMasterId jobMasterId = JobMasterId.generate();
     private final ComponentMainThreadExecutor mainThreadExecutor =
             ComponentMainThreadExecutorServiceAdapter.forMainThread();
-    private final RequestSlotMatchingStrategy requestSlotMatchingStrategy;
+
+    @Parameter private RequestSlotMatchingStrategy requestSlotMatchingStrategy;
 
     private RequirementListener requirementListener;
     private DeclarativeSlotPoolBridge declarativeSlotPoolBridge;
 
-    @Parameterized.Parameters(name = "RequestSlotMatchingStrategy: {0}")
+    @Parameters(name = "RequestSlotMatchingStrategy: {0}")
     public static Collection<RequestSlotMatchingStrategy> data() throws IOException {
         return Arrays.asList(
                 SimpleRequestSlotMatchingStrategy.INSTANCE,
                 PreferredAllocationRequestSlotMatchingStrategy.INSTANCE);
     }
 
-    public DeclarativeSlotPoolBridgeResourceDeclarationTest(
-            RequestSlotMatchingStrategy requestSlotMatchingStrategy) {
-        this.requestSlotMatchingStrategy = requestSlotMatchingStrategy;
-    }
-
-    @Before
-    public void setup() throws Exception {
+    @BeforeEach
+    void setup() {
         requirementListener = new RequirementListener();
 
         final TestingDeclarativeSlotPoolBuilder slotPoolBuilder =
@@ -100,27 +96,26 @@ public class DeclarativeSlotPoolBridgeResourceDeclarationTest extends TestLogger
                         declarativeSlotPoolFactory, requestSlotMatchingStrategy);
     }
 
-    @After
-    public void teardown() throws Exception {
+    @AfterEach
+    void teardown() {
         if (declarativeSlotPoolBridge != null) {
             declarativeSlotPoolBridge.close();
         }
     }
 
-    @Test
-    public void testRequirementsIncreasedOnNewAllocation() throws Exception {
+    @TestTemplate
+    void testRequirementsIncreasedOnNewAllocation() throws Exception {
         declarativeSlotPoolBridge.start(jobMasterId, "localhost", mainThreadExecutor);
 
         // requesting the allocation of a new slot should increase the requirements
         declarativeSlotPoolBridge.requestNewAllocatedSlot(
                 new SlotRequestId(), ResourceProfile.UNKNOWN, Time.minutes(5));
-        assertThat(
-                requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN),
-                is(1));
+        assertThat(requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN))
+                .isOne();
     }
 
-    @Test
-    public void testRequirementsDecreasedOnAllocationTimeout() throws Exception {
+    @TestTemplate
+    void testRequirementsDecreasedOnAllocationTimeout() throws Exception {
         final ScheduledExecutorService scheduledExecutorService =
                 Executors.newSingleThreadScheduledExecutor();
         try {
@@ -141,19 +136,17 @@ public class DeclarativeSlotPoolBridgeResourceDeclarationTest extends TestLogger
                             .get();
 
             // waiting for the timeout
-            assertThat(
-                    allocationFuture,
-                    FlinkMatchers.futureWillCompleteExceptionally(Duration.ofMinutes(1)));
-
+            assertThatFuture(allocationFuture).failsWithin(Duration.ofMinutes(1));
             // when the allocation fails the requirements should be reduced (it is the users
             // responsibility to retry)
             CompletableFuture.runAsync(
                             () ->
                                     assertThat(
-                                            requirementListener
-                                                    .getRequirements()
-                                                    .getResourceCount(ResourceProfile.UNKNOWN),
-                                            is(0)),
+                                                    requirementListener
+                                                            .getRequirements()
+                                                            .getResourceCount(
+                                                                    ResourceProfile.UNKNOWN))
+                                            .isZero(),
                             mainThreadExecutor)
                     .join();
         } finally {
@@ -161,20 +154,19 @@ public class DeclarativeSlotPoolBridgeResourceDeclarationTest extends TestLogger
         }
     }
 
-    @Test
-    public void testRequirementsUnchangedOnNewSlotsNotification() throws Exception {
+    @TestTemplate
+    void testRequirementsUnchangedOnNewSlotsNotification() throws Exception {
         declarativeSlotPoolBridge.start(jobMasterId, "localhost", mainThreadExecutor);
 
         // notifications about new slots should not affect requirements
         final PhysicalSlot newSlot = createAllocatedSlot(new AllocationID());
         declarativeSlotPoolBridge.newSlotsAreAvailable(Collections.singleton(newSlot));
-        assertThat(
-                requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN),
-                is(0));
+        assertThat(requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN))
+                .isZero();
     }
 
-    @Test
-    public void testRequirementsIncreasedOnSlotReservation() throws Exception {
+    @TestTemplate
+    void testRequirementsIncreasedOnSlotReservation() throws Exception {
         declarativeSlotPoolBridge.start(jobMasterId, "localhost", mainThreadExecutor);
 
         final PhysicalSlot newSlot = createAllocatedSlot(new AllocationID());
@@ -184,13 +176,12 @@ public class DeclarativeSlotPoolBridgeResourceDeclarationTest extends TestLogger
         final SlotRequestId slotRequestId = new SlotRequestId();
         declarativeSlotPoolBridge.allocateAvailableSlot(
                 slotRequestId, newSlot.getAllocationId(), ResourceProfile.UNKNOWN);
-        assertThat(
-                requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN),
-                is(1));
+        assertThat(requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN))
+                .isOne();
     }
 
-    @Test
-    public void testRequirementsDecreasedOnSlotFreeing() throws Exception {
+    @TestTemplate
+    void testRequirementsDecreasedOnSlotFreeing() throws Exception {
         declarativeSlotPoolBridge.start(jobMasterId, "localhost", mainThreadExecutor);
 
         final PhysicalSlot newSlot = createAllocatedSlot(new AllocationID());
@@ -203,13 +194,12 @@ public class DeclarativeSlotPoolBridgeResourceDeclarationTest extends TestLogger
         // releasing (==freeing) a [reserved] slot should decrease the requirements
         declarativeSlotPoolBridge.releaseSlot(
                 slotRequestId, new RuntimeException("Test exception"));
-        assertThat(
-                requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN),
-                is(0));
+        assertThat(requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN))
+                .isZero();
     }
 
-    @Test
-    public void testRequirementsDecreasedOnSlotAllocationFailure() throws Exception {
+    @TestTemplate
+    void testRequirementsDecreasedOnSlotAllocationFailure() throws Exception {
         declarativeSlotPoolBridge.start(jobMasterId, "localhost", mainThreadExecutor);
 
         final PhysicalSlot newSlot = createAllocatedSlot(new AllocationID());
@@ -223,9 +213,8 @@ public class DeclarativeSlotPoolBridgeResourceDeclarationTest extends TestLogger
                 newSlot.getTaskManagerLocation().getResourceID(),
                 newSlot.getAllocationId(),
                 new RuntimeException("Test exception"));
-        assertThat(
-                requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN),
-                is(0));
+        assertThat(requirementListener.getRequirements().getResourceCount(ResourceProfile.UNKNOWN))
+                .isZero();
     }
 
     private static final class RequirementListener {
