@@ -20,13 +20,11 @@ package org.apache.flink.runtime.jobmaster.slotpool;
 
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.time.Time;
-import org.apache.flink.core.testutils.FlinkMatchers;
 import org.apache.flink.runtime.clusterframework.types.AllocationID;
 import org.apache.flink.runtime.clusterframework.types.ResourceProfile;
 import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutor;
 import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutorServiceAdapter;
 import org.apache.flink.runtime.executiongraph.utils.SimpleAckingTaskManagerGateway;
-import org.apache.flink.runtime.jobmanager.scheduler.NoResourceAvailableException;
 import org.apache.flink.runtime.jobmaster.JobMasterId;
 import org.apache.flink.runtime.jobmaster.RpcTaskManagerGateway;
 import org.apache.flink.runtime.jobmaster.SlotRequestId;
@@ -34,13 +32,14 @@ import org.apache.flink.runtime.taskexecutor.TestingTaskExecutorGatewayBuilder;
 import org.apache.flink.runtime.taskexecutor.slot.SlotOffer;
 import org.apache.flink.runtime.taskmanager.LocalTaskManagerLocation;
 import org.apache.flink.runtime.util.ResourceCounter;
-import org.apache.flink.util.TestLogger;
+import org.apache.flink.testutils.junit.extensions.parameterized.Parameter;
+import org.apache.flink.testutils.junit.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.flink.testutils.junit.extensions.parameterized.Parameters;
 import org.apache.flink.util.clock.SystemClock;
 import org.apache.flink.util.concurrent.FutureUtils;
 
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import javax.annotation.Nonnull;
 
@@ -55,34 +54,30 @@ import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ExecutionException;
 import java.util.stream.Collectors;
 
-import static org.hamcrest.CoreMatchers.is;
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.fail;
+import static org.apache.flink.core.testutils.FlinkAssertions.assertThatFuture;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 /** Tests for the {@link DeclarativeSlotPoolBridge}. */
-@RunWith(Parameterized.class)
-public class DeclarativeSlotPoolBridgeTest extends TestLogger {
+@ExtendWith(ParameterizedTestExtension.class)
+class DeclarativeSlotPoolBridgeTest {
 
     private static final Time rpcTimeout = Time.seconds(20);
     private static final JobID jobId = new JobID();
     private static final JobMasterId jobMasterId = JobMasterId.generate();
     private final ComponentMainThreadExecutor mainThreadExecutor =
             ComponentMainThreadExecutorServiceAdapter.forMainThread();
-    private final RequestSlotMatchingStrategy requestSlotMatchingStrategy;
+    @Parameter private RequestSlotMatchingStrategy requestSlotMatchingStrategy;
 
-    @Parameterized.Parameters(name = "RequestSlotMatchingStrategy: {0}")
+    @Parameters(name = "RequestSlotMatchingStrategy: {0}")
     public static Collection<RequestSlotMatchingStrategy> data() throws IOException {
         return Arrays.asList(
                 SimpleRequestSlotMatchingStrategy.INSTANCE,
                 PreferredAllocationRequestSlotMatchingStrategy.INSTANCE);
     }
 
-    public DeclarativeSlotPoolBridgeTest(RequestSlotMatchingStrategy requestSlotMatchingStrategy) {
-        this.requestSlotMatchingStrategy = requestSlotMatchingStrategy;
-    }
-
-    @Test
-    public void testSlotOffer() throws Exception {
+    @TestTemplate
+    void testSlotOffer() throws Exception {
         final SlotRequestId slotRequestId = new SlotRequestId();
         final AllocationID expectedAllocationId = new AllocationID();
         final PhysicalSlot allocatedSlot = createAllocatedSlot(expectedAllocationId);
@@ -105,8 +100,8 @@ public class DeclarativeSlotPoolBridgeTest extends TestLogger {
         }
     }
 
-    @Test
-    public void testNotEnoughResourcesAvailableFailsPendingRequests() throws Exception {
+    @TestTemplate
+    void testNotEnoughResourcesAvailableFailsPendingRequests() throws Exception {
         final SlotRequestId slotRequestId = new SlotRequestId();
 
         final TestingDeclarativeSlotPoolFactory declarativeSlotPoolFactory =
@@ -132,15 +127,12 @@ public class DeclarativeSlotPoolBridgeTest extends TestLogger {
                             declarativeSlotPoolBridge.notifyNotEnoughResourcesAvailable(
                                     Collections.emptyList()));
 
-            assertThat(
-                    slotAllocationFuture,
-                    FlinkMatchers.futureWillCompleteExceptionally(
-                            NoResourceAvailableException.class, Duration.ofSeconds(10)));
+            assertThatFuture(slotAllocationFuture).failsWithin(Duration.ofSeconds(10));
         }
     }
 
-    @Test
-    public void testReleasingAllocatedSlot() throws Exception {
+    @TestTemplate
+    void testReleasingAllocatedSlot() throws Exception {
         final CompletableFuture<AllocationID> releaseSlotFuture = new CompletableFuture<>();
         final AllocationID expectedAllocationId = new AllocationID();
         final PhysicalSlot allocatedSlot = createAllocatedSlot(expectedAllocationId);
@@ -149,7 +141,7 @@ public class DeclarativeSlotPoolBridgeTest extends TestLogger {
                 TestingDeclarativeSlotPool.builder()
                         .setReserveFreeSlotFunction(
                                 (allocationId, resourceProfile) -> {
-                                    assertThat(allocationId, is(expectedAllocationId));
+                                    assertThat(allocationId).isSameAs(expectedAllocationId);
                                     return allocatedSlot;
                                 })
                         .setFreeReservedSlotFunction(
@@ -171,12 +163,12 @@ public class DeclarativeSlotPoolBridgeTest extends TestLogger {
                     slotRequestId, expectedAllocationId, allocatedSlot.getResourceProfile());
             declarativeSlotPoolBridge.releaseSlot(slotRequestId, null);
 
-            assertThat(releaseSlotFuture.join(), is(expectedAllocationId));
+            assertThat(releaseSlotFuture.join()).isSameAs(expectedAllocationId);
         }
     }
 
-    @Test
-    public void testNoConcurrentModificationWhenSuspendingAndReleasingSlot() throws Exception {
+    @TestTemplate
+    void testNoConcurrentModificationWhenSuspendingAndReleasingSlot() throws Exception {
         try (DeclarativeSlotPoolBridge declarativeSlotPoolBridge =
                 createDeclarativeSlotPoolBridge(
                         new DefaultDeclarativeSlotPoolFactory(), requestSlotMatchingStrategy)) {
@@ -208,17 +200,14 @@ public class DeclarativeSlotPoolBridgeTest extends TestLogger {
 
             declarativeSlotPoolBridge.close();
 
-            try {
-                FutureUtils.waitForAll(slotFutures).get();
-                fail("The slot futures should be completed exceptionally.");
-            } catch (ExecutionException expected) {
-                // expected
-            }
+            assertThatThrownBy(() -> FutureUtils.waitForAll(slotFutures).get())
+                    .as("The slot futures should be completed exceptionally.")
+                    .isInstanceOf(ExecutionException.class);
         }
     }
 
-    @Test
-    public void testAcceptingOfferedSlotsWithoutResourceManagerConnected() throws Exception {
+    @TestTemplate
+    void testAcceptingOfferedSlotsWithoutResourceManagerConnected() throws Exception {
         try (DeclarativeSlotPoolBridge declarativeSlotPoolBridge =
                 createDeclarativeSlotPoolBridge(
                         new DefaultDeclarativeSlotPoolFactory(), requestSlotMatchingStrategy)) {
@@ -239,12 +228,12 @@ public class DeclarativeSlotPoolBridgeTest extends TestLogger {
                     new SimpleAckingTaskManagerGateway(),
                     Collections.singleton(new SlotOffer(allocationId, 0, ResourceProfile.ANY)));
 
-            assertThat(slotFuture.join().getAllocationId(), is(allocationId));
+            assertThat(slotFuture.join().getAllocationId()).isSameAs(allocationId);
         }
     }
 
-    @Test
-    public void testIfJobIsRestartingAllOfferedSlotsWillBeRegistered() throws Exception {
+    @TestTemplate
+    void testIfJobIsRestartingAllOfferedSlotsWillBeRegistered() throws Exception {
         final CompletableFuture<Void> registerSlotsCalledFuture = new CompletableFuture<>();
         final TestingDeclarativeSlotPoolFactory declarativeSlotPoolFactory =
                 new TestingDeclarativeSlotPoolFactory(
