@@ -44,7 +44,7 @@ import org.apache.flink.util.MutableObjectIterator;
 
 import org.apache.flink.shaded.guava31.com.google.common.collect.Ordering;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.io.EOFException;
 import java.util.ArrayList;
@@ -55,13 +55,11 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Random;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.fail;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assertions.fail;
 
-public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
+class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
 
     private static final long RANDOM_SEED = 58723953465322L;
 
@@ -130,7 +128,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
      * of the different constructor calls.
      */
     @Test
-    public void testHashTableGrowthWithInsert() {
+    void testHashTableGrowthWithInsert() {
         try {
             final int numElements = 1000000;
 
@@ -151,14 +149,13 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
                 MutableObjectIterator<Tuple2<Long, String>> iter = table.getEntryIterator();
                 Tuple2<Long, String> next;
                 while ((next = iter.next()) != null) {
-                    assertNotNull(next.f0);
-                    assertNotNull(next.f1);
-                    assertEquals(next.f0.longValue(), Long.parseLong(next.f1));
+                    assertThat(next.f1).isNotNull();
+                    assertThat(next.f0).isNotNull().isEqualTo(Long.parseLong(next.f1));
 
                     bitSet.set(next.f0.intValue());
                 }
 
-                assertEquals(numElements, bitSet.cardinality());
+                assertThat(bitSet.cardinality()).isEqualTo(numElements);
             }
 
             // make sure all entries are contained via the prober
@@ -169,8 +166,8 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
                 Tuple2<Long, String> reuse = new Tuple2<>();
 
                 for (long i = 0; i < numElements; i++) {
-                    assertNotNull(proper.getMatchFor(i, reuse));
-                    assertNull(proper.getMatchFor(i + numElements, reuse));
+                    assertThat(proper.getMatchFor(i, reuse)).isNotNull();
+                    assertThat(proper.getMatchFor(i + numElements, reuse)).isNull();
                 }
             }
 
@@ -188,7 +185,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
      * because of the different constructor calls.
      */
     @Test
-    public void testHashTableGrowthWithInsertOrReplace() {
+    void testHashTableGrowthWithInsertOrReplace() {
         try {
             final int numElements = 1000000;
 
@@ -209,14 +206,13 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
                 MutableObjectIterator<Tuple2<Long, String>> iter = table.getEntryIterator();
                 Tuple2<Long, String> next;
                 while ((next = iter.next()) != null) {
-                    assertNotNull(next.f0);
-                    assertNotNull(next.f1);
-                    assertEquals(next.f0.longValue(), Long.parseLong(next.f1));
+                    assertThat(next.f1).isNotNull();
+                    assertThat(next.f0).isNotNull().isEqualTo(Long.parseLong(next.f1));
 
                     bitSet.set(next.f0.intValue());
                 }
 
-                assertEquals(numElements, bitSet.cardinality());
+                assertThat(bitSet.cardinality()).isEqualTo(numElements);
             }
 
             // make sure all entries are contained via the prober
@@ -227,8 +223,8 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
                 Tuple2<Long, String> reuse = new Tuple2<>();
 
                 for (long i = 0; i < numElements; i++) {
-                    assertNotNull(proper.getMatchFor(i, reuse));
-                    assertNull(proper.getMatchFor(i + numElements, reuse));
+                    assertThat(proper.getMatchFor(i, reuse)).isNotNull();
+                    assertThat(proper.getMatchFor(i + numElements, reuse)).isNull();
                 }
             }
 
@@ -286,7 +282,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
     }
 
     @Test
-    public void testWithIntPair() throws Exception {
+    void testWithIntPair() throws Exception {
         Random rnd = new Random(RANDOM_SEED);
 
         // varying the keyRange between 1000 and 1000000 can make a 5x speed difference
@@ -352,7 +348,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
 
         // Check results
 
-        assertEquals(expectedOutput.size(), actualOutput.size());
+        assertThat(actualOutput).hasSameSizeAs(expectedOutput);
 
         Integer[] expectedValues = new Integer[expectedOutput.size()];
         for (int i = 0; i < expectedOutput.size(); i++) {
@@ -365,7 +361,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
 
         Arrays.sort(expectedValues, Ordering.<Integer>natural());
         Arrays.sort(actualValues, Ordering.<Integer>natural());
-        assertArrayEquals(expectedValues, actualValues);
+        assertThat(actualValues).isEqualTo(expectedValues);
     }
 
     class SumReducer implements ReduceFunction<IntPair> {
@@ -381,7 +377,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
     }
 
     @Test
-    public void testWithLengthChangingReduceFunction() throws Exception {
+    void testWithLengthChangingReduceFunction() throws Exception {
         Random rnd = new Random(RANDOM_SEED);
 
         final int numKeys = 10000;
@@ -466,7 +462,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
 
             // Check results
 
-            assertEquals(expectedOutput.size(), actualOutput.size());
+            assertThat(actualOutput).hasSameSizeAs(expectedOutput);
 
             String[] expectedValues = new String[expectedOutput.size()];
             for (int i = 0; i < expectedOutput.size(); i++) {
@@ -479,7 +475,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
 
             Arrays.sort(expectedValues, Ordering.<String>natural());
             Arrays.sort(actualValues, Ordering.<String>natural());
-            assertArrayEquals(expectedValues, actualValues);
+            assertThat(actualValues).isEqualTo(expectedValues);
 
             expectedOutput.clear();
             actualOutput.clear();
@@ -515,7 +511,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
      * lots of compactions will happen.
      */
     @Test
-    public void testLargeRecordsWithManyCompactions() {
+    void testLargeRecordsWithManyCompactions() {
         try {
             final int numElements = 1000;
 
@@ -541,7 +537,7 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
                     prober = table.getProber(comparator, new SameTypePairComparator<>(comparator));
             Tuple2<Long, String> reuse = new Tuple2<>();
             for (long i = 0; i < numElements; i++) {
-                assertNotNull(prober.getMatchFor(Tuple2.of(i, longString2), reuse));
+                assertThat(prober.getMatchFor(Tuple2.of(i, longString1), reuse)).isNotNull();
             }
 
             table.close();
@@ -560,31 +556,25 @@ public class InPlaceMutableHashTableTest extends MutableHashTableTestBase {
     }
 
     @Test
-    public void testOutOfMemory() {
-        try {
-            List<MemorySegment> memory = getMemory(100, 1024);
+    void testOutOfMemory() {
+        List<MemorySegment> memory = getMemory(100, 1024);
 
-            InPlaceMutableHashTable<Tuple2<Long, String>> table =
-                    new InPlaceMutableHashTable<>(serializer, comparator, memory);
+        InPlaceMutableHashTable<Tuple2<Long, String>> table =
+                new InPlaceMutableHashTable<>(serializer, comparator, memory);
 
-            try {
-                final int numElements = 100000;
+        final int numElements = 100000;
 
-                table.open();
+        table.open();
 
-                // Insert too many elements
-                for (long i = 0; i < numElements; i++) {
-                    table.insertOrReplaceRecord(Tuple2.of(i, "alma"));
-                }
+        // Insert too many elements
+        assertThatThrownBy(
+                        () -> {
+                            for (long i = 0; i < numElements; i++) {
+                                table.insertOrReplaceRecord(Tuple2.of(i, "alma"));
+                            }
+                        })
+                .isInstanceOf(EOFException.class);
 
-                fail("We should have got out of memory (EOFException)");
-            } catch (EOFException e) {
-                // OK
-                table.close();
-            }
-        } catch (Exception e) {
-            e.printStackTrace();
-            fail(e.getMessage());
-        }
+        table.close();
     }
 }
