@@ -19,20 +19,24 @@
 package org.apache.flink.runtime.resourcemanager.slotmanager;
 
 import org.apache.flink.api.common.JobID;
+import org.apache.flink.api.common.resources.CPUResource;
 import org.apache.flink.api.common.resources.ExternalResource;
 import org.apache.flink.api.common.time.Time;
+import org.apache.flink.configuration.MemorySize;
 import org.apache.flink.runtime.clusterframework.types.ResourceProfile;
 import org.apache.flink.runtime.slots.ResourceRequirement;
 import org.apache.flink.runtime.util.ResourceCounter;
 
 import org.junit.jupiter.api.Test;
 
+import java.math.BigDecimal;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 
+import static org.apache.flink.configuration.TaskManagerOptions.TaskManagerLoadBalanceMode;
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for the {@link DefaultResourceAllocationStrategy}. */
@@ -41,9 +45,10 @@ class DefaultResourceAllocationStrategyTest {
             ResourceProfile.fromResources(1, 100);
     private static final int NUM_OF_SLOTS = 5;
     private static final DefaultResourceAllocationStrategy ANY_MATCHING_STRATEGY =
-            createStrategy(false);
+            createStrategy(TaskManagerLoadBalanceMode.NONE);
 
-    private static final DefaultResourceAllocationStrategy EVENLY_STRATEGY = createStrategy(true);
+    private static final DefaultResourceAllocationStrategy EVENLY_STRATEGY =
+            createStrategy(TaskManagerLoadBalanceMode.SLOTS);
 
     @Test
     void testFulfillRequirementWithRegisteredResources() {
@@ -523,21 +528,204 @@ class DefaultResourceAllocationStrategyTest {
         assertThat(result.getTaskManagersToRelease()).isEmpty();
     }
 
-    private static DefaultResourceAllocationStrategy createStrategy(boolean evenlySpreadOutSlots) {
-        return createStrategy(evenlySpreadOutSlots, 0);
+    @Test
+    void testMinRequiredCPULimitInTryReconcile() {
+        CPUResource minRequiredCPU =
+                DEFAULT_SLOT_RESOURCE
+                        .getCpuCores()
+                        .multiply(NUM_OF_SLOTS)
+                        .multiply(BigDecimal.valueOf(4.5));
+
+        testMinResourceLimitInReconcile(minRequiredCPU, MemorySize.ZERO, 2);
+        testMinResourceLimitInReconcileWithNoResource(minRequiredCPU, MemorySize.ZERO, 5);
     }
 
-    private static DefaultResourceAllocationStrategy createStrategy(int redundantTaskManagerNum) {
-        return createStrategy(false, redundantTaskManagerNum);
+    @Test
+    void testMinRequiredMemoryLimitInTryReconcile() {
+        MemorySize minRequiredMemory =
+                DEFAULT_SLOT_RESOURCE.getTotalMemory().multiply(NUM_OF_SLOTS).multiply(3.5);
+        testMinResourceLimitInReconcile(new CPUResource(0.0), minRequiredMemory, 1);
+        testMinResourceLimitInReconcileWithNoResource(new CPUResource(0.0), minRequiredMemory, 4);
+    }
+
+    @Test
+    void testMinRequiredCPULimitInTryFulfill() {
+        CPUResource minRequiredCPU =
+                DEFAULT_SLOT_RESOURCE
+                        .getCpuCores()
+                        .multiply(NUM_OF_SLOTS)
+                        .multiply(BigDecimal.valueOf(4.5));
+        testMinRequiredResourceLimitInFulfillRequirements(minRequiredCPU, MemorySize.ZERO, 4);
+    }
+
+    @Test
+    void testMinRequiredCPULimitInTryFulfillWithRequirement() {
+        CPUResource minRequiredCPU =
+                DEFAULT_SLOT_RESOURCE
+                        .getCpuCores()
+                        .multiply(NUM_OF_SLOTS)
+                        .multiply(BigDecimal.valueOf(4.5));
+        List<ResourceRequirement> resourceRequirements =
+                Collections.singletonList(
+                        ResourceRequirement.create(DEFAULT_SLOT_RESOURCE, 3 * NUM_OF_SLOTS));
+
+        testMinRequiredResourceLimitInFulfillRequirements(
+                minRequiredCPU, MemorySize.ZERO, 4, resourceRequirements);
+    }
+
+    @Test
+    void testMinRequiredMemoryLimitInTryFulfill() {
+        MemorySize minRequiredMemory =
+                DEFAULT_SLOT_RESOURCE.getTotalMemory().multiply(NUM_OF_SLOTS).multiply(3.5);
+        testMinRequiredResourceLimitInFulfillRequirements(
+                new CPUResource(0.0), minRequiredMemory, 3);
+    }
+
+    @Test
+    void testMinRequiredMemoryLimitInTryFulfillWithRequirement() {
+        CPUResource minRequiredCPU =
+                DEFAULT_SLOT_RESOURCE
+                        .getCpuCores()
+                        .multiply(NUM_OF_SLOTS)
+                        .multiply(BigDecimal.valueOf(4.5));
+        List<ResourceRequirement> resourceRequirements =
+                Collections.singletonList(
+                        ResourceRequirement.create(DEFAULT_SLOT_RESOURCE, 3 * NUM_OF_SLOTS));
+        testMinRequiredResourceLimitInFulfillRequirements(
+                minRequiredCPU, MemorySize.ZERO, 4, resourceRequirements);
+    }
+
+    void testMinResourceLimitInReconcile(
+            CPUResource minRequiredCPU,
+            MemorySize minRequiredMemory,
+            int pendingTaskManagersToAllocate) {
+
+        final TaskManagerInfo taskManagerInUse =
+                new TestingTaskManagerInfo(
+                        DEFAULT_SLOT_RESOURCE.multiply(NUM_OF_SLOTS),
+                        DEFAULT_SLOT_RESOURCE.multiply(NUM_OF_SLOTS),
+                        DEFAULT_SLOT_RESOURCE);
+
+        final TestingTaskManagerInfo taskManagerIdle =
+                new TestingTaskManagerInfo(
+                        DEFAULT_SLOT_RESOURCE.multiply(NUM_OF_SLOTS),
+                        DEFAULT_SLOT_RESOURCE.multiply(NUM_OF_SLOTS),
+                        DEFAULT_SLOT_RESOURCE);
+        taskManagerIdle.setIdleSince(System.currentTimeMillis() - 10);
+
+        final PendingTaskManager pendingTaskManager =
+                new PendingTaskManager(DEFAULT_SLOT_RESOURCE.multiply(NUM_OF_SLOTS), NUM_OF_SLOTS);
+
+        final TaskManagerResourceInfoProvider taskManagerResourceInfoProvider =
+                TestingTaskManagerResourceInfoProvider.newBuilder()
+                        .setRegisteredTaskManagersSupplier(
+                                () -> Arrays.asList(taskManagerInUse, taskManagerIdle))
+                        .setPendingTaskManagersSupplier(
+                                () -> Collections.singletonList(pendingTaskManager))
+                        .build();
+
+        DefaultResourceAllocationStrategy strategy =
+                createStrategy(minRequiredCPU, minRequiredMemory);
+        ResourceReconcileResult result =
+                strategy.tryReconcileClusterResources(taskManagerResourceInfoProvider);
+
+        assertThat(result.getPendingTaskManagersToRelease()).isEmpty();
+        assertThat(result.getTaskManagersToRelease()).isEmpty();
+        assertThat(result.getPendingTaskManagersToAllocate())
+                .hasSize(pendingTaskManagersToAllocate);
+    }
+
+    void testMinResourceLimitInReconcileWithNoResource(
+            CPUResource minRequiredCPU,
+            MemorySize minRequiredMemory,
+            int pendingTaskManagersToAllocate) {
+
+        final TaskManagerResourceInfoProvider taskManagerResourceInfoProvider =
+                TestingTaskManagerResourceInfoProvider.newBuilder()
+                        .setRegisteredTaskManagersSupplier(Arrays::asList)
+                        .setPendingTaskManagersSupplier(Arrays::asList)
+                        .build();
+
+        DefaultResourceAllocationStrategy strategy =
+                createStrategy(minRequiredCPU, minRequiredMemory);
+        ResourceReconcileResult result =
+                strategy.tryReconcileClusterResources(taskManagerResourceInfoProvider);
+
+        assertThat(result.getPendingTaskManagersToRelease()).isEmpty();
+        assertThat(result.getTaskManagersToRelease()).isEmpty();
+        assertThat(result.getPendingTaskManagersToAllocate())
+                .hasSize(pendingTaskManagersToAllocate);
+    }
+
+    void testMinRequiredResourceLimitInFulfillRequirements(
+            CPUResource minRequiredCPU,
+            MemorySize minRequiredMemory,
+            int pendingTaskManagersToAllocate) {
+        testMinRequiredResourceLimitInFulfillRequirements(
+                minRequiredCPU,
+                minRequiredMemory,
+                pendingTaskManagersToAllocate,
+                Collections.emptyList());
+    }
+
+    void testMinRequiredResourceLimitInFulfillRequirements(
+            CPUResource minRequiredCPU,
+            MemorySize minRequiredMemory,
+            int pendingTaskManagersToAllocate,
+            List<ResourceRequirement> requirements) {
+        final JobID jobId = new JobID();
+        final PendingTaskManager pendingTaskManager =
+                new PendingTaskManager(DEFAULT_SLOT_RESOURCE.multiply(NUM_OF_SLOTS), NUM_OF_SLOTS);
+
+        final TaskManagerResourceInfoProvider taskManagerResourceInfoProvider =
+                TestingTaskManagerResourceInfoProvider.newBuilder()
+                        .setRegisteredTaskManagersSupplier(Arrays::asList)
+                        .setPendingTaskManagersSupplier(
+                                () -> Collections.singletonList(pendingTaskManager))
+                        .build();
+
+        DefaultResourceAllocationStrategy strategy =
+                createStrategy(minRequiredCPU, minRequiredMemory);
+        ResourceAllocationResult result =
+                strategy.tryFulfillRequirements(
+                        Collections.singletonMap(jobId, requirements),
+                        taskManagerResourceInfoProvider,
+                        resourceID -> false);
+
+        assertThat(result.getPendingTaskManagersToAllocate())
+                .hasSize(pendingTaskManagersToAllocate);
     }
 
     private static DefaultResourceAllocationStrategy createStrategy(
-            boolean evenlySpreadOutSlots, int redundantTaskManagerNum) {
+            TaskManagerLoadBalanceMode taskManagerLoadBalanceMode) {
+        return createStrategy(taskManagerLoadBalanceMode, 0);
+    }
+
+    private static DefaultResourceAllocationStrategy createStrategy(int redundantTaskManagerNum) {
+        return createStrategy(TaskManagerLoadBalanceMode.NONE, redundantTaskManagerNum);
+    }
+
+    private static DefaultResourceAllocationStrategy createStrategy(
+            TaskManagerLoadBalanceMode taskManagerLoadBalanceMode, int redundantTaskManagerNum) {
         return new DefaultResourceAllocationStrategy(
                 DEFAULT_SLOT_RESOURCE.multiply(NUM_OF_SLOTS),
                 NUM_OF_SLOTS,
-                evenlySpreadOutSlots,
+                taskManagerLoadBalanceMode,
                 Time.milliseconds(0),
-                redundantTaskManagerNum);
+                redundantTaskManagerNum,
+                new CPUResource(0.0),
+                MemorySize.ZERO);
+    }
+
+    private static DefaultResourceAllocationStrategy createStrategy(
+            CPUResource minRequiredCPU, MemorySize minRequiredMemory) {
+        return new DefaultResourceAllocationStrategy(
+                DEFAULT_SLOT_RESOURCE.multiply(NUM_OF_SLOTS),
+                NUM_OF_SLOTS,
+                TaskManagerLoadBalanceMode.NONE,
+                Time.milliseconds(0),
+                0,
+                minRequiredCPU,
+                minRequiredMemory);
     }
 }
