@@ -22,6 +22,7 @@ import org.apache.flink.runtime.resourcemanager.WorkerResourceSpec;
 import org.apache.flink.util.concurrent.Executors;
 import org.apache.flink.util.concurrent.ScheduledExecutor;
 
+import java.time.Duration;
 import java.util.concurrent.Executor;
 
 /** Builder for {@link TaskExecutorManager}. */
@@ -33,9 +34,10 @@ public class TaskExecutorManagerBuilder {
     private boolean waitResultConsumedBeforeRelease = true;
     private int redundantTaskManagerNum = 0;
     private Time taskManagerTimeout = Time.seconds(5);
+    private Duration declareNeededResourceDelay = Duration.ofMillis(0);
     private final ScheduledExecutor scheduledExecutor;
     private Executor mainThreadExecutor = Executors.directExecutor();
-    private ResourceActions newResourceActions = new TestingResourceActionsBuilder().build();
+    private ResourceAllocator newResourceAllocator = new TestingResourceAllocatorBuilder().build();
 
     public TaskExecutorManagerBuilder(ScheduledExecutor scheduledExecutor) {
         this.scheduledExecutor = scheduledExecutor;
@@ -78,8 +80,14 @@ public class TaskExecutorManagerBuilder {
         return this;
     }
 
-    public TaskExecutorManagerBuilder setResourceActions(ResourceActions newResourceActions) {
-        this.newResourceActions = newResourceActions;
+    public TaskExecutorManagerBuilder setResourceAllocator(ResourceAllocator newResourceAllocator) {
+        this.newResourceAllocator = newResourceAllocator;
+        return this;
+    }
+
+    public TaskExecutorManagerBuilder setDeclareNeededResourceDelay(
+            Duration declareNeededResourceDelay) {
+        this.declareNeededResourceDelay = declareNeededResourceDelay;
         return this;
     }
 
@@ -91,8 +99,9 @@ public class TaskExecutorManagerBuilder {
                 waitResultConsumedBeforeRelease,
                 redundantTaskManagerNum,
                 taskManagerTimeout,
+                declareNeededResourceDelay,
                 scheduledExecutor,
                 mainThreadExecutor,
-                newResourceActions);
+                newResourceAllocator);
     }
 }
