@@ -45,6 +45,7 @@ import org.apache.flink.runtime.resourcemanager.TaskExecutorRegistration;
 import org.apache.flink.runtime.resourcemanager.TaskManagerInfoWithSlots;
 import org.apache.flink.runtime.resourcemanager.exceptions.UnknownTaskExecutorException;
 import org.apache.flink.runtime.rest.messages.LogInfo;
+import org.apache.flink.runtime.rest.messages.ProfilingInfo;
 import org.apache.flink.runtime.rest.messages.ThreadDumpInfo;
 import org.apache.flink.runtime.rest.messages.taskmanager.TaskManagerInfo;
 import org.apache.flink.runtime.shuffle.ShuffleDescriptor;
@@ -59,6 +60,7 @@ import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.concurrent.FutureUtils;
 import org.apache.flink.util.function.QuadFunction;
 
+import java.time.Duration;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
@@ -95,6 +97,10 @@ public class TestingResourceManagerGateway implements ResourceManagerGateway {
     private volatile Function<Tuple2<ResourceID, String>, CompletableFuture<TransientBlobKey>>
             requestTaskManagerFileUploadByNameFunction;
 
+    private volatile Function<
+                    Tuple3<ResourceID, String, FileType>, CompletableFuture<TransientBlobKey>>
+            requestTaskManagerFileUploadByNameAndTypeFunction;
+
     private volatile Consumer<Tuple2<ResourceID, Throwable>> disconnectTaskExecutorConsumer;
 
     private volatile Function<
@@ -118,6 +124,12 @@ public class TestingResourceManagerGateway implements ResourceManagerGateway {
     private volatile Function<ResourceID, CompletableFuture<ThreadDumpInfo>>
             requestThreadDumpFunction;
 
+    private volatile Function<ResourceID, CompletableFuture<ProfilingInfo>>
+            requestProfilingFunction;
+
+    private volatile Function<ResourceID, CompletableFuture<Collection<ProfilingInfo>>>
+            requestProfilingListFunction;
+
     private volatile BiFunction<JobMasterId, ResourceRequirements, CompletableFuture<Acknowledge>>
             declareRequiredResourcesFunction =
                     (ignoredA, ignoredB) ->
@@ -187,6 +199,13 @@ public class TestingResourceManagerGateway implements ResourceManagerGateway {
                 requestTaskManagerFileUploadByNameFunction;
     }
 
+    public void setRequestTaskManagerFileUploadByNameAndTypeFunction(
+            Function<Tuple3<ResourceID, String, FileType>, CompletableFuture<TransientBlobKey>>
+                    requestTaskManagerFileUploadByNameAndTypeFunction) {
+        this.requestTaskManagerFileUploadByNameAndTypeFunction =
+                requestTaskManagerFileUploadByNameAndTypeFunction;
+    }
+
     public void setRequestTaskManagerLogListFunction(
             Function<ResourceID, CompletableFuture<Collection<LogInfo>>>
                     requestTaskManagerLogListFunction) {
@@ -237,6 +256,17 @@ public class TestingResourceManagerGateway implements ResourceManagerGateway {
         this.requestThreadDumpFunction = requestThreadDumpFunction;
     }
 
+    public void setRequestProfilingFunction(
+            Function<ResourceID, CompletableFuture<ProfilingInfo>> requestProfilingFunction) {
+        this.requestProfilingFunction = requestProfilingFunction;
+    }
+
+    public void setRequestProfilingListFunction(
+            Function<ResourceID, CompletableFuture<Collection<ProfilingInfo>>>
+                    requestProfilingListFunction) {
+        this.requestProfilingListFunction = requestProfilingListFunction;
+    }
+
     public void setDeclareRequiredResourcesFunction(
             BiFunction<JobMasterId, ResourceRequirements, CompletableFuture<Acknowledge>>
                     declareRequiredResourcesFunction) {
@@ -441,6 +471,19 @@ public class TestingResourceManagerGateway implements ResourceManagerGateway {
         }
     }
 
+    @Override
+    public CompletableFuture<TransientBlobKey> requestTaskManagerFileUploadByNameAndType(
+            ResourceID taskManagerId, String fileName, FileType fileType, Duration timeout) {
+        final Function<Tuple3<ResourceID, String, FileType>, CompletableFuture<TransientBlobKey>>
+                function = requestTaskManagerFileUploadByNameAndTypeFunction;
+
+        if (function != null) {
+            return function.apply(Tuple3.of(taskManagerId, fileName, fileType));
+        } else {
+            return CompletableFuture.completedFuture(new TransientBlobKey());
+        }
+    }
+
     @Override
     public CompletableFuture<Collection<LogInfo>> requestTaskManagerLogList(
             ResourceID taskManagerId, Time timeout) {
@@ -482,6 +525,37 @@ public class TestingResourceManagerGateway implements ResourceManagerGateway {
         }
     }
 
+    @Override
+    public CompletableFuture<Collection<ProfilingInfo>> requestTaskManagerProfilingList(
+            ResourceID taskManagerId, Duration timeout) {
+        final Function<ResourceID, CompletableFuture<Collection<ProfilingInfo>>> function =
+                this.requestProfilingListFunction;
+
+        if (function != null) {
+            return function.apply(taskManagerId);
+        } else {
+            return FutureUtils.completedExceptionally(
+                    new UnknownTaskExecutorException(taskManagerId));
+        }
+    }
+
+    @Override
+    public CompletableFuture<ProfilingInfo> requestProfiling(
+            ResourceID taskManagerId,
+            int duration,
+            ProfilingInfo.ProfilingMode mode,
+            Duration timeout) {
+        final Function<ResourceID, CompletableFuture<ProfilingInfo>> function =
+                this.requestProfilingFunction;
+
+        if (function != null) {
+            return function.apply(taskManagerId);
+        } else {
+            return FutureUtils.completedExceptionally(
+                    new UnknownTaskExecutorException(taskManagerId));
+        }
+    }
+
     @Override
     public ResourceManagerId getFencingToken() {
         return resourceManagerId;
