@@ -21,6 +21,9 @@ package org.apache.flink.runtime.rest.messages;
 import org.apache.flink.runtime.execution.ExecutionState;
 import org.apache.flink.runtime.jobgraph.JobVertexID;
 import org.apache.flink.runtime.rest.messages.job.metrics.IOMetricsInfo;
+import org.apache.flink.testutils.junit.extensions.parameterized.NoOpTestExtension;
+
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -32,7 +35,8 @@ import java.util.Random;
 import static org.apache.flink.runtime.rest.messages.JobVertexTaskManagersInfo.TaskManagersInfo;
 
 /** Tests that the {@link JobVertexTaskManagersInfo} can be marshalled and unmarshalled. */
-public class JobVertexTaskManagersInfoTest
+@ExtendWith(NoOpTestExtension.class)
+class JobVertexTaskManagersInfoTest
         extends RestResponseMarshallingTestBase<JobVertexTaskManagersInfo> {
     @Override
     protected Class<JobVertexTaskManagersInfo> getTestResponseClass() {
@@ -66,6 +70,7 @@ public class JobVertexTaskManagersInfoTest
         taskManagersInfoList.add(
                 new TaskManagersInfo(
                         "host1",
+                        "host1:123",
                         ExecutionState.CANCELING,
                         1L,
                         2L,
