@@ -25,6 +25,9 @@ import org.apache.flink.runtime.jobgraph.JobVertexID;
 import org.apache.flink.runtime.rest.messages.JobPlanInfo;
 import org.apache.flink.runtime.rest.messages.RestResponseMarshallingTestBase;
 import org.apache.flink.runtime.rest.messages.job.metrics.IOMetricsInfo;
+import org.apache.flink.testutils.junit.extensions.parameterized.NoOpTestExtension;
+
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -33,7 +36,8 @@ import java.util.Map;
 import java.util.Random;
 
 /** Tests (un)marshalling of the {@link JobDetailsInfo}. */
-public class JobDetailsInfoTest extends RestResponseMarshallingTestBase<JobDetailsInfo> {
+@ExtendWith(NoOpTestExtension.class)
+class JobDetailsInfoTest extends RestResponseMarshallingTestBase<JobDetailsInfo> {
 
     @Override
     protected Class<JobDetailsInfo> getTestResponseClass() {
