@@ -20,14 +20,19 @@ package org.apache.flink.runtime.scheduler;
 
 import org.apache.flink.api.common.time.Time;
 import org.apache.flink.configuration.Configuration;
+import org.apache.flink.core.execution.SavepointFormatType;
 import org.apache.flink.core.testutils.FlinkMatchers;
 import org.apache.flink.runtime.blob.VoidBlobWriter;
+import org.apache.flink.runtime.checkpoint.CheckpointProperties;
+import org.apache.flink.runtime.checkpoint.CheckpointStatsTracker;
 import org.apache.flink.runtime.checkpoint.CheckpointsCleaner;
 import org.apache.flink.runtime.checkpoint.CompletedCheckpoint;
 import org.apache.flink.runtime.checkpoint.StandaloneCheckpointIDCounter;
 import org.apache.flink.runtime.checkpoint.StandaloneCompletedCheckpointStore;
+import org.apache.flink.runtime.checkpoint.SubTaskInitializationMetricsBuilder;
 import org.apache.flink.runtime.deployment.TaskDeploymentDescriptorFactory;
 import org.apache.flink.runtime.executiongraph.DefaultVertexAttemptNumberStore;
+import org.apache.flink.runtime.executiongraph.ExecutionGraph;
 import org.apache.flink.runtime.io.network.partition.NoOpJobMasterPartitionTracker;
 import org.apache.flink.runtime.jobgraph.JobGraph;
 import org.apache.flink.runtime.jobgraph.JobVertex;
@@ -35,12 +40,16 @@ import org.apache.flink.runtime.jobgraph.OperatorID;
 import org.apache.flink.runtime.jobgraph.SavepointRestoreSettings;
 import org.apache.flink.runtime.jobmaster.DefaultExecutionDeploymentTracker;
 import org.apache.flink.runtime.jobmaster.TestUtils;
+import org.apache.flink.runtime.metrics.groups.JobManagerJobMetricGroup;
 import org.apache.flink.runtime.metrics.groups.UnregisteredMetricGroups;
 import org.apache.flink.runtime.shuffle.ShuffleTestUtils;
 import org.apache.flink.runtime.testtasks.NoOpInvokable;
 import org.apache.flink.testutils.TestingUtils;
 import org.apache.flink.testutils.executor.TestExecutorResource;
+import org.apache.flink.traces.Span;
+import org.apache.flink.traces.SpanBuilder;
 import org.apache.flink.util.TestLogger;
+import org.apache.flink.util.clock.SystemClock;
 
 import org.hamcrest.MatcherAssert;
 import org.hamcrest.Matchers;
@@ -52,8 +61,12 @@ import javax.annotation.Nonnull;
 
 import java.io.File;
 import java.io.IOException;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Optional;
 import java.util.concurrent.ScheduledExecutorService;
 
+import static org.hamcrest.Matchers.hasSize;
 import static org.hamcrest.Matchers.notNullValue;
 import static org.junit.Assert.assertThat;
 import static org.junit.Assert.fail;
@@ -69,7 +82,7 @@ public class DefaultExecutionGraphFactoryTest extends TestLogger {
 
     @Test
     public void testRestoringModifiedJobFromSavepointFails() throws Exception {
-        final JobGraph jobGraphWithNewOperator = createJobGraphWithSavepoint(false, 42L);
+        final JobGraph jobGraphWithNewOperator = createJobGraphWithSavepoint(false, 42L, 1);
 
         final ExecutionGraphFactory executionGraphFactory = createExecutionGraphFactory();
 
@@ -98,7 +111,7 @@ public class DefaultExecutionGraphFactoryTest extends TestLogger {
             throws Exception {
         // create savepoint data
         final long savepointId = 42L;
-        final JobGraph jobGraphWithNewOperator = createJobGraphWithSavepoint(true, savepointId);
+        final JobGraph jobGraphWithNewOperator = createJobGraphWithSavepoint(true, savepointId, 1);
 
         final ExecutionGraphFactory executionGraphFactory = createExecutionGraphFactory();
 
@@ -124,8 +137,65 @@ public class DefaultExecutionGraphFactoryTest extends TestLogger {
         MatcherAssert.assertThat(savepoint.getCheckpointID(), Matchers.is(savepointId));
     }
 
+    @Test
+    public void testCheckpointStatsTrackerUpdatedWithNewParallelism() throws Exception {
+        final long savepointId = 42L;
+        final JobGraph jobGraphWithParallelism2 = createJobGraphWithSavepoint(true, savepointId, 2);
+
+        List<Span> spans = new ArrayList<>();
+        final ExecutionGraphFactory executionGraphFactory =
+                createExecutionGraphFactory(
+                        new UnregisteredMetricGroups.UnregisteredJobManagerJobMetricGroup() {
+                            @Override
+                            public void addSpan(SpanBuilder spanBuilder) {
+                                spans.add(spanBuilder.build());
+                            }
+                        });
+
+        final StandaloneCompletedCheckpointStore completedCheckpointStore =
+                new StandaloneCompletedCheckpointStore(1);
+        ExecutionGraph executionGraph =
+                executionGraphFactory.createAndRestoreExecutionGraph(
+                        jobGraphWithParallelism2,
+                        completedCheckpointStore,
+                        new CheckpointsCleaner(),
+                        new StandaloneCheckpointIDCounter(),
+                        TaskDeploymentDescriptorFactory.PartitionLocationConstraint.CAN_BE_UNKNOWN,
+                        0L,
+                        new DefaultVertexAttemptNumberStore(),
+                        vertexId ->
+                                new DefaultVertexParallelismInfo(
+                                        1, 1337, integer -> Optional.empty()),
+                        (execution, previousState, newState) -> {},
+                        rp -> false,
+                        log);
+
+        CheckpointStatsTracker checkpointStatsTracker = executionGraph.getCheckpointStatsTracker();
+        checkpointStatsTracker.reportInitializationStartTs(
+                SystemClock.getInstance().absoluteTimeMillis());
+
+        checkpointStatsTracker.reportRestoredCheckpoint(
+                savepointId,
+                CheckpointProperties.forSavepoint(false, SavepointFormatType.NATIVE),
+                "foo",
+                1337);
+        checkpointStatsTracker.reportInitializationMetrics(
+                new SubTaskInitializationMetricsBuilder(
+                                SystemClock.getInstance().absoluteTimeMillis())
+                        .build());
+
+        MatcherAssert.assertThat(spans, hasSize(1));
+    }
+
     @Nonnull
     private ExecutionGraphFactory createExecutionGraphFactory() {
+        return createExecutionGraphFactory(
+                UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup());
+    }
+
+    @Nonnull
+    private ExecutionGraphFactory createExecutionGraphFactory(
+            JobManagerJobMetricGroup metricGroup) {
         final ExecutionGraphFactory executionGraphFactory =
                 new DefaultExecutionGraphFactory(
                         new Configuration(),
@@ -134,7 +204,7 @@ public class DefaultExecutionGraphFactoryTest extends TestLogger {
                         EXECUTOR_RESOURCE.getExecutor(),
                         EXECUTOR_RESOURCE.getExecutor(),
                         Time.milliseconds(0L),
-                        UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup(),
+                        metricGroup,
                         VoidBlobWriter.getInstance(),
                         ShuffleTestUtils.DEFAULT_SHUFFLE_MASTER,
                         NoOpJobMasterPartitionTracker.INSTANCE);
@@ -142,8 +212,8 @@ public class DefaultExecutionGraphFactoryTest extends TestLogger {
     }
 
     @Nonnull
-    private JobGraph createJobGraphWithSavepoint(boolean allowNonRestoredState, long savepointId)
-            throws IOException {
+    private JobGraph createJobGraphWithSavepoint(
+            boolean allowNonRestoredState, long savepointId, int parallelism) throws IOException {
         // create savepoint data
         final OperatorID operatorID = new OperatorID();
         final File savepointFile =
@@ -158,7 +228,7 @@ public class DefaultExecutionGraphFactoryTest extends TestLogger {
         // create a new operator
         final JobVertex jobVertex = new JobVertex("New operator");
         jobVertex.setInvokableClass(NoOpInvokable.class);
-        jobVertex.setParallelism(1);
+        jobVertex.setParallelism(parallelism);
 
         // this test will fail in the end due to the previously created Savepoint having a state for
         // a given OperatorID that does not match any operator of the newly created JobGraph
