@@ -28,7 +28,6 @@ import org.apache.flink.runtime.io.network.partition.ResultPartitionType;
 import org.apache.flink.runtime.jobgraph.JobGraph;
 import org.apache.flink.runtime.jobgraph.JobVertex;
 import org.apache.flink.runtime.jobgraph.OperatorID;
-import org.apache.flink.runtime.metrics.groups.UnregisteredMetricGroups;
 import org.apache.flink.runtime.operators.coordination.TestingOperatorCoordinator;
 import org.apache.flink.testutils.TestingUtils;
 import org.apache.flink.testutils.executor.TestExecutorResource;
@@ -64,17 +63,17 @@ public class DefaultOperatorCoordinatorHandlerTest {
         ExecutionJobVertex ejv2 = executionGraph.getJobVertex(jobVertices[1].getID());
         executionGraph.start(ComponentMainThreadExecutorServiceAdapter.forMainThread());
 
-        executionGraph.initializeJobVertex(
-                ejv1, 0L, UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup());
+        executionGraph.initializeJobVertex(ejv1, 0L);
 
         DefaultOperatorCoordinatorHandler handler =
                 new DefaultOperatorCoordinatorHandler(executionGraph, throwable -> {});
         assertThat(handler.getCoordinatorMap().keySet(), containsInAnyOrder(operatorId1));
 
-        executionGraph.initializeJobVertex(
-                ejv2, 0L, UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup());
+        executionGraph.initializeJobVertex(ejv2, 0L);
         handler.registerAndStartNewCoordinators(
-                ejv2.getOperatorCoordinators(), executionGraph.getJobMasterMainThreadExecutor());
+                ejv2.getOperatorCoordinators(),
+                executionGraph.getJobMasterMainThreadExecutor(),
+                ejv2.getParallelism());
 
         assertThat(
                 handler.getCoordinatorMap().keySet(), containsInAnyOrder(operatorId1, operatorId2));
