@@ -22,7 +22,6 @@ import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.JobStatus;
 import org.apache.flink.api.common.time.Time;
 import org.apache.flink.core.execution.SavepointFormatType;
-import org.apache.flink.core.testutils.CompletedScheduledFuture;
 import org.apache.flink.runtime.JobException;
 import org.apache.flink.runtime.blob.BlobWriter;
 import org.apache.flink.runtime.blob.PermanentBlobKey;
@@ -51,7 +50,7 @@ import org.apache.flink.runtime.executiongraph.JobVertexInputInfo;
 import org.apache.flink.runtime.executiongraph.MarkPartitionFinishedStrategy;
 import org.apache.flink.runtime.executiongraph.TaskExecutionStateTransition;
 import org.apache.flink.runtime.executiongraph.TestingDefaultExecutionGraphBuilder;
-import org.apache.flink.runtime.executiongraph.failover.flip1.partitionrelease.PartitionGroupReleaseStrategy;
+import org.apache.flink.runtime.executiongraph.failover.partitionrelease.PartitionGroupReleaseStrategy;
 import org.apache.flink.runtime.failure.FailureEnricherUtils;
 import org.apache.flink.runtime.io.network.partition.JobMasterPartitionTracker;
 import org.apache.flink.runtime.jobgraph.IntermediateDataSetID;
@@ -72,6 +71,7 @@ import org.apache.flink.runtime.shuffle.ShuffleMaster;
 import org.apache.flink.runtime.taskmanager.TaskExecutionState;
 import org.apache.flink.testutils.TestingUtils;
 import org.apache.flink.testutils.executor.TestExecutorResource;
+import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.TestLogger;
 
 import org.junit.ClassRule;
@@ -82,6 +82,7 @@ import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 
 import java.time.Duration;
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
@@ -92,6 +93,7 @@ import java.util.concurrent.Executor;
 import java.util.concurrent.ForkJoinPool;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ScheduledFuture;
+import java.util.concurrent.TimeUnit;
 import java.util.function.Consumer;
 import java.util.function.Function;
 import java.util.function.Supplier;
@@ -136,7 +138,7 @@ public class ExecutingTest extends TestLogger {
                     new MockExecutionGraph(() -> Collections.singletonList(mockExecutionJobVertex));
             executionGraph.transitionToRunning();
             final MockExecutionVertex mockExecutionVertex =
-                    ((MockExecutionVertex) mockExecutionJobVertex.getMockExecutionVertex());
+                    (MockExecutionVertex) mockExecutionJobVertex.getMockExecutionVertex();
             mockExecutionVertex.setMockedExecutionState(ExecutionState.RUNNING);
 
             new Executing(
@@ -146,7 +148,10 @@ public class ExecutingTest extends TestLogger {
                     log,
                     ctx,
                     ClassLoader.getSystemClassLoader(),
-                    new ArrayList<>());
+                    new ArrayList<>(),
+                    Duration.ZERO,
+                    null,
+                    Instant.now());
             assertThat(mockExecutionVertex.isDeployCalled(), is(false));
         }
     }
@@ -164,7 +169,10 @@ public class ExecutingTest extends TestLogger {
                     log,
                     ctx,
                     ClassLoader.getSystemClassLoader(),
-                    new ArrayList<>());
+                    new ArrayList<>(),
+                    Duration.ZERO,
+                    null,
+                    Instant.now());
         }
     }
 
@@ -190,10 +198,10 @@ public class ExecutingTest extends TestLogger {
         try (MockExecutingContext ctx = new MockExecutingContext()) {
             Executing exec = new ExecutingStateBuilder().build(ctx);
             ctx.setExpectFailing(
-                    (failingArguments -> {
+                    failingArguments -> {
                         assertThat(failingArguments.getExecutionGraph(), notNullValue());
                         assertThat(failingArguments.getFailureCause().getMessage(), is(failureMsg));
-                    }));
+                    });
             ctx.setHowToHandleFailure(FailureResult::canNotRestart);
             exec.handleGlobalFailure(
                     new RuntimeException(failureMsg), FailureEnricherUtils.EMPTY_FAILURE_LABELS);
@@ -206,9 +214,9 @@ public class ExecutingTest extends TestLogger {
         try (MockExecutingContext ctx = new MockExecutingContext()) {
             Executing exec = new ExecutingStateBuilder().build(ctx);
             ctx.setExpectRestarting(
-                    (restartingArguments ->
-                            assertThat(restartingArguments.getBackoffTime(), is(duration))));
-            ctx.setHowToHandleFailure((f) -> FailureResult.canRestart(f, duration));
+                    restartingArguments ->
+                            assertThat(restartingArguments.getBackoffTime(), is(duration)));
+            ctx.setHowToHandleFailure(f -> FailureResult.canRestart(f, duration));
             exec.handleGlobalFailure(
                     new RuntimeException("Recoverable error"),
                     FailureEnricherUtils.EMPTY_FAILURE_LABELS);
@@ -244,39 +252,120 @@ public class ExecutingTest extends TestLogger {
         try (MockExecutingContext ctx = new MockExecutingContext()) {
             Executing exec = new ExecutingStateBuilder().build(ctx);
             ctx.setExpectFinished(
-                    archivedExecutionGraph -> {
-                        assertThat(archivedExecutionGraph.getState(), is(JobStatus.SUSPENDED));
-                    });
+                    archivedExecutionGraph ->
+                            assertThat(archivedExecutionGraph.getState(), is(JobStatus.SUSPENDED)));
             exec.suspend(new RuntimeException("suspend"));
         }
     }
 
     @Test
-    public void testNotifyNewResourcesAvailableWithCanScaleUpTransitionsToRestarting()
+    public void testNotifyNewResourcesAvailableBeforeCooldownIsOverScheduledStateChange()
             throws Exception {
         try (MockExecutingContext ctx = new MockExecutingContext()) {
-            Executing exec = new ExecutingStateBuilder().build(ctx);
-
+            // do not wait too long in the test
+            final Duration scalingIntervalMin = Duration.ofSeconds(1L);
+            final ExecutingStateBuilder executingStateBuilder =
+                    new ExecutingStateBuilder().setScalingIntervalMin(scalingIntervalMin);
+            Executing exec = executingStateBuilder.build(ctx);
+            // => rescale
+            ctx.setCanScaleUp(true);
+            // scheduled rescale should restart the job after cooldown
             ctx.setExpectRestarting(
-                    restartingArguments -> {
-                        // expect immediate restart on scale up
-                        assertThat(restartingArguments.getBackoffTime(), is(Duration.ZERO));
-                    });
-            ctx.setCanScaleUp(() -> true);
+                    restartingArguments ->
+                            assertThat(restartingArguments.getBackoffTime(), is(Duration.ZERO)));
             exec.onNewResourcesAvailable();
         }
     }
 
     @Test
-    public void testNotifyNewResourcesAvailableWithNoResourcesAndNoStateChange() throws Exception {
+    public void testNotifyNewResourcesAvailableAfterCooldownIsOverStateChange() throws Exception {
+        try (MockExecutingContext ctx = new MockExecutingContext()) {
+            final ExecutingStateBuilder executingStateBuilder =
+                    new ExecutingStateBuilder()
+                            .setScalingIntervalMin(Duration.ofSeconds(20L))
+                            .setLastRescale(Instant.now().minus(Duration.ofSeconds(30L)));
+            Executing exec = executingStateBuilder.build(ctx);
+            // => rescale
+            ctx.setCanScaleUp(true);
+            // immediate rescale
+            ctx.setExpectRestarting(
+                    restartingArguments ->
+                            assertThat(restartingArguments.getBackoffTime(), is(Duration.ZERO)));
+            exec.onNewResourcesAvailable();
+        }
+    }
+
+    @Test
+    public void testNotifyNewResourcesAvailableWithCanScaleUpWithoutForceTransitionsToRestarting()
+            throws Exception {
         try (MockExecutingContext ctx = new MockExecutingContext()) {
             Executing exec = new ExecutingStateBuilder().build(ctx);
-            ctx.setCanScaleUp(() -> false);
+
+            ctx.setExpectRestarting(
+                    restartingArguments ->
+                            // immediate rescale
+                            assertThat(restartingArguments.getBackoffTime(), is(Duration.ZERO)));
+            ctx.setCanScaleUp(true); // => rescale
+            exec.onNewResourcesAvailable();
+        }
+    }
+
+    @Test
+    public void testNotifyNewResourcesAvailableWithCantScaleUpWithoutForceAndCantScaleUpWithForce()
+            throws Exception {
+        try (MockExecutingContext ctx = new MockExecutingContext()) {
+            Executing exec =
+                    new ExecutingStateBuilder()
+                            .setScalingIntervalMax(Duration.ofSeconds(1L))
+                            .build(ctx);
+            // => schedule force rescale but resource lost on timeout => no rescale
+            ctx.setCanScaleUp(false, false);
             exec.onNewResourcesAvailable();
             ctx.assertNoStateTransition();
         }
     }
 
+    @Test
+    public void
+            testNotifyNewResourcesAvailableWithCantScaleUpWithoutForceAndCanScaleUpWithForceScheduled()
+                    throws Exception {
+        try (MockExecutingContext ctx = new MockExecutingContext()) {
+            final ExecutingStateBuilder executingStateBuilder =
+                    new ExecutingStateBuilder()
+                            .setScalingIntervalMin(Duration.ofSeconds(20L))
+                            .setScalingIntervalMax(Duration.ofSeconds(30L))
+                            .setLastRescale(Instant.now().minus(Duration.ofSeconds(25L)));
+            Executing exec = executingStateBuilder.build(ctx);
+            // => schedule force rescale and resource still there after timeout => rescale
+            ctx.setCanScaleUp(false, true);
+            // rescale after scaling-interval.max
+            ctx.setExpectRestarting(
+                    restartingArguments ->
+                            assertThat(restartingArguments.getBackoffTime(), is(Duration.ZERO)));
+            exec.onNewResourcesAvailable();
+        }
+    }
+
+    @Test
+    public void
+            testNotifyNewResourcesAvailableWithCantScaleUpWithoutForceAndCanScaleUpWithForceImmediate()
+                    throws Exception {
+        try (MockExecutingContext ctx = new MockExecutingContext()) {
+            final ExecutingStateBuilder executingStateBuilder =
+                    new ExecutingStateBuilder()
+                            .setScalingIntervalMin(Duration.ofSeconds(20L))
+                            .setScalingIntervalMax(Duration.ofSeconds(30L))
+                            .setLastRescale(Instant.now().minus(Duration.ofSeconds(70L)));
+            Executing exec = executingStateBuilder.build(ctx);
+            // => immediate force rescale and resource still there after timeout => rescale
+            ctx.setCanScaleUp(false, true);
+            ctx.setExpectRestarting(
+                    restartingArguments ->
+                            assertThat(restartingArguments.getBackoffTime(), is(Duration.ZERO)));
+            exec.onNewResourcesAvailable();
+        }
+    }
+
     @Test
     public void testFailureReportedViaUpdateTaskExecutionStateCausesFailingOnNoRestart()
             throws Exception {
@@ -314,8 +403,7 @@ public class ExecutingTest extends TestLogger {
                     new ExecutingStateBuilder()
                             .setExecutionGraph(returnsFailedStateExecutionGraph)
                             .build(ctx);
-            ctx.setHowToHandleFailure(
-                    (failure) -> FailureResult.canRestart(failure, Duration.ZERO));
+            ctx.setHowToHandleFailure(failure -> FailureResult.canRestart(failure, Duration.ZERO));
             ctx.setExpectRestarting(assertNonNull());
 
             Exception exception = new RuntimeException();
@@ -468,24 +556,17 @@ public class ExecutingTest extends TestLogger {
 
     @Test
     public void testExecutingChecksForNewResourcesWhenBeingCreated() throws Exception {
-        try (MockExecutingContext context = new MockExecutingContext()) {
-            context.setCanScaleUp(() -> true);
-            context.setExpectRestarting(
-                    restartingArguments -> {
-                        // expect immediate restart on scale up
-                        assertThat(restartingArguments.getBackoffTime(), is(Duration.ZERO));
-                    });
+        try (MockExecutingContext ctx = new MockExecutingContext()) {
+            ctx.setCanScaleUp(true);
+            ctx.setExpectRestarting(
+                    restartingArguments ->
+                            // immediate rescale
+                            assertThat(restartingArguments.getBackoffTime(), is(Duration.ZERO)));
 
-            final Executing executing = new ExecutingStateBuilder().build(context);
+            new ExecutingStateBuilder().build(ctx);
         }
     }
 
-    public static TaskExecutionStateTransition createFailingStateTransition(
-            ExecutionAttemptID attemptId) throws JobException {
-        return new TaskExecutionStateTransition(
-                new TaskExecutionState(attemptId, ExecutionState.FAILED, new RuntimeException()));
-    }
-
     public static TaskExecutionStateTransition createFailingStateTransition(
             ExecutionAttemptID attemptId, Exception exception) throws JobException {
         return new TaskExecutionStateTransition(
@@ -497,6 +578,9 @@ public class ExecutingTest extends TestLogger {
                 TestingDefaultExecutionGraphBuilder.newBuilder()
                         .build(EXECUTOR_RESOURCE.getExecutor());
         private OperatorCoordinatorHandler operatorCoordinatorHandler;
+        private Duration scalingIntervalMin = Duration.ZERO;
+        @Nullable private Duration scalingIntervalMax;
+        private Instant lastRescale = Instant.now();
 
         private ExecutingStateBuilder() throws JobException, JobExecutionException {
             operatorCoordinatorHandler = new TestingOperatorCoordinatorHandler();
@@ -513,17 +597,41 @@ public class ExecutingTest extends TestLogger {
             return this;
         }
 
+        public ExecutingStateBuilder setScalingIntervalMin(Duration scalingIntervalMin) {
+            this.scalingIntervalMin = scalingIntervalMin;
+            return this;
+        }
+
+        public ExecutingStateBuilder setScalingIntervalMax(Duration scalingIntervalMax) {
+            this.scalingIntervalMax = scalingIntervalMax;
+            return this;
+        }
+
+        public ExecutingStateBuilder setLastRescale(Instant lastRescale) {
+            this.lastRescale = lastRescale;
+            return this;
+        }
+
         private Executing build(MockExecutingContext ctx) {
             executionGraph.transitionToRunning();
 
-            return new Executing(
-                    executionGraph,
-                    getExecutionGraphHandler(executionGraph, ctx.getMainThreadExecutor()),
-                    operatorCoordinatorHandler,
-                    log,
-                    ctx,
-                    ClassLoader.getSystemClassLoader(),
-                    new ArrayList<>());
+            try {
+                return new Executing(
+                        executionGraph,
+                        getExecutionGraphHandler(executionGraph, ctx.getMainThreadExecutor()),
+                        operatorCoordinatorHandler,
+                        log,
+                        ctx,
+                        ClassLoader.getSystemClassLoader(),
+                        new ArrayList<>(),
+                        scalingIntervalMin,
+                        scalingIntervalMax,
+                        lastRescale);
+            } finally {
+                Preconditions.checkState(
+                        !ctx.hadStateTransition,
+                        "State construction is an on-going state transition, during which no further transitions are allowed.");
+            }
         }
     }
 
@@ -544,7 +652,8 @@ public class ExecutingTest extends TestLogger {
                 new StateValidator<>("cancelling");
 
         private Function<Throwable, FailureResult> howToHandleFailure;
-        private Supplier<Boolean> canScaleUp = () -> false;
+        private boolean canScaleUpWithoutForce = false;
+        private boolean canScaleUpWithForce = false;
         private StateValidator<StopWithSavepointArguments> stopWithSavepointValidator =
                 new StateValidator<>("stopWithSavepoint");
         private CompletableFuture<String> mockedStopWithSavepointOperationFuture =
@@ -570,8 +679,13 @@ public class ExecutingTest extends TestLogger {
             this.howToHandleFailure = function;
         }
 
-        public void setCanScaleUp(Supplier<Boolean> supplier) {
-            this.canScaleUp = supplier;
+        public void setCanScaleUp(boolean canScaleUpWithoutForce, boolean canScaleUpWithForce) {
+            this.canScaleUpWithoutForce = canScaleUpWithoutForce;
+            this.canScaleUpWithForce = canScaleUpWithForce;
+        }
+
+        public void setCanScaleUp(boolean canScaleUpWithoutForce) {
+            this.canScaleUpWithoutForce = canScaleUpWithoutForce;
         }
 
         // --------- Interface Implementations ------- //
@@ -594,8 +708,12 @@ public class ExecutingTest extends TestLogger {
         }
 
         @Override
-        public boolean shouldRescale(ExecutionGraph executionGraph) {
-            return canScaleUp.get();
+        public boolean shouldRescale(ExecutionGraph executionGraph, boolean forceRescale) {
+            if (forceRescale) {
+                return canScaleUpWithForce;
+            } else {
+                return canScaleUpWithoutForce;
+            }
         }
 
         @Override
@@ -651,11 +769,11 @@ public class ExecutingTest extends TestLogger {
 
         @Override
         public ScheduledFuture<?> runIfState(State expectedState, Runnable action, Duration delay) {
-            if (!hadStateTransition) {
-                action.run();
-            }
-
-            return CompletedScheduledFuture.create(null);
+            return getMainThreadExecutor()
+                    .schedule(
+                            () -> runIfState(expectedState, action),
+                            delay.toMillis(),
+                            TimeUnit.MILLISECONDS);
         }
 
         @Override
@@ -828,15 +946,15 @@ public class ExecutingTest extends TestLogger {
             super(
                     new MockInternalExecutionGraphAccessor(),
                     new JobVertex("test"),
-                    new DefaultVertexParallelismInfo(1, 1, max -> Optional.empty()));
+                    new DefaultVertexParallelismInfo(1, 1, max -> Optional.empty()),
+                    new CoordinatorStoreImpl(),
+                    UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup());
 
             initialize(
                     1,
                     Time.milliseconds(1L),
                     1L,
-                    new DefaultSubtaskAttemptNumberStore(Collections.emptyList()),
-                    new CoordinatorStoreImpl(),
-                    UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup());
+                    new DefaultSubtaskAttemptNumberStore(Collections.emptyList()));
             mockExecutionVertex = executionVertexSupplier.apply(this);
         }
 
