@@ -22,8 +22,8 @@ import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutor;
 import org.apache.flink.runtime.concurrent.ManuallyTriggeredComponentMainThreadExecutor;
 import org.apache.flink.runtime.executiongraph.ArchivedExecutionGraph;
 import org.apache.flink.runtime.scheduler.exceptionhistory.RootExceptionHistoryEntry;
+import org.apache.flink.util.Preconditions;
 
-import java.util.concurrent.TimeUnit;
 import java.util.function.Consumer;
 
 import static org.hamcrest.CoreMatchers.is;
@@ -73,8 +73,7 @@ class MockStateWithExecutionGraphContext implements StateWithExecutionGraph.Cont
     public void close() throws Exception {
         // trigger executor to make sure there are no outstanding state transitions
         triggerExecutors();
-        executor.shutdown();
-        executor.awaitTermination(10, TimeUnit.MINUTES);
+        Preconditions.checkState(executor.shutdownNow().isEmpty());
         finishedStateValidator.close();
     }
 
