@@ -54,6 +54,7 @@ class DefaultVertexParallelismAndInputInfosDeciderTest {
 
     private static final int MAX_PARALLELISM = 100;
     private static final int MIN_PARALLELISM = 3;
+    private static final int VERTEX_MAX_PARALLELISM = 256;
     private static final int DEFAULT_SOURCE_PARALLELISM = 10;
     private static final long DATA_VOLUME_PER_TASK = 1024 * 1024 * 1024L;
 
@@ -298,6 +299,7 @@ class DefaultVertexParallelismAndInputInfosDeciderTest {
                         new JobVertexID(),
                         Collections.singletonList(allToAllBlockingResultInfo),
                         3,
+                        MIN_PARALLELISM,
                         MAX_PARALLELISM);
 
         assertThat(parallelismAndInputInfos.getParallelism()).isEqualTo(3);
@@ -322,6 +324,36 @@ class DefaultVertexParallelismAndInputInfosDeciderTest {
         assertThat(parallelismAndInputInfos.getJobVertexInputInfos()).isEmpty();
     }
 
+    @Test
+    void testDynamicSourceParallelismWithUpstreamInputs() {
+        final DefaultVertexParallelismAndInputInfosDecider decider =
+                createDecider(MIN_PARALLELISM, MAX_PARALLELISM, DATA_VOLUME_PER_TASK);
+
+        AllToAllBlockingResultInfo allToAllBlockingResultInfo =
+                createAllToAllBlockingResultInfo(
+                        new long[] {10L, 15L, 13L, 12L, 1L, 10L, 8L, 20L, 12L, 17L});
+        int dynamicSourceParallelism = 4;
+        ParallelismAndInputInfos parallelismAndInputInfos =
+                decider.decideParallelismAndInputInfosForVertex(
+                        new JobVertexID(),
+                        Collections.singletonList(allToAllBlockingResultInfo),
+                        -1,
+                        dynamicSourceParallelism,
+                        MAX_PARALLELISM);
+
+        assertThat(parallelismAndInputInfos.getParallelism()).isEqualTo(4);
+        assertThat(parallelismAndInputInfos.getJobVertexInputInfos()).hasSize(1);
+
+        checkAllToAllJobVertexInputInfo(
+                Iterables.getOnlyElement(
+                        parallelismAndInputInfos.getJobVertexInputInfos().values()),
+                Arrays.asList(
+                        new IndexRange(0, 1),
+                        new IndexRange(2, 5),
+                        new IndexRange(6, 7),
+                        new IndexRange(8, 9)));
+    }
+
     @Test
     void testEvenlyDistributeDataWithMaxSubpartitionLimitation() {
         long[] subpartitionBytes = new long[1024];
@@ -348,6 +380,45 @@ class DefaultVertexParallelismAndInputInfosDeciderTest {
                 subpartitionRanges);
     }
 
+    @Test
+    void testComputeSourceParallelismUpperBound() {
+        Configuration configuration = new Configuration();
+        configuration.setInteger(
+                BatchExecutionOptions.ADAPTIVE_AUTO_PARALLELISM_DEFAULT_SOURCE_PARALLELISM,
+                DEFAULT_SOURCE_PARALLELISM);
+        VertexParallelismAndInputInfosDecider vertexParallelismAndInputInfosDecider =
+                DefaultVertexParallelismAndInputInfosDecider.from(MAX_PARALLELISM, configuration);
+        assertThat(
+                        vertexParallelismAndInputInfosDecider.computeSourceParallelismUpperBound(
+                                new JobVertexID(), VERTEX_MAX_PARALLELISM))
+                .isEqualTo(DEFAULT_SOURCE_PARALLELISM);
+    }
+
+    @Test
+    void testComputeSourceParallelismUpperBoundFallback() {
+        Configuration configuration = new Configuration();
+        VertexParallelismAndInputInfosDecider vertexParallelismAndInputInfosDecider =
+                DefaultVertexParallelismAndInputInfosDecider.from(MAX_PARALLELISM, configuration);
+        assertThat(
+                        vertexParallelismAndInputInfosDecider.computeSourceParallelismUpperBound(
+                                new JobVertexID(), VERTEX_MAX_PARALLELISM))
+                .isEqualTo(MAX_PARALLELISM);
+    }
+
+    @Test
+    void testComputeSourceParallelismUpperBoundNotExceedMaxParallelism() {
+        Configuration configuration = new Configuration();
+        configuration.setInteger(
+                BatchExecutionOptions.ADAPTIVE_AUTO_PARALLELISM_DEFAULT_SOURCE_PARALLELISM,
+                VERTEX_MAX_PARALLELISM * 2);
+        VertexParallelismAndInputInfosDecider vertexParallelismAndInputInfosDecider =
+                DefaultVertexParallelismAndInputInfosDecider.from(MAX_PARALLELISM, configuration);
+        assertThat(
+                        vertexParallelismAndInputInfosDecider.computeSourceParallelismUpperBound(
+                                new JobVertexID(), VERTEX_MAX_PARALLELISM))
+                .isEqualTo(VERTEX_MAX_PARALLELISM);
+    }
+
     private static void checkAllToAllJobVertexInputInfo(
             JobVertexInputInfo jobVertexInputInfo, List<IndexRange> subpartitionRanges) {
         checkAllToAllJobVertexInputInfo(
@@ -395,12 +466,12 @@ class DefaultVertexParallelismAndInputInfosDeciderTest {
             int defaultSourceParallelism) {
         Configuration configuration = new Configuration();
 
-        configuration.setInteger(
+        configuration.set(
                 BatchExecutionOptions.ADAPTIVE_AUTO_PARALLELISM_MIN_PARALLELISM, minParallelism);
         configuration.set(
                 BatchExecutionOptions.ADAPTIVE_AUTO_PARALLELISM_AVG_DATA_VOLUME_PER_TASK,
                 new MemorySize(dataVolumePerTask));
-        configuration.setInteger(
+        configuration.set(
                 BatchExecutionOptions.ADAPTIVE_AUTO_PARALLELISM_DEFAULT_SOURCE_PARALLELISM,
                 defaultSourceParallelism);
 
@@ -431,7 +502,7 @@ class DefaultVertexParallelismAndInputInfosDeciderTest {
         final DefaultVertexParallelismAndInputInfosDecider decider =
                 createDecider(minParallelism, maxParallelism, dataVolumePerTask);
         return decider.decideParallelismAndInputInfosForVertex(
-                new JobVertexID(), consumedResults, -1, maxParallelism);
+                new JobVertexID(), consumedResults, -1, minParallelism, maxParallelism);
     }
 
     private AllToAllBlockingResultInfo createAllToAllBlockingResultInfo(
