@@ -21,12 +21,14 @@ package org.apache.flink.runtime.scheduler.benchmark.e2e;
 import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutor;
 import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutorServiceAdapter;
 import org.apache.flink.runtime.jobgraph.JobGraph;
+import org.apache.flink.runtime.jobgraph.JobType;
 import org.apache.flink.runtime.jobgraph.JobVertex;
 import org.apache.flink.runtime.jobmaster.slotpool.DeclarativeSlotPoolBridgeBuilder;
 import org.apache.flink.runtime.jobmaster.slotpool.LocationPreferenceSlotSelectionStrategy;
 import org.apache.flink.runtime.jobmaster.slotpool.PhysicalSlotProvider;
 import org.apache.flink.runtime.jobmaster.slotpool.PhysicalSlotProviderImpl;
 import org.apache.flink.runtime.jobmaster.slotpool.SlotPool;
+import org.apache.flink.runtime.jobmaster.slotpool.SlotSelectionStrategy;
 import org.apache.flink.runtime.scheduler.DefaultScheduler;
 import org.apache.flink.runtime.scheduler.DefaultSchedulerBuilder;
 import org.apache.flink.runtime.scheduler.SchedulerTestingUtils;
@@ -36,6 +38,7 @@ import org.apache.flink.runtime.scheduler.benchmark.SchedulerBenchmarkBase;
 import java.util.List;
 import java.util.concurrent.ScheduledExecutorService;
 
+import static org.apache.flink.runtime.scheduler.benchmark.SchedulerBenchmarkUtils.createAdaptiveBatchScheduler;
 import static org.apache.flink.runtime.scheduler.benchmark.SchedulerBenchmarkUtils.createDefaultJobVertices;
 import static org.apache.flink.runtime.scheduler.benchmark.SchedulerBenchmarkUtils.createJobGraph;
 
@@ -47,12 +50,14 @@ public class SchedulerEndToEndBenchmarkBase extends SchedulerBenchmarkBase {
 
     ComponentMainThreadExecutor mainThreadExecutor;
 
+    JobConfiguration jobConfiguration;
     JobGraph jobGraph;
     PhysicalSlotProvider physicalSlotProvider;
     SlotPool slotPool;
 
     public void setup(JobConfiguration jobConfiguration) throws Exception {
         super.setup();
+        this.jobConfiguration = jobConfiguration;
 
         mainThreadExecutor =
                 ComponentMainThreadExecutorServiceAdapter.forSingleThreadExecutor(
@@ -62,25 +67,34 @@ public class SchedulerEndToEndBenchmarkBase extends SchedulerBenchmarkBase {
         jobGraph = createJobGraph(jobVertices, jobConfiguration);
 
         slotPool = new DeclarativeSlotPoolBridgeBuilder().buildAndStart(mainThreadExecutor);
-        physicalSlotProvider = createPhysicalSlotProvider(slotPool);
+        SlotSelectionStrategy slotSelectionStrategy =
+                jobConfiguration.isEvenlySpreadOutSlots()
+                        ? LocationPreferenceSlotSelectionStrategy.createEvenlySpreadOut()
+                        : LocationPreferenceSlotSelectionStrategy.createDefault();
+        physicalSlotProvider = createPhysicalSlotProvider(slotSelectionStrategy, slotPool);
     }
 
-    private static PhysicalSlotProvider createPhysicalSlotProvider(SlotPool slotPool) {
+    private static PhysicalSlotProvider createPhysicalSlotProvider(
+            SlotSelectionStrategy slotSelectionStrategy, SlotPool slotPool) {
 
-        return new PhysicalSlotProviderImpl(
-                LocationPreferenceSlotSelectionStrategy.createDefault(), slotPool);
+        return new PhysicalSlotProviderImpl(slotSelectionStrategy, slotPool);
     }
 
-    static DefaultScheduler createScheduler(
+    DefaultScheduler createScheduler(
             JobGraph jobGraph,
             PhysicalSlotProvider physicalSlotProvider,
             ComponentMainThreadExecutor mainThreadExecutor,
             ScheduledExecutorService executorService)
             throws Exception {
-        return new DefaultSchedulerBuilder(jobGraph, mainThreadExecutor, executorService)
-                .setExecutionSlotAllocatorFactory(
-                        SchedulerTestingUtils.newSlotSharingExecutionSlotAllocatorFactory(
-                                physicalSlotProvider))
-                .build();
+        DefaultSchedulerBuilder schedulerBuilder =
+                new DefaultSchedulerBuilder(jobGraph, mainThreadExecutor, executorService)
+                        .setExecutionSlotAllocatorFactory(
+                                SchedulerTestingUtils.newSlotSharingExecutionSlotAllocatorFactory(
+                                        physicalSlotProvider));
+        if (jobGraph.getJobType() == JobType.BATCH) {
+            return createAdaptiveBatchScheduler(schedulerBuilder, jobConfiguration);
+        } else {
+            return schedulerBuilder.build();
+        }
     }
 }
