@@ -198,8 +198,7 @@ public class MiniClusterResource extends ExternalResource {
     private void startMiniCluster() throws Exception {
         final Configuration configuration =
                 new Configuration(miniClusterResourceConfiguration.getConfiguration());
-        configuration.setString(
-                CoreOptions.TMP_DIRS, temporaryFolder.newFolder().getAbsolutePath());
+        configuration.set(CoreOptions.TMP_DIRS, temporaryFolder.newFolder().getAbsolutePath());
         if (!configuration.contains(CheckpointingOptions.CHECKPOINTS_DIRECTORY)) {
             // The channel state or checkpoint file may exceed the upper limit of
             // JobManagerCheckpointStorage, so use FileSystemCheckpointStorage as
@@ -212,7 +211,7 @@ public class MiniClusterResource extends ExternalResource {
         // we need to set this since a lot of test expect this because TestBaseUtils.startCluster()
         // enabled this by default
         if (!configuration.contains(CoreOptions.FILESYTEM_DEFAULT_OVERRIDE)) {
-            configuration.setBoolean(CoreOptions.FILESYTEM_DEFAULT_OVERRIDE, true);
+            configuration.set(CoreOptions.FILESYTEM_DEFAULT_OVERRIDE, true);
         }
 
         if (!configuration.contains(TaskManagerOptions.MANAGED_MEMORY_SIZE)) {
@@ -220,10 +219,10 @@ public class MiniClusterResource extends ExternalResource {
         }
 
         // set rest and rpc port to 0 to avoid clashes with concurrent MiniClusters
-        configuration.setInteger(JobManagerOptions.PORT, 0);
+        configuration.set(JobManagerOptions.PORT, 0);
         if (!(configuration.contains(RestOptions.BIND_PORT)
                 || configuration.contains(RestOptions.PORT))) {
-            configuration.setString(RestOptions.BIND_PORT, "0");
+            configuration.set(RestOptions.BIND_PORT, "0");
         }
 
         randomizeConfiguration(configuration);
@@ -264,8 +263,8 @@ public class MiniClusterResource extends ExternalResource {
 
     private void createClientConfiguration(URI restAddress) {
         Configuration restClientConfig = new Configuration();
-        restClientConfig.setString(JobManagerOptions.ADDRESS, restAddress.getHost());
-        restClientConfig.setInteger(RestOptions.PORT, restAddress.getPort());
+        restClientConfig.set(JobManagerOptions.ADDRESS, restAddress.getHost());
+        restClientConfig.set(RestOptions.PORT, restAddress.getPort());
         this.restClusterClientConfig = new UnmodifiableConfiguration(restClientConfig);
     }
 }
