@@ -18,24 +18,18 @@
 
 package org.apache.flink.runtime.throughput;
 
-import org.apache.flink.util.TestLogger;
-
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.util.OptionalInt;
 
 import static org.apache.flink.configuration.TaskManagerOptions.BUFFER_DEBLOAT_THRESHOLD_PERCENTAGES;
-import static org.hamcrest.CoreMatchers.is;
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /** Test for {@link BufferDebloater}. */
-public class BufferDebloaterTest extends TestLogger {
+class BufferDebloaterTest {
 
     @Test
-    public void testZeroBuffersInUse() {
+    void testZeroBuffersInUse() {
         // if the gate returns the zero buffers in use it should be transformed to 1.
         testBufferDebloater()
                 .withDebloatTarget(1000)
@@ -46,7 +40,7 @@ public class BufferDebloaterTest extends TestLogger {
     }
 
     @Test
-    public void testCorrectBufferSizeCalculation() {
+    void testCorrectBufferSizeCalculation() {
         testBufferDebloater()
                 .withDebloatTarget(1200)
                 .withBufferSize(50, 1100)
@@ -56,7 +50,7 @@ public class BufferDebloaterTest extends TestLogger {
     }
 
     @Test
-    public void testCalculatedBufferSizeLessThanMin() {
+    void testCalculatedBufferSizeLessThanMin() {
         testBufferDebloater()
                 .withDebloatTarget(1200)
                 .withBufferSize(250, 1100)
@@ -66,7 +60,7 @@ public class BufferDebloaterTest extends TestLogger {
     }
 
     @Test
-    public void testCalculatedBufferSizeForThroughputZero() {
+    void testCalculatedBufferSizeForThroughputZero() {
         // When the throughput is zero then min buffer size will be taken.
         testBufferDebloater()
                 .withDebloatTarget(1200)
@@ -77,7 +71,7 @@ public class BufferDebloaterTest extends TestLogger {
     }
 
     @Test
-    public void testConfiguredConsumptionTimeIsTooLow() {
+    void testConfiguredConsumptionTimeIsTooLow() {
         // When the consumption time is low then min buffer size will be taken.
         testBufferDebloater()
                 .withDebloatTarget(7)
@@ -88,7 +82,7 @@ public class BufferDebloaterTest extends TestLogger {
     }
 
     @Test
-    public void testCalculatedBufferSizeGreaterThanMax() {
+    void testCalculatedBufferSizeGreaterThanMax() {
         // New calculated buffer size should be more than max value it means that we should take max
         // value which means that no updates should happen because the old value equal to new value.
         testBufferDebloater()
@@ -100,7 +94,7 @@ public class BufferDebloaterTest extends TestLogger {
     }
 
     @Test
-    public void testCalculatedBufferSlightlyDifferentFromCurrentOne() {
+    void testCalculatedBufferSlightlyDifferentFromCurrentOne() {
         // New calculated buffer size should be a little less than current value(or max value which
         // is the same) it means that no updates should happen because the new value is not so
         // different from the old one.
@@ -113,7 +107,7 @@ public class BufferDebloaterTest extends TestLogger {
     }
 
     @Test
-    public void testAnnouncedMaxBufferSizeDespiteLastDiffLessThanThreshold() {
+    void testAnnouncedMaxBufferSizeDespiteLastDiffLessThanThreshold() {
         final int numberOfBuffersInUse = 1;
         BufferDebloater bufferDebloater =
                 testBufferDebloater()
@@ -125,21 +119,21 @@ public class BufferDebloaterTest extends TestLogger {
 
         // Calculate the buffer size a little lower than the max buffer size.
         bufferDebloater.recalculateBufferSize(1000, numberOfBuffersInUse);
-        assertThat(bufferDebloater.getLastBufferSize(), is(1000));
+        assertThat(bufferDebloater.getLastBufferSize()).isEqualTo(1000);
 
         // Recalculate the buffer size to max value.
         bufferDebloater.recalculateBufferSize(2000, numberOfBuffersInUse);
 
         // The max value should be announced despite it differ from the previous one by less than
         // threshold value.
-        assertThat(bufferDebloater.getLastBufferSize(), is(1100));
+        assertThat(bufferDebloater.getLastBufferSize()).isEqualTo(1100);
 
         // Make sure that there is no repeated announcement of max buffer size.
         bufferDebloater.recalculateBufferSize(2000, numberOfBuffersInUse);
     }
 
     @Test
-    public void testAnnouncedMinBufferSizeEvenDespiteLastDiffLessThanThreshold() {
+    void testAnnouncedMinBufferSizeEvenDespiteLastDiffLessThanThreshold() {
         final int numberOfBuffersInUse = 1;
         BufferDebloater bufferDebloater =
                 testBufferDebloater()
@@ -151,21 +145,21 @@ public class BufferDebloaterTest extends TestLogger {
 
         // Calculate the buffer size a little greater than the min buffer size.
         bufferDebloater.recalculateBufferSize(60, numberOfBuffersInUse);
-        assertThat(bufferDebloater.getLastBufferSize(), is(60));
+        assertThat(bufferDebloater.getLastBufferSize()).isEqualTo(60);
 
         // Recalculate the buffer size to min value.
         bufferDebloater.recalculateBufferSize(40, numberOfBuffersInUse);
 
         // The min value should be announced despite it differ from the previous one by less than
         // threshold value.
-        assertThat(bufferDebloater.getLastBufferSize(), is(50));
+        assertThat(bufferDebloater.getLastBufferSize()).isEqualTo(50);
 
         // Make sure that there is no repeated announcement of min buffer size.
         bufferDebloater.recalculateBufferSize(40, numberOfBuffersInUse);
     }
 
     @Test
-    public void testSkipUpdate() {
+    void testSkipUpdate() {
         int maxBufferSize = 32768;
         int minBufferSize = 256;
         double threshold = 0.3;
@@ -180,36 +174,39 @@ public class BufferDebloaterTest extends TestLogger {
         int currentBufferSize = maxBufferSize / 2;
 
         OptionalInt optionalInt = bufferDebloater.recalculateBufferSize(currentBufferSize, 1);
-        assertTrue(optionalInt.isPresent());
-        assertEquals(currentBufferSize, optionalInt.getAsInt());
+        assertThat(optionalInt).isPresent().hasValue(currentBufferSize);
 
         // It is true because less than threshold.
-        assertTrue(bufferDebloater.skipUpdate(currentBufferSize));
-        assertTrue(bufferDebloater.skipUpdate(currentBufferSize - 1));
-        assertTrue(bufferDebloater.skipUpdate(currentBufferSize + 1));
+        assertThat(bufferDebloater.skipUpdate(currentBufferSize)).isTrue();
+        assertThat(bufferDebloater.skipUpdate(currentBufferSize - 1)).isTrue();
+        assertThat(bufferDebloater.skipUpdate(currentBufferSize + 1)).isTrue();
 
-        assertTrue(
-                bufferDebloater.skipUpdate(
-                        currentBufferSize - (int) (currentBufferSize * threshold) + 1));
-        assertTrue(
-                bufferDebloater.skipUpdate(
-                        currentBufferSize + (int) (currentBufferSize * threshold) - 1));
+        assertThat(
+                        bufferDebloater.skipUpdate(
+                                currentBufferSize - (int) (currentBufferSize * threshold) + 1))
+                .isTrue();
+        assertThat(
+                        bufferDebloater.skipUpdate(
+                                currentBufferSize + (int) (currentBufferSize * threshold) - 1))
+                .isTrue();
 
         // It is false because it reaches threshold.
-        assertFalse(
-                bufferDebloater.skipUpdate(
-                        currentBufferSize - (int) (currentBufferSize * threshold)));
-        assertFalse(
-                bufferDebloater.skipUpdate(
-                        currentBufferSize + (int) (currentBufferSize * threshold)));
-        assertFalse(bufferDebloater.skipUpdate(minBufferSize + 1));
-        assertFalse(bufferDebloater.skipUpdate(minBufferSize));
-        assertFalse(bufferDebloater.skipUpdate(maxBufferSize - 1));
-        assertFalse(bufferDebloater.skipUpdate(maxBufferSize));
+        assertThat(
+                        bufferDebloater.skipUpdate(
+                                currentBufferSize - (int) (currentBufferSize * threshold)))
+                .isFalse();
+        assertThat(
+                        bufferDebloater.skipUpdate(
+                                currentBufferSize + (int) (currentBufferSize * threshold)))
+                .isFalse();
+        assertThat(bufferDebloater.skipUpdate(minBufferSize + 1)).isFalse();
+        assertThat(bufferDebloater.skipUpdate(minBufferSize)).isFalse();
+        assertThat(bufferDebloater.skipUpdate(maxBufferSize - 1)).isFalse();
+        assertThat(bufferDebloater.skipUpdate(maxBufferSize)).isFalse();
 
         // Beyond the min and max size is always false.
-        assertFalse(bufferDebloater.skipUpdate(maxBufferSize + 1));
-        assertFalse(bufferDebloater.skipUpdate(minBufferSize - 1));
+        assertThat(bufferDebloater.skipUpdate(maxBufferSize + 1)).isFalse();
+        assertThat(bufferDebloater.skipUpdate(minBufferSize - 1)).isFalse();
     }
 
     public static BufferDebloaterTestBuilder testBufferDebloater() {
@@ -257,7 +254,7 @@ public class BufferDebloaterTest extends TestLogger {
             final OptionalInt newBufferSize =
                     bufferDebloater.recalculateBufferSize(throughput, numberOfBuffersInUse);
 
-            assertFalse(newBufferSize.isPresent());
+            assertThat(newBufferSize).isNotPresent();
         }
 
         public BufferDebloater expectBufferSize(int expectedBufferSize) {
@@ -267,8 +264,7 @@ public class BufferDebloaterTest extends TestLogger {
             final OptionalInt newBufferSize =
                     bufferDebloater.recalculateBufferSize(throughput, numberOfBuffersInUse);
 
-            assertTrue(newBufferSize.isPresent());
-            assertThat(newBufferSize.getAsInt(), is(expectedBufferSize));
+            assertThat(newBufferSize).isPresent().hasValue(expectedBufferSize);
             return bufferDebloater;
         }
 
