@@ -45,7 +45,14 @@ import scala.reflect.ClassTag
  *   Type of the left input of the cross.
  * @tparam R
  *   Type of the right input of the cross.
+ * @deprecated
+ *   All Flink Scala APIs are deprecated and will be removed in a future Flink major version. You
+ *   can still build your application in Scala, but you should move to the Java version of either
+ *   the DataStream and/or Table API.
+ * @see
+ *   <a href="https://s.apache.org/flip-265">FLIP-265 Deprecate and remove Scala API support</a>
  */
+@deprecated(org.apache.flink.api.scala.FLIP_265_WARNING, since = "1.18.0")
 @Public
 class CrossDataSet[L, R](
     defaultCross: CrossOperator[L, R, (L, R)],
