@@ -19,8 +19,8 @@ package org.apache.flink.api.scala
 
 import org.apache.flink.api.common.InvalidProgramException
 
-import org.junit.Assert
-import org.junit.Test
+import org.assertj.core.api.Assertions.assertThatThrownBy
+import org.junit.jupiter.api.Test
 
 class MinByOperatorTest {
   private val emptyTupleData = List[(Int, Long, String, Long, Int)]()
@@ -30,125 +30,128 @@ class MinByOperatorTest {
   def testMinByKeyFieldsDataset(): Unit = {
     val env = ExecutionEnvironment.getExecutionEnvironment
     val collection = env.fromCollection(emptyTupleData)
-    try {
-      collection.minBy(4, 0, 1, 2, 3)
-    } catch {
-      case e: Exception => Assert.fail();
-    }
+    collection.minBy(4, 0, 1, 2, 3)
   }
 
   /**
    * This test validates that an index which is out of bounds throws an IndexOutOfBoundsException.
    */
-  @Test(expected = classOf[IndexOutOfBoundsException])
-  def testOutOfTupleBoundsDataset1() {
+  @Test
+  def testOutOfTupleBoundsDataset1(): Unit = {
 
     val env = ExecutionEnvironment.getExecutionEnvironment
     val collection = env.fromCollection(emptyTupleData)
 
     // should not work, key out of tuple bounds
-    collection.minBy(5)
+    assertThatThrownBy(() => collection.minBy(5))
+      .isInstanceOf(classOf[IndexOutOfBoundsException])
   }
 
   /**
    * This test validates that an index which is out of bounds throws an IndexOutOfBoundsException.
    */
-  @Test(expected = classOf[IndexOutOfBoundsException])
-  def testOutOfTupleBoundsDataset2() {
+  @Test
+  def testOutOfTupleBoundsDataset2(): Unit = {
     val env = ExecutionEnvironment.getExecutionEnvironment
     val collection = env.fromCollection(emptyTupleData)
 
     // should not work, key out of tuple bounds
-    collection.minBy(-1)
+    assertThatThrownBy(() => collection.minBy(-1))
+      .isInstanceOf(classOf[IndexOutOfBoundsException])
   }
 
   /**
    * This test validates that an index which is out of bounds throws an IndexOutOfBoundsException.
    */
-  @Test(expected = classOf[IndexOutOfBoundsException])
-  def testOutOfTupleBoundsDataset3() {
+  @Test
+  def testOutOfTupleBoundsDataset3(): Unit = {
     val env = ExecutionEnvironment.getExecutionEnvironment
     val collection = env.fromCollection(emptyTupleData)
 
     // should not work, key out of tuple bounds
-    collection.minBy(1, 2, 3, 4, -1)
+    assertThatThrownBy(() => collection.minBy(1, 2, 3, 4, -1))
+      .isInstanceOf(classOf[IndexOutOfBoundsException])
   }
 
   /**
    * This test validates that an InvalidProgramException is thrown when minBy is used on a custom
    * data type.
    */
-  @Test(expected = classOf[InvalidProgramException])
-  def testCustomKeyFieldsDataset() {
+  @Test
+  def testCustomKeyFieldsDataset(): Unit = {
 
     val env = ExecutionEnvironment.getExecutionEnvironment
 
     val customDS = env.fromCollection(customTypeData)
     // should not work: groups on custom type
-    customDS.minBy(0)
+    assertThatThrownBy(() => customDS.minBy(0))
+      .isInstanceOf(classOf[InvalidProgramException])
   }
 
   /** This test validates that no exceptions is thrown when an empty grouping calls minBy(). */
   @Test
-  def testMinByKeyFieldsGrouping() {
+  def testMinByKeyFieldsGrouping(): Unit = {
 
     val env = ExecutionEnvironment.getExecutionEnvironment
     val groupDs = env.fromCollection(emptyTupleData).groupBy(0)
     // should work
-    try {
-      groupDs.minBy(4, 0, 1, 2, 3)
-    } catch {
-      case e: Exception => Assert.fail()
-    }
+    groupDs.minBy(4, 0, 1, 2, 3)
   }
 
   /**
    * This test validates that an InvalidProgramException is thrown when minBy is used on a custom
    * data type.
    */
-  @Test(expected = classOf[InvalidProgramException])
-  def testCustomKeyFieldsGrouping() {
+  @Test
+  def testCustomKeyFieldsGrouping(): Unit = {
 
     val env = ExecutionEnvironment.getExecutionEnvironment
-    val groupDs: GroupedDataSet[CustomType] = env.fromCollection(customTypeData).groupBy(0)
+    assertThatThrownBy(
+      () => {
+        val groupDs: GroupedDataSet[CustomType] = env.fromCollection(customTypeData).groupBy(0)
 
-    groupDs.minBy(0)
+        groupDs.minBy(0)
+      })
+      .isInstanceOf(classOf[InvalidProgramException])
   }
 
   /**
    * This test validates that an index which is out of bounds throws an IndexOutOfBoundsException.
    */
-  @Test(expected = classOf[IndexOutOfBoundsException])
-  def testOutOfTupleBoundsGrouping1() {
+  @Test
+  def testOutOfTupleBoundsGrouping1(): Unit = {
 
     val env = ExecutionEnvironment.getExecutionEnvironment
     val groupDs = env.fromCollection(emptyTupleData).groupBy(0)
 
-    groupDs.minBy(5)
+    assertThatThrownBy(() => groupDs.minBy(5))
+      .isInstanceOf(classOf[IndexOutOfBoundsException])
   }
 
   /**
    * This test validates that an index which is out of bounds throws an IndexOutOfBoundsException.
    */
-  @Test(expected = classOf[IndexOutOfBoundsException])
-  def testOutOfTupleBoundsGrouping2() {
+  @Test
+  def testOutOfTupleBoundsGrouping2(): Unit = {
 
     val env = ExecutionEnvironment.getExecutionEnvironment
     val groupDs = env.fromCollection(emptyTupleData).groupBy(0)
 
-    groupDs.minBy(-1)
+    assertThatThrownBy(() => groupDs.minBy(-1))
+      .isInstanceOf(classOf[IndexOutOfBoundsException])
   }
 
   /**
    * s This test validates that an index which is out of bounds throws an IndexOutOfBoundsException.
    */
-  @Test(expected = classOf[IndexOutOfBoundsException])
-  def testOutOfTupleBoundsGrouping3() {
+  @Test
+  def testOutOfTupleBoundsGrouping3(): Unit = {
 
     val env = ExecutionEnvironment.getExecutionEnvironment
     val groupDs = env.fromCollection(emptyTupleData).groupBy(0)
 
-    groupDs.minBy(1, 2, 3, 4, -1)
+    assertThatThrownBy(() => groupDs.minBy(1, 2, 3, 4, -1))
+      .isInstanceOf(classOf[IndexOutOfBoundsException])
   }
 
   class CustomType(var myInt: Int, var myLong: Long, var myString: String) {
